@@ -5,12 +5,9 @@
 #include "blimp/client/app/android/blimp_app_jni_registrar.h"
 
 #include "base/android/jni_registrar.h"
-#include "blimp/client/app/android/blimp_client_session_android.h"
 #include "blimp/client/app/android/blimp_contents_display.h"
+#include "blimp/client/app/android/blimp_environment.h"
 #include "blimp/client/app/android/blimp_library_loader.h"
-#include "blimp/client/app/android/tab_control_feature_android.h"
-#include "blimp/client/app/android/toolbar.h"
-#include "blimp/client/core/contents/android/ime_helper_dialog.h"
 #include "components/safe_json/android/component_jni_registrar.h"
 
 namespace blimp {
@@ -18,13 +15,10 @@ namespace client {
 namespace {
 
 base::android::RegistrationMethod kBlimpRegistrationMethods[] = {
-    {"BlimpClientSessionAndroid", BlimpClientSessionAndroid::RegisterJni},
     {"BlimpLibraryLoader", RegisterBlimpLibraryLoaderJni},
+    {"BlimpEnvironment", BlimpEnvironment::RegisterJni},
     {"BlimpContentsDisplay", app::BlimpContentsDisplay::RegisterJni},
-    {"ImeHelperDialog", ImeHelperDialog::RegisterJni},
     {"SafeJson", safe_json::android::RegisterSafeJsonJni},
-    {"TabControlFeatureAndroid", TabControlFeatureAndroid::RegisterJni},
-    {"Toolbar", Toolbar::RegisterJni},
 };
 
 }  // namespace
