@@ -8,6 +8,8 @@
 #include "blimp/client/core/contents/android/blimp_contents_jni_registrar.h"
 #include "blimp/client/core/context/android/blimp_client_context_impl_android.h"
 #include "blimp/client/core/settings/android/blimp_settings_android.h"
+#include "blimp/client/core/settings/android/settings_android.h"
+#include "blimp/client/core/settings/android/settings_observer_proxy.h"
 
 namespace blimp {
 namespace client {
@@ -18,6 +20,8 @@ base::android::RegistrationMethod kBlimpRegistrationMethods[] = {
      BlimpClientContextImplAndroid::RegisterJni},
     {"BlimpContentsJni", RegisterBlimpContentsJni},
     {"BlimpSettingsAndroid", BlimpSettingsAndroid::RegisterJni},
+    {"SettingsAndroid", SettingsAndroid::RegisterJni},
+    {"SettingsObserverProxy", SettingsObserverProxy::RegisterJni},
 };
 
 }  // namespace
