@@ -9,10 +9,6 @@
 #include "base/memory/ref_counted.h"
 #include "blimp/client/public/compositor/compositor_dependencies.h"
 
-namespace cc {
-class ContextProvider;
-}
-
 namespace blimp {
 namespace client {
 
@@ -26,7 +22,7 @@ class CompositorDependenciesImpl : public CompositorDependencies {
   // CompositorDependencies implementation.
   gpu::GpuMemoryBufferManager* GetGpuMemoryBufferManager() override;
   cc::SurfaceManager* GetSurfaceManager() override;
-  uint32_t AllocateSurfaceClientId() override;
+  cc::FrameSinkId AllocateFrameSinkId() override;
   void GetContextProviders(const ContextProviderCallback& callback) override;
 
  private:
