@@ -8,10 +8,6 @@
 #include "base/macros.h"
 #include "content/public/browser/content_browser_client.h"
 
-namespace content {
-class GeolocationDelegate;
-}  // namespace content
-
 namespace blimp {
 namespace engine {
 
@@ -33,7 +29,7 @@ class BlimpContentBrowserClient : public content::ContentBrowserClient {
   void OverrideWebkitPrefs(content::RenderViewHost* render_view_host,
                            content::WebPreferences* prefs) override;
   void ExposeInterfacesToRenderer(
-      shell::InterfaceRegistry* registry,
+      service_manager::InterfaceRegistry* registry,
       content::RenderProcessHost* render_process_host) override;
   std::unique_ptr<base::Value> GetServiceManifestOverlay(
       const std::string& name) override;
