@@ -27,12 +27,14 @@ size_t RegisterEngineCrashKeys() {
       // browser/:
       { "third-party-modules-loaded", crash_keys::kSmallSize },
       { "third-party-modules-not-loaded", crash_keys::kSmallSize },
+      { "enrolled-to-domain", crash_keys::kSmallSize },
 
       // //content crash keys
       { "bad_message_reason", crash_keys::kSmallSize },
       { "channel_error_bt", crash_keys::kMediumSize },
       { "discardable-memory-allocated", crash_keys::kSmallSize },
       { "discardable-memory-free", crash_keys::kSmallSize },
+      { "mojo-message-error", crash_keys::kMediumSize },
       { "ppapi_path", crash_keys::kMediumSize },
       { "remove_route_bt", crash_keys::kMediumSize },
       { "rwhvm_window", crash_keys::kMediumSize },
@@ -102,13 +104,13 @@ size_t RegisterEngineCrashKeys() {
       { "swdh_register_cannot_scope_url", crash_keys::kLargeSize },
       { "swdh_register_cannot_script_url", crash_keys::kLargeSize },
 
-      // Temporary for https://crbug.com/619294.
-      { "swdh_unregister_cannot_host_url", crash_keys::kLargeSize },
-      { "swdh_unregister_cannot_scope_url", crash_keys::kLargeSize },
-
       // Temporary for https://crbug.com/630496.
       { "swdh_get_registration_cannot_host_url", crash_keys::kLargeSize },
       { "swdh_get_registration_cannot_document_url", crash_keys::kLargeSize },
+
+      // Temporary for https://crbug.com/668633.
+      { "swdh_set_hosted_version_worker_pid", crash_keys::kSmallSize },
+      { "swdh_set_hosted_version_host_pid", crash_keys::kSmallSize },
     };
 
   return base::debug::InitCrashKeys(engine_keys, arraysize(engine_keys),
