@@ -14,14 +14,17 @@
 #include "blimp/net/input_message_converter.h"
 #include "content/public/browser/render_widget_host.h"
 #include "content/public/browser/render_widget_host_view.h"
+#include "content/public/common/form_field_data.h"
 #include "net/base/net_errors.h"
-#include "third_party/WebKit/public/web/WebInputEvent.h"
+#include "third_party/WebKit/public/platform/WebInputEvent.h"
+#include "ui/events/event.h"
+#include "ui/events/keycodes/dom/dom_code.h"
 
 namespace blimp {
 namespace engine {
 
 EngineRenderWidgetFeature::EngineRenderWidgetFeature(SettingsManager* settings)
-    : settings_manager_(settings) {
+    : settings_manager_(settings), weak_factory_(this) {
   DCHECK(settings_manager_);
   settings_manager_->AddObserver(this);
 }
@@ -133,9 +136,7 @@ void EngineRenderWidgetFeature::SendCompositorMessage(
 void EngineRenderWidgetFeature::SendShowImeRequest(
     const int tab_id,
     content::RenderWidgetHost* render_widget_host,
-    const ui::TextInputClient* client) {
-  DCHECK(client);
-
+    const content::FormFieldData& field) {
   ImeMessage* ime_message;
   std::unique_ptr<BlimpMessage> blimp_message =
       CreateBlimpMessage(&ime_message, tab_id);
@@ -145,13 +146,9 @@ void EngineRenderWidgetFeature::SendShowImeRequest(
   ime_message->set_render_widget_id(render_widget_id);
   ime_message->set_type(ImeMessage::SHOW_IME);
   ime_message->set_text_input_type(
-      InputMessageConverter::TextInputTypeToProto(client->GetTextInputType()));
-
-  gfx::Range text_range;
-  base::string16 existing_text;
-  client->GetTextRange(&text_range);
-  client->GetTextFromRange(text_range, &existing_text);
-  ime_message->set_ime_text(base::UTF16ToUTF8(existing_text));
+      InputMessageConverter::TextInputTypeToProto(field.text_input_type));
+  ime_message->set_ime_text(field.text);
+  // TODO(shaktisahu): Add remaining fields to proto.
 
   ime_message_sender_->ProcessMessage(std::move(blimp_message),
                                       net::CompletionCallback());
@@ -229,8 +226,17 @@ void EngineRenderWidgetFeature::ProcessMessage(
       render_widget_host =
           GetRenderWidgetHost(target_tab_id, message->ime().render_widget_id());
       if (render_widget_host && render_widget_host->GetView()) {
-        SetTextFromIME(render_widget_host->GetView()->GetTextInputClient(),
-                       message->ime().ime_text());
+        SetTextFromIME(render_widget_host, message->ime().ime_text(),
+                       message->ime().auto_submit());
+
+        // TODO(shaktisahu): Remove this fake HIDE_IME request once the blimp
+        // IME design is completed (crbug/661328).
+        base::ThreadTaskRunnerHandle::Get()->PostDelayedTask(
+            FROM_HERE,
+            base::Bind(&EngineRenderWidgetFeature::SendHideImeRequest,
+                       weak_factory_.GetWeakPtr(), target_tab_id,
+                       render_widget_host),
+            base::TimeDelta::FromMilliseconds(1500));
       }
       break;
     default:
@@ -256,16 +262,39 @@ void EngineRenderWidgetFeature::OnWebPreferencesChanged() {
   }
 }
 
-void EngineRenderWidgetFeature::SetTextFromIME(ui::TextInputClient* client,
-                                               std::string text) {
-  if (client && client->GetTextInputType() != ui::TEXT_INPUT_TYPE_NONE) {
-    // Clear out any existing text first and then insert new text entered
-    // through IME.
-    gfx::Range text_range;
-    client->GetTextRange(&text_range);
-    client->ExtendSelectionAndDelete(text_range.length(), text_range.length());
+void EngineRenderWidgetFeature::SetTextFromIME(
+    content::RenderWidgetHost* render_widget_host,
+    std::string text,
+    bool auto_submit) {
+  ui::TextInputClient* client =
+      render_widget_host->GetView()->GetTextInputClient();
+  DCHECK(client);
 
-    client->InsertText(base::UTF8ToUTF16(text));
+  if (!client || client->GetTextInputType() == ui::TEXT_INPUT_TYPE_NONE)
+    return;
+
+  // Clear out any existing text first and then insert new text entered
+  // through IME.
+  gfx::Range text_range;
+  client->GetTextRange(&text_range);
+  client->ExtendSelectionAndDelete(text_range.length(), text_range.length());
+
+  client->InsertText(base::UTF8ToUTF16(text));
+
+  if (auto_submit) {
+    // Send a synthetic key event to the renderer notifying that user has hit
+    // Return key. This should submit the current form.
+    ui::KeyEvent press(ui::ET_KEY_PRESSED, ui::VKEY_RETURN, ui::DomCode::ENTER,
+                       0);
+    ui::KeyEvent char_event('\r', ui::VKEY_RETURN, 0);
+    ui::KeyEvent release(ui::ET_KEY_RELEASED, ui::VKEY_RETURN,
+                         ui::DomCode::ENTER, 0);
+    render_widget_host->ForwardKeyboardEvent(
+        content::NativeWebKeyboardEvent(press));
+    render_widget_host->ForwardKeyboardEvent(
+        content::NativeWebKeyboardEvent(char_event));
+    render_widget_host->ForwardKeyboardEvent(
+        content::NativeWebKeyboardEvent(release));
   }
 }
 
