@@ -21,7 +21,7 @@
 #include "blimp/engine/app/switches.h"
 #include "blimp/engine/app/ui/blimp_layout_manager.h"
 #include "blimp/engine/app/ui/blimp_screen.h"
-#include "blimp/engine/app/ui/blimp_window_tree_client.h"
+#include "blimp/engine/app/ui/blimp_window_parenting_client.h"
 #include "blimp/engine/app/ui/blimp_window_tree_host.h"
 #include "blimp/engine/common/blimp_browser_context.h"
 #include "blimp/engine/common/blimp_user_agent.h"
@@ -72,6 +72,9 @@ const int kDefaultDisplayWidth = 800;
 const int kDefaultDisplayHeight = 600;
 const uint16_t kDefaultPort = 25467;
 
+const char kTcpTransport[] = "tcp";
+const char kGrpcTransport[] = "grpc";
+
 // Focus rules that support activating an child window.
 class FocusRulesImpl : public wm::BaseFocusRules {
  public:
@@ -99,6 +102,20 @@ base::Closure QuitCurrentMessageLoopClosure() {
                     base::MessageLoop::QuitWhenIdleClosure());
 }
 
+EngineConnectionManager::EngineTransportType GetTransportType() {
+  const std::string transport_parsed =
+      base::CommandLine::ForCurrentProcess()->GetSwitchValueASCII(
+          kEngineTransport);
+  if (transport_parsed == kTcpTransport || transport_parsed.empty()) {
+    return EngineConnectionManager::EngineTransportType::TCP;
+  } else if (transport_parsed == kGrpcTransport) {
+    return EngineConnectionManager::EngineTransportType::GRPC;
+  }
+  LOG(FATAL) << "--engine-transport must either be empty or one of "
+             << kGrpcTransport << ", " << kTcpTransport;
+  return EngineConnectionManager::EngineTransportType::TCP;
+}
+
 net::IPAddress GetListeningAddress() {
   if (base::CommandLine::ForCurrentProcess()->HasSwitch(kAllowNonLocalhost)) {
     return net::IPAddress::IPv4AllZeros();
@@ -139,6 +156,8 @@ class EngineNetworkComponents : public ConnectionHandler,
                   base::WeakPtr<BlobChannelSender> blob_channel_sender,
                   const std::string& client_token);
 
+  // TODO(perumaal): Remove this once gRPC support is ready.
+  //                 See crbug.com/659279.
   uint16_t GetPortForTesting() { return port_; }
 
   BrowserConnectionHandler* connection_handler() {
@@ -189,19 +208,19 @@ void EngineNetworkComponents::Initialize(
       base::MakeUnique<EngineAuthenticationHandler>(this, client_token);
 
   // Plumb unauthenticated connections to |authentication_handler_|.
-  connection_manager_ =
-      base::MakeUnique<EngineConnectionManager>(authentication_handler_.get());
+  connection_manager_ = base::MakeUnique<EngineConnectionManager>(
+      authentication_handler_.get(), net_log_);
 
   blob_channel_service_ =
       base::MakeUnique<BlobChannelService>(blob_channel_sender, ui_task_runner);
 
   // Adds BlimpTransports to connection_manager_.
   net::IPEndPoint address(GetListeningAddress(), GetListeningPort());
-  TCPEngineTransport* transport = new TCPEngineTransport(address, net_log_);
-  connection_manager_->AddTransport(base::WrapUnique(transport));
-
-  transport->GetLocalAddress(&address);
+  connection_manager_->ConnectTransport(&address, GetTransportType());
   port_ = address.port();
+
+  // Print the engine port for client_engine_integration script, please do not
+  // remove this log.
   DVLOG(1) << "Engine port #: " << port_;
 }
 
@@ -281,12 +300,13 @@ void BlimpEngineSession::Initialize() {
   capture_client_.reset(
       new aura::client::DefaultCaptureClient(window_tree_host_->window()));
 
-  window_tree_client_.reset(
-      new BlimpWindowTreeClient(window_tree_host_->window()));
+  window_parenting_client_.reset(
+      new BlimpWindowParentingClient(window_tree_host_->window()));
 
   window_tree_host_->GetInputMethod()->AddObserver(this);
 
-  window_tree_host_->SetBounds(gfx::Rect(screen_->GetPrimaryDisplay().size()));
+  window_tree_host_->SetBoundsInPixels(
+      gfx::Rect(screen_->GetPrimaryDisplay().size()));
 
   RegisterFeatures();
 
@@ -374,7 +394,7 @@ void BlimpEngineSession::HandleResize(float device_pixel_ratio,
                                       const gfx::Size& size) {
   DVLOG(1) << "Resize to " << size.ToString() << ", " << device_pixel_ratio;
   screen_->UpdateDisplayScaleAndSize(device_pixel_ratio, size);
-  window_tree_host_->SetBounds(gfx::Rect(size));
+  window_tree_host_->SetBoundsInPixels(gfx::Rect(size));
   if (tab_) {
     tab_->Resize(device_pixel_ratio,
                  screen_->GetPrimaryDisplay().bounds().size());
@@ -402,14 +422,11 @@ void BlimpEngineSession::OnTextInputStateChanged(
   ui::TextInputType type =
       client ? client->GetTextInputType() : ui::TEXT_INPUT_TYPE_NONE;
 
-  // TODO(shaktisahu): Propagate the new type to the client.
   // Hide IME, when text input is out of focus, i.e. if the text input type
   // changes to ui::TEXT_INPUT_TYPE_NONE. For other text input types,
   // OnShowImeIfNeeded is used instead to send show IME request to client.
   if (type == ui::TEXT_INPUT_TYPE_NONE)
-    render_widget_feature_.SendHideImeRequest(
-        tab_->tab_id(),
-        tab_->web_contents()->GetRenderWidgetHostView()->GetRenderWidgetHost());
+    tab_->HideTextInputUI();
 }
 
 void BlimpEngineSession::OnInputMethodDestroyed(
@@ -422,10 +439,7 @@ void BlimpEngineSession::OnShowImeIfNeeded() {
       !window_tree_host_->GetInputMethod()->GetTextInputClient())
     return;
 
-  render_widget_feature_.SendShowImeRequest(
-      tab_->tab_id(),
-      tab_->web_contents()->GetRenderWidgetHostView()->GetRenderWidgetHost(),
-      window_tree_host_->GetInputMethod()->GetTextInputClient());
+  tab_->ShowTextInputUI();
 }
 
 void BlimpEngineSession::ProcessMessage(
