@@ -30,13 +30,12 @@ class WindowTreeHost;
 
 namespace client {
 class DefaultCaptureClient;
-class WindowTreeClient;
+class WindowParentingClient;
 }  // namespace client
 }  // namespace aura
 
 namespace content {
 class BrowserContext;
-class RenderViewHost;
 class WebContents;
 }
 
@@ -54,10 +53,7 @@ class FocusController;
 
 namespace blimp {
 
-class BlimpConnection;
 class BlimpMessage;
-class BlimpMessageThreadPipe;
-class BlobCache;
 class HeliumBlobSenderDelegate;
 class ThreadPipeManager;
 class SettingsManager;
@@ -66,7 +62,6 @@ namespace engine {
 
 class BlimpBrowserContext;
 class BlimpEngineConfig;
-class BlimpFocusClient;
 class BlimpScreen;
 class BlimpWindowTreeHost;
 class EngineNetworkComponents;
@@ -178,7 +173,7 @@ class BlimpEngineSession : public BlimpMessageProcessor,
   std::unique_ptr<aura::client::DefaultCaptureClient> capture_client_;
 
   // Used to attach null-parented windows (e.g. popups) to the root window.
-  std::unique_ptr<aura::client::WindowTreeClient> window_tree_client_;
+  std::unique_ptr<aura::client::WindowParentingClient> window_parenting_client_;
 
   // Manages all global settings for the engine session.
   SettingsManager* settings_manager_;
