@@ -33,7 +33,7 @@ class BLIMP_NET_EXPORT BlimpMessageCheckpointer : public BlimpMessageProcessor {
   ~BlimpMessageCheckpointer() override;
 
   // BlimpMessageProcessor interface.
-  void ProcessMessage(scoped_ptr<BlimpMessage> message,
+  void ProcessMessage(std::unique_ptr<BlimpMessage> message,
                       const net::CompletionCallback& callback) override;
 
  private:
