@@ -53,7 +53,7 @@ import org.chromium.chrome.browser.tabmodel.TabModelSelector;
 import org.chromium.chrome.browser.util.ColorUtils;
 import org.chromium.chrome.browser.widget.ClipDrawableProgressBar.DrawingInfo;
 import org.chromium.chrome.browser.widget.ControlContainer;
-import org.chromium.content.browser.ContentViewClient;
+import org.chromium.content.browser.ContentView;
 import org.chromium.content.browser.ContentViewCore;
 import org.chromium.content.browser.SPenSupport;
 import org.chromium.ui.UiUtils;
@@ -73,7 +73,8 @@ import java.util.List;
  * drawn by the UI compositor on the native side.
  */
 public class CompositorViewHolder extends CoordinatorLayout
-        implements LayoutManagerHost, LayoutRenderHost, Invalidator.Host, FullscreenListener {
+        implements ContentOffsetProvider, LayoutManagerHost, LayoutRenderHost, Invalidator.Host,
+                FullscreenListener {
 
     private boolean mIsKeyboardShowing = false;
 
@@ -116,13 +117,19 @@ public class CompositorViewHolder extends CoordinatorLayout
     private boolean mEnableCompositorTabStrip;
 
     // Cache objects that should not be created frequently.
-    private final Rect mCacheViewport = new Rect();
-    private final Rect mCacheVisibleViewport = new Rect();
+    private final RectF mCacheViewport = new RectF();
     private DrawingInfo mProgressBarDrawingInfo;
 
     // If we've drawn at least one frame.
     private boolean mHasDrawnOnce = false;
 
+    /**
+     * The desired size of this view in {@link MeasureSpec}. Set by the host
+     * when it should be different from that of the parent.
+     */
+    private int mDesiredWidthMeasureSpec = ContentView.DEFAULT_MEASURE_SPEC;
+    private int mDesiredHeightMeasureSpec = ContentView.DEFAULT_MEASURE_SPEC;
+
     /**
      * This view is created on demand to display debugging information.
      */
@@ -203,7 +210,7 @@ public class CompositorViewHolder extends CoordinatorLayout
             @Override
             public void onLayoutChange(View v, int left, int top, int right, int bottom,
                     int oldLeft, int oldTop, int oldRight, int oldBottom) {
-                propagateViewportToLayouts(right - left, bottom - top);
+                onViewportChanged();
 
                 // If there's an event that needs to occur after the keyboard is hidden, post
                 // it as a delayed event.  Otherwise this happens in the midst of the
@@ -229,7 +236,7 @@ public class CompositorViewHolder extends CoordinatorLayout
      */
     public void setLayoutManager(LayoutManager layoutManager) {
         mLayoutManager = layoutManager;
-        propagateViewportToLayouts(getWidth(), getHeight());
+        onViewportChanged();
     }
 
     /**
@@ -239,6 +246,16 @@ public class CompositorViewHolder extends CoordinatorLayout
         mCompositorView.setRootView(view);
     }
 
+    /**
+     * Set the desired size of the view. The values are in {@link MeasureSpec}.
+     * @param width The width of the content view.
+     * @param height The height of the content view.
+     */
+    public void setDesiredMeasureSpec(int width, int height) {
+        mDesiredWidthMeasureSpec = width;
+        mDesiredHeightMeasureSpec = height;
+    }
+
     /**
      * @param controlContainer The ControlContainer.
      */
@@ -313,10 +330,6 @@ public class CompositorViewHolder extends CoordinatorLayout
         return mCompositorView.getResourceManager();
     }
 
-    public ContentOffsetProvider getContentOffsetProvider() {
-        return mCompositorView;
-    }
-
     /**
      * @return The {@link DynamicResourceLoader} for registering resources.
      */
@@ -440,7 +453,7 @@ public class CompositorViewHolder extends CoordinatorLayout
     public void onStart() {
         if (mFullscreenManager != null) {
             mLastContentOffset = mFullscreenManager.getContentOffset();
-            mLastVisibleContentOffset = mFullscreenManager.getVisibleContentOffset();
+            mLastVisibleContentOffset = mFullscreenManager.getTopVisibleContentOffset();
             mFullscreenManager.addListener(this);
         }
         requestRender();
@@ -456,13 +469,13 @@ public class CompositorViewHolder extends CoordinatorLayout
     @Override
     public void onContentOffsetChanged(float offset) {
         mLastContentOffset = offset;
-        propagateViewportToLayouts(getWidth(), getHeight());
+        onViewportChanged();
     }
 
     @Override
     public void onVisibleContentOffsetChanged(float offset, boolean needsAnimate) {
         mLastVisibleContentOffset = offset;
-        propagateViewportToLayouts(getWidth(), getHeight());
+        onViewportChanged();
         if (needsAnimate) requestRender();
     }
 
@@ -497,19 +510,12 @@ public class CompositorViewHolder extends CoordinatorLayout
         }
     }
 
-    private void propagateViewportToLayouts(int contentWidth, int contentHeight) {
-        int heightMinusTopControls = contentHeight - getTopControlsHeightPixels();
-        mCacheViewport.set(0, (int) mLastContentOffset, contentWidth, contentHeight);
-        mCacheVisibleViewport.set(0, (int) mLastVisibleContentOffset, contentWidth, contentHeight);
+    private void onViewportChanged() {
         // TODO(changwan): check if this can be merged with setContentMotionEventOffsets.
         if (mTabVisible != null && mTabVisible.getContentViewCore() != null) {
-            mTabVisible.getContentViewCore().setSmartClipOffsets(
-                    -mCacheViewport.left, -mCacheViewport.top);
-        }
-        if (mLayoutManager != null) {
-            mLayoutManager.pushNewViewport(
-                    mCacheViewport, mCacheVisibleViewport, heightMinusTopControls);
+            mTabVisible.getContentViewCore().setSmartClipOffsets(0, (int) -mLastContentOffset);
         }
+        if (mLayoutManager != null) mLayoutManager.onViewportChanged();
     }
 
     /**
@@ -535,6 +541,41 @@ public class CompositorViewHolder extends CoordinatorLayout
         TraceEvent.end("CompositorViewHolder:layout");
     }
 
+    @Override
+    public void getWindowViewport(RectF outRect) {
+        outRect.set(0, 0, getWidth(), getHeight());
+    }
+
+    @Override
+    public void getVisibleViewport(RectF outRect) {
+        getWindowViewport(outRect);
+
+        float bottomControlOffset = 0;
+        if (mFullscreenManager != null) {
+            // All of these values are in pixels.
+            outRect.top += mFullscreenManager.getTopVisibleContentOffset();
+            bottomControlOffset = mFullscreenManager.getBottomControlOffset();
+        }
+        outRect.bottom -= (getBottomControlsHeightPixels() - bottomControlOffset);
+    }
+
+    @Override
+    public void getViewportFullControls(RectF outRect) {
+        getWindowViewport(outRect);
+
+        if (mFullscreenManager != null) {
+            // All of these values are in pixels.
+            outRect.top += mFullscreenManager.getTopControlsHeight();
+            outRect.bottom -= mFullscreenManager.getBottomControlsHeight();
+        }
+    }
+
+    @Override
+    public float getHeightMinusBrowserControls() {
+        return getHeight() - (getTopControlsHeightPixels() + getBottomControlsHeightPixels());
+
+    }
+
     @Override
     public void requestRender() {
         mCompositorView.requestRender();
@@ -583,11 +624,6 @@ public class CompositorViewHolder extends CoordinatorLayout
         return this;
     }
 
-    @Override
-    public int getLayoutTabsDrawnCount() {
-        return mCompositorView.getLastLayerCount();
-    }
-
     @Override
     public void pushDebugRect(Rect rect, int color) {
         if (mDebugOverlay == null) {
@@ -609,7 +645,7 @@ public class CompositorViewHolder extends CoordinatorLayout
     @Override
     protected void onLayout(boolean changed, int l, int t, int r, int b) {
         if (changed) {
-            propagateViewportToLayouts(r - l, b - t);
+            onViewportChanged();
         }
         super.onLayout(changed, l, t, r, b);
 
@@ -636,42 +672,49 @@ public class CompositorViewHolder extends CoordinatorLayout
         mFullscreenManager = fullscreen;
         if (mFullscreenManager != null) {
             mLastContentOffset = mFullscreenManager.getContentOffset();
-            mLastVisibleContentOffset = mFullscreenManager.getVisibleContentOffset();
+            mLastVisibleContentOffset = mFullscreenManager.getTopVisibleContentOffset();
             mFullscreenManager.addListener(this);
         }
-        propagateViewportToLayouts(getWidth(), getHeight());
-    }
-
-    /**
-     * Note that the returned rect is reused for other calls.
-     */
-    @Override
-    public Rect getVisibleViewport(Rect rect) {
-        if (rect == null) rect = new Rect();
-        rect.set(0, (int) mLastVisibleContentOffset, getWidth(), getHeight());
-        return rect;
+        onViewportChanged();
     }
 
     @Override
-    public int getTopControlsBackgroundColor() {
+    public int getBrowserControlsBackgroundColor() {
         return mTabVisible == null ? Color.WHITE : mTabVisible.getThemeColor();
     }
 
     @Override
-    public float getTopControlsUrlBarAlpha() {
+    public float getBrowserControlsUrlBarAlpha() {
         return mTabVisible == null
                 ? 1.f
                 : ColorUtils.getTextBoxAlphaForToolbarBackground(mTabVisible);
     }
 
     @Override
-    public boolean areTopControlsPermanentlyHidden() {
-        return mFullscreenManager != null && mFullscreenManager.areTopControlsPermanentlyHidden();
+    public boolean areBrowserControlsPermanentlyHidden() {
+        return mFullscreenManager != null
+                && mFullscreenManager.areBrowserControlsPermanentlyHidden();
+    }
+
+    /**
+     * @return The height of the top browser controls in pixels.
+     */
+    public int getTopControlsHeightPixels() {
+        return mFullscreenManager != null ? mFullscreenManager.getTopControlsHeight() : 0;
+    }
+
+    /**
+     * @return The height of the bottom conrols in pixels.
+     */
+    public int getBottomControlsHeightPixels() {
+        return mFullscreenManager != null ? mFullscreenManager.getBottomControlsHeight() : 0;
     }
 
     @Override
-    public int getTopControlsHeightPixels() {
-        return mFullscreenManager != null ? mFullscreenManager.getTopControlsHeight() : 0;
+    public float getOverlayTranslateY() {
+        return areBrowserControlsPermanentlyHidden()
+                ? getTopControlsHeightPixels()
+                : mLastVisibleContentOffset;
     }
 
     /**
@@ -883,38 +926,29 @@ public class CompositorViewHolder extends CoordinatorLayout
      */
     private void initializeContentViewCore(ContentViewCore contentViewCore) {
         contentViewCore.setCurrentTouchEventOffsets(0.f, 0.f);
-        contentViewCore.setTopControlsHeight(
-                getTopControlsHeightPixels(), contentViewCore.doTopControlsShrinkBlinkSize());
+        contentViewCore.setTopControlsHeight(getTopControlsHeightPixels(),
+                contentViewCore.doBrowserControlsShrinkBlinkSize());
+        contentViewCore.setBottomControlsHeight(getBottomControlsHeightPixels());
 
         adjustPhysicalBackingSize(contentViewCore,
                 mCompositorView.getWidth(), mCompositorView.getHeight());
     }
 
     /**
-     * Adjusts the physical backing size of a given ContentViewCore. This method will first check
-     * if the ContentViewCore's client wants to override the size and, if so, it will use the
-     * values provided by the {@link ContentViewClient#getDesiredWidthMeasureSpec()} and
-     * {@link ContentViewClient#getDesiredHeightMeasureSpec()} methods. If no value is provided
-     * in one of these methods, the values from the |width| and |height| arguments will be
-     * used instead.
-     *
+     * Adjusts the physical backing size of a given ContentViewCore. This method checks
+     * the associated container view to see if the size needs to be overriden, such as when used for
+     * {@link OverlayPanel}.
      * @param contentViewCore The {@link ContentViewCore} to resize.
      * @param width The default width.
      * @param height The default height.
      */
     private void adjustPhysicalBackingSize(ContentViewCore contentViewCore, int width, int height) {
-        ContentViewClient client = contentViewCore.getContentViewClient();
-
-        int desiredWidthMeasureSpec = client.getDesiredWidthMeasureSpec();
-        if (MeasureSpec.getMode(desiredWidthMeasureSpec) != MeasureSpec.UNSPECIFIED) {
-            width = MeasureSpec.getSize(desiredWidthMeasureSpec);
+        if (mDesiredWidthMeasureSpec != ContentView.DEFAULT_MEASURE_SPEC) {
+            width = MeasureSpec.getSize(mDesiredWidthMeasureSpec);
         }
-
-        int desiredHeightMeasureSpec = client.getDesiredHeightMeasureSpec();
-        if (MeasureSpec.getMode(desiredHeightMeasureSpec) != MeasureSpec.UNSPECIFIED) {
-            height = MeasureSpec.getSize(desiredHeightMeasureSpec);
+        if (mDesiredHeightMeasureSpec != ContentView.DEFAULT_MEASURE_SPEC) {
+            height = MeasureSpec.getSize(mDesiredHeightMeasureSpec);
         }
-
         contentViewCore.onPhysicalBackingSizeChanged(width, height);
     }
 
