@@ -6,6 +6,7 @@ package org.chromium.chrome.browser.compositor.bottombar;
 
 import android.text.TextUtils;
 import android.view.View;
+import android.view.View.MeasureSpec;
 import android.view.ViewGroup;
 
 import org.chromium.base.VisibleForTesting;
@@ -21,7 +22,6 @@ import org.chromium.components.navigation_interception.NavigationParams;
 import org.chromium.components.web_contents_delegate_android.WebContentsDelegateAndroid;
 import org.chromium.content.browser.ContentVideoViewEmbedder;
 import org.chromium.content.browser.ContentView;
-import org.chromium.content.browser.ContentViewClient;
 import org.chromium.content.browser.ContentViewCore;
 import org.chromium.content_public.browser.LoadUrlParams;
 import org.chromium.content_public.browser.WebContents;
@@ -72,9 +72,6 @@ public class OverlayPanelContent {
     /** Whether the content view is currently being displayed. */
     private boolean mIsContentViewShowing;
 
-    /** The ContentViewCore responsible for displaying content. */
-    private ContentViewClient mContentViewClient;
-
     /** The observer used by this object to inform implementers of different events. */
     private OverlayContentDelegate mContentDelegate;
 
@@ -88,6 +85,10 @@ public class OverlayPanelContent {
     // java layer. Otherwise, the instance could be garbage-collected unexpectedly.
     private InterceptNavigationDelegate mInterceptNavigationDelegate;
 
+    /** The desired size of the {@link ContentView} associated with this panel content. */
+    private int mContentViewWidth;
+    private int mContentViewHeight;
+
     // ============================================================================================
     // InterceptNavigationDelegateImpl
     // ============================================================================================
@@ -198,6 +199,17 @@ public class OverlayPanelContent {
         }
     }
 
+    /**
+     * Set the desired size of the underlying {@link ContentView}. This is determined
+     * by the {@link OverlayPanel} before the creation of the content view.
+     * @param width The width of the content view.
+     * @param height The height of the content view.
+     */
+    void setContentViewSize(int width, int height) {
+        mContentViewWidth = width;
+        mContentViewHeight = height;
+    }
+
     /**
      * Makes the content visible, causing it to be rendered.
      */
@@ -228,13 +240,15 @@ public class OverlayPanelContent {
 
         mContentViewCore = createContentViewCore(mActivity);
 
-        if (mContentViewClient == null) {
-            mContentViewClient = new ContentViewClient();
-        }
-
-        mContentViewCore.setContentViewClient(mContentViewClient);
-
         ContentView cv = ContentView.createContentView(mActivity, mContentViewCore);
+        if (mContentViewWidth != 0 || mContentViewHeight != 0) {
+            int width = mContentViewWidth == 0 ? ContentView.DEFAULT_MEASURE_SPEC
+                    : MeasureSpec.makeMeasureSpec(mContentViewWidth, MeasureSpec.EXACTLY);
+            int height = mContentViewHeight == 0 ? ContentView.DEFAULT_MEASURE_SPEC
+                    : MeasureSpec.makeMeasureSpec(mContentViewHeight, MeasureSpec.EXACTLY);
+            cv.setDesiredMeasureSpec(width, height);
+            mActivity.getCompositorViewHolder().setDesiredMeasureSpec(width, height);
+        }
 
         // Creates an initially hidden WebContents which gets shown when the panel is opened.
         WebContents panelWebContents = WebContentsFactory.createWebContents(false, true);
@@ -252,7 +266,6 @@ public class OverlayPanelContent {
 
                     @Override
                     public View acquireView() {
-                        assert false : "Shold not reach here";
                         return null;
                     }
 
@@ -287,8 +300,7 @@ public class OverlayPanelContent {
 
                     @Override
                     public void didStartProvisionalLoadForFrame(long frameId, long parentFrameId,
-                            boolean isMainFrame, String validatedUrl, boolean isErrorPage,
-                            boolean isIframeSrcdoc) {
+                            boolean isMainFrame, String validatedUrl, boolean isErrorPage) {
                         if (isMainFrame) {
                             mContentDelegate.onMainFrameLoadStarted(validatedUrl,
                                     !TextUtils.equals(validatedUrl, mLoadedUrl));
@@ -348,16 +360,16 @@ public class OverlayPanelContent {
     // ============================================================================================
 
     /**
-     * Calls updateTopControlsState on the ContentViewCore.
+     * Calls updateBrowserControlsState on the ContentViewCore.
      * @param enableHiding Enable the toolbar's ability to hide.
      * @param enableShowing If the toolbar is allowed to show.
      * @param animate If the toolbar should animate when showing/hiding.
      */
-    public void updateTopControlsState(boolean enableHiding, boolean enableShowing,
-            boolean animate) {
+    public void updateBrowserControlsState(
+            boolean enableHiding, boolean enableShowing, boolean animate) {
         if (mContentViewCore != null && mContentViewCore.getWebContents() != null) {
-            mContentViewCore.getWebContents().updateTopControlsState(enableHiding, enableShowing,
-                    animate);
+            mContentViewCore.getWebContents().updateBrowserControlsState(
+                    enableHiding, enableShowing, animate);
         }
     }
 
@@ -427,17 +439,6 @@ public class OverlayPanelContent {
         return httpResultCode <= 0 || httpResultCode >= 400;
     }
 
-    /**
-     * Set a ContentViewClient for this panel to use (will be reused for each new ContentViewCore).
-     * @param viewClient The ContentViewClient to use.
-     */
-    public void setContentViewClient(ContentViewClient viewClient) {
-        mContentViewClient = viewClient;
-        if (mContentViewCore != null) {
-            mContentViewCore.setContentViewClient(mContentViewClient);
-        }
-    }
-
     /**
      * @return true if the ContentViewCore is visible on the page.
      */
