@@ -7,8 +7,7 @@ package org.chromium.chrome.browser.compositor.layouts;
 import static org.chromium.chrome.browser.compositor.layouts.ChromeAnimation.AnimatableAnimation.createAnimation;
 
 import android.content.Context;
-import android.graphics.Point;
-import android.graphics.Rect;
+import android.graphics.PointF;
 import android.graphics.RectF;
 import android.view.MotionEvent;
 import android.view.View;
@@ -54,55 +53,19 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
         public static final int LANDSCAPE = 2;
     }
 
-    /**
-     * The sizing requirements of each layout.  These flags allow each layout to specify certain
-     * sizing allowances/constraints by combining them.
-     *
-     * TODO(dtrainor): Flesh out support for all of these flag combinations.
-     */
-    public interface SizingFlags {
-        /**
-         * The toolbar is allowed to be hidden.
-         */
-        public static final int ALLOW_TOOLBAR_HIDE = 0x1;
+    /** The possible variations of the visible viewport that different layouts may need. */
+    public enum ViewportMode {
+        /** The viewport is assumed to be always fullscreen. */
+        ALWAYS_FULLSCREEN,
 
-        /**
-         * The toolbar is allowed to be shown.
-         */
-        public static final int ALLOW_TOOLBAR_SHOW = 0x10;
+        /** The viewport is assuming that browser controls are permenantly shown. */
+        ALWAYS_SHOWING_BROWSER_CONTROLS,
 
-        /**
-         * The toolbar is allowed to animate between the transitions. Note that this flag is not
-         * completely supported in all combinations with the other flags.  As functionality is
-         * added and required this will be improved.
-         */
-        public static final int ALLOW_TOOLBAR_ANIMATE = 0x100;
+        /** The viewport will account for animating browser controls (both shown and hidden). */
+        DYNAMIC_BROWSER_CONTROLS,
 
-        /**
-         * The layout requires a fullscreen size regardless of the toolbar position.
-         */
-        public static final int REQUIRE_FULLSCREEN_SIZE = 0x1000;
-
-        /**
-         * The layout does not support fullscreen and it should animate the toolbar away.
-         * A helper flag to make it easier to specify restrictions.
-         */
-        public static final int HELPER_NO_FULLSCREEN_SUPPORT =
-                ALLOW_TOOLBAR_SHOW | ALLOW_TOOLBAR_ANIMATE;
-
-        /**
-         * The layout supports persistent fullscreen and should hide the toolbar immediately.
-         * A helper flag to make it easier to specify restrictions.
-         */
-        public static final int HELPER_HIDE_TOOLBAR_IMMEDIATE = ALLOW_TOOLBAR_HIDE;
-
-        /**
-         * The layout fully supports fullscreen and the toolbar is allowed to show, hide, and
-         * animate.
-         * A helper flag to make it easier to specify restrictions.
-         */
-        public static final int HELPER_SUPPORTS_FULLSCREEN =
-                ALLOW_TOOLBAR_HIDE | ALLOW_TOOLBAR_SHOW | ALLOW_TOOLBAR_ANIMATE;
+        /** Use a viewport that accounts for the browser controls state in the previous layout. */
+        USE_PREVIOUS_BROWSER_CONTROLS_STATE
     }
 
     // Defines to make the code easier to read.
@@ -115,9 +78,9 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
     public static final long UNSTALLED_ANIMATION_DURATION_MS = 500;
 
     // Drawing area properties.
-    private float mWidth;
-    private float mHeight;
-    private float mHeightMinusTopControls;
+    private float mWidthDp;
+    private float mHeightDp;
+    private float mHeightMinusBrowserControlsDp;
 
     /** A {@link Context} instance. */
     private Context mContext;
@@ -149,6 +112,9 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
     // The next id to show when the layout is hidden, or TabBase#INVALID_TAB_ID if no change.
     private int mNextTabId = Tab.INVALID_TAB_ID;
 
+    // The ratio of dp to px.
+    private final float mDpToPx;
+
     /**
      * The {@link Layout} is not usable until sizeChanged is called.
      * This is convenient this way so we can pre-create the layout before the host is fully defined.
@@ -165,11 +131,12 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
         mEventFilter = eventFilter;
 
         // Invalid sizes
-        mWidth = -1;
-        mHeight = -1;
-        mHeightMinusTopControls = -1;
+        mWidthDp = -1;
+        mHeightDp = -1;
+        mHeightMinusBrowserControlsDp = -1;
 
         mCurrentOrientation = Orientation.UNSET;
+        mDpToPx = context.getResources().getDisplayMetrics().density;
     }
 
     /**
@@ -326,30 +293,32 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
     /**
      * Called when the size of the viewport has changed.
      * @param visibleViewport        The visible viewport that represents the area on the screen
-     *                               this {@link Layout} gets to draw to (potentially takes into
-     *                               account top controls).
-     * @param screenViewport         The viewport of the screen.
-     * @param heightMinusTopControls The height the {@link Layout} gets excluding the height of the
-     *                               top controls.  TODO(dtrainor): Look at getting rid of this.
+     *                               this {@link Layout} gets to draw to in px (potentially takes
+     *                               into account browser controls).
+     * @param screenViewport         The viewport of the screen in px.
+     * @param heightMinusBrowserControls The height the {@link Layout} gets excluding the height of
+     *                               the browser controls in px. TODO(dtrainor): Look at getting rid
+     *                               of this.
      * @param orientation            The new orientation.  Valid values are defined by
      *                               {@link Orientation}.
      */
-    public final void sizeChanged(RectF visibleViewport, RectF screenViewport,
-            float heightMinusTopControls, int orientation) {
+    public final void sizeChanged(RectF visibleViewportPx, RectF screenViewportPx,
+            float heightMinusBrowserControlsPx, int orientation) {
         // 1. Pull out this Layout's width and height properties based on the viewport.
-        float width = screenViewport.width();
-        float height = screenViewport.height();
+        float width = screenViewportPx.width() / mDpToPx;
+        float height = screenViewportPx.height() / mDpToPx;
+        float heightMinusBrowserControlsDp = heightMinusBrowserControlsPx / mDpToPx;
 
         // 2. Check if any Layout-specific properties have changed.
-        boolean layoutPropertiesChanged = mWidth != width
-                || mHeight != height
-                || mHeightMinusTopControls != heightMinusTopControls
+        boolean layoutPropertiesChanged = Float.compare(mWidthDp, width) != 0
+                || Float.compare(mHeightDp, height) != 0
+                || Float.compare(mHeightMinusBrowserControlsDp, heightMinusBrowserControlsDp) != 0
                 || mCurrentOrientation != orientation;
 
         // 3. Update the internal sizing properties.
-        mWidth = width;
-        mHeight = height;
-        mHeightMinusTopControls = heightMinusTopControls;
+        mWidthDp = width;
+        mHeightDp = height;
+        mHeightMinusBrowserControlsDp = heightMinusBrowserControlsDp;
         mCurrentOrientation = orientation;
 
         // 4. Notify the actual Layout if necessary.
@@ -359,7 +328,7 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
 
         // 5. TODO(dtrainor): Notify the overlay objects.
         for (int i = 0; i < mSceneOverlays.size(); i++) {
-            mSceneOverlays.get(i).onSizeChanged(width, height, visibleViewport.top, orientation);
+            mSceneOverlays.get(i).onSizeChanged(width, height, visibleViewportPx.top, orientation);
         }
     }
 
@@ -399,10 +368,10 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
     }
 
     /**
-     * @return Information about the sizing requirements of this layout.
+     * @return The sizing mode for the layout.
      */
-    public int getSizingFlags() {
-        return SizingFlags.HELPER_NO_FULLSCREEN_SUPPORT;
+    public ViewportMode getViewportMode() {
+        return ViewportMode.ALWAYS_SHOWING_BROWSER_CONTROLS;
     }
 
     /**
@@ -560,24 +529,24 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
     }
 
     /**
-     * @return The width of the drawing area.
+     * @return The width of the drawing area in dp.
      */
     public float getWidth() {
-        return mWidth;
+        return mWidthDp;
     }
 
     /**
-     * @return The height of the drawing area.
+     * @return The height of the drawing area in dp.
      */
     public float getHeight() {
-        return mHeight;
+        return mHeightDp;
     }
 
     /**
-     * @return The height of the drawing area minus the top controls.
+     * @return The height of the drawing area minus the browser controls in dp.
      */
-    public float getHeightMinusTopControls() {
-        return mHeightMinusTopControls;
+    public float getHeightMinusBrowserControls() {
+        return mHeightMinusBrowserControlsDp;
     }
 
     /**
@@ -1079,14 +1048,6 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
         return false;
     }
 
-    /**
-     * @return The number of drawn tabs. This does not count the one culled out.
-     */
-    @VisibleForTesting
-    public int getLayoutTabsDrawnCount() {
-        return mRenderHost.getLayoutTabsDrawnCount();
-    }
-
     /**
      * Setting this will only take effect the next time this layout is shown.  If it is currently
      * showing the original filter will still be used.
@@ -1104,7 +1065,7 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
      * @return The {@link EventFilter} the {@link Layout} is listening to.
      */
     public EventFilter findInterceptingEventFilter(
-            MotionEvent e, Point offsets, boolean isKeyboardShowing) {
+            MotionEvent e, PointF offsets, boolean isKeyboardShowing) {
         // The last added overlay will be drawn on top of everything else, therefore the last
         // filter added should have the first chance to intercept any touch events.
         for (int i = mSceneOverlays.size() - 1; i >= 0; i--) {
@@ -1124,8 +1085,8 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
     /**
      * Build a {@link SceneLayer} if it hasn't already been built, and update it and return it.
      *
-     * @param viewport          A viewport in which to display content.
-     * @param contentViewport   The visible section of the viewport.
+     * @param viewport          A viewport in which to display content in px.
+     * @param visibleViewport   The visible section of the viewport in px.
      * @param layerTitleCache   A layer title cache.
      * @param tabContentManager A tab content manager.
      * @param resourceManager   A resource manager.
@@ -1133,13 +1094,13 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
      * @return                  A {@link SceneLayer} that represents the content for this
      *                          {@link Layout}.
      */
-    public final SceneLayer getUpdatedSceneLayer(Rect viewport, Rect contentViewport,
+    public final SceneLayer getUpdatedSceneLayer(RectF viewport, RectF visibleViewport,
             LayerTitleCache layerTitleCache, TabContentManager tabContentManager,
             ResourceManager resourceManager, ChromeFullscreenManager fullscreenManager) {
-        updateSceneLayer(viewport, contentViewport, layerTitleCache, tabContentManager,
+        updateSceneLayer(viewport, visibleViewport, layerTitleCache, tabContentManager,
                 resourceManager, fullscreenManager);
 
-        float offsetPx = fullscreenManager != null ? fullscreenManager.getControlOffset() : 0.f;
+        float offsetPx = fullscreenManager != null ? fullscreenManager.getTopControlOffset() : 0.f;
         float dpToPx = getContext().getResources().getDisplayMetrics().density;
         float offsetDp = offsetPx / dpToPx;
 
@@ -1149,7 +1110,7 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
             if (!mSceneOverlays.get(i).isSceneOverlayTreeShowing()) continue;
 
             SceneOverlayLayer overlayLayer = mSceneOverlays.get(i).getUpdatedSceneOverlayTree(
-                    layerTitleCache, resourceManager, offsetDp);
+                    viewport, visibleViewport, layerTitleCache, resourceManager, offsetDp);
 
             overlayLayer.setContentTree(content);
             content = overlayLayer;
@@ -1159,16 +1120,23 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
     }
 
     /**
-     * @return Whether or not to force the top controls Android view to hide.
+     * @return Whether or not to force the browser controls Android view to hide.
      */
-    public boolean forceHideTopControlsAndroidView() {
+    public boolean forceHideBrowserControlsAndroidView() {
         for (int i = 0; i < mSceneOverlays.size(); i++) {
-            // If any overlay wants to hide tha Android version of the top controls, hide them.
-            if (mSceneOverlays.get(i).shouldHideAndroidTopControls()) return true;
+            // If any overlay wants to hide tha Android version of the browser controls, hide them.
+            if (mSceneOverlays.get(i).shouldHideAndroidBrowserControls()) return true;
         }
         return false;
     }
 
+    /**
+     * @return Whether or not the layout should permenantly show the browser controls.
+     */
+    public boolean forceShowBrowserControlsAndroidView() {
+        return false;
+    }
+
     /**
      * @return Whether the tabstrip's event filter is enabled.
      */
@@ -1188,7 +1156,7 @@ public abstract class Layout implements TabContentManager.ThumbnailChangeListene
      * Update {@link SceneLayer} instance this layout holds. Any class inheriting {@link Layout}
      * should override this function in order for other functions to work.
      */
-    protected void updateSceneLayer(Rect viewport, Rect contentViewport,
+    protected void updateSceneLayer(RectF viewport, RectF contentViewport,
             LayerTitleCache layerTitleCache, TabContentManager tabContentManager,
             ResourceManager resourceManager, ChromeFullscreenManager fullscreenManager) {
     }
