@@ -6,7 +6,7 @@ package org.chromium.chrome.browser.compositor.scene_layer;
 
 import android.content.Context;
 import android.content.res.Resources;
-import android.graphics.Rect;
+import android.graphics.RectF;
 
 import org.chromium.base.ApiCompatibilityUtils;
 import org.chromium.base.annotations.JNINamespace;
@@ -16,6 +16,7 @@ import org.chromium.chrome.browser.compositor.layouts.Layout;
 import org.chromium.chrome.browser.compositor.layouts.Layout.Orientation;
 import org.chromium.chrome.browser.compositor.layouts.components.LayoutTab;
 import org.chromium.chrome.browser.compositor.layouts.content.TabContentManager;
+import org.chromium.chrome.browser.fullscreen.ChromeFullscreenManager;
 import org.chromium.chrome.browser.util.ColorUtils;
 import org.chromium.ui.resources.ResourceManager;
 
@@ -33,11 +34,17 @@ public class TabListSceneLayer extends SceneLayer {
      * disabled ScheduleComposite calls as this will change the tree and could subsequently cause
      * unnecessary follow up renders.
      * @param context         The {@link Context} to use to query device information.
+     * @param viewport        The viewport for the screen.
+     * @param contentViewport The visible viewport.
      * @param layout          The {@link Layout} to push to the screen.
+     * @param layerTitleCache An object for accessing tab layer titles.
+     * @param tabContentManager An object for accessing tab content.
+     * @param resourceManager An object for accessing static and dynamic resources.
+     * @param fullscreenManager The fullscreen manager for browser controls information.
      */
-    public void pushLayers(Context context, Rect viewport, Rect contentViewport, Layout layout,
+    public void pushLayers(Context context, RectF viewport, RectF contentViewport, Layout layout,
             LayerTitleCache layerTitleCache, TabContentManager tabContentManager,
-            ResourceManager resourceManager) {
+            ResourceManager resourceManager, ChromeFullscreenManager fullscreenManager) {
         if (mNativePtr == 0) return;
 
         Resources res = context.getResources();
@@ -73,7 +80,8 @@ public class TabListSceneLayer extends SceneLayer {
                     R.drawable.tabswitcher_border_frame_decoration, R.drawable.logo_card_back,
                     R.drawable.tabswitcher_border_frame,
                     R.drawable.tabswitcher_border_frame_inner_shadow,
-                    t.canUseLiveTexture(), t.getBackgroundColor(),
+                    t.canUseLiveTexture(), fullscreenManager.areBrowserControlsAtBottom(),
+                    t.getBackgroundColor(),
                     ApiCompatibilityUtils.getColor(res, borderColorResource), t.isIncognito(),
                     layout.getOrientation() == Orientation.PORTRAIT, t.getRenderX() * dpToPx,
                     t.getRenderY() * dpToPx, t.getScaledContentWidth() * dpToPx,
@@ -91,7 +99,7 @@ public class TabListSceneLayer extends SceneLayer {
                     defaultThemeColor, t.getToolbarBackgroundColor(), closeButtonColor,
                     t.anonymizeToolbar(), R.drawable.textbox, t.getTextBoxBackgroundColor(),
                     t.getTextBoxAlpha(), t.getToolbarAlpha(), t.getToolbarYOffset() * dpToPx,
-                    t.getSideBorderScale(), true, t.insetBorderVertical());
+                    t.getSideBorderScale(), t.insetBorderVertical());
         }
         nativeFinishBuildingFrame(mNativePtr);
     }
@@ -131,7 +139,8 @@ public class TabListSceneLayer extends SceneLayer {
     private native void nativePutTabLayer(long nativeTabListSceneLayer, int id,
             int toolbarResourceId, int closeButtonResourceId, int shadowResourceId,
             int contourResourceId, int backLogoResourceId, int borderResourceId,
-            int borderInnerShadowResourceId, boolean canUseLiveLayer, int tabBackgroundColor,
+            int borderInnerShadowResourceId, boolean canUseLiveLayer,
+            boolean browserControlsAtBottom, int tabBackgroundColor,
             int backLogoColor, boolean incognito, boolean isPortrait, float x, float y, float width,
             float height, float contentWidth, float contentHeight, float visibleContentHeight,
             float shadowX, float shadowY, float shadowWidth, float shadowHeight, float pivotX,
@@ -142,5 +151,5 @@ public class TabListSceneLayer extends SceneLayer {
             int toolbarBackgroundColor, int closeButtonColor, boolean anonymizeToolbar,
             int toolbarTextBoxResource, int toolbarTextBoxBackgroundColor,
             float toolbarTextBoxAlpha, float toolbarAlpha, float toolbarYOffset,
-            float sideBorderScale, boolean attachContent, boolean insetVerticalBorder);
+            float sideBorderScale, boolean insetVerticalBorder);
 }
