@@ -696,9 +696,7 @@ public class ContextualSearchManager implements ContextualSearchManagementDelega
             doLiteralSearch = true;
         }
 
-        boolean quickActionShown =
-                mSearchPanel.getSearchBarControl().getQuickActionControl().hasQuickAction();
-        boolean receivedContextualCardsData = !quickActionShown && !TextUtils.isEmpty(caption)
+        boolean receivedContextualCardsData = !TextUtils.isEmpty(caption)
                 || !TextUtils.isEmpty(thumbnailUrl);
         if (ContextualSearchFieldTrial.shouldHideContextualCardsData()) {
             // Clear the thumbnail URL and caption so that they are not displayed in the bar. This
@@ -725,6 +723,8 @@ public class ContextualSearchManager implements ContextualSearchManagementDelega
         }
 
         if (ContextualSearchFieldTrial.isContextualSearchSingleActionsEnabled()) {
+            boolean quickActionShown =
+                    mSearchPanel.getSearchBarControl().getQuickActionControl().hasQuickAction();
             ContextualSearchUma.logQuickActionShown(quickActionShown, quickActionCategory);
             mSearchPanel.getPanelMetrics().setWasQuickActionShown(quickActionShown,
                     quickActionCategory);
