@@ -39,24 +39,20 @@ class TapSuppression extends ContextualSearchHeuristic {
         mIsSecondTap = previousTapState != null && previousTapState.wasSuppressed()
                 && !shouldHandleFirstTap();
 
-        boolean doSuppressTap = false;
-        if (mIsTapSuppressionEnabled) {
-            if (mIsSecondTap) {
-                boolean shouldHandle = shouldHandleSecondTap(previousTapState, x, y);
-                doSuppressTap = !shouldHandle;
-            } else {
-                doSuppressTap = !shouldHandleFirstTap();
-                if (doSuppressTap) {
-                    RecordUserAction.record("ContextualSearch.TapSuppressed.TapThresholdExceeded");
-                }
+        if (mIsSecondTap) {
+            boolean shouldHandle = shouldHandleSecondTap(previousTapState, x, y);
+            mIsConditionSatisfied = !shouldHandle;
+        } else {
+            mIsConditionSatisfied = !shouldHandleFirstTap();
+            if (mIsConditionSatisfied && mIsTapSuppressionEnabled) {
+                RecordUserAction.record("ContextualSearch.TapSuppressed.TapThresholdExceeded");
             }
         }
-        mIsConditionSatisfied = doSuppressTap;
     }
 
     @Override
-    protected boolean isConditionSatisfied() {
-        return mIsConditionSatisfied;
+    protected boolean isConditionSatisfiedAndEnabled() {
+        return mIsTapSuppressionEnabled && mIsConditionSatisfied;
     }
 
     @Override
@@ -68,11 +64,6 @@ class TapSuppression extends ContextualSearchHeuristic {
         }
     }
 
-    @Override
-    protected boolean isConditionSatisfiedForAggregateLogging() {
-        return !mIsSecondTap && !shouldHandleFirstTap();
-    }
-
     /**
      * @return Whether a first tap should be handled or not.
      */
