@@ -65,7 +65,6 @@ import org.chromium.chrome.browser.tabmodel.TabModel.TabLaunchType;
 import org.chromium.chrome.browser.tabmodel.TabModelObserver;
 import org.chromium.chrome.browser.tabmodel.TabModelSelector;
 import org.chromium.chrome.browser.tabmodel.TabModelSelectorImpl;
-import org.chromium.chrome.browser.tabmodel.TabPersistencePolicy;
 import org.chromium.chrome.browser.toolbar.ToolbarControlContainer;
 import org.chromium.chrome.browser.util.ColorUtils;
 import org.chromium.chrome.browser.util.UrlUtilities;
@@ -99,6 +98,7 @@ public class CustomTabActivity extends ChromeActivity {
     private CustomTabContentHandler mCustomTabContentHandler;
     private Tab mMainTab;
     private CustomTabBottomBarDelegate mBottomBarDelegate;
+    private CustomTabTabPersistencePolicy mTabPersistencePolicy;
 
     // This is to give the right package name while using the client's resources during an
     // overridePendingTransition call.
@@ -107,7 +107,7 @@ public class CustomTabActivity extends ChromeActivity {
     private boolean mShouldOverridePackage;
 
     private boolean mHasCreatedTabEarly;
-    private boolean mIsInitialResume = true;
+    private boolean mIsInitialStart = true;
     // Whether there is any prerender associated with the session.
     private boolean mHasPrerender;
     private CustomTabObserver mTabObserver;
@@ -131,11 +131,12 @@ public class CustomTabActivity extends ChromeActivity {
         }
 
         @Override
-        public void onFirstContentfulPaint(WebContents webContents, long firstContentfulPaintMs) {
+        public void onFirstContentfulPaint(
+                WebContents webContents, long navigationStartTick, long firstContentfulPaintMs) {
             if (webContents != mTab.getWebContents()) return;
 
-            mConnection.notifyPageLoadMetric(
-                    mSession, PageLoadMetrics.FIRST_CONTENTFUL_PAINT, firstContentfulPaintMs);
+            mConnection.notifyPageLoadMetric(mSession, PageLoadMetrics.FIRST_CONTENTFUL_PAINT,
+                    navigationStartTick, firstContentfulPaintMs);
         }
     }
 
@@ -347,10 +348,10 @@ public class CustomTabActivity extends ChromeActivity {
 
     @Override
     protected TabModelSelector createTabModelSelector() {
-        TabPersistencePolicy persistencePolicy = new CustomTabTabPersistencePolicy(
+        mTabPersistencePolicy = new CustomTabTabPersistencePolicy(
                 getTaskId(), getSavedInstanceState() != null);
 
-        return new TabModelSelectorImpl(this, this, persistencePolicy, false, false);
+        return new TabModelSelectorImpl(this, this, mTabPersistencePolicy, false, false);
     }
 
     @Override
@@ -486,6 +487,13 @@ public class CustomTabActivity extends ChromeActivity {
 
         // Put Sync in the correct state by calling tab state initialized. crbug.com/581811.
         getTabModelSelector().markTabStateInitialized();
+        SharedPreferences preferences = ContextUtils.getAppSharedPreferences();
+        String lastUrl = preferences.getString(LAST_URL_PREF, null);
+        if (lastUrl != null && lastUrl.equals(getUrlToLoad())) {
+            RecordUserAction.record("CustomTabsMenuOpenSameUrl");
+        } else {
+            preferences.edit().putString(LAST_URL_PREF, getUrlToLoad()).apply();
+        }
         super.finishNativeInitialization();
     }
 
@@ -569,28 +577,14 @@ public class CustomTabActivity extends ChromeActivity {
     public void onStartWithNative() {
         super.onStartWithNative();
         setActiveContentHandler(mCustomTabContentHandler);
-        if (mHasCreatedTabEarly && !mMainTab.isLoading()) postDeferredStartupIfNeeded();
-    }
 
-    @Override
-    public void onResumeWithNative() {
-        super.onResumeWithNative();
-
-        if (getSavedInstanceState() != null || !mIsInitialResume) {
+        if (getSavedInstanceState() != null || !mIsInitialStart) {
             if (mIntentDataProvider.isOpenedByChrome()) {
                 RecordUserAction.record("ChromeGeneratedCustomTab.StartedReopened");
             } else {
                 RecordUserAction.record("CustomTabs.StartedReopened");
             }
         } else {
-            SharedPreferences preferences = ContextUtils.getAppSharedPreferences();
-            String lastUrl = preferences.getString(LAST_URL_PREF, null);
-            if (lastUrl != null && lastUrl.equals(getUrlToLoad())) {
-                RecordUserAction.record("CustomTabsMenuOpenSameUrl");
-            } else {
-                preferences.edit().putString(LAST_URL_PREF, getUrlToLoad()).apply();
-            }
-
             if (mIntentDataProvider.isOpenedByChrome()) {
                 RecordUserAction.record("ChromeGeneratedCustomTab.StartedInitially");
             } else {
@@ -602,7 +596,8 @@ public class CustomTabActivity extends ChromeActivity {
                 RecordUserAction.record("CustomTabs.StartedInitially");
             }
         }
-        mIsInitialResume = false;
+        if (mHasCreatedTabEarly && !mMainTab.isLoading()) postDeferredStartupIfNeeded();
+        mIsInitialStart = false;
     }
 
     @Override
@@ -616,7 +611,12 @@ public class CustomTabActivity extends ChromeActivity {
     public void onStopWithNative() {
         super.onStopWithNative();
         setActiveContentHandler(null);
-        if (!mIsClosing) getTabModelSelector().saveState();
+        if (mIsClosing) {
+            getTabModelSelector().closeAllTabs(true);
+            mTabPersistencePolicy.deleteMetadataStateFileAsync();
+        } else {
+            getTabModelSelector().saveState();
+        }
     }
 
     /**
@@ -721,6 +721,7 @@ public class CustomTabActivity extends ChromeActivity {
      * @param reparenting true iff the activity finishes due to tab reparenting.
      */
     public final void finishAndClose(boolean reparenting) {
+        if (mIsClosing) return;
         mIsClosing = true;
         if (!reparenting) {
             // Closing the activity destroys the renderer as well. Re-create a spare renderer some
@@ -877,6 +878,14 @@ public class CustomTabActivity extends ChromeActivity {
         return mIntentDataProvider;
     }
 
+    /**
+     * @return The tab persistence policy for this activity.
+     */
+    @VisibleForTesting
+    CustomTabTabPersistencePolicy getTabPersistencePolicyForTest() {
+        return mTabPersistencePolicy;
+    }
+
     /**
      * Opens the URL currently being displayed in the Custom Tab in the regular browser.
      * @param forceReparenting Whether tab reparenting should be forced for testing.
