@@ -8,21 +8,23 @@ import android.app.Activity;
 import android.content.Context;
 import android.content.Intent;
 import android.content.pm.ResolveInfo;
-import android.os.TransactionTooLargeException;
 import android.text.TextUtils;
 
-import org.chromium.base.Log;
 import org.chromium.base.VisibleForTesting;
 import org.chromium.chrome.browser.contextmenu.ChromeContextMenuPopulator;
 import org.chromium.chrome.browser.contextmenu.ContextMenuPopulator;
 import org.chromium.chrome.browser.externalnav.ExternalNavigationDelegateImpl;
 import org.chromium.chrome.browser.externalnav.ExternalNavigationHandler;
+import org.chromium.chrome.browser.fullscreen.BrowserStateBrowserControlsVisibilityDelegate;
+import org.chromium.chrome.browser.fullscreen.ComposedBrowserControlsVisibilityDelegate;
+import org.chromium.chrome.browser.tab.BrowserControlsVisibilityDelegate;
 import org.chromium.chrome.browser.tab.InterceptNavigationDelegateImpl;
 import org.chromium.chrome.browser.tab.Tab;
 import org.chromium.chrome.browser.tab.TabContextMenuItemDelegate;
 import org.chromium.chrome.browser.tab.TabDelegateFactory;
+import org.chromium.chrome.browser.tab.TabStateBrowserControlsVisibilityDelegate;
 import org.chromium.chrome.browser.tab.TabWebContentsDelegateAndroid;
-import org.chromium.chrome.browser.tab.TopControlsVisibilityDelegate;
+import org.chromium.chrome.browser.util.IntentUtils;
 import org.chromium.chrome.browser.util.UrlUtilities;
 
 /**
@@ -82,7 +84,7 @@ public class CustomTabDelegateFactory extends TabDelegateFactory {
                 }
                 return false;
             } catch (RuntimeException e) {
-                logTransactionTooLargeOrRethrow(e, intent);
+                IntentUtils.logTransactionTooLargeOrRethrow(e, intent);
                 return false;
             }
         }
@@ -104,7 +106,7 @@ public class CustomTabDelegateFactory extends TabDelegateFactory {
                     }
                 }
             } catch (RuntimeException e) {
-                logTransactionTooLargeOrRethrow(e, intent);
+                IntentUtils.logTransactionTooLargeOrRethrow(e, intent);
             }
             return false;
         }
@@ -116,15 +118,6 @@ public class CustomTabDelegateFactory extends TabDelegateFactory {
         public boolean hasExternalActivityStarted() {
             return mHasActivityStarted;
         }
-
-        private static void logTransactionTooLargeOrRethrow(RuntimeException e, Intent intent) {
-            // See http://crbug.com/369574.
-            if (e.getCause() instanceof TransactionTooLargeException) {
-                Log.e(TAG, "Could not resolve Activity for intent " + intent.toString(), e);
-            } else {
-                throw e;
-            }
-        }
     }
 
     private static class CustomTabWebContentsDelegate extends TabWebContentsDelegateAndroid {
@@ -146,28 +139,36 @@ public class CustomTabDelegateFactory extends TabDelegateFactory {
         }
     }
 
-    private final boolean mShouldHideTopControls;
+    private final boolean mShouldHideBrowserControls;
     private final boolean mIsOpenedByChrome;
+    private final BrowserStateBrowserControlsVisibilityDelegate mBrowserStateVisibilityDelegate;
 
     private ExternalNavigationDelegateImpl mNavigationDelegate;
     private ExternalNavigationHandler mNavigationHandler;
 
     /**
-     * @param shouldHideTopControls Whether or not the top controls may auto-hide.
+     * @param shouldHideBrowserControls Whether or not the browser controls may auto-hide.
+     * @param isOpenedByChrome Whether the CustomTab was originally opened by Chrome.
+     * @param visibilityDelegate The delegate that handles browser control visibility associated
+     *                           with browser actions (as opposed to tab state).
      */
-    public CustomTabDelegateFactory(boolean shouldHideTopControls, boolean isOpenedByChrome) {
-        mShouldHideTopControls = shouldHideTopControls;
+    public CustomTabDelegateFactory(boolean shouldHideBrowserControls, boolean isOpenedByChrome,
+            BrowserStateBrowserControlsVisibilityDelegate visibilityDelegate) {
+        mShouldHideBrowserControls = shouldHideBrowserControls;
         mIsOpenedByChrome = isOpenedByChrome;
+        mBrowserStateVisibilityDelegate = visibilityDelegate;
     }
 
     @Override
-    public TopControlsVisibilityDelegate createTopControlsVisibilityDelegate(Tab tab) {
-        return new TopControlsVisibilityDelegate(tab) {
-            @Override
-            public boolean isHidingTopControlsEnabled() {
-                return mShouldHideTopControls && super.isHidingTopControlsEnabled();
-            }
-        };
+    public BrowserControlsVisibilityDelegate createBrowserControlsVisibilityDelegate(Tab tab) {
+        return new ComposedBrowserControlsVisibilityDelegate(
+                new TabStateBrowserControlsVisibilityDelegate(tab) {
+                    @Override
+                    public boolean isHidingBrowserControlsEnabled() {
+                        return mShouldHideBrowserControls && super.isHidingBrowserControlsEnabled();
+                    }
+                },
+                mBrowserStateVisibilityDelegate);
     }
 
     @Override
