@@ -19,6 +19,7 @@ import android.os.Build;
 import android.os.Bundle;
 import android.os.Process;
 import android.os.StrictMode;
+import android.os.SystemClock;
 import android.support.customtabs.CustomTabsCallback;
 import android.support.customtabs.CustomTabsIntent;
 import android.support.customtabs.CustomTabsService;
@@ -31,6 +32,8 @@ import org.chromium.base.CommandLine;
 import org.chromium.base.Log;
 import org.chromium.base.SysUtils;
 import org.chromium.base.ThreadUtils;
+import org.chromium.base.TimeUtils;
+import org.chromium.base.TraceEvent;
 import org.chromium.base.VisibleForTesting;
 import org.chromium.base.annotations.SuppressFBWarnings;
 import org.chromium.base.library_loader.ProcessInitException;
@@ -42,6 +45,7 @@ import org.chromium.chrome.browser.IntentHandler;
 import org.chromium.chrome.browser.WarmupManager;
 import org.chromium.chrome.browser.device.DeviceClassManager;
 import org.chromium.chrome.browser.init.ChromeBrowserInitializer;
+import org.chromium.chrome.browser.metrics.PageLoadMetrics;
 import org.chromium.chrome.browser.net.spdyproxy.DataReductionProxySettings;
 import org.chromium.chrome.browser.preferences.PrefServiceBridge;
 import org.chromium.chrome.browser.prerender.ExternalPrerenderHandler;
@@ -129,6 +133,10 @@ public class CustomTabsConnection {
     private final AtomicBoolean mWarmupHasBeenFinished = new AtomicBoolean();
     private ExternalPrerenderHandler mExternalPrerenderHandler;
 
+    // Conversion between native TimeTicks and SystemClock.uptimeMillis().
+    private long mNativeTickOffsetUs;
+    private boolean mNativeTickOffsetUsComputed;
+
     /**
      * <strong>DO NOT CALL</strong>
      * Public to be instanciable from {@link ChromeApplication}. This is however
@@ -213,9 +221,14 @@ public class CustomTabsConnection {
     }
 
     public boolean warmup(long flags) {
-        boolean success = warmupInternal(true);
-        logCall("warmup()", success);
-        return success;
+        try {
+            TraceEvent.begin("CustomTabsConnection.warmup");
+            boolean success = warmupInternal(true);
+            logCall("warmup()", success);
+            return success;
+        } finally {
+            TraceEvent.end("CustomTabsConnection.warmup");
+        }
     }
 
     /**
@@ -241,17 +254,38 @@ public class CustomTabsConnection {
         ThreadUtils.postOnUiThread(new Runnable() {
             @Override
             public void run() {
-                if (!initialized) initializeBrowser(mApplication);
-                if (mayCreateSpareWebContents && mSpeculation == null
-                        && !SysUtils.isLowEndDevice()) {
-                    WarmupManager.getInstance().createSpareWebContents();
-                    // The throttling database uses shared preferences, that can cause a StrictMode
-                    // violation on the first access. Make sure that this access is not in
-                    // mayLauchUrl.
-                    RequestThrottler.getForUid(mApplication, uid);
+                try {
+                    TraceEvent.begin("CustomTabsConnection.warmupInternal");
+                    // Ordering of actions here:
+                    // 1. Initializing the browser needs to be done once, and first.
+                    // 2. Creating a spare renderer takes time, in other threads and processes, so
+                    //    start it sooner rather than later. Can be done several times.
+                    // 3. Initializing the ResourcePrefetchPredictor is done once, and triggers
+                    //    work on other threads, start it early.
+                    // 4. RequestThrottler first access has to be done only once.
 
-                    Profile profile = Profile.getLastUsedProfile();
-                    new ResourcePrefetchPredictor(profile).startInitialization();
+                    // (1)
+                    if (!initialized) initializeBrowser(mApplication);
+
+                    // (2)
+                    if (mayCreateSpareWebContents && mSpeculation == null
+                            && !SysUtils.isLowEndDevice()) {
+                        WarmupManager.getInstance().createSpareWebContents();
+                    }
+
+                    if (!initialized) {
+                        // (3)
+                        Profile profile = Profile.getLastUsedProfile();
+                        new ResourcePrefetchPredictor(profile).startInitialization();
+
+                        // (4)
+                        // The throttling database uses shared preferences, that can cause a
+                        // StrictMode violation on the first access. Make sure that this access is
+                        // not in mayLauchUrl.
+                        RequestThrottler.getForUid(mApplication, uid);
+                    }
+                } finally {
+                    TraceEvent.end("CustomTabsConnection.warmupInternal");
                 }
                 mWarmupHasBeenFinished.set(true);
             }
@@ -342,9 +376,14 @@ public class CustomTabsConnection {
 
     public boolean mayLaunchUrl(CustomTabsSessionToken session, Uri url, Bundle extras,
             List<Bundle> otherLikelyBundles) {
-        boolean success = mayLaunchUrlInternal(session, url, extras, otherLikelyBundles);
-        logCall("mayLaunchUrl()", success);
-        return success;
+        try {
+            TraceEvent.begin("CustomTabsConnection.mayLaunchUrl");
+            boolean success = mayLaunchUrlInternal(session, url, extras, otherLikelyBundles);
+            logCall("mayLaunchUrl()", success);
+            return success;
+        } finally {
+            TraceEvent.end("CustomTabsConnection.mayLaunchUrl");
+        }
     }
 
     private boolean mayLaunchUrlInternal(final CustomTabsSessionToken session, Uri url,
@@ -370,10 +409,16 @@ public class CustomTabsConnection {
         ThreadUtils.postOnUiThread(new Runnable() {
             @Override
             public void run() {
-                if (lowConfidence) {
-                    lowConfidenceMayLaunchUrl(otherLikelyBundles);
-                } else {
-                    highConfidenceMayLaunchUrl(session, uid, urlString, extras, otherLikelyBundles);
+                try {
+                    TraceEvent.begin("CustomTabsConnection.mayLaunchUrlInternal");
+                    if (lowConfidence) {
+                        lowConfidenceMayLaunchUrl(otherLikelyBundles);
+                    } else {
+                        highConfidenceMayLaunchUrl(
+                                session, uid, urlString, extras, otherLikelyBundles);
+                    }
+                } finally {
+                    TraceEvent.end("CustomTabsConnection.mayLaunchUrlInternal");
                 }
             }
         });
@@ -688,12 +733,26 @@ public class CustomTabsConnection {
      *
      * @param session Session identifier.
      * @param metricName Name of the page load metric.
+     * @param navigationStartTick Absolute navigation start time, as TimeTicks taken from native.
+     *
      * @param offsetMs Offset in ms from navigationStart.
      */
-    boolean notifyPageLoadMetric(CustomTabsSessionToken session, String metricName, long offsetMs) {
+    boolean notifyPageLoadMetric(CustomTabsSessionToken session, String metricName,
+            long navigationStartTick, long offsetMs) {
         CustomTabsCallback callback = mClientManager.getCallbackForSession(session);
         if (callback == null) return false;
+
+        if (!mNativeTickOffsetUsComputed) {
+            // Compute offset from time ticks to uptimeMillis.
+            mNativeTickOffsetUsComputed = true;
+            long nativeNowUs = TimeUtils.nativeGetTimeTicksNowUs();
+            long javaNowUs = SystemClock.uptimeMillis() * 1000;
+            mNativeTickOffsetUs = nativeNowUs - javaNowUs;
+        }
+
         Bundle args = new Bundle();
+        args.putLong(PageLoadMetrics.NAVIGATION_START,
+                (navigationStartTick - mNativeTickOffsetUs) / 1000);
         args.putLong(metricName, offsetMs);
         try {
             callback.extraCallback(PAGE_LOAD_METRICS_CALLBACK, args);
