@@ -15,6 +15,7 @@ import android.widget.CheckBox;
 import android.widget.TextView;
 
 import org.chromium.base.ContextUtils;
+import org.chromium.base.FieldTrialList;
 import org.chromium.base.metrics.RecordHistogram;
 import org.chromium.chrome.R;
 import org.chromium.chrome.browser.EmbedContentViewActivity;
@@ -32,7 +33,7 @@ import org.chromium.content_public.common.Referrer;
 public class DataUseTabUIManager {
 
     private static final String SHARED_PREF_DATA_USE_DIALOG_OPT_OUT = "data_use_dialog_opt_out";
-    private static final String FIELD_TRIAL_NAME = "ExternalDataUseObserver";
+    private static final String DATA_USE_FIELD_TRIAL = "ExternalDataUseObserver";
 
     /**
      * Data use started UI snackbar will not be shown if {@link DISABLE_DATA_USE_STARTED_UI_PARAM}
@@ -225,22 +226,26 @@ public class DataUseTabUIManager {
      * @return true if the data use tracking started UI (snackbar) should be shown.
      */
     public static boolean shouldShowDataUseStartedUI() {
-        // UI should be shown only in non-roaming-cellular, or UI could be disabled in finch.
-        return nativeIsNonRoamingCellularConnection()
+        // UI should be shown only when field trial is active, not disabled in Finch and in
+        // non-roaming-cellular connection.
+        return FieldTrialList.trialExists(DATA_USE_FIELD_TRIAL)
                 && !DISABLE_DATA_USE_UI_PARAM_VALUE.equals(
                            VariationsAssociatedData.getVariationParamValue(
-                                   FIELD_TRIAL_NAME, DISABLE_DATA_USE_STARTED_UI_PARAM));
+                                   DATA_USE_FIELD_TRIAL, DISABLE_DATA_USE_STARTED_UI_PARAM))
+                && nativeIsNonRoamingCellularConnection();
     }
 
     /**
      * @return true if the data use tracking ended UI (snackbar or interstitial) should be shown.
      */
     public static boolean shouldShowDataUseEndedUI() {
-        // UI should be shown only in non-roaming-cellular, or UI could be disabled in finch.
-        return nativeIsNonRoamingCellularConnection()
+        // UI should be shown only when field trial is active, not disabled in Finch and in
+        // non-roaming-cellular connection.
+        return FieldTrialList.trialExists(DATA_USE_FIELD_TRIAL)
                 && !DISABLE_DATA_USE_UI_PARAM_VALUE.equals(
                            VariationsAssociatedData.getVariationParamValue(
-                                   FIELD_TRIAL_NAME, DISABLE_DATA_USE_ENDED_UI_PARAM));
+                                   DATA_USE_FIELD_TRIAL, DISABLE_DATA_USE_ENDED_UI_PARAM))
+                && nativeIsNonRoamingCellularConnection();
     }
 
     /**
@@ -257,7 +262,7 @@ public class DataUseTabUIManager {
                        SHARED_PREF_DATA_USE_DIALOG_OPT_OUT, false)
                 || DISABLE_DATA_USE_UI_PARAM_VALUE.equals(
                            VariationsAssociatedData.getVariationParamValue(
-                                   FIELD_TRIAL_NAME, DISABLE_DATA_USE_ENDED_DIALOG_PARAM));
+                                   DATA_USE_FIELD_TRIAL, DISABLE_DATA_USE_ENDED_DIALOG_PARAM));
     }
 
     /**
