@@ -4,9 +4,14 @@
 
 package org.chromium.chrome.browser.download;
 
+import org.chromium.base.annotations.CalledByNative;
+
 /**
  * A generic class representing a download item. The item can be either downloaded through the
- * Android DownloadManager, or through Chrome's network stack
+ * Android DownloadManager, or through Chrome's network stack.
+ *
+ * This represents the native DownloadItem at a specific point in time -- the native side
+ * DownloadManager must be queried for the correct status.
  */
 public class DownloadItem {
     static final long INVALID_DOWNLOAD_ID = -1L;
@@ -107,4 +112,13 @@ public class DownloadItem {
     public boolean hasBeenExternallyRemoved() {
         return mHasBeenExternallyRemoved;
     }
+
+    @CalledByNative
+    private static DownloadItem createDownloadItem(
+            DownloadInfo downloadInfo, long startTimestamp, boolean hasBeenExternallyRemoved) {
+        DownloadItem downloadItem = new DownloadItem(false, downloadInfo);
+        downloadItem.setStartTime(startTimestamp);
+        downloadItem.setHasBeenExternallyRemoved(hasBeenExternallyRemoved);
+        return downloadItem;
+    }
 }
