@@ -207,9 +207,9 @@ public class DownloadManagerService extends BroadcastReceiver implements
      * Creates DownloadManagerService.
      */
     @SuppressFBWarnings("LI_LAZY_INIT") // Findbugs doesn't see this is only UI thread.
-    public static DownloadManagerService getDownloadManagerService(final Context context) {
+    public static DownloadManagerService getDownloadManagerService(Context context) {
         ThreadUtils.assertOnUiThread();
-        assert context == context.getApplicationContext();
+        context = context.getApplicationContext();
         if (sDownloadManagerService == null) {
             sDownloadManagerService = new DownloadManagerService(context,
                     new SystemDownloadNotifier(context),  new Handler(), UPDATE_DELAY_MILLIS);
@@ -606,7 +606,7 @@ public class DownloadManagerService extends BroadcastReceiver implements
             long downloadId = mDownloadManagerDelegate.addCompletedDownload(
                     downloadInfo.getFileName(), description, downloadInfo.getMimeType(),
                     downloadInfo.getFilePath(), downloadInfo.getContentLength(),
-                    downloadInfo.getOriginalUrl(), downloadInfo.getReferer(),
+                    downloadInfo.getOriginalUrl(), downloadInfo.getReferrer(),
                     downloadInfo.getDownloadGuid());
             downloadItem.setSystemDownloadId(downloadId);
             return true;
@@ -886,7 +886,7 @@ public class DownloadManagerService extends BroadcastReceiver implements
             request.setDescription(description);
             request.setTitle(info.getFileName());
             request.addRequestHeader("Cookie", info.getCookie());
-            request.addRequestHeader("Referer", info.getReferer());
+            request.addRequestHeader("Referer", info.getReferrer());
             request.addRequestHeader("User-Agent", info.getUserAgent());
 
             DownloadManager manager =
@@ -986,12 +986,11 @@ public class DownloadManagerService extends BroadcastReceiver implements
             Context context, @Nullable String filePath, long downloadId,
             boolean isSupportedMimeType) {
         assert !ThreadUtils.runningOnUiThread();
-        Uri contentUri = DownloadManagerDelegate.getContentUriFromDownloadManager(
-                context, downloadId);
-        if (contentUri == null) return null;
-
         DownloadManager manager =
                 (DownloadManager) context.getSystemService(Context.DOWNLOAD_SERVICE);
+        Uri contentUri = manager.getUriForDownloadedFile(downloadId);
+        if (contentUri == null) return null;
+
         String mimeType = manager.getMimeTypeForDownloadedFile(downloadId);
         if (isSupportedMimeType) {
             // Redirect the user to an internal media viewer.  The file path is necessary to show
@@ -1000,6 +999,7 @@ public class DownloadManagerService extends BroadcastReceiver implements
             if (filePath != null) fileUri = Uri.fromFile(new File(filePath));
             return DownloadUtils.getMediaViewerIntentForDownloadItem(fileUri, contentUri, mimeType);
         }
+
         return DownloadUtils.createViewIntentForDownloadItem(contentUri, mimeType);
     }
 
@@ -1552,6 +1552,17 @@ public class DownloadManagerService extends BroadcastReceiver implements
         nativeGetAllDownloads(getNativeDownloadManagerService(), isOffTheRecord);
     }
 
+    /**
+     * Fires an Intent that alerts the DownloadNotificationService that an action must be taken
+     * for a particular item.
+     */
+    @Override
+    public void broadcastDownloadAction(DownloadItem downloadItem, String action) {
+        Intent intent = DownloadNotificationService.buildActionIntent(mContext, action,
+                downloadItem.getId(), downloadItem.getDownloadInfo().getFileName(), false);
+        mContext.sendBroadcast(intent);
+    }
+
     /**
      * Checks if the files associated with any downloads have been removed by an external action.
      * @param isOffTheRecord Whether or not to check downloads for the off the record profile.
@@ -1578,6 +1589,13 @@ public class DownloadManagerService extends BroadcastReceiver implements
         }
     }
 
+    @CalledByNative
+    private void onDownloadItemCreated(DownloadItem item) {
+        for (DownloadHistoryAdapter adapter : mHistoryAdapters) {
+            adapter.onDownloadItemCreated(item);
+        }
+    }
+
     @CalledByNative
     private void onDownloadItemUpdated(DownloadItem item) {
         for (DownloadHistoryAdapter adapter : mHistoryAdapters) {
@@ -1657,33 +1675,6 @@ public class DownloadManagerService extends BroadcastReceiver implements
     @Override
     public void purgeActiveNetworkList(long[] activeNetIds) {}
 
-    @CalledByNative
-    private static DownloadItem createDownloadItem(String guid, String displayName,
-            String filepath, String url, String mimeType, long startTimestamp, long totalBytes,
-            boolean hasBeenExternallyRemoved, boolean isIncognito, int state,
-            int percentCompleted, boolean isPaused) {
-        // Remap the MIME type first.
-        File file = new File(filepath);
-        String newMimeType =
-                ChromeDownloadDelegate.remapGenericMimeType(mimeType, url, file.getName());
-
-        DownloadInfo.Builder builder = new DownloadInfo.Builder()
-                .setDownloadGuid(guid)
-                .setFileName(displayName)
-                .setFilePath(filepath)
-                .setUrl(url)
-                .setMimeType(newMimeType)
-                .setContentLength(totalBytes)
-                .setIsOffTheRecord(isIncognito)
-                .setPercentCompleted(percentCompleted)
-                .setIsPaused(isPaused)
-                .setState(state);
-        DownloadItem downloadItem = new DownloadItem(false, builder.build());
-        downloadItem.setStartTime(startTimestamp);
-        downloadItem.setHasBeenExternallyRemoved(hasBeenExternallyRemoved);
-        return downloadItem;
-    }
-
     private static native boolean nativeIsSupportedMimeType(String mimeType);
 
     private native long nativeInit();
