@@ -40,12 +40,10 @@ import org.chromium.chrome.browser.init.EmptyBrowserParts;
 import org.chromium.chrome.browser.offlinepages.downloads.OfflinePageDownloadBridge;
 import org.chromium.chrome.browser.util.IntentUtils;
 
-import java.text.NumberFormat;
 import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
-import java.util.Locale;
 import java.util.Set;
 
 /**
@@ -53,25 +51,23 @@ import java.util.Set;
  * Chrome gets killed.
  */
 public class DownloadNotificationService extends Service {
-    static final String EXTRA_DOWNLOAD_NOTIFICATION_ID = "DownloadNotificationId";
     static final String EXTRA_DOWNLOAD_GUID = "DownloadGuid";
-    static final String EXTRA_DOWNLOAD_FILE_NAME = "DownloadFileName";
     static final String EXTRA_DOWNLOAD_FILE_PATH = "DownloadFilePath";
     static final String EXTRA_NOTIFICATION_DISMISSED = "NotificationDismissed";
-    static final String EXTRA_DOWNLOAD_IS_OFF_THE_RECORD = "DownloadIsOffTheRecord";
-    static final String EXTRA_DOWNLOAD_IS_OFFLINE_PAGE = "DownloadIsOfflinePage";
     static final String EXTRA_IS_SUPPORTED_MIME_TYPE = "IsSupportedMimeType";
-    static final String ACTION_DOWNLOAD_CANCEL =
+
+    public static final String ACTION_DOWNLOAD_CANCEL =
             "org.chromium.chrome.browser.download.DOWNLOAD_CANCEL";
-    static final String ACTION_DOWNLOAD_PAUSE =
+    public static final String ACTION_DOWNLOAD_PAUSE =
             "org.chromium.chrome.browser.download.DOWNLOAD_PAUSE";
-    static final String ACTION_DOWNLOAD_RESUME =
+    public static final String ACTION_DOWNLOAD_RESUME =
             "org.chromium.chrome.browser.download.DOWNLOAD_RESUME";
-    public static final String ACTION_DOWNLOAD_RESUME_ALL =
+    static final String ACTION_DOWNLOAD_RESUME_ALL =
             "org.chromium.chrome.browser.download.DOWNLOAD_RESUME_ALL";
     public static final String ACTION_DOWNLOAD_OPEN =
             "org.chromium.chrome.browser.download.DOWNLOAD_OPEN";
-    static final int INVALID_DOWNLOAD_PERCENTAGE = -1;
+
+    public static final int INVALID_DOWNLOAD_PERCENTAGE = -1;
     @VisibleForTesting
     static final String PENDING_DOWNLOAD_NOTIFICATIONS = "PendingDownloadNotifications";
     static final String NOTIFICATION_NAMESPACE = "DownloadNotificationService";
@@ -115,11 +111,11 @@ public class DownloadNotificationService extends Service {
             // activity should be pause the notification.
             if (tasks.size() > 0) return;
         }
-        mStopPostingProgressNotifications = true;
         // This funcion is called when Chrome is swiped away from the recent apps
         // drawer. So it doesn't catch all scenarios that chrome can get killed.
         // This will only help Android 4.4.2.
         onBrowserKilled();
+        mStopPostingProgressNotifications = true;
     }
 
     @Override
@@ -153,13 +149,19 @@ public class DownloadNotificationService extends Service {
         cancelOffTheRecordNotifications();
         pauseAllDownloads();
         if (!mDownloadSharedPreferenceEntries.isEmpty()) {
+            boolean scheduleAutoResumption = false;
             boolean allowMeteredConnection = false;
             for (int i = 0; i < mDownloadSharedPreferenceEntries.size(); ++i) {
-                if (mDownloadSharedPreferenceEntries.get(i).canDownloadWhileMetered) {
-                    allowMeteredConnection = true;
+                DownloadSharedPreferenceEntry entry = mDownloadSharedPreferenceEntries.get(i);
+                if (entry.isAutoResumable) {
+                    scheduleAutoResumption = true;
+                    if (mDownloadSharedPreferenceEntries.get(i).canDownloadWhileMetered) {
+                        allowMeteredConnection = true;
+                        break;
+                    }
                 }
             }
-            if (mNumAutoResumptionAttemptLeft > 0) {
+            if (scheduleAutoResumption && mNumAutoResumptionAttemptLeft > 0) {
                 DownloadResumptionScheduler.getDownloadResumptionScheduler(mContext).schedule(
                         allowMeteredConnection);
             }
@@ -216,7 +218,7 @@ public class DownloadNotificationService extends Service {
     }
 
     /**
-     * Add a in-progress download notification.
+     * Adds or updates an in-progress download notification.
      * @param downloadGuid GUID of the download.
      * @param fileName File name of the download.
      * @param percentage Percentage completed. Value should be between 0 to 100 if
@@ -225,42 +227,83 @@ public class DownloadNotificationService extends Service {
      * @param startTime Time when download started.
      * @param isOffTheRecord Whether the download is off the record.
      * @param canDownloadWhileMetered Whether the download can happen in metered network.
+     * @param isOfflinePage Whether the download is for offline page.
      */
     public void notifyDownloadProgress(String downloadGuid, String fileName, int percentage,
             long timeRemainingInMillis, long startTime, boolean isOffTheRecord,
             boolean canDownloadWhileMetered, boolean isOfflinePage) {
+        updateActiveDownloadNotification(downloadGuid, fileName, percentage, timeRemainingInMillis,
+                startTime, isOffTheRecord, canDownloadWhileMetered, isOfflinePage, false);
+    }
+
+    /**
+     * Adds or updates a pending download notification.
+     * @param downloadGuid GUID of the download.
+     * @param fileName File name of the download.
+     * @param isOffTheRecord Whether the download is off the record.
+     * @param canDownloadWhileMetered Whether the download can happen in metered network.
+     * @param isOfflinePage Whether the download is for offline page.
+     */
+    private void notifyDownloadPending(String downloadGuid, String fileName, boolean isOffTheRecord,
+            boolean canDownloadWhileMetered, boolean isOfflinePage) {
+        updateActiveDownloadNotification(downloadGuid, fileName, INVALID_DOWNLOAD_PERCENTAGE,
+                0, 0, isOffTheRecord, canDownloadWhileMetered, isOfflinePage, true);
+    }
+
+    /**
+     * Helper method to update the notification for an active download, the download is either in
+     * progress or pending.
+     * @param downloadGuid GUID of the download.
+     * @param fileName File name of the download.
+     * @param percentage Percentage completed. Value should be between 0 to 100 if
+     *        the percentage can be determined, or -1 if it is unknown.
+     * @param timeRemainingInMillis Remaining download time in milliseconds.
+     * @param startTime Time when download started.
+     * @param isOffTheRecord Whether the download is off the record.
+     * @param canDownloadWhileMetered Whether the download can happen in metered network.
+     * @param isOfflinePage Whether the download is for offline page.
+     * @param isDownloadPending Whether the download is pending.
+     */
+    private void updateActiveDownloadNotification(String downloadGuid, String fileName,
+            int percentage, long timeRemainingInMillis, long startTime, boolean isOffTheRecord,
+            boolean canDownloadWhileMetered, boolean isOfflinePage, boolean isDownloadPending) {
         if (mStopPostingProgressNotifications) return;
-        boolean indeterminate = percentage == INVALID_DOWNLOAD_PERCENTAGE;
+        String contentText = mContext.getResources().getString(isDownloadPending
+                ? R.string.download_notification_pending : R.string.download_started);
+        int resId = isDownloadPending ? android.R.drawable.stat_sys_download_done
+                : android.R.drawable.stat_sys_download;
         NotificationCompat.Builder builder = buildNotification(
-                android.R.drawable.stat_sys_download, fileName, null);
-        builder.setOngoing(true).setProgress(100, percentage, indeterminate);
+                resId, fileName, contentText);
+        boolean indeterminate = (percentage == INVALID_DOWNLOAD_PERCENTAGE) || isDownloadPending;
+        builder.setOngoing(true);
+        // Avoid moving animations while download is not downloading.
+        if (!isDownloadPending) {
+            builder.setProgress(100, percentage, indeterminate);
+        }
         builder.setPriority(Notification.PRIORITY_HIGH);
-        if (!indeterminate) {
-            NumberFormat formatter = NumberFormat.getPercentInstance(Locale.getDefault());
-            String percentText = formatter.format(percentage / 100.0);
+        if (!indeterminate && !isOfflinePage) {
             String duration = formatRemainingTime(mContext, timeRemainingInMillis);
-            builder.setContentText(duration);
             if (Build.VERSION.CODENAME.equals("N")
                     || Build.VERSION.SDK_INT > Build.VERSION_CODES.M) {
-                builder.setSubText(percentText);
+                builder.setSubText(duration);
             } else {
-                builder.setContentInfo(percentText);
+                builder.setContentInfo(duration);
             }
         }
         int notificationId = getNotificationId(downloadGuid);
         int itemType = isOfflinePage ? DownloadSharedPreferenceEntry.ITEM_TYPE_OFFLINE_PAGE
                                      : DownloadSharedPreferenceEntry.ITEM_TYPE_DOWNLOAD;
         addOrReplaceSharedPreferenceEntry(new DownloadSharedPreferenceEntry(notificationId,
-                isOffTheRecord, canDownloadWhileMetered, downloadGuid, fileName, itemType));
+                isOffTheRecord, canDownloadWhileMetered, downloadGuid, fileName, itemType, true));
         if (startTime > 0) builder.setWhen(startTime);
         Intent cancelIntent = buildActionIntent(
-                ACTION_DOWNLOAD_CANCEL, notificationId, downloadGuid, fileName, isOfflinePage);
+                mContext, ACTION_DOWNLOAD_CANCEL, downloadGuid, fileName, isOfflinePage);
         builder.addAction(R.drawable.btn_close_white,
                 mContext.getResources().getString(R.string.download_notification_cancel_button),
                 buildPendingIntent(cancelIntent, notificationId));
         Intent pauseIntent = buildActionIntent(
-                ACTION_DOWNLOAD_PAUSE, notificationId, downloadGuid, fileName, isOfflinePage);
-        builder.addAction(R.drawable.ic_vidcontrol_pause,
+                mContext, ACTION_DOWNLOAD_PAUSE, downloadGuid, fileName, isOfflinePage);
+        builder.addAction(R.drawable.ic_media_control_pause,
                 mContext.getResources().getString(R.string.download_notification_pause_button),
                 buildPendingIntent(pauseIntent, notificationId));
         updateNotification(notificationId, builder.build());
@@ -271,12 +314,12 @@ public class DownloadNotificationService extends Service {
 
     /**
      * Cancel a download notification.
-     * @notificationId Notification ID of the download
+     * @param notificationId Notification ID of the download
      * @param downloadGuid GUID of the download.
      */
     @VisibleForTesting
-    void cancelNotification(int notificaitonId, String downloadGuid) {
-        mNotificationManager.cancel(NOTIFICATION_NAMESPACE, notificaitonId);
+    void cancelNotification(int notificationId, String downloadGuid) {
+        mNotificationManager.cancel(NOTIFICATION_NAMESPACE, notificationId);
         removeSharedPreferenceEntry(downloadGuid);
         mDownloadsInProgress.remove(downloadGuid);
     }
@@ -305,32 +348,37 @@ public class DownloadNotificationService extends Service {
             notifyDownloadFailed(downloadGuid, entry.fileName);
             return;
         }
+        // If download is already paused, do nothing.
+        if (!entry.isAutoResumable) return;
+        // If download is interrupted due to network disconnection, show download pending state.
+        if (isAutoResumable) {
+            notifyDownloadPending(entry.downloadGuid, entry.fileName, entry.isOffTheRecord,
+                    entry.canDownloadWhileMetered, entry.isOfflinePage());
+            mDownloadsInProgress.remove(downloadGuid);
+            return;
+        }
+        String contentText = mContext.getResources().getString(
+                R.string.download_notification_paused);
         NotificationCompat.Builder builder = buildNotification(
-                android.R.drawable.ic_media_pause, entry.fileName,
-                mContext.getResources().getString(R.string.download_notification_paused));
-        Intent cancelIntent = buildActionIntent(
-                ACTION_DOWNLOAD_CANCEL, entry.notificationId, entry.downloadGuid, entry.fileName,
-                entry.isOfflinePage());
+                android.R.drawable.ic_media_pause, entry.fileName, contentText);
+        Intent cancelIntent = buildActionIntent(mContext, ACTION_DOWNLOAD_CANCEL,
+                entry.downloadGuid, entry.fileName, entry.isOfflinePage());
         Intent dismissIntent = new Intent(cancelIntent);
         dismissIntent.putExtra(EXTRA_NOTIFICATION_DISMISSED, true);
         builder.setDeleteIntent(buildPendingIntent(dismissIntent, entry.notificationId));
         builder.addAction(R.drawable.btn_close_white,
                 mContext.getResources().getString(R.string.download_notification_cancel_button),
                 buildPendingIntent(cancelIntent, entry.notificationId));
-        Intent resumeIntent = buildActionIntent(
-                ACTION_DOWNLOAD_RESUME, entry.notificationId, entry.downloadGuid, entry.fileName,
-                entry.isOfflinePage());
-        resumeIntent.putExtra(EXTRA_DOWNLOAD_IS_OFF_THE_RECORD, entry.isOffTheRecord);
+        Intent resumeIntent = buildActionIntent(mContext, ACTION_DOWNLOAD_RESUME,
+                entry.downloadGuid, entry.fileName, entry.isOfflinePage());
         builder.addAction(R.drawable.ic_get_app_white_24dp,
                 mContext.getResources().getString(R.string.download_notification_resume_button),
                 buildPendingIntent(resumeIntent, entry.notificationId));
         updateNotification(entry.notificationId, builder.build());
-        // If download is not auto resumable, there is no need to keep it in SharedPreferences.
-        // Keep off the record downloads in SharedPreferences so we can cancel it when browser is
-        // killed.
-        if (!isAutoResumable && !entry.isOffTheRecord) {
-            removeSharedPreferenceEntry(downloadGuid);
-        }
+        // Update the SharedPreference entry with the new isAutoResumable value.
+        addOrReplaceSharedPreferenceEntry(new DownloadSharedPreferenceEntry(entry.notificationId,
+                entry.isOffTheRecord, entry.canDownloadWhileMetered, entry.downloadGuid,
+                entry.fileName, entry.itemType, isAutoResumable));
         mDownloadsInProgress.remove(downloadGuid);
     }
 
@@ -356,8 +404,8 @@ public class DownloadNotificationService extends Service {
                 mContext.getPackageName(), DownloadBroadcastReceiver.class.getName());
         Intent intent;
         if (isOfflinePage) {
-            intent = buildActionIntent(ACTION_DOWNLOAD_OPEN, notificationId, downloadGuid, fileName,
-                    isOfflinePage);
+            intent = buildActionIntent(
+                    mContext, ACTION_DOWNLOAD_OPEN, downloadGuid, fileName, isOfflinePage);
         } else {
             intent = new Intent(DownloadManager.ACTION_NOTIFICATION_CLICKED);
             long[] idArray = {systemDownloadId};
@@ -438,23 +486,19 @@ public class DownloadNotificationService extends Service {
 
     /**
      * Helper method to build an download action Intent from the provided information.
+     * @param context {@link Context} to pull resources from.
      * @param action Download action to perform.
-     * @param notificationId ID of the notification.
      * @param downloadGuid GUID of the download.
      * @param fileName Name of the download file.
      * @param isOfflinePage Whether the intent is for offline page download.
      */
-    private Intent buildActionIntent(
-            String action, int notificationId, String downloadGuid, String fileName,
-            boolean isOfflinePage) {
+    static Intent buildActionIntent(Context context, String action, String downloadGuid,
+            String fileName, boolean isOfflinePage) {
         ComponentName component = new ComponentName(
-                mContext.getPackageName(), DownloadBroadcastReceiver.class.getName());
+                context.getPackageName(), DownloadBroadcastReceiver.class.getName());
         Intent intent = new Intent(action);
         intent.setComponent(component);
-        intent.putExtra(EXTRA_DOWNLOAD_NOTIFICATION_ID, notificationId);
         intent.putExtra(EXTRA_DOWNLOAD_GUID, downloadGuid);
-        intent.putExtra(EXTRA_DOWNLOAD_FILE_NAME, fileName);
-        intent.putExtra(EXTRA_DOWNLOAD_IS_OFFLINE_PAGE, isOfflinePage);
         return intent;
     }
 
@@ -503,25 +547,13 @@ public class DownloadNotificationService extends Service {
     }
 
     /**
-     * Retrives DownloadSharedPreferenceEntry from a download action intent.
+     * Retrieves DownloadSharedPreferenceEntry from a download action intent.
      * @param intent Intent that contains the download action.
      */
     private DownloadSharedPreferenceEntry getDownloadEntryFromIntent(Intent intent) {
         if (intent.getAction() == ACTION_DOWNLOAD_RESUME_ALL) return null;
         String guid = IntentUtils.safeGetStringExtra(intent, EXTRA_DOWNLOAD_GUID);
-        DownloadSharedPreferenceEntry entry = getDownloadSharedPreferenceEntry(guid);
-        if (entry != null) return entry;
-        int notificationId = IntentUtils.safeGetIntExtra(
-                intent, EXTRA_DOWNLOAD_NOTIFICATION_ID, -1);
-        String fileName = IntentUtils.safeGetStringExtra(intent, EXTRA_DOWNLOAD_FILE_NAME);
-        boolean metered = DownloadManagerService.isActiveNetworkMetered(mContext);
-        boolean isOffTheRecord =  IntentUtils.safeGetBooleanExtra(
-                intent, EXTRA_DOWNLOAD_IS_OFF_THE_RECORD, false);
-        boolean isOfflinePage =  IntentUtils.safeGetBooleanExtra(
-                intent, EXTRA_DOWNLOAD_IS_OFFLINE_PAGE, false);
-        return new DownloadSharedPreferenceEntry(notificationId, isOffTheRecord, metered, guid,
-                fileName, isOfflinePage ? DownloadSharedPreferenceEntry.ITEM_TYPE_OFFLINE_PAGE
-                        : DownloadSharedPreferenceEntry.ITEM_TYPE_DOWNLOAD);
+        return getDownloadSharedPreferenceEntry(guid);
     }
 
     /**
@@ -531,6 +563,7 @@ public class DownloadNotificationService extends Service {
      */
     private void handleDownloadOperation(final Intent intent) {
         final DownloadSharedPreferenceEntry entry = getDownloadEntryFromIntent(intent);
+        if (entry == null) return;
         if (intent.getAction() == ACTION_DOWNLOAD_PAUSE) {
             // If browser process already goes away, the download should have already paused. Do
             // nothing in that case.
@@ -545,6 +578,7 @@ public class DownloadNotificationService extends Service {
                 // is not metered previously.
                 entry.canDownloadWhileMetered = metered;
             }
+            entry.isAutoResumable = true;
             // Update the SharedPreference entry.
             addOrReplaceSharedPreferenceEntry(entry);
         } else if (intent.getAction() == ACTION_DOWNLOAD_RESUME_ALL
@@ -585,9 +619,9 @@ public class DownloadNotificationService extends Service {
                                 entry.isOffTheRecord);
                         break;
                     case ACTION_DOWNLOAD_RESUME:
-                        notifyDownloadProgress(entry.downloadGuid, entry.fileName,
-                                INVALID_DOWNLOAD_PERCENTAGE, 0, 0, entry.isOffTheRecord,
-                                entry.canDownloadWhileMetered, entry.isOfflinePage());
+                        notifyDownloadPending(entry.downloadGuid, entry.fileName,
+                                entry.isOffTheRecord, entry.canDownloadWhileMetered,
+                                entry.isOfflinePage());
                         downloadServiceDelegate.resumeDownload(entry.buildDownloadItem(), true);
                         break;
                     case ACTION_DOWNLOAD_RESUME_ALL:
@@ -656,16 +690,7 @@ public class DownloadNotificationService extends Service {
                 && !ACTION_DOWNLOAD_OPEN.equals(intent.getAction())) {
             return false;
         }
-        if (!intent.hasExtra(EXTRA_DOWNLOAD_NOTIFICATION_ID)
-                || !intent.hasExtra(EXTRA_DOWNLOAD_FILE_NAME)
-                || !intent.hasExtra(EXTRA_DOWNLOAD_GUID)) {
-            return false;
-        }
-        final int notificationId =
-                IntentUtils.safeGetIntExtra(intent, EXTRA_DOWNLOAD_NOTIFICATION_ID, -1);
-        if (notificationId == -1) return false;
-        final String fileName = IntentUtils.safeGetStringExtra(intent, EXTRA_DOWNLOAD_FILE_NAME);
-        if (fileName == null) return false;
+        if (!intent.hasExtra(EXTRA_DOWNLOAD_GUID)) return false;
         final String guid = IntentUtils.safeGetStringExtra(intent, EXTRA_DOWNLOAD_GUID);
         if (!DownloadSharedPreferenceEntry.isValidGUID(guid)) return false;
         return true;
@@ -674,7 +699,7 @@ public class DownloadNotificationService extends Service {
     /**
      * Adds a DownloadSharedPreferenceEntry to SharedPrefs. If an entry with the GUID already exists
      * in SharedPrefs, update it if it has changed.
-     * @param DownloadSharedPreferenceEntry A DownloadSharedPreferenceEntry to be added.
+     * @param pendingEntry A DownloadSharedPreferenceEntry to be added.
      */
     private void addOrReplaceSharedPreferenceEntry(DownloadSharedPreferenceEntry pendingEntry) {
         Iterator<DownloadSharedPreferenceEntry> iterator =
@@ -721,10 +746,11 @@ public class DownloadNotificationService extends Service {
         if (!DownloadManagerService.hasDownloadManagerService()) return;
         for (int i = 0; i < mDownloadSharedPreferenceEntries.size(); ++i) {
             DownloadSharedPreferenceEntry entry = mDownloadSharedPreferenceEntries.get(i);
+            if (!entry.isAutoResumable) continue;
             if (mDownloadsInProgress.contains(entry.downloadGuid)) continue;
             if (!entry.canDownloadWhileMetered && isNetworkMetered) continue;
-            notifyDownloadProgress(entry.downloadGuid, entry.fileName, INVALID_DOWNLOAD_PERCENTAGE,
-                    0, 0, false, entry.canDownloadWhileMetered, entry.isOfflinePage());
+            notifyDownloadPending(entry.downloadGuid, entry.fileName, false,
+                    entry.canDownloadWhileMetered, entry.isOfflinePage());
             DownloadServiceDelegate downloadServiceDelegate = getServiceDelegate(entry.itemType);
             downloadServiceDelegate.resumeDownload(entry.buildDownloadItem(), false);
             downloadServiceDelegate.destroyServiceDelegate();
