@@ -11,7 +11,9 @@ import android.text.TextUtils;
 import org.chromium.base.ContextUtils;
 import org.chromium.base.metrics.RecordHistogram;
 import org.chromium.chrome.R;
+import org.chromium.chrome.browser.download.DownloadInfo;
 import org.chromium.chrome.browser.download.DownloadItem;
+import org.chromium.chrome.browser.download.DownloadNotificationService;
 import org.chromium.chrome.browser.download.DownloadUtils;
 import org.chromium.chrome.browser.offlinepages.downloads.OfflinePageDownloadItem;
 import org.chromium.chrome.browser.widget.DateDividedAdapter.TimedItem;
@@ -66,7 +68,9 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
 
     protected final BackendProvider mBackendProvider;
     protected final ComponentName mComponentName;
+    protected File mFile;
     private Long mStableId;
+    private boolean mIsDeletionPending;
 
     private DownloadHistoryItemWrapper(BackendProvider provider, ComponentName component) {
         mBackendProvider = provider;
@@ -83,9 +87,31 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
         return mStableId;
     }
 
+    /** @return Whether the file will soon be deleted. */
+    final boolean isDeletionPending() {
+        return mIsDeletionPending;
+    }
+
+    /** Track whether or not the file will soon be deleted. */
+    final void setIsDeletionPending(boolean state) {
+        mIsDeletionPending = state;
+    }
+
+    /** @return Whether this download should be shown to the user. */
+    boolean isVisibleToUser(int filter) {
+        if (isDeletionPending()) return false;
+        return filter == getFilterType() || filter == DownloadFilter.FILTER_ALL;
+    }
+
     /** @return Item that is being wrapped. */
     abstract Object getItem();
 
+    /**
+     * Replaces the item being wrapped with a new one.
+     * @return Whether or not the user needs to be informed of changes to the data.
+     */
+    abstract boolean replaceItem(Object item);
+
     /** @return ID representing the download. */
     abstract String getId();
 
@@ -93,7 +119,10 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
     abstract String getFilePath();
 
     /** @return The file where the download resides. */
-    public abstract File getFile();
+    public final File getFile() {
+        if (mFile == null) mFile = new File(getFilePath());
+        return mFile;
+    }
 
     /** @return String to display for the file. */
     abstract String getDisplayFileName();
@@ -114,32 +143,46 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
     public abstract int getFileExtensionType();
 
     /** @return How much of the download has completed, or -1 if there is no progress. */
-    public abstract int getDownloadProgress();
+    abstract int getDownloadProgress();
 
-    /** @return Whether or not the file is completely downloaded. */
-    public abstract boolean isComplete();
+    /** @return ID of the String indicating the status of the download. */
+    abstract int getStatusString();
+
+    /** @return Whether the file for this item has been removed through an external action. */
+    abstract boolean hasBeenExternallyRemoved();
+
+    /** @return Whether this download is associated with the off the record profile. */
+    abstract boolean isOffTheRecord();
+
+    /** @return Whether the item has been completely downloaded. */
+    abstract boolean isComplete();
+
+    /** @return Whether the download is currently paused. */
+    abstract boolean isPaused();
+
+    /** @return Whether the download can be resumed. */
+    abstract boolean isResumable();
 
     /** Called when the user wants to open the file. */
     abstract void open();
 
+    /** Called when the user tries to cancel downloading the file. */
+    abstract void cancel();
+
+    /** Called when the user tries to pause downloading the file. */
+    abstract void pause();
+
+    /** Called when the user tries to resume downloading the file. */
+    abstract void resume();
+
     /**
-     * Called when the user wants to remove the download from the backend. May also delete the file
-     * associated with the download item.
+     * Called when the user wants to remove the download from the backend.
+     * May also delete the file associated with the download item.
+     *
      * @return Whether the file associated with the download item was deleted.
      */
     abstract boolean remove();
 
-    /**
-     * @return Whether the file associated with this item has been removed through an external
-     *         action.
-     */
-    abstract boolean hasBeenExternallyRemoved();
-
-    /**
-     * @return Whether this download is associated with the off the record profile.
-     */
-    abstract boolean isOffTheRecord();
-
     protected void recordOpenSuccess() {
         RecordHistogram.recordEnumeratedHistogram("Android.DownloadManager.Item.OpenSucceeded",
                 getFilterType(), DownloadFilter.FILTER_BOUNDARY);
@@ -164,8 +207,7 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
 
     /** Wraps a {@link DownloadItem}. */
     public static class DownloadItemWrapper extends DownloadHistoryItemWrapper {
-        private final DownloadItem mItem;
-        private File mFile;
+        private DownloadItem mItem;
         private Integer mFileExtensionType;
 
         DownloadItemWrapper(DownloadItem item, BackendProvider provider, ComponentName component) {
@@ -178,6 +220,18 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
             return mItem;
         }
 
+        @Override
+        public boolean replaceItem(Object item) {
+            assert item instanceof DownloadItem;
+            DownloadItem downloadItem = (DownloadItem) item;
+            assert TextUtils.equals(mItem.getId(), downloadItem.getId());
+
+            boolean visuallyChanged = isNewItemVisiblyDifferent(downloadItem);
+            mItem = downloadItem;
+            mFile = null;
+            return visuallyChanged;
+        }
+
         @Override
         public String getId() {
             return mItem.getId();
@@ -193,12 +247,6 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
             return mItem.getDownloadInfo().getFilePath();
         }
 
-        @Override
-        public File getFile() {
-            if (mFile == null) mFile = new File(getFilePath());
-            return mFile;
-        }
-
         @Override
         public String getDisplayFileName() {
             return mItem.getDownloadInfo().getFileName();
@@ -255,6 +303,23 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
             return mItem.getDownloadInfo().getPercentCompleted();
         }
 
+        @Override
+        public int getStatusString() {
+            int state = mItem.getDownloadInfo().state();
+            if (mItem.getDownloadInfo().isPaused()) {
+                // TODO(dfalcantara): Account for paused downloads after restarting Chrome.
+                return R.string.download_notification_paused;
+            } else if (state == DownloadState.INTERRUPTED) {
+                return R.string.download_notification_pending;
+            } else if (state == DownloadState.COMPLETE) {
+                return R.string.download_notification_completed;
+            } else if (state == DownloadState.IN_PROGRESS) {
+                return R.string.download_started;
+            } else {
+                return 0;
+            }
+        }
+
         @Override
         public void open() {
             Context context = ContextUtils.getApplicationContext();
@@ -272,6 +337,24 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
             }
         }
 
+        @Override
+        public void cancel() {
+            mBackendProvider.getDownloadDelegate().broadcastDownloadAction(
+                    mItem, DownloadNotificationService.ACTION_DOWNLOAD_CANCEL);
+        }
+
+        @Override
+        public void pause() {
+            mBackendProvider.getDownloadDelegate().broadcastDownloadAction(
+                    mItem, DownloadNotificationService.ACTION_DOWNLOAD_PAUSE);
+        }
+
+        @Override
+        public void resume() {
+            mBackendProvider.getDownloadDelegate().broadcastDownloadAction(
+                    mItem, DownloadNotificationService.ACTION_DOWNLOAD_RESUME);
+        }
+
         @Override
         public boolean remove() {
             // Tell the DownloadManager to remove the file from history.
@@ -293,12 +376,49 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
         public boolean isComplete() {
             return mItem.getDownloadInfo().state() == DownloadState.COMPLETE;
         }
+
+        @Override
+        public boolean isPaused() {
+            return mItem.getDownloadInfo().isPaused();
+        }
+
+        @Override
+        public boolean isResumable() {
+            return mItem.getDownloadInfo().isResumable();
+        }
+
+        @Override
+        boolean isVisibleToUser(int filter) {
+            if (!super.isVisibleToUser(filter)) return false;
+
+            if (TextUtils.isEmpty(getFilePath()) || TextUtils.isEmpty(getDisplayFileName())) {
+                return false;
+            }
+
+            if (mItem.getDownloadInfo().state() == DownloadState.CANCELLED) {
+                return false;
+            }
+
+            return true;
+        }
+
+        /** @return whether the given DownloadItem is visibly different from the current one. */
+        private boolean isNewItemVisiblyDifferent(DownloadItem newItem) {
+            DownloadInfo oldInfo = mItem.getDownloadInfo();
+            DownloadInfo newInfo = newItem.getDownloadInfo();
+
+            if (oldInfo.getPercentCompleted() != newInfo.getPercentCompleted()) return true;
+            if (oldInfo.state() != newInfo.state()) return true;
+            if (oldInfo.isPaused() != newInfo.isPaused()) return true;
+            if (!TextUtils.equals(oldInfo.getFilePath(), newInfo.getFilePath())) return true;
+
+            return false;
+        }
     }
 
     /** Wraps a {@link OfflinePageDownloadItem}. */
     public static class OfflinePageItemWrapper extends DownloadHistoryItemWrapper {
-        private final OfflinePageDownloadItem mItem;
-        private File mFile;
+        private OfflinePageDownloadItem mItem;
 
         OfflinePageItemWrapper(OfflinePageDownloadItem item, BackendProvider provider,
                 ComponentName component) {
@@ -311,6 +431,17 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
             return mItem;
         }
 
+        @Override
+        public boolean replaceItem(Object item) {
+            assert item instanceof OfflinePageDownloadItem;
+            OfflinePageDownloadItem newItem = (OfflinePageDownloadItem) item;
+            assert TextUtils.equals(newItem.getGuid(), mItem.getGuid());
+
+            mItem = newItem;
+            mFile = null;
+            return true;
+        }
+
         @Override
         public String getId() {
             return mItem.getGuid();
@@ -326,12 +457,6 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
             return mItem.getTargetPath();
         }
 
-        @Override
-        public File getFile() {
-            if (mFile == null) mFile = new File(getFilePath());
-            return mFile;
-        }
-
         @Override
         public String getDisplayFileName() {
             String title = mItem.getTitle();
@@ -373,12 +498,32 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
             return -1;
         }
 
+        @Override
+        public int getStatusString() {
+            return R.string.download_notification_completed;
+        }
+
         @Override
         public void open() {
             mBackendProvider.getOfflinePageBridge().openItem(getId(), mComponentName);
             recordOpenSuccess();
         }
 
+        @Override
+        public void cancel() {
+            assert false;
+        }
+
+        @Override
+        public void pause() {
+            assert false;
+        }
+
+        @Override
+        public void resume() {
+            assert false;
+        }
+
         @Override
         public boolean remove() {
             mBackendProvider.getOfflinePageBridge().deleteItem(getId());
@@ -398,8 +543,17 @@ public abstract class DownloadHistoryItemWrapper extends TimedItem {
 
         @Override
         public boolean isComplete() {
-            // Incomplete offline pages aren't shown yet.
             return true;
         }
+
+        @Override
+        public boolean isPaused() {
+            return false;
+        }
+
+        @Override
+        public boolean isResumable() {
+            return false;
+        }
     }
 }
