@@ -127,13 +127,6 @@ public abstract class UserRecoverableErrorHandler {
          */
         private final Activity mActivity;
 
-        private Dialog mDialog;
-
-        /**
-         * Last error code from Google Play Services.
-         */
-        private int mErrorCode;
-
         /**
          * Create a new Modal Dialog handler for the specified activity and error code. The
          * specified activity may be used to launch the dialog via
@@ -148,34 +141,19 @@ public abstract class UserRecoverableErrorHandler {
 
         /**
          * Displays the dialog in a modal manner using
-         * {@link GoogleApiAvailability#getErrorDialog(Activity, int, int)}.
+         * {@link GoogleApiAvailability#showErrorDialog(int, Activity, int)}.
          * @param context the context in which the error was encountered
          * @param errorCode the error code from Google Play Services
          */
         @Override
         protected final void handle(final Context context, final int errorCode) {
-            // Assume old dialogs generated by the same error handler are obsolete when an error
-            // with a different error code is encountered.
-            if (mErrorCode != errorCode) {
-                cancelDialog();
-            }
-            if (mDialog == null) {
-                mDialog = GoogleApiAvailability.getInstance().getErrorDialog(
-                        mActivity, errorCode, NO_RESPONSE_REQUIRED);
-                mErrorCode = errorCode;
-            }
-            // This can happen if |errorCode| is ConnectionResult.SERVICE_INVALID.
-            if (mDialog != null) {
-                mDialog.show();
+            final Dialog dialog = GoogleApiAvailability.getInstance().getErrorDialog(
+                    mActivity, errorCode, NO_RESPONSE_REQUIRED);
+            if (dialog != null) {
+                // This can happen if |errorCode| is ConnectionResult.SERVICE_INVALID.
+                dialog.show();
             }
             sErrorHandlerActionHistogramSample.record(ERROR_HANDLER_ACTION_MODAL_DIALOG);
         }
-
-        public void cancelDialog() {
-            if (mDialog != null) {
-                mDialog.cancel();
-                mDialog = null;
-            }
-        }
     }
 }
