@@ -133,6 +133,7 @@ public class ExternalNavigationHandler {
     }
 
     private boolean resolversSubsetOf(List<ResolveInfo> infos, List<ResolveInfo> container) {
+        if (container == null) return false;
         HashSet<ComponentName> containerSet = new HashSet<>();
         for (ResolveInfo info : container) {
             containerSet.add(
@@ -160,11 +161,6 @@ public class ExternalNavigationHandler {
             return OverrideUrlLoadingResult.NO_OVERRIDE;
         }
 
-        // http://crbug.com/605302 : Allow Chrome to handle all pdf file downloads.
-        if (mDelegate.isPdfDownload(params.getUrl())) {
-            return OverrideUrlLoadingResult.NO_OVERRIDE;
-        }
-
         // pageTransition is a combination of an enumeration (core value) and bitmask.
         int pageTransitionCore = params.getPageTransition() & PageTransition.CORE_MASK;
         boolean isLink = pageTransitionCore == PageTransition.LINK;
@@ -195,6 +191,11 @@ public class ExternalNavigationHandler {
             return OverrideUrlLoadingResult.NO_OVERRIDE;
         }
 
+        // http://crbug.com/605302 : Allow Chrome to handle all pdf file downloads.
+        if (!isExternalProtocol && mDelegate.isPdfDownload(params.getUrl())) {
+            return OverrideUrlLoadingResult.NO_OVERRIDE;
+        }
+
         // If accessing a file URL, ensure that the user has granted the necessary file access
         // to Chrome.  This check should happen for reloads, navigations, etc..., which is why
         // it occurs before the subsequent blocks.
@@ -320,6 +321,8 @@ public class ExternalNavigationHandler {
         }
 
         List<ResolveInfo> resolvingInfos = mDelegate.queryIntentActivities(intent);
+        if (resolvingInfos == null) return OverrideUrlLoadingResult.NO_OVERRIDE;
+
         boolean canResolveActivity = resolvingInfos.size() > 0;
         // check whether the intent can be resolved. If not, we will see
         // whether we can download it from the Market.
@@ -444,7 +447,7 @@ public class ExternalNavigationHandler {
 
                     if (previousIntent != null
                             && resolversSubsetOf(resolvingInfos,
-                                       mDelegate.queryIntentActivities(previousIntent))) {
+                                    mDelegate.queryIntentActivities(previousIntent))) {
                         return OverrideUrlLoadingResult.NO_OVERRIDE;
                     }
                 }
@@ -454,7 +457,7 @@ public class ExternalNavigationHandler {
         boolean isDirectInstantAppsIntent = isExternalProtocol
                 && SUPERVISOR_PKG.equals(intent.getPackage());
         boolean shouldProxyForInstantApps = isDirectInstantAppsIntent
-                && mDelegate.isSerpReferrer(params.getReferrerUrl(), params.getTab());
+                && mDelegate.isSerpReferrer(params.getTab());
         if (shouldProxyForInstantApps) {
             intent.putExtra(InstantAppsHandler.IS_GOOGLE_SEARCH_REFERRER, true);
         } else if (isDirectInstantAppsIntent) {
@@ -564,8 +567,10 @@ public class ExternalNavigationHandler {
         if (url.startsWith(SCHEME_WTAI_MC)) return true;
         try {
             Intent intent = Intent.parseUri(url, Intent.URI_INTENT_SCHEME);
-            return intent.getPackage() != null
-                    || mDelegate.queryIntentActivities(intent).size() > 0;
+            if (intent.getPackage() != null) return true;
+
+            List<ResolveInfo> resolvingInfos = mDelegate.queryIntentActivities(intent);
+            if (resolvingInfos != null && resolvingInfos.size() > 0) return true;
         } catch (Exception ex) {
             // Ignore the error.
             Log.w(TAG, "Bad URI %s", url, ex);
