@@ -178,7 +178,7 @@ public class FullscreenHtmlApiHandler {
     }
 
     /**
-     * Enters or exits persistent fullscreen mode.  In this mode, the top controls will be
+     * Enters or exits persistent fullscreen mode.  In this mode, the browser controls will be
      * permanently hidden until this mode is exited.
      *
      * @param enabled Whether to enable persistent fullscreen mode.
@@ -297,6 +297,10 @@ public class FullscreenHtmlApiHandler {
         };
         contentView.addOnLayoutChangeListener(mFullscreenOnLayoutChangeListener);
         contentView.setSystemUiVisibility(systemUiVisibility);
+
+        // Request a layout so the updated system visibility takes affect.
+        contentView.getRootView().requestLayout();
+
         mContentViewCoreInFullscreen = contentViewCore;
         mTabInFullscreen = tab;
     }
