@@ -111,7 +111,8 @@ public class DataReductionPromoInfoBar extends ConfirmInfoBar {
             }
 
             DataReductionPromoInfoBar.launch(webContents,
-                    BitmapFactory.decodeResource(context.getResources(), R.mipmap.app_icon),
+                    BitmapFactory.decodeResource(context.getResources(),
+                            R.drawable.infobar_chrome),
                     context.getString(R.string.data_reduction_promo_infobar_title),
                     context.getString(R.string.data_reduction_promo_infobar_text),
                     context.getString(R.string.data_reduction_promo_infobar_button),
