@@ -5,12 +5,14 @@
 package org.chromium.chrome.browser.mojo;
 
 import org.chromium.base.annotations.CalledByNative;
+import org.chromium.blink.mojom.BarcodeDetection;
 import org.chromium.chrome.browser.payments.PaymentRequestFactory;
+import org.chromium.chrome.browser.shapedetection.BarcodeDetectionFactory;
 import org.chromium.chrome.browser.webshare.ShareServiceImplementationFactory;
 import org.chromium.content_public.browser.InterfaceRegistrar;
 import org.chromium.content_public.browser.WebContents;
 import org.chromium.payments.mojom.PaymentRequest;
-import org.chromium.services.shell.InterfaceRegistry;
+import org.chromium.services.service_manager.InterfaceRegistry;
 import org.chromium.webshare.mojom.ShareService;
 
 /** Registers mojo interface implementations exposed to C++ code at the Chrome layer. */
@@ -28,5 +30,7 @@ class ChromeWebContentsInterfaceRegistrar implements InterfaceRegistrar<WebConte
         registry.addInterface(PaymentRequest.MANAGER, new PaymentRequestFactory(webContents));
         registry.addInterface(
                 ShareService.MANAGER, new ShareServiceImplementationFactory(webContents));
+        registry.addInterface(
+                BarcodeDetection.MANAGER, new BarcodeDetectionFactory(webContents));
     }
 }
