@@ -168,7 +168,7 @@ public class NewTabPage
     /**
      * Object that registered through the {@link NewTabPageManager}, and that will be notified when
      * the {@link NewTabPage} is destroyed.
-     * @see NewTabPageManager#setDestructionObserver(DestructionObserver)
+     * @see NewTabPageManager#addDestructionObserver(DestructionObserver)
      */
     public interface DestructionObserver { void onDestroy(); }
 
@@ -356,12 +356,12 @@ public class NewTabPage
             mSnippetsBridge.onSuggestionOpened(article, windowOpenDisposition);
             NewTabPageUma.recordAction(NewTabPageUma.ACTION_OPENED_SNIPPET);
 
-            if (article.mIsDownloadedAsset) {
+            if (article.mIsAssetDownload) {
                 assert windowOpenDisposition == WindowOpenDisposition.CURRENT_TAB
                         || windowOpenDisposition == WindowOpenDisposition.NEW_WINDOW
                         || windowOpenDisposition == WindowOpenDisposition.NEW_FOREGROUND_TAB;
                 DownloadUtils.openFile(
-                        article.getDownloadAssetFile(), article.getDownloadAssetMimeType(), false);
+                        article.getAssetDownloadFile(), article.getAssetDownloadMimeType(), false);
                 return;
             }
 
@@ -382,7 +382,7 @@ public class NewTabPage
             // We explicitly open an offline page only for offline page downloads. For all other
             // sections the URL is opened and it is up to Offline Pages whether to open its offline
             // page (e.g. when offline).
-            if (article.isDownload() && !article.mIsDownloadedAsset) {
+            if (article.isDownload() && !article.mIsAssetDownload) {
                 assert article.getOfflinePageOfflineId() != null;
                 assert windowOpenDisposition == WindowOpenDisposition.CURRENT_TAB
                         || windowOpenDisposition == WindowOpenDisposition.NEW_WINDOW
@@ -637,13 +637,15 @@ public class NewTabPage
 
             int tileTypes[] = new int[items.length];
             int sources[] = new int[items.length];
+            String tileUrls[] = new String[items.length];
 
             for (int i = 0; i < items.length; i++) {
                 tileTypes[i] = items[i].getTileType();
                 sources[i] = items[i].getSource();
+                tileUrls[i] = items[i].getUrl();
             }
 
-            mMostVisitedSites.recordTileTypeMetrics(tileTypes, sources);
+            mMostVisitedSites.recordPageImpression(tileTypes, sources, tileUrls);
 
             if (isNtpOfflinePagesEnabled()) {
                 final int maxNumTiles = 12;
@@ -749,7 +751,7 @@ public class NewTabPage
 
         LayoutInflater inflater = LayoutInflater.from(activity);
         mNewTabPageView = (NewTabPageView) inflater.inflate(R.layout.new_tab_page_view, null);
-        mNewTabPageView.initialize(mNewTabPageManager, mActivity, mSearchProviderHasLogo,
+        mNewTabPageView.initialize(mNewTabPageManager, mTab, mSearchProviderHasLogo,
                 getScrollPositionFromNavigationEntry());
 
         DownloadManagerService.getDownloadManagerService(ContextUtils.getApplicationContext())
@@ -757,6 +759,7 @@ public class NewTabPage
 
         RecordHistogram.recordBooleanHistogram(
                 "NewTabPage.MobileIsUserOnline", NetworkChangeNotifier.isOnline());
+        NewTabPageUma.recordLoadType(mActivity);
     }
 
     private static MostVisitedSites buildMostVisitedSites(Profile profile) {
