@@ -69,7 +69,7 @@ class ActionItem extends OptionalLeaf {
     }
 
     @VisibleForTesting
-    void performAction(NewTabPageManager manager, NewTabPageAdapter adapter) {
+    void performAction(NewTabPageManager manager) {
         manager.trackSnippetCategoryActionClick(mCategoryInfo.getCategory(), getPosition());
 
         switch (mCurrentAction) {
@@ -77,13 +77,10 @@ class ActionItem extends OptionalLeaf {
                 mCategoryInfo.performViewAllAction(manager);
                 return;
             case ACTION_FETCH_MORE:
+            case ACTION_RELOAD:
                 manager.getSuggestionsSource().fetchSuggestions(
                         mCategoryInfo.getCategory(), mParentSection.getDisplayedSuggestionIds());
-                mParentSection.onFetchMore();
-                return;
-            case ACTION_RELOAD:
-                // TODO(dgn): reload only the current section. https://crbug.com/634892
-                adapter.reloadSnippets();
+                mParentSection.onFetchStarted();
                 return;
             case ACTION_NONE:
             default:
@@ -112,8 +109,7 @@ class ActionItem extends OptionalLeaf {
                     .setOnClickListener(new View.OnClickListener() {
                         @Override
                         public void onClick(View v) {
-                            mActionListItem.performAction(
-                                    manager, recyclerView.getNewTabPageAdapter());
+                            mActionListItem.performAction(manager);
                         }
                     });
 
