@@ -19,11 +19,16 @@ public final class CardsVariationParameters {
     // Also defined in ntp_snippets_constants.cc
     private static final String FIELD_TRIAL_NAME = "NTPSnippets";
 
-    private static final String PARAM_FIRST_CARD_OFFSET = "first_card_offset";
     private static final String PARAM_FAVICON_SERVICE_NAME = "favicons_fetch_from_service";
-    private static final String PARAM_DISABLED_VALUE = "off";
+    private static final String PARAM_FIRST_CARD_OFFSET = "first_card_offset";
+    private static final String PARAM_FIRST_CARD_ANIMATION_MAX_RUNS =
+            "first_card_animation_max_runs";
     private static final String PARAM_SCROLL_BELOW_THE_FOLD = "scroll_below_the_fold";
 
+    private static final String PARAM_DISABLED_VALUE = "off";
+
+    private static final int FIRST_CARD_ANIMATION_DEFAULT_VALUE = 7;
+
     private CardsVariationParameters() {}
 
     /**
@@ -31,19 +36,14 @@ public final class CardsVariationParameters {
      * with a command line flag). It will return 0 if there is no such field trial.
      */
     public static int getFirstCardOffsetDp() {
-        // TODO(jkrcal): Get parameter by feature name, not field trial name.
-        String value = VariationsAssociatedData.getVariationParamValue(
-                FIELD_TRIAL_NAME, PARAM_FIRST_CARD_OFFSET);
+        return getIntValue(PARAM_FIRST_CARD_OFFSET, 0);
+    }
 
-        if (!TextUtils.isEmpty(value)) {
-            try {
-                return Integer.parseInt(value);
-            } catch (NumberFormatException ex) {
-                Log.w(TAG, "Cannot parse card offset experiment value, %s.", value);
-            }
-        }
-
-        return 0;
+    /**
+     * Gets the number of times the first card peeking animation should run.
+     */
+    public static int getFirstCardAnimationMaxRuns() {
+        return getIntValue(PARAM_FIRST_CARD_ANIMATION_MAX_RUNS, FIRST_CARD_ANIMATION_DEFAULT_VALUE);
     }
 
     /**
@@ -58,4 +58,20 @@ public final class CardsVariationParameters {
         return !PARAM_DISABLED_VALUE.equals(VariationsAssociatedData.getVariationParamValue(
                 FIELD_TRIAL_NAME, PARAM_FAVICON_SERVICE_NAME));
     }
+
+    private static int getIntValue(String paramName, int defaultValue) {
+        // TODO(jkrcal): Get parameter by feature name, not field trial name.
+        String value = VariationsAssociatedData.getVariationParamValue(
+                FIELD_TRIAL_NAME, paramName);
+
+        if (!TextUtils.isEmpty(value)) {
+            try {
+                return Integer.parseInt(value);
+            } catch (NumberFormatException ex) {
+                Log.w(TAG, "Cannot parse %s experiment value, %s.", paramName, value);
+            }
+        }
+
+        return defaultValue;
+    }
 }
