@@ -49,13 +49,9 @@ public class NewTabPageRecyclerView extends RecyclerView implements TouchDisable
     private static final int PEEKING_CARD_ANIMATION_TIME_MS = 1000;
     private static final int PEEKING_CARD_ANIMATION_START_DELAY_MS = 300;
 
-    private static final String PREF_ANIMATION_RUN_COUNT = "ntp_recycler_view_animation_run_count";
-
     private final GestureDetector mGestureDetector;
     private final LinearLayoutManager mLayoutManager;
     private final int mToolbarHeight;
-    private final int mSearchBoxTransitionLength;
-    private final int mPeekingHeight;
     private final int mMaxHeaderHeight;
     /** How much of the first card is visible above the fold with the increased visibility UI. */
     private final int mPeekingCardBounceDistance;
@@ -86,9 +82,6 @@ public class NewTabPageRecyclerView extends RecyclerView implements TouchDisable
     /** Whether the above-the-fold left space for a peeking card to be displayed. */
     private boolean mHasSpaceForPeekingCard;
 
-    /** Whether the above-the-fold view has ever been rendered. */
-    private boolean mHasRenderedAboveTheFoldView;
-
     /**
      * Constructor needed to inflate from XML.
      */
@@ -113,24 +106,8 @@ public class NewTabPageRecyclerView extends RecyclerView implements TouchDisable
         mMaxHeaderHeight = res.getDimensionPixelSize(R.dimen.snippets_article_header_height);
         mPeekingCardBounceDistance =
                 res.getDimensionPixelSize(R.dimen.snippets_peeking_card_bounce_distance);
-        mSearchBoxTransitionLength =
-                res.getDimensionPixelSize(R.dimen.ntp_search_box_transition_length);
-        mPeekingHeight = res.getDimensionPixelSize(R.dimen.snippets_padding);
 
         setHasFixedSize(true);
-
-        addOnChildAttachStateChangeListener(new OnChildAttachStateChangeListener() {
-            @Override
-            public void onChildViewAttachedToWindow(View view) {
-                if (view == mAboveTheFoldView) {
-                    mHasRenderedAboveTheFoldView = true;
-                    removeOnChildAttachStateChangeListener(this);
-                }
-            }
-
-            @Override
-            public void onChildViewDetachedFromWindow(View view) {}
-        });
     }
 
     public boolean isFirstItemVisible() {
@@ -208,7 +185,7 @@ public class NewTabPageRecyclerView extends RecyclerView implements TouchDisable
      * Updates the space added at the end of the list to make sure the above/below the fold
      * distinction can be preserved.
      */
-    public void refreshBottomSpacing() {
+    private void refreshBottomSpacing() {
         ViewHolder bottomSpacingViewHolder = findBottomSpacer();
 
         // It might not be in the layout yet if it's not visible or ready to be displayed.
@@ -230,11 +207,8 @@ public class NewTabPageRecyclerView extends RecyclerView implements TouchDisable
             return 0;
         }
 
-        if (firstVisiblePos > aboveTheFoldPosition && mHasRenderedAboveTheFoldView) {
-            // We have enough items to fill the viewport, since we have scrolled past the
-            // above-the-fold item. We must check whether the above-the-fold view has been rendered
-            // at least once, because it's possible to skip right over it if the initial scroll
-            // position is not 0, in which case we may need the spacer to be taller than 0.
+        // We have enough items to fill the view, since the above-the-fold item is not even visible.
+        if (firstVisiblePos > aboveTheFoldPosition) {
             return 0;
         }
 
@@ -450,15 +424,14 @@ public class NewTabPageRecyclerView extends RecyclerView implements TouchDisable
      */
     public void snapScroll(View fakeBox, int parentScrollY, int parentHeight) {
         // Snap scroll to prevent resting in the middle of the omnibox transition.
+        final int searchBoxTransitionLength = getResources()
+                .getDimensionPixelSize(R.dimen.ntp_search_box_transition_length);
         int fakeBoxUpperBound = fakeBox.getTop() + fakeBox.getPaddingTop();
-        if (scrollOutOfRegion(fakeBoxUpperBound - mSearchBoxTransitionLength, fakeBoxUpperBound)) {
+        if (scrollOutOfRegion(fakeBoxUpperBound - searchBoxTransitionLength, fakeBoxUpperBound)) {
             // The snap scrolling regions should never overlap.
             return;
         }
 
-        // Snap scroll to prevent only part of the toolbar from showing.
-        if (scrollOutOfRegion(0, mToolbarHeight)) return;
-
         // Snap scroll to prevent resting in the middle of the peeking card transition
         // and to allow the peeking card to peek a bit before snapping back.
         CardViewHolder peekingCardViewHolder = findFirstCard();
@@ -472,8 +445,10 @@ public class NewTabPageRecyclerView extends RecyclerView implements TouchDisable
 
             View peekingCardView = peekingCardViewHolder.itemView;
             View headerView = firstHeaderViewHolder.itemView;
+            final int peekingHeight = getResources().getDimensionPixelSize(
+                    R.dimen.snippets_padding);
 
-            // |A + B - C| gives the offset of the peeking card relative to the RecyclerView,
+            // |A + B - C| gives the offset of the peeking card relative to the Recycler View,
             // so scrolling to this point would put the peeking card at the top of the
             // screen. Remove the |headerView| height which gets dynamically increased with
             // scrolling.
@@ -485,10 +460,10 @@ public class NewTabPageRecyclerView extends RecyclerView implements TouchDisable
                     + parentScrollY // B.
                     - headerView.getHeight()  // C.
                     - parentHeight  // D.
-                    + mPeekingHeight;  // E.
+                    + peekingHeight;  // E.
 
             // The height of the region in which the the peeking card will snap.
-            int snapScrollHeight = mPeekingHeight + headerView.getHeight();
+            int snapScrollHeight = peekingHeight + headerView.getHeight();
 
             scrollOutOfRegion(start,
                               start + snapScrollHeight,
@@ -504,9 +479,8 @@ public class NewTabPageRecyclerView extends RecyclerView implements TouchDisable
 
     /**
      * Animates the card being swiped to the right as if the user had dismissed it. Any changes to
-     * the animation here should be reflected also in
-     * {@link #updateViewStateForDismiss(float, ViewHolder)} and reset in
-     * {@link CardViewHolder#onBindViewHolder()}.
+     * the animation here should be reflected also in {@link #updateViewStateForDismiss} and reset
+     * in {@link CardViewHolder#onBindViewHolder()}.
      */
     public void dismissItemWithAnimation(final ViewHolder viewHolder) {
         // We need to check the position, as the view holder might have been removed.
@@ -562,8 +536,8 @@ public class NewTabPageRecyclerView extends RecyclerView implements TouchDisable
      * @param dX The amount of horizontal displacement caused by user's action.
      * @param viewHolder The view holder containing the view to be updated.
      */
-    public void updateViewStateForDismiss(float dX, ViewHolder viewHolder) {
-        if (!((NewTabPageViewHolder) viewHolder).isDismissable()) return;
+    public void updateViewStateForDismiss(float dX, NewTabPageViewHolder viewHolder) {
+        if (!viewHolder.isDismissable()) return;
 
         viewHolder.itemView.setTranslationX(dX);
 
