@@ -6,8 +6,6 @@ package org.chromium.chrome.browser.ntp.snippets;
 import android.graphics.Bitmap;
 import android.support.annotation.Nullable;
 
-import org.chromium.chrome.browser.ntp.snippets.ContentSuggestionsCardLayout.ContentSuggestionsCardLayoutEnum;
-
 import java.io.File;
 
 /**
@@ -47,10 +45,6 @@ public class SnippetArticle {
     /** The position of this article in the complete list. Populated by NewTabPageAdapter. */
     public int mGlobalPosition = -1;
 
-    /** The layout that should be used to display the snippet. */
-    @ContentSuggestionsCardLayoutEnum
-    public final int mCardLayout;
-
     /** Bitmap of the thumbnail, fetched lazily, when the RecyclerView wants to show the snippet. */
     private Bitmap mThumbnailBitmap;
 
@@ -60,17 +54,14 @@ public class SnippetArticle {
     /** To be run when the offline status of the article or AMP article changes. */
     private Runnable mOfflineStatusChangeRunnable;
 
-    /** Whether the linked article represents a downloaded asset. */
-    public boolean mIsDownloadedAsset;
+    /** Whether the linked article represents an asset download. */
+    public boolean mIsAssetDownload;
 
-    /** The path to the downloaded asset (only for download asset articles). */
-    private String mDownloadAssetPath;
+    /** The path to the asset download (only for asset download articles). */
+    private File mAssetDownloadFile;
 
-    /** The downloaded asset (only for download asset articles). */
-    private File mFile;
-
-    /** The mime type of the downloaded asset (only for download asset articles). */
-    private String mDownloadAssetMimeType;
+    /** The mime type of the asset download (only for asset download articles). */
+    private String mAssetDownloadMimeType;
 
     /** The tab id of the corresponding tab (only for recent tab articles). */
     private String mRecentTabId;
@@ -83,7 +74,7 @@ public class SnippetArticle {
      */
     public SnippetArticle(int category, String idWithinCategory, String title, String publisher,
             String previewText, String url, String ampUrl, long timestamp, float score,
-            int position, @ContentSuggestionsCardLayoutEnum int cardLayout) {
+            int position) {
         mCategory = category;
         mIdWithinCategory = idWithinCategory;
         mTitle = title;
@@ -94,7 +85,6 @@ public class SnippetArticle {
         mPublishTimestampMilliseconds = timestamp;
         mScore = score;
         mPosition = position;
-        mCardLayout = cardLayout;
     }
 
     @Override
@@ -144,42 +134,43 @@ public class SnippetArticle {
     }
 
     /**
-     * @return the downloaded asset. May only be called if mIsDownloadedAsset is {@code true} and
-     * this snippet belongs to DOWNLOADS category.
+     * @return the asset download path. May only be called if {@link #mIsAssetDownload} is
+     * {@code true} (which implies that this snippet belongs to the DOWNLOADS category).
      */
-    public File getDownloadAssetFile() {
+    public File getAssetDownloadFile() {
         assert isDownload();
-        if (mFile == null) mFile = new File(mDownloadAssetPath);
-        return mFile;
+        assert mIsAssetDownload;
+        return mAssetDownloadFile;
     }
 
     /**
-     * @return the mime type of the download asset. May only be called if mIsDownloadAsset is
-     * {@code true} and this snippet belongs to DOWNLOADS category.
+     * @return the mime type of the asset download. May only be called if {@link #mIsAssetDownload}
+     * is {@code true} (which implies that this snippet belongs to the DOWNLOADS category).
      */
-    public String getDownloadAssetMimeType() {
+    public String getAssetDownloadMimeType() {
         assert isDownload();
-        return mDownloadAssetMimeType;
+        assert mIsAssetDownload;
+        return mAssetDownloadMimeType;
     }
 
     /**
-     * Marks the article suggestion as a download asset with the given path and mime type. May only
+     * Marks the article suggestion as an asset download with the given path and mime type. May only
      * be called if this snippet belongs to DOWNLOADS category.
      */
-    public void setDownloadAssetData(String filePath, String mimeType) {
+    public void setAssetDownloadData(String filePath, String mimeType) {
         assert isDownload();
-        mIsDownloadedAsset = true;
-        mDownloadAssetPath = filePath;
-        mDownloadAssetMimeType = mimeType;
+        mIsAssetDownload = true;
+        mAssetDownloadFile = new File(filePath);
+        mAssetDownloadMimeType = mimeType;
     }
 
     /**
-     * Marks the article suggestion as a download offline page with the given id. May only be called
-     * if this snippet belongs to DOWNLOADS category.
+     * Marks the article suggestion as an offline page download with the given id. May only
+     * be called if this snippet belongs to DOWNLOADS category.
      */
-    public void setDownloadOfflinePageData(long offlinePageId) {
+    public void setOfflinePageDownloadData(long offlinePageId) {
         assert isDownload();
-        mIsDownloadedAsset = false;
+        mIsAssetDownload = false;
         setOfflinePageOfflineId(offlinePageId);
     }
 
