@@ -38,6 +38,7 @@ import org.chromium.chrome.browser.ntp.cards.CardsVariationParameters;
 import org.chromium.chrome.browser.ntp.cards.DisplayStyleObserverAdapter;
 import org.chromium.chrome.browser.ntp.cards.ImpressionTracker;
 import org.chromium.chrome.browser.ntp.cards.NewTabPageRecyclerView;
+import org.chromium.chrome.browser.ntp.cards.SuggestionsCategoryInfo;
 import org.chromium.ui.mojom.WindowOpenDisposition;
 
 import java.net.URI;
@@ -65,6 +66,7 @@ public class SnippetArticleViewHolder
 
     private FetchImageCallback mImageCallback;
     private SnippetArticle mArticle;
+    private SuggestionsCategoryInfo mCategoryInfo;
     private int mPublisherFaviconSizePx;
 
     private final boolean mUseFaviconService;
@@ -149,7 +151,8 @@ public class SnippetArticleViewHolder
      */
     private void updateLayout() {
         boolean narrow = mUiConfig.getCurrentDisplayStyle() == UiConfig.DISPLAY_STYLE_NARROW;
-        boolean minimal = mArticle.mCardLayout == ContentSuggestionsCardLayout.MINIMAL_CARD;
+        boolean minimal =
+                mCategoryInfo.getCardLayout() == ContentSuggestionsCardLayout.MINIMAL_CARD;
 
         // If the screen is narrow or we are using the minimal layout, hide the article snippet.
         boolean hideSnippet = narrow || minimal;
@@ -182,13 +185,14 @@ public class SnippetArticleViewHolder
         mPublisherBar.setLayoutParams(params);
     }
 
-    public void onBindViewHolder(SnippetArticle article) {
+    public void onBindViewHolder(SnippetArticle article, SuggestionsCategoryInfo categoryInfo) {
         super.onBindViewHolder();
 
         // No longer listen for offline status changes to the old article.
         if (mArticle != null) mArticle.setOfflineStatusChangeRunnable(null);
 
         mArticle = article;
+        mCategoryInfo = categoryInfo;
         updateLayout();
 
         mHeadlineTextView.setText(mArticle.mTitle);
@@ -251,7 +255,7 @@ public class SnippetArticleViewHolder
             Runnable offlineChecker = new Runnable() {
                 @Override
                 public void run() {
-                    if (mArticle.getOfflinePageOfflineId() != null || mArticle.mIsDownloadedAsset) {
+                    if (mArticle.getOfflinePageOfflineId() != null || mArticle.mIsAssetDownload) {
                         mOfflineBadge.setVisibility(View.VISIBLE);
                     }
                 }
