@@ -65,13 +65,6 @@ public class SnippetsBridge implements SuggestionsSource {
         mObserver = null;
     }
 
-    /**
-     * Fetches new snippets.
-     */
-    public static void fetchSnippets(boolean forceRequest) {
-        nativeFetchSnippets(forceRequest);
-    }
-
     /**
      * Reschedules the fetching of snippets.
      */
@@ -79,6 +72,16 @@ public class SnippetsBridge implements SuggestionsSource {
         nativeRescheduleFetching();
     }
 
+    public static void fetchRemoteSuggestionsFromBackground() {
+        // Do not force regular background fetches.
+        nativeFetchRemoteSuggestionsInTheBackground();
+    }
+
+    @Override
+    public void fetchRemoteSuggestions() {
+        nativeFetchRemoteSuggestions();
+    }
+
     @Override
     public int[] getCategories() {
         assert mNativeSnippetsBridge != 0;
@@ -201,35 +204,31 @@ public class SnippetsBridge implements SuggestionsSource {
     }
 
     @CalledByNative
-    private static void addSuggestion(List<SnippetArticle> suggestions, int category, String id,
-            String title, String publisher, String previewText, String url, String ampUrl,
-            long timestamp, float score, int cardLayout) {
+    private static SnippetArticle addSuggestion(List<SnippetArticle> suggestions, int category,
+            String id, String title, String publisher, String previewText, String url,
+            String ampUrl, long timestamp, float score) {
         int position = suggestions.size();
         suggestions.add(new SnippetArticle(category, id, title, publisher, previewText, url, ampUrl,
-                timestamp, score, position, cardLayout));
-    }
-
-    // TODO(vitaliii): Remove all |.*ForLastSuggestion| methods and instead make |addSuggestion|
-    // return the suggestion and set the values there.
-    @CalledByNative
-    private static void setDownloadAssetDataForLastSuggestion(
-            List<SnippetArticle> suggestions, String filePath, String mimeType) {
-        assert suggestions.size() > 0;
-        suggestions.get(suggestions.size() - 1).setDownloadAssetData(filePath, mimeType);
+                timestamp, score, position));
+        return suggestions.get(position);
     }
 
     @CalledByNative
-    private static void setDownloadOfflinePageDataForLastSuggestion(
-            List<SnippetArticle> suggestions, long offlinePageId) {
-        assert suggestions.size() > 0;
-        suggestions.get(suggestions.size() - 1).setDownloadOfflinePageData(offlinePageId);
+    private static void setAssetDownloadDataForSuggestion(
+            SnippetArticle suggestion, String filePath, String mimeType) {
+        suggestion.setAssetDownloadData(filePath, mimeType);
     }
 
     @CalledByNative
-    private static void setRecentTabDataForLastSuggestion(
-            List<SnippetArticle> suggestions, String tabId, long offlinePageId) {
-        assert suggestions.size() > 0;
-        suggestions.get(suggestions.size() - 1).setRecentTabData(tabId, offlinePageId);
+    private static void setOfflinePageDownloadDataForSuggestion(
+            SnippetArticle suggestion, long offlinePageId) {
+        suggestion.setOfflinePageDownloadData(offlinePageId);
+    }
+
+    @CalledByNative
+    private static void setRecentTabDataForSuggestion(
+            SnippetArticle suggestion, String tabId, long offlinePageId) {
+        suggestion.setRecentTabData(tabId, offlinePageId);
     }
 
     @CalledByNative
@@ -265,9 +264,15 @@ public class SnippetsBridge implements SuggestionsSource {
         if (mObserver != null) mObserver.onSuggestionInvalidated(category, idWithinCategory);
     }
 
+    @CalledByNative
+    private void onFullRefreshRequired() {
+        if (mObserver != null) mObserver.onFullRefreshRequired();
+    }
+
     private native long nativeInit(Profile profile);
     private native void nativeDestroy(long nativeNTPSnippetsBridge);
-    private static native void nativeFetchSnippets(boolean forceRequest);
+    private static native void nativeFetchRemoteSuggestions();
+    private static native void nativeFetchRemoteSuggestionsInTheBackground();
     private static native void nativeRescheduleFetching();
     private native int[] nativeGetCategories(long nativeNTPSnippetsBridge);
     private native int nativeGetCategoryStatus(long nativeNTPSnippetsBridge, int category);
