@@ -14,6 +14,8 @@ import android.os.Process;
 import android.util.Base64;
 
 import org.chromium.base.ApiCompatibilityUtils;
+import org.chromium.base.ContextUtils;
+import org.chromium.base.annotations.CalledByNative;
 import org.chromium.base.metrics.RecordHistogram;
 import org.chromium.chrome.browser.preferences.website.ContentSetting;
 import org.chromium.chrome.browser.preferences.website.GeolocationInfo;
@@ -146,6 +148,12 @@ public class GeolocationHeader {
         return "X-Geo: a " + locationBase64;
     }
 
+    @CalledByNative
+    public static boolean hasGeolocationPermission() {
+        Context context = ContextUtils.getApplicationContext();
+        return hasGeolocationPermission(context);
+    }
+
     static boolean hasGeolocationPermission(Context context) {
         int pid = Process.myPid();
         int uid = Process.myUid();
