@@ -10,6 +10,7 @@ import android.telephony.PhoneNumberUtils;
 import android.text.TextUtils;
 
 import org.chromium.chrome.R;
+import org.chromium.chrome.browser.autofill.PersonalDataManager;
 import org.chromium.chrome.browser.autofill.PersonalDataManager.AutofillProfile;
 import org.chromium.chrome.browser.payments.ui.PaymentOption;
 import org.chromium.chrome.browser.preferences.autofill.AutofillProfileBridge;
@@ -58,6 +59,9 @@ public class AutofillAddress extends PaymentOption {
     private Context mContext;
     private AutofillProfile mProfile;
     @Nullable private Pattern mLanguageScriptCodePattern;
+    @Nullable private String mShippingLabelWithCountry;
+    @Nullable private String mShippingLabelWithoutCountry;
+    @Nullable private String mBillingLabel;
 
     /**
      * Builds the autofill address.
@@ -85,6 +89,12 @@ public class AutofillAddress extends PaymentOption {
      * @param profile The new profile to use.
      */
     public void completeAddress(AutofillProfile profile) {
+        // Since the profile changed, our cached labels are now out of date. Set them to null so the
+        // labels are recomputed next time they are needed.
+        mShippingLabelWithCountry = null;
+        mShippingLabelWithoutCountry = null;
+        mBillingLabel = null;
+
         mProfile = profile;
         updateIdentifierAndLabels(mProfile.getGUID(), mProfile.getFullName(), mProfile.getLabel(),
                 mProfile.getPhoneNumber());
@@ -92,6 +102,57 @@ public class AutofillAddress extends PaymentOption {
         assert mIsComplete;
     }
 
+    /**
+     * Gets the shipping address label which includes the country for the profile associated with
+     * this address and sets it as sublabel for this PaymentOption.
+     */
+    public void setShippingAddressLabelWithCountry() {
+        assert mProfile != null;
+
+        if (mShippingLabelWithCountry == null) {
+            mShippingLabelWithCountry =
+                    PersonalDataManager.getInstance()
+                            .getShippingAddressLabelWithCountryForPaymentRequest(mProfile);
+        }
+
+        mProfile.setLabel(mShippingLabelWithCountry);
+        updateSublabel(mProfile.getLabel());
+    }
+
+    /**
+     * Gets the shipping address label which does not include the country for the profile associated
+     * with this address and sets it as sublabel for this PaymentOption.
+     */
+    public void setShippingAddressLabelWithoutCountry() {
+        assert mProfile != null;
+
+        if (mShippingLabelWithoutCountry == null) {
+            mShippingLabelWithoutCountry =
+                    PersonalDataManager.getInstance()
+                            .getShippingAddressLabelWithoutCountryForPaymentRequest(mProfile);
+        }
+
+        mProfile.setLabel(mShippingLabelWithoutCountry);
+        updateSublabel(mProfile.getLabel());
+    }
+
+    /*
+     * Gets the billing address label for the profile associated with this address and sets it as
+     * sublabel for this PaymentOption.
+     */
+    public void setBillingAddressLabel() {
+        assert mProfile != null;
+
+        if (mBillingLabel == null) {
+            mBillingLabel =
+                    PersonalDataManager.getInstance().getBillingAddressLabelForPaymentRequest(
+                            mProfile);
+        }
+
+        mProfile.setLabel(mBillingLabel);
+        updateSublabel(mProfile.getLabel());
+    }
+
     /**
      * Checks whether this address is complete and updates edit message, edit title and complete
      * status.
@@ -102,7 +163,6 @@ public class AutofillAddress extends PaymentOption {
 
         switch (checkAddressCompletionStatus(mProfile)) {
             case COMPLETE:
-                editTitleResId = R.string.autofill_edit_profile;
                 break;
             case INVALID_ADDRESS:
                 editMessageResId = R.string.payments_invalid_address;
