@@ -22,7 +22,10 @@ import org.chromium.payments.mojom.PaymentMethodData;
 
 import java.io.IOException;
 import java.io.StringWriter;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
+import java.util.Set;
 
 import javax.annotation.Nullable;
 
@@ -39,7 +42,6 @@ public class AutofillPaymentInstrument extends PaymentInstrument
     @Nullable private InstrumentDetailsCallback mCallback;
     private boolean mIsWaitingForBillingNormalization;
     private boolean mIsWaitingForFullCardDetails;
-    private boolean mHasValidNumberAndName;
 
     /**
      * Builds a payment instrument for the given credit card.
@@ -65,20 +67,20 @@ public class AutofillPaymentInstrument extends PaymentInstrument
     }
 
     @Override
-    public String getInstrumentMethodName() {
-        return mCard.getBasicCardPaymentType();
+    public Set<String> getInstrumentMethodNames() {
+        Set<String> result = new HashSet<>();
+        result.add(mCard.getBasicCardPaymentType());
+        return result;
     }
 
     @Override
-    public void getInstrumentDetails(String unusedMerchantName, String unusedOrigin,
-            PaymentItem unusedTotal, List<PaymentItem> unusedCart, PaymentMethodData unusedDetails,
+    public void invokePaymentApp(String unusedMerchantName, String unusedOrigin,
+            PaymentItem unusedTotal, List<PaymentItem> unusedCart,
+            Map<String, PaymentMethodData> unusedMethodData,
             InstrumentDetailsCallback callback) {
         // The billing address should never be null for a credit card at this point.
         assert mBillingAddress != null;
-        assert AutofillAddress.checkAddressCompletionStatus(mBillingAddress)
-                == AutofillAddress.COMPLETE;
         assert mIsComplete;
-        assert mHasValidNumberAndName;
         assert mCallback == null;
         mCallback = callback;
 
@@ -109,7 +111,7 @@ public class AutofillPaymentInstrument extends PaymentInstrument
         mIsWaitingForFullCardDetails = false;
 
         // Show the loading UI while the address gets normalized.
-        mCallback.loadingInstrumentDetails();
+        mCallback.onInstrumentDetailsLoadingWithoutUI();
 
         // Wait for the billing address normalization before sending the instrument details.
         if (mIsWaitingForBillingNormalization) {
@@ -208,22 +210,11 @@ public class AutofillPaymentInstrument extends PaymentInstrument
     @Override
     public void dismissInstrument() {}
 
-    /**
-     * @return Whether the card is complete and ready to be sent to the merchant as-is. If true,
-     * this card has a valid card number, a non-empty name on card, and a complete billing address.
-     */
+    /** @return Whether the card is complete and ready to be sent to the merchant as-is. */
     public boolean isComplete() {
         return mIsComplete;
     }
 
-    /**
-     * @return Whether the card number is valid and name on card is non-empty. Billing address is
-     * not taken into consideration.
-     */
-    public boolean isValid() {
-        return mHasValidNumberAndName;
-    }
-
     /**
      * Updates the instrument and marks it "complete." Called after the user has edited this
      * instrument.
@@ -248,19 +239,15 @@ public class AutofillPaymentInstrument extends PaymentInstrument
                               mContext.getResources(), card.getIssuerIconDrawableId()));
         checkAndUpateCardCompleteness();
         assert mIsComplete;
-        assert mHasValidNumberAndName;
     }
 
     /**
      * Checks whether card is complete, i.e., can be sent to the merchant as-is without editing
      * first. And updates edit message, edit title and complete status.
      *
-     * For both local and server cards, verifies that the billing address is present. For local
+     * For both local and server cards, verifies that the billing address is complete. For local
      * cards also verifies that the card number is valid and the name on card is not empty.
      *
-     * Does not check that the billing address has all of the required fields. This is done
-     * elsewhere to filter out such billing addresses entirely.
-     *
      * Does not check the expiration date. If the card is expired, the user has the opportunity
      * update the expiration date when providing their CVC in the card unmask dialog.
      *
@@ -269,7 +256,7 @@ public class AutofillPaymentInstrument extends PaymentInstrument
      */
     private void checkAndUpateCardCompleteness() {
         int editMessageResId = 0; // Zero is the invalid resource Id.
-        int editTitleResId = R.string.payments_edit_card;
+        int editTitleResId = 0;
         int invalidFieldsCount = 0;
 
         if (mBillingAddress == null) {
@@ -278,10 +265,8 @@ public class AutofillPaymentInstrument extends PaymentInstrument
             invalidFieldsCount++;
         }
 
-        mHasValidNumberAndName = true;
         if (mCard.getIsLocal()) {
             if (TextUtils.isEmpty(mCard.getName())) {
-                mHasValidNumberAndName = false;
                 editMessageResId = R.string.payments_name_on_card_required;
                 editTitleResId = R.string.payments_add_name_on_card;
                 invalidFieldsCount++;
@@ -290,7 +275,6 @@ public class AutofillPaymentInstrument extends PaymentInstrument
             if (PersonalDataManager.getInstance().getBasicCardPaymentType(
                         mCard.getNumber().toString(), true)
                     == null) {
-                mHasValidNumberAndName = false;
                 editMessageResId = R.string.payments_card_number_invalid;
                 editTitleResId = R.string.payments_add_valid_card_number;
                 invalidFieldsCount++;
@@ -303,7 +287,7 @@ public class AutofillPaymentInstrument extends PaymentInstrument
         }
 
         mEditMessage = editMessageResId == 0 ? null : mContext.getString(editMessageResId);
-        mEditTitle = mContext.getString(editTitleResId);
+        mEditTitle = editTitleResId == 0 ? null : mContext.getString(editTitleResId);
         mIsComplete = mEditMessage == null;
     }
 
@@ -316,4 +300,4 @@ public class AutofillPaymentInstrument extends PaymentInstrument
     public AutofillProfile getBillingAddress() {
         return mBillingAddress;
     }
-}
\ No newline at end of file
+}
