@@ -18,6 +18,7 @@ import org.chromium.chrome.browser.autofill.PersonalDataManager.CreditCard;
 import org.chromium.chrome.browser.payments.PaymentRequestImpl.PaymentRequestServiceObserverForTest;
 import org.chromium.chrome.browser.payments.ui.EditorFieldModel;
 import org.chromium.chrome.browser.payments.ui.EditorFieldModel.EditorFieldValidator;
+import org.chromium.chrome.browser.payments.ui.EditorFieldModel.EditorValueIconGenerator;
 import org.chromium.chrome.browser.payments.ui.EditorModel;
 import org.chromium.chrome.browser.preferences.autofill.AutofillProfileBridge.DropdownKeyValue;
 import org.chromium.content.browser.ContentViewCore;
@@ -66,21 +67,21 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
         }
     }
 
-    /** The dropdown key that indicates absence of billing address. */
-    private static final String BILLING_ADDRESS_NONE = "";
-
     /** The dropdown key that triggers the address editor to add a new billing address. */
     private static final String BILLING_ADDRESS_ADD_NEW = "add";
 
+    /** The shared preference for the 'save card to device' checkbox status*/
+    private static final String CHECK_SAVE_CARD_TO_DEVICE = "check_save_card_to_device";
+
     /** The web contents where the web payments API is invoked. */
     private final WebContents mWebContents;
 
     /**
-     * The map from GUIDs to profiles that can be used for billing address. This cache avoids
-     * re-reading profiles from disk, which may have changed due to sync, for example.
-     * updateBillingAddress() updates this cache.
+     * The list of profiles that can be used for billing address. This cache avoids re-reading
+     * profiles from disk, which may have changed due to sync, for example. updateBillingAddress()
+     * updates this cache.
      */
-    private final Map<String, AutofillProfile> mProfilesForBillingAddress;
+    private final List<AutofillProfile> mProfilesForBillingAddress;
 
     /** Used for verifying billing address completeness and also editing billing addresses. */
     private final AddressEditor mAddressEditor;
@@ -109,6 +110,7 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
 
     private final Handler mHandler;
     private final EditorFieldValidator mCardNumberValidator;
+    private final EditorValueIconGenerator mCardIconGenerator;
     private final AsyncTask<Void, Void, Calendar> mCalendar;
 
     @Nullable private EditorFieldModel mIconHint;
@@ -142,17 +144,19 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
         mAddressEditor = addressEditor;
         mObserverForTest = observerForTest;
 
-        List<AutofillProfile> profiles = PersonalDataManager.getInstance().getProfilesToSuggest(
-                true /* includeName */);
-        mProfilesForBillingAddress = new HashMap<>();
+        List<AutofillProfile> profiles =
+                PersonalDataManager.getInstance().getBillingAddressesToSuggest();
+        mProfilesForBillingAddress = new ArrayList<>();
         for (int i = 0; i < profiles.size(); i++) {
             AutofillProfile profile = profiles.get(i);
             // 1) Include only local profiles, because GUIDs of server profiles change on every
             //    browser restart. Server profiles are not supported as billing addresses.
             // 2) Include only complete profiles, so that user launches the editor only when
             //    explicitly selecting [+ ADD ADDRESS] in the dropdown.
-            if (profile.getIsLocal() && mAddressEditor.isProfileComplete(profile)) {
-                mProfilesForBillingAddress.put(profile.getGUID(), profile);
+            if (profile.getIsLocal()
+                    && AutofillAddress.checkAddressCompletionStatus(profile)
+                            == AutofillAddress.COMPLETE) {
+                mProfilesForBillingAddress.add(profile);
             }
         }
 
@@ -167,6 +171,8 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
                 new CardTypeInfo(R.drawable.pr_jcb, R.string.autofill_cc_jcb));
         mCardTypes.put("mastercard",
                 new CardTypeInfo(R.drawable.pr_mc, R.string.autofill_cc_mastercard));
+        mCardTypes.put("mir",
+                new CardTypeInfo(R.drawable.pr_mir, R.string.autofill_cc_mir));
         mCardTypes.put("unionpay",
                 new CardTypeInfo(R.drawable.pr_unionpay, R.string.autofill_cc_union_pay));
         mCardTypes.put("visa",
@@ -179,9 +185,22 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
         mCardNumberValidator = new EditorFieldValidator() {
             @Override
             public boolean isValid(@Nullable CharSequence value) {
-                return value != null && mAcceptedCardTypes.contains(
-                        PersonalDataManager.getInstance().getBasicCardPaymentTypeIfValid(
-                                value.toString()));
+                return value != null
+                        && mAcceptedCardTypes.contains(
+                                   PersonalDataManager.getInstance().getBasicCardPaymentType(
+                                           value.toString(), true));
+            }
+        };
+
+        mCardIconGenerator = new EditorValueIconGenerator() {
+            @Override
+            public int getIconResourceId(@Nullable CharSequence value) {
+                if (value == null) return 0;
+                CardTypeInfo cardTypeInfo =
+                        mCardTypes.get(PersonalDataManager.getInstance().getBasicCardPaymentType(
+                                value.toString(), false));
+                if (cardTypeInfo == null) return 0;
+                return cardTypeInfo.icon;
             }
         };
 
@@ -194,33 +213,6 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
         mCalendar.execute();
     }
 
-    /**
-     * Returns whether the given credit card is complete, i.e., can be sent to the merchant as-is
-     * without editing first.
-     *
-     * For both local and server cards, verifies that the billing address is complete. For local
-     * cards also verifies that the card number is valid and the name on card is not empty.
-     *
-     * Does not check the expiration date. If the card is expired, the user has the opportunity
-     * update the expiration date when providing their CVC in the card unmask dialog.
-     *
-     * Does not check that the card type is accepted by the merchant. This is done elsewhere to
-     * filter out such cards from view entirely. Cards that are not accepted by the merchant should
-     * not be edited.
-     *
-     * @param card The card to check.
-     * @return Whether the card is complete.
-     */
-    public boolean isCardComplete(CreditCard card) {
-        if (card == null || !mProfilesForBillingAddress.containsKey(card.getBillingAddressId())) {
-            return false;
-        }
-
-        if (!card.getIsLocal()) return true;
-
-        return !TextUtils.isEmpty(card.getName()) && mCardNumberValidator.isValid(card.getNumber());
-    }
-
     /**
      * Adds accepted payment methods to the editor, if they are recognized credit card types.
      *
@@ -263,14 +255,12 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
 
         // Ensure that |instrument| and |card| are never null.
         final AutofillPaymentInstrument instrument = isNewCard
-                ? new AutofillPaymentInstrument(mWebContents, new CreditCard(), null)
+                ? new AutofillPaymentInstrument(mContext, mWebContents, new CreditCard(), null)
                 : toEdit;
         final CreditCard card = instrument.getCard();
 
-        // The title of the editor depends on whether we're adding a new card or editing an existing
-        // card.
-        final EditorModel editor = new EditorModel(mContext.getString(
-                isNewCard ? R.string.payments_create_card : R.string.payments_edit_card));
+        final EditorModel editor = new EditorModel(
+                isNewCard ? mContext.getString(R.string.payments_add_card) : toEdit.getEditTitle());
 
         if (card.getIsLocal()) {
             Calendar calendar = null;
@@ -292,7 +282,9 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
         } else {
             // Display some information about the server card.
             editor.addField(EditorFieldModel.createLabel(card.getObfuscatedNumber(), card.getName(),
-                    card.getFormattedExpirationDate(mContext), card.getIssuerIconDrawableId()));
+                    mContext.getString(R.string.payments_credit_card_expiration_date_abbr,
+                            card.getMonth(), card.getYear()),
+                    card.getIssuerIconDrawableId()));
         }
 
         // Always show the billing address dropdown.
@@ -301,11 +293,12 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
         // Allow saving new cards on disk.
         if (isNewCard) addSaveCardCheckbox(editor);
 
-        // If the user clicks [Cancel], send a null card back to the caller.
+        // If the user clicks [Cancel], send |toEdit| card back to the caller (will return original
+        // state, which could be null, a full card, or a partial card).
         editor.setCancelCallback(new Runnable() {
             @Override
             public void run() {
-                callback.onResult(null);
+                callback.onResult(toEdit);
             }
         });
 
@@ -315,8 +308,13 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
             @Override
             public void run() {
                 commitChanges(card, isNewCard);
-                instrument.completeInstrument(
-                        card, mProfilesForBillingAddress.get(card.getBillingAddressId()));
+                for (int i = 0; i < mProfilesForBillingAddress.size(); ++i) {
+                    if (TextUtils.equals(mProfilesForBillingAddress.get(i).getGUID(),
+                            card.getBillingAddressId())) {
+                        instrument.completeInstrument(card, mProfilesForBillingAddress.get(i));
+                        break;
+                    }
+                }
                 callback.onResult(instrument);
             }
         });
@@ -325,14 +323,26 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
     }
 
     /**
-     * Adds the given billing address to the list of billing addresses. If the address is already
-     * known, then updates the existing address. Should be called before opening the card editor.
+     * Adds the given billing address to the list of billing addresses, if it's complete. If the
+     * address is already known, then updates the existing address. Should be called before opening
+     * the card editor.
      *
-     * @param billingAddress The billing address to add or update. Should not be null. Should be
-     *                       complete.
+     * @param billingAddress The billing address to add or update. Should not be null.
      */
-    public void updateBillingAddress(AutofillAddress billingAddress) {
-        mProfilesForBillingAddress.put(billingAddress.getIdentifier(), billingAddress.getProfile());
+    public void updateBillingAddressIfComplete(AutofillAddress billingAddress) {
+        if (!billingAddress.isComplete()) return;
+
+        for (int i = 0; i < mProfilesForBillingAddress.size(); ++i) {
+            if (TextUtils.equals(mProfilesForBillingAddress.get(i).getGUID(),
+                        billingAddress.getIdentifier())) {
+                mProfilesForBillingAddress.set(i, billingAddress.getProfile());
+                return;
+            }
+        }
+
+        // No matching profile was found. Add the new profile at the top of the list.
+        billingAddress.setBillingAddressLabel();
+        mProfilesForBillingAddress.add(0, new AutofillProfile(billingAddress.getProfile()));
     }
 
     /**
@@ -370,8 +380,8 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
         if (mNumberField == null) {
             mNumberField = EditorFieldModel.createTextInput(
                     EditorFieldModel.INPUT_TYPE_HINT_CREDIT_CARD,
-                    mContext.getString(R.string.autofill_credit_card_editor_number),
-                    null, mCardNumberValidator,
+                    mContext.getString(R.string.autofill_credit_card_editor_number), null,
+                    mCardNumberValidator, mCardIconGenerator,
                     mContext.getString(R.string.payments_field_required_validation_message),
                     mContext.getString(R.string.payments_card_number_invalid_validation_message),
                     null);
@@ -394,9 +404,9 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
         if (mNameField == null) {
             mNameField = EditorFieldModel.createTextInput(
                     EditorFieldModel.INPUT_TYPE_HINT_PERSON_NAME,
-                    mContext.getString(R.string.autofill_credit_card_editor_name), null, null,
-                    mContext.getString(R.string.payments_field_required_validation_message),
-                    null, null);
+                    mContext.getString(R.string.autofill_credit_card_editor_name), null, null, null,
+                    mContext.getString(R.string.payments_field_required_validation_message), null,
+                    null);
         }
         mNameField.setValue(card.getName());
         editor.addField(mNameField);
@@ -450,7 +460,8 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
         // Expiration year dropdown is side-by-side with the expiration year dropdown. The dropdown
         // should include the card's expiration year, so it's not cached.
         mYearField = EditorFieldModel.createDropdown(
-                null /* label */, buildYearDropdownKeyValues(calendar, card.getYear()));
+                null /* label */, buildYearDropdownKeyValues(calendar, card.getYear()),
+                null /* hint */);
         mYearField.setIsFullLine(false);
         if (mYearField.getDropdownKeys().contains(card.getYear())) {
             mYearField.setValue(card.getYear());
@@ -511,23 +522,20 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
      */
     private void addBillingAddressDropdown(EditorModel editor, final CreditCard card) {
         final List<DropdownKeyValue> billingAddresses = new ArrayList<>();
-        billingAddresses.add(new DropdownKeyValue(BILLING_ADDRESS_NONE,
-                mContext.getString(R.string.select)));
 
-        for (Map.Entry<String, AutofillProfile> address : mProfilesForBillingAddress.entrySet()) {
-            // Key is profile GUID. Value is profile label.
-            billingAddresses.add(
-                    new DropdownKeyValue(address.getKey(), address.getValue().getLabel()));
+        for (int i = 0; i < mProfilesForBillingAddress.size(); ++i) {
+            billingAddresses.add(new DropdownKeyValue(mProfilesForBillingAddress.get(i).getGUID(),
+                    mProfilesForBillingAddress.get(i).getLabel()));
         }
 
         billingAddresses.add(new DropdownKeyValue(BILLING_ADDRESS_ADD_NEW,
                 mContext.getString(R.string.autofill_create_profile)));
 
         // Don't cache the billing address dropdown, because the user may have added or removed
-        // profiles.
+        // profiles. Also pass the "Select" dropdown item as a hint to the dropdown constructor.
         mBillingAddressField = EditorFieldModel.createDropdown(
                 mContext.getString(R.string.autofill_credit_card_editor_billing_address),
-                billingAddresses);
+                billingAddresses, mContext.getString(R.string.select));
 
         // The billing address is required.
         mBillingAddressField.setRequiredErrorMessage(
@@ -550,12 +558,15 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
                             // User has cancelled the address editor.
                             mBillingAddressField.setValue(null);
                         } else {
+                            // Set the billing address label.
+                            billingAddress.setBillingAddressLabel();
+
                             // User has added a new complete address. Add it to the top of the
-                            // dropdown, under the "Select" prompt.
-                            mProfilesForBillingAddress.put(
-                                    billingAddress.getIdentifier(), billingAddress.getProfile());
-                            billingAddresses.add(1, new DropdownKeyValue(
-                                    billingAddress.getIdentifier(), billingAddress.getSublabel()));
+                            // dropdown.
+                            mProfilesForBillingAddress.add(billingAddress.getProfile());
+                            billingAddresses.add(
+                                    0, new DropdownKeyValue(billingAddress.getIdentifier(),
+                                               billingAddress.getSublabel()));
                             mBillingAddressField.setDropdownKeyValues(billingAddresses);
                             mBillingAddressField.setValue(billingAddress.getIdentifier());
                         }
@@ -578,9 +589,9 @@ public class CardEditor extends EditorBase<AutofillPaymentInstrument>
     private void addSaveCardCheckbox(EditorModel editor) {
         if (mSaveCardCheckbox == null) {
             mSaveCardCheckbox = EditorFieldModel.createCheckbox(
-                    mContext.getString(R.string.payments_save_card_to_device_checkbox));
+                    mContext.getString(R.string.payments_save_card_to_device_checkbox),
+                    CHECK_SAVE_CARD_TO_DEVICE);
         }
-        mSaveCardCheckbox.setIsChecked(true);
         editor.addField(mSaveCardCheckbox);
     }
 
