@@ -8,15 +8,22 @@ import android.content.Context;
 import android.content.res.Resources;
 import android.graphics.Color;
 import android.graphics.Typeface;
+import android.graphics.drawable.Drawable;
+import android.os.Handler;
+import android.support.v4.view.animation.LinearOutSlowInInterpolator;
 import android.text.SpannableStringBuilder;
 import android.text.TextUtils;
 import android.text.TextUtils.TruncateAt;
+import android.text.style.AbsoluteSizeSpan;
+import android.text.style.ForegroundColorSpan;
 import android.text.style.StyleSpan;
 import android.view.Gravity;
 import android.view.LayoutInflater;
 import android.view.MotionEvent;
 import android.view.View;
 import android.view.ViewGroup;
+import android.view.animation.AlphaAnimation;
+import android.view.animation.Animation;
 import android.widget.Button;
 import android.widget.GridLayout;
 import android.widget.ImageButton;
@@ -77,6 +84,9 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
          */
         void onPaymentOptionChanged(PaymentRequestSection section, PaymentOption option);
 
+        /** Called when the user clicks the edit icon of the selected PaymentOption. */
+        void onEditPaymentOption(PaymentRequestSection section, PaymentOption option);
+
         /** Called when the user requests adding a new PaymentOption to a given section. */
         void onAddPaymentOption(PaymentRequestSection section);
 
@@ -135,7 +145,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
     private TextView mSummaryLeftTextView;
     private TextView mSummaryRightTextView;
 
-    private int mLogoResourceId;
+    private Drawable mLogo;
     private boolean mIsSummaryAllowed = true;
 
     /**
@@ -173,12 +183,24 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
     /**
      * Sets what logo should be displayed.
      *
-     * @param resourceId ID of the logo to display.
+     * @param logo The logo to display.
      */
-    protected void setLogoResource(int resourceId) {
+    protected void setLogoDrawable(Drawable logo) {
         assert isLogoNecessary();
-        mLogoResourceId = resourceId;
-        mLogoView.setImageResource(resourceId);
+        mLogo = logo;
+        mLogoView.setImageDrawable(mLogo);
+    }
+
+    /** Returns the LinearLayout containing the summary texts of the section. */
+    protected LinearLayout getSummaryLayout() {
+        assert mSummaryLayout != null;
+        return mSummaryLayout;
+    }
+
+    /** Returns the right summary TextView. */
+    protected TextView getSummaryRightTextView() {
+        assert mSummaryRightTextView != null;
+        return mSummaryRightTextView;
     }
 
     @Override
@@ -242,8 +264,10 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
     /**
      * Sets how the summary text should be displayed.
      *
-     * @param leftTruncate How to truncate the left summary text.  Set to null to clear.
-     * @param rightTruncate How to truncate the right summary text.  Set to null to clear.
+     * @param leftTruncate      How to truncate the left summary text.  Set to null to clear.
+     * @param leftIsSingleLine  Whether the left summary text should be a single line.
+     * @param rightTruncate     How to truncate the right summary text.  Set to null to clear.
+     * @param rightIsSingleLine Whether the right summary text should be a single line.
      */
     public void setSummaryProperties(@Nullable TruncateAt leftTruncate, boolean leftIsSingleLine,
             @Nullable TruncateAt rightTruncate, boolean rightIsSingleLine) {
@@ -411,7 +435,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
 
         // Update whether the logo is displayed.
         if (mLogoView != null) {
-            boolean show = mLogoResourceId != 0 && mDisplayMode != DISPLAY_MODE_FOCUSED;
+            boolean show = mLogo != null && mDisplayMode != DISPLAY_MODE_FOCUSED;
             mLogoView.setVisibility(show ? VISIBLE : GONE);
         }
 
@@ -456,44 +480,73 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
     }
 
     /**
-     * Section with a secondary TextView beneath the summary to show additional details.
+     * Section with three extra TextViews beneath the summary to show additional details.
      *
      * ............................................................................
-     * . TITLE                                                          | CHEVRON .
+     * . TITLE                                                          |         .
+     * .................................................................|         .
+     * . LEFT SUMMARY TEXT                        |  RIGHT SUMMARY TEXT | CHEVRON .
      * .................................................................|    or   .
-     * . LEFT SUMMARY TEXT                        |  RIGHT SUMMARY TEXT |   ADD   .
+     * . EXTRA TEXT ONE                                                 |   ADD   .
      * .................................................................|    or   .
-     * . EXTRA TEXT                                                     |  SELECT .
+     * . EXTRA TEXT TWO                                                 |  SELECT .
+     * .................................................................|         .
+     * . EXTRA TEXT THREE                                               |         .
      * ............................................................................
      */
-    public static class ExtraTextSection extends PaymentRequestSection {
-        private TextView mExtraTextView;
+    public static class ExtraTextsSection extends PaymentRequestSection {
+        private TextView[] mExtraTextViews;
         private int mEditButtonState = EDIT_BUTTON_GONE;
 
-        public ExtraTextSection(Context context, String sectionName, SectionDelegate delegate) {
+        public ExtraTextsSection(Context context, String sectionName, SectionDelegate delegate) {
             super(context, sectionName, delegate);
-            setExtraText(null);
+            setExtraTexts(new String[] {null, null, null});
         }
 
         @Override
         protected void createMainSectionContent(LinearLayout mainSectionLayout) {
             Context context = mainSectionLayout.getContext();
 
-            mExtraTextView = new TextView(context);
-            ApiCompatibilityUtils.setTextAppearance(
-                    mExtraTextView, R.style.PaymentsUiSectionDescriptiveTextEndAligned);
-            mainSectionLayout.addView(mExtraTextView, new LinearLayout.LayoutParams(
-                    LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
+            mExtraTextViews = new TextView[3];
+            for (int i = 0; i < mExtraTextViews.length; i++) {
+                mExtraTextViews[i] = new TextView(context);
+                ApiCompatibilityUtils.setTextAppearance(
+                        mExtraTextViews[i], R.style.PaymentsUiSectionDefaultText);
+                mainSectionLayout.addView(
+                        mExtraTextViews[i], new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT,
+                                                    LayoutParams.WRAP_CONTENT));
+            }
         }
 
         /**
-         * Sets the CharSequence that is displayed in the secondary TextView.
+         * Sets the CharSequences that are displayed in the extra TextViews.
          *
-         * @param text Text to display.
+         * @param extraTexts Texts to display in the extra TextViews.
          */
-        public void setExtraText(CharSequence text) {
-            mExtraTextView.setText(text);
-            mExtraTextView.setVisibility(TextUtils.isEmpty(text) ? GONE : VISIBLE);
+        public void setExtraTexts(CharSequence[] extraTexts) {
+            assert extraTexts.length == mExtraTextViews.length;
+
+            for (int i = 0; i < mExtraTextViews.length; i++) {
+                mExtraTextViews[i].setText(extraTexts[i]);
+                mExtraTextViews[i].setVisibility(TextUtils.isEmpty(extraTexts[i]) ? GONE : VISIBLE);
+            }
+        }
+
+        /**
+         * Sets how the extra texts should be displayed.
+         *
+         * @param textsTruncate How to truncate the extra texts. Set the element to null to clear.
+         * @param textsAreSingleLine Whether the extra texts should be displayed in a single line.
+         */
+        public void setExtraTextsProperties(
+                TruncateAt[] textsTruncate, boolean[] textsAreSingleLine) {
+            assert textsTruncate.length == mExtraTextViews.length;
+            assert textsAreSingleLine.length == mExtraTextViews.length;
+
+            for (int i = 0; i < mExtraTextViews.length; i++) {
+                mExtraTextViews[i].setEllipsize(textsTruncate[i]);
+                mExtraTextViews[i].setSingleLine(textsAreSingleLine[i]);
+            }
         }
 
         /** Sets the state of the edit button. */
@@ -519,7 +572,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
      * ............................................................................
      * . TITLE                                                          |         .
      * .................................................................| CHERVON .
-     * . LEFT SUMMARY TEXT                        |  RIGHT SUMMARY TEXT |    or   .
+     * . LEFT SUMMARY TEXT          | UPDATE TEXT |  RIGHT SUMMARY TEXT |    or   .
      * .................................................................|   ADD   .
      * .                                      | Line item 1 |    $13.99 |    or   .
      * .                                      | Line item 2 |      $.99 |  SELECT .
@@ -527,17 +580,54 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
      * ............................................................................
      */
     public static class LineItemBreakdownSection extends PaymentRequestSection {
+        /** The duration of the animation to show and hide the update text. */
+        static final int UPDATE_TEXT_ANIMATION_DURATION_MS = 500;
+
+        /** The amount of time where the update text is visible before fading out. */
+        static final int UPDATE_TEXT_VISIBILITY_DURATION_MS = 5000;
+
+        /** The GridLayout that shows a breakdown of all the items in the user's card. */
         private GridLayout mBreakdownLayout;
 
+        /**
+         * The TextView that is used to display the updated message to the user when the total price
+         * of their cart changes. It's the second child of the mSummaryLayout.
+         */
+        private TextView mUpdatedView;
+
+        /** The runnable used to fade out the mUpdatedView. */
+        private Runnable mFadeOutRunnable = new Runnable() {
+            @Override
+            public void run() {
+                Animation out = new AlphaAnimation(mUpdatedView.getAlpha(), 0.0f);
+                out.setDuration(UPDATE_TEXT_ANIMATION_DURATION_MS);
+                out.setInterpolator(new LinearOutSlowInInterpolator());
+                out.setFillAfter(true);
+                mUpdatedView.startAnimation(out);
+            }
+        };
+
+        /** The Handler used to post the mFadeOutRunnables. */
+        private Handler mHandler = new Handler();
+
         public LineItemBreakdownSection(
-                Context context, String sectionName, SectionDelegate delegate) {
+                Context context, String sectionName, SectionDelegate delegate, String updatedText) {
             super(context, sectionName, delegate);
+
+            // The mUpdatedView should have been created in the base constructor's call to
+            // createMainSectionContent(...).
+            assert mUpdatedView != null;
+            mUpdatedView.setText(updatedText);
         }
 
+        // This method is called in PaymentRequestSection's constructor.
         @Override
         protected void createMainSectionContent(LinearLayout mainSectionLayout) {
             Context context = mainSectionLayout.getContext();
 
+            // Add a label that will be used to indicate that the total cart price has been updated.
+            addUpdateText(mainSectionLayout);
+
             // The breakdown is represented by an end-aligned GridLayout that takes up only as much
             // space as it needs.  The GridLayout ensures a consistent margin between the columns.
             mBreakdownLayout = new GridLayout(context);
@@ -548,6 +638,38 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             mainSectionLayout.addView(mBreakdownLayout, breakdownParams);
         }
 
+        /**
+         * Adds a text view to the summary layout that will be used to indicate that the total price
+         * of the card been updated. The text to display should be set later in the constructor.
+         *
+         * @param mainSectionLayout The layout of this section.
+         */
+        private void addUpdateText(LinearLayout mainSectionLayout) {
+            assert mUpdatedView == null;
+
+            Context context = mainSectionLayout.getContext();
+
+            // Create the view and set the text appearance and layout parameters.
+            mUpdatedView = new TextView(context);
+            ApiCompatibilityUtils.setTextAppearance(
+                    mUpdatedView, R.style.PaymentsUiSectionDefaultText);
+            LinearLayout.LayoutParams updatedLayoutParams = new LinearLayout.LayoutParams(
+                    LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
+            ApiCompatibilityUtils.setTextAlignment(mUpdatedView, TEXT_ALIGNMENT_TEXT_END);
+            mUpdatedView.setTextColor(ApiCompatibilityUtils.getColor(
+                    context.getResources(), R.color.google_green_700));
+            ApiCompatibilityUtils.setMarginEnd(
+                    updatedLayoutParams, context.getResources().getDimensionPixelSize(
+                                                 R.dimen.payments_section_small_spacing));
+
+            // Set the view to initially be invisible.
+            mUpdatedView.setVisibility(View.INVISIBLE);
+
+            // Add the update text just before the last summary text.
+            getSummaryLayout().addView(
+                    mUpdatedView, getSummaryLayout().getChildCount() - 1, updatedLayoutParams);
+        }
+
         /**
          * Updates the total and how it's broken down.
          *
@@ -556,9 +678,14 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         public void update(ShoppingCart cart) {
             Context context = mBreakdownLayout.getContext();
 
+            CharSequence totalPrice = createValueString(
+                    cart.getTotal().getCurrency(), cart.getTotal().getPrice(), true);
+
+            // Show the updated text view if the total changed.
+            showUpdateIfTextChanged(totalPrice);
+
             // Update the summary to display information about the total.
-            setSummaryText(cart.getTotal().getLabel(), createValueString(
-                    cart.getTotal().getCurrency(), cart.getTotal().getPrice(), true));
+            setSummaryText(cart.getTotal().getLabel(), totalPrice);
 
             mBreakdownLayout.removeAllViews();
             if (cart.getContents() == null) return;
@@ -573,8 +700,9 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 LineItem item = cart.getContents().get(i);
 
                 TextView description = new TextView(context);
-                ApiCompatibilityUtils.setTextAppearance(
-                        description, R.style.PaymentsUiSectionDescriptiveTextEndAligned);
+                ApiCompatibilityUtils.setTextAppearance(description, item.getIsPending()
+                                ? R.style.PaymentsUiSectionPendingTextEndAligned
+                                : R.style.PaymentsUiSectionDescriptiveTextEndAligned);
                 description.setText(item.getLabel());
                 description.setEllipsize(TruncateAt.END);
                 description.setMaxLines(2);
@@ -583,8 +711,9 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 }
 
                 TextView amount = new TextView(context);
-                ApiCompatibilityUtils.setTextAppearance(
-                        amount, R.style.PaymentsUiSectionDescriptiveTextEndAligned);
+                ApiCompatibilityUtils.setTextAppearance(amount, item.getIsPending()
+                                ? R.style.PaymentsUiSectionPendingTextEndAligned
+                                : R.style.PaymentsUiSectionDescriptiveTextEndAligned);
                 amount.setText(createValueString(item.getCurrency(), item.getPrice(), false));
 
                 // Each item is represented by a row in the GridLayout.
@@ -603,6 +732,42 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             }
         }
 
+        /**
+         * Show the update text if the cart total has changed. Should be called before changing the
+         * cart total because the old total is needed for comparison.
+         *
+         * @param rightText The new cart total that will replace the one currently displayed.
+         */
+        private void showUpdateIfTextChanged(@Nullable CharSequence rightText) {
+            // If either the old or new text was null do nothing.
+            if (rightText == null || getSummaryRightTextView().getText() == null) return;
+
+            // Show the update text only if the current and new cart totals are different and if the
+            // old total was visible to the user.
+            if (!TextUtils.equals(getSummaryRightTextView().getText(), rightText)
+                    && getSummaryRightTextView().getVisibility() == VISIBLE) {
+                startUpdateViewAnimation();
+            }
+        }
+
+        /**
+         * Starts the animation to make the update text view fade in then fade out.
+         */
+        private void startUpdateViewAnimation() {
+            // Create and start a fade in anmiation for the mUpdatedView. Re-use the current alpha
+            // to avoid restarting a previous or current fade in animation.
+            Animation in = new AlphaAnimation(mUpdatedView.getAlpha(), 1.0f);
+            in.setDuration(UPDATE_TEXT_ANIMATION_DURATION_MS);
+            in.setInterpolator(new LinearOutSlowInInterpolator());
+            in.setFillAfter(true);
+            mUpdatedView.startAnimation(in);
+
+            // Cancel all pending fade out animations and create a new on to be executed a little
+            // while after the fade in.
+            mHandler.removeCallbacks(mFadeOutRunnable);
+            mHandler.postDelayed(mFadeOutRunnable, UPDATE_TEXT_VISIBILITY_DURATION_MS);
+        }
+
         /**
          * Builds a CharSequence that displays a value in a particular currency.
          *
@@ -654,9 +819,9 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
      * .................................................................|                | CHEVRON .
      * . Descriptive text that spans all three columns because it can.  |                |    or   .
      * . ! Warning text that displays a big scary warning and icon.     |           LOGO |   ADD   .
-     * . O Option 1                                              ICON 1 |                |    or   .
-     * . O Option 2                                              ICON 2 |                |  SELECT .
-     * . O Option 3                                              ICON 3 |                |         .
+     * . O Option 1                                  ICON 1 | Edit Icon |                |    or   .
+     * . O Option 2                                  ICON 2 | Edit Icon |                |  SELECT .
+     * . O Option 3                                  ICON 3 | Edit Icon |                |         .
      * . + ADD THING                                                    |                |         .
      * .............................................................................................
      */
@@ -667,6 +832,19 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         private final List<TextView> mLabelsForTest = new ArrayList<>();
         private boolean mCanAddItems = true;
 
+        /**
+         * Observer to be notified when the OptionSection changes focus state.
+         */
+        public interface FocusChangedObserver {
+            /*
+             * Called when the OptionSection view gets or loses focus.
+             *
+             * @param dataType  The type of the data contained in the section.
+             * @param willFocus Whether the section is getting the focus.
+             */
+            void onFocusChanged(@PaymentRequestUI.DataType int dataType, boolean willFocus);
+        }
+
         /**
          * Displays a row representing either a selectable option or some flavor text.
          *
@@ -674,6 +852,8 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
          *   row type.
          * + The "label" is text describing the row.
          * + The "icon" is a logo representing the option, like a credit card.
+         * + The "edit icon" is a pencil icon with a vertical separator to indicate the option is
+         *   editable, clicking on it brings up corresponding editor.
          */
         public class OptionRow {
             private static final int OPTION_ROW_TYPE_OPTION = 0;
@@ -685,17 +865,21 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             private final PaymentOption mOption;
             private final View mButton;
             private final TextView mLabel;
-            private final View mIcon;
+            private final View mOptionIcon;
+            private final View mEditIcon;
 
             public OptionRow(GridLayout parent, int rowIndex, int rowType, PaymentOption item,
                     boolean isSelected) {
-                boolean iconExists = item != null && item.getDrawableIconId() != 0;
+                boolean optionIconExists = item != null && item.getDrawableIcon() != null;
+                boolean editIconExists = item != null && item.isEditable() && isSelected;
                 boolean isEnabled = item != null && item.isValid();
                 mRowType = rowType;
                 mOption = item;
                 mButton = createButton(parent, rowIndex, isSelected, isEnabled);
-                mLabel = createLabel(parent, rowIndex, iconExists, isEnabled);
-                mIcon = iconExists ? createIcon(parent, rowIndex) : null;
+                mLabel = createLabel(parent, rowIndex, optionIconExists, editIconExists, isEnabled);
+                mOptionIcon = optionIconExists
+                        ? createOptionIcon(parent, rowIndex, editIconExists) : null;
+                mEditIcon = editIconExists ? createEditIcon(parent, rowIndex) : null;
             }
 
             /** Sets the selected state of this item, alerting the delegate if selected. */
@@ -709,6 +893,11 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 }
             }
 
+            /** Returns whether this OptionRow's RadioButton is checked. */
+            public boolean isChecked() {
+                return ((RadioButton) mButton).isChecked();
+            }
+
             /** Change the label for the row. */
             public void setLabel(int stringId) {
                 setLabel(getContext().getString(stringId));
@@ -777,17 +966,20 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 return view;
             }
 
-            private TextView createLabel(
-                    GridLayout parent, int rowIndex, boolean iconExists, boolean isEnabled) {
+            private TextView createLabel(GridLayout parent, int rowIndex, boolean optionIconExists,
+                    boolean editIconExists, boolean isEnabled) {
                 Context context = parent.getContext();
                 Resources resources = context.getResources();
 
                 // By default, the label appears to the right of the "button" in the second column.
-                // + If there is no button and no icon, the label spans the whole row.
-                // + If there is no icon, the label spans two columns.
+                // + If there is no button, no option and edit icon, the label spans the whole row.
+                // + If there is no option and edit icon, the label spans three columns.
+                // + If there is no edit icon or option icon, the label spans two columns.
                 // + Otherwise, the label occupies only its own column.
                 int columnStart = 1;
-                int columnSpan = iconExists ? 1 : 2;
+                int columnSpan = 1;
+                if (!optionIconExists) columnSpan++;
+                if (!editIconExists) columnSpan++;
 
                 TextView labelView = new TextView(context);
                 if (mRowType == OPTION_ROW_TYPE_OPTION) {
@@ -795,8 +987,9 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                     ApiCompatibilityUtils.setTextAppearance(labelView, isEnabled
                             ? R.style.PaymentsUiSectionDefaultText
                             : R.style.PaymentsUiSectionDisabledText);
-                    labelView.setText(convertOptionToString(
-                            mOption, mDelegate.isBoldLabelNeeded(OptionSection.this)));
+                    labelView.setText(convertOptionToString(mOption,
+                            mDelegate.isBoldLabelNeeded(OptionSection.this),
+                            false /* singleLine */));
                     labelView.setEnabled(isEnabled);
                 } else if (mRowType == OPTION_ROW_TYPE_ADD) {
                     // Shows string saying that the user can add a new option, e.g. credit card no.
@@ -813,47 +1006,70 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 } else if (mRowType == OPTION_ROW_TYPE_DESCRIPTION) {
                     // The description spans all the columns.
                     columnStart = 0;
-                    columnSpan = 3;
+                    columnSpan = 4;
 
                     ApiCompatibilityUtils.setTextAppearance(
                             labelView, R.style.PaymentsUiSectionDescriptiveText);
                 } else if (mRowType == OPTION_ROW_TYPE_WARNING) {
-                    // Warnings use two columns.
-                    columnSpan = 2;
+                    // Warnings use three columns.
+                    columnSpan = 3;
                     ApiCompatibilityUtils.setTextAppearance(
                             labelView, R.style.PaymentsUiSectionWarningText);
                 }
 
-                // The label spans two columns if no icon exists.  Setting the view width to 0
-                // forces it to stretch.
+                // The label spans two columns if no option or edit icon, or spans three columns if
+                // no option and edit icons. Setting the view width to 0 forces it to stretch.
                 GridLayout.LayoutParams labelParams = new GridLayout.LayoutParams(
                         GridLayout.spec(rowIndex, 1, GridLayout.CENTER),
                         GridLayout.spec(columnStart, columnSpan, GridLayout.FILL));
                 labelParams.topMargin = mVerticalMargin;
                 labelParams.width = 0;
+                if (optionIconExists) {
+                    // Margin at the end of the label instead of the start of the option icon to
+                    // allow option icon in the the next row align with the end of label (include
+                    // end margin) when edit icon exits in that row, like below:
+                    // ---Label---------------------[label margin]|---option icon---|
+                    // ---Label---[label margin]|---option icon---|----edit icon----|
+                    ApiCompatibilityUtils.setMarginEnd(labelParams, mLargeSpacing);
+                }
                 parent.addView(labelView, labelParams);
 
                 labelView.setOnClickListener(OptionSection.this);
                 return labelView;
             }
 
-            private View createIcon(GridLayout parent, int rowIndex) {
+            private View createOptionIcon(GridLayout parent, int rowIndex, boolean editIconExists) {
                 // The icon has a pre-defined width.
-                ImageView icon = new ImageView(parent.getContext());
-                icon.setImportantForAccessibility(IMPORTANT_FOR_ACCESSIBILITY_NO);
-                icon.setBackgroundResource(R.drawable.payments_ui_logo_bg);
-                icon.setImageResource(mOption.getDrawableIconId());
-                icon.setMaxWidth(mIconMaxWidth);
+                ImageView optionIcon = new ImageView(parent.getContext());
+                optionIcon.setImportantForAccessibility(IMPORTANT_FOR_ACCESSIBILITY_NO);
+                optionIcon.setBackgroundResource(R.drawable.payments_ui_logo_bg);
+                optionIcon.setImageDrawable(mOption.getDrawableIcon());
+                optionIcon.setMaxWidth(mIconMaxWidth);
+
+                // Place option icon at column three if no edit icon.
+                int columnStart = editIconExists ? 2 : 3;
+                GridLayout.LayoutParams iconParams = new GridLayout.LayoutParams(
+                        GridLayout.spec(rowIndex, 1, GridLayout.CENTER),
+                        GridLayout.spec(columnStart, 1));
+                iconParams.topMargin = mVerticalMargin;
+                parent.addView(optionIcon, iconParams);
+
+                optionIcon.setOnClickListener(OptionSection.this);
+                return optionIcon;
+            }
+
+            private View createEditIcon(GridLayout parent, int rowIndex) {
+                View editorIcon = LayoutInflater.from(parent.getContext())
+                                          .inflate(R.layout.payment_option_edit_icon, null);
 
                 // The icon floats to the right of everything.
                 GridLayout.LayoutParams iconParams = new GridLayout.LayoutParams(
-                        GridLayout.spec(rowIndex, 1, GridLayout.CENTER), GridLayout.spec(2, 1));
+                        GridLayout.spec(rowIndex, 1, GridLayout.CENTER), GridLayout.spec(3, 1));
                 iconParams.topMargin = mVerticalMargin;
-                ApiCompatibilityUtils.setMarginStart(iconParams, mLargeSpacing);
-                parent.addView(icon, iconParams);
+                parent.addView(editorIcon, iconParams);
 
-                icon.setOnClickListener(OptionSection.this);
-                return icon;
+                editorIcon.setOnClickListener(OptionSection.this);
+                return editorIcon;
             }
         }
 
@@ -875,6 +1091,11 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         /** SectionInformation that is used to populate the views in this section. */
         private SectionInformation mSectionInformation;
 
+        /** Indicates whether the summary should be a single line. */
+        private boolean mSummaryInSingleLine = false;
+
+        private FocusChangedObserver mFocusChangedObserver;
+
         /**
          * Constructs an OptionSection.
          *
@@ -891,23 +1112,38 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             setSummaryText(null, null);
         }
 
+        /**
+         * Registers the delegate to be notified when this OptionSection gains or loses focus.
+         *
+         * @param delegate The delegate to notify.
+         */
+        public void setOptionSectionFocusChangedObserver(FocusChangedObserver observer) {
+            mFocusChangedObserver = observer;
+        }
+
         @Override
         public void handleClick(View v) {
-            // Handle click on the "ADD THING" button.
             for (int i = 0; i < mOptionRows.size(); i++) {
                 OptionRow row = mOptionRows.get(i);
-                boolean wasClicked = row.mButton == v || row.mLabel == v || row.mIcon == v;
-                if (row.mOption == null && wasClicked) {
+                boolean clickedSelect = row.mButton == v || row.mLabel == v || row.mOptionIcon == v;
+                // Handle click on the "ADD THING" button.
+                if (row.mOption == null && clickedSelect) {
                     mDelegate.onAddPaymentOption(this);
                     return;
                 }
+
+                // Handle click on the edit icon.
+                if (row.mOption != null && row.mEditIcon == v) {
+                    mDelegate.onEditPaymentOption(this, row.mOption);
+                    return;
+                }
             }
 
             // Update the radio button state: checked/unchecked.
             for (int i = 0; i < mOptionRows.size(); i++) {
                 OptionRow row = mOptionRows.get(i);
-                boolean wasClicked = row.mButton == v || row.mLabel == v || row.mIcon == v;
-                if (row.mOption != null) row.setChecked(wasClicked);
+                boolean clickedSelect = row.mButton == v || row.mLabel == v || row.mOptionIcon == v;
+                if (row.mOption != null) row.setChecked(clickedSelect);
             }
         }
 
@@ -920,6 +1156,12 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 return;
             }
 
+            // Notify the observer that the focus is going to change.
+            if (mFocusChangedObserver != null) {
+                mFocusChangedObserver.onFocusChanged(
+                        mSectionInformation.getDataType(), shouldFocus);
+            }
+
             super.focusSection(shouldFocus);
         }
 
@@ -928,13 +1170,27 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             return true;
         }
 
+        @Override
+        public void setSummaryProperties(@Nullable TruncateAt leftTruncate,
+                boolean leftIsSingleLine, @Nullable TruncateAt rightTruncate,
+                boolean rightIsSingleLine) {
+            super.setSummaryProperties(
+                    leftTruncate, leftIsSingleLine, rightTruncate, rightIsSingleLine);
+
+            // Updates the summary if necessary after properties are changed.
+            mSummaryInSingleLine = leftIsSingleLine;
+            if (mSectionInformation != null) {
+                updateSelectedItem(mSectionInformation.getSelectedItem());
+            }
+        }
+
         @Override
         protected void createMainSectionContent(LinearLayout mainSectionLayout) {
             Context context = mainSectionLayout.getContext();
             mCheckingProgress = createLoadingSpinner();
 
             mOptionLayout = new GridLayout(context);
-            mOptionLayout.setColumnCount(3);
+            mOptionLayout.setColumnCount(4);
             mainSectionLayout.addView(mOptionLayout, new LinearLayout.LayoutParams(
                     LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
         }
@@ -1024,12 +1280,15 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
 
         private void updateSelectedItem(PaymentOption selectedItem) {
             if (selectedItem == null) {
-                setLogoResource(0);
+                setLogoDrawable(null);
                 setIsSummaryAllowed(false);
                 setSummaryText(null, null);
             } else {
-                setLogoResource(selectedItem.getDrawableIconId());
-                setSummaryText(convertOptionToString(selectedItem, false), null);
+                setLogoDrawable(selectedItem.getDrawableIcon());
+                setSummaryText(
+                        convertOptionToString(selectedItem, false /* useBoldLabel */,
+                                mSummaryInSingleLine),
+                        null);
             }
 
             updateControlLayout();
@@ -1084,23 +1343,39 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             }
         }
 
-        private CharSequence convertOptionToString(PaymentOption item, boolean useBoldLabel) {
+        private CharSequence convertOptionToString(
+                PaymentOption item, boolean useBoldLabel, boolean singleLine) {
             SpannableStringBuilder builder = new SpannableStringBuilder(item.getLabel());
+            String labelSeparator = singleLine
+                    ? getContext().getString(R.string.autofill_address_summary_separator)
+                    : "\n";
             if (useBoldLabel) {
                 builder.setSpan(
                         new StyleSpan(android.graphics.Typeface.BOLD), 0, builder.length(), 0);
             }
 
             if (!TextUtils.isEmpty(item.getSublabel())) {
-                if (builder.length() > 0) builder.append("\n");
+                if (builder.length() > 0) builder.append(labelSeparator);
                 builder.append(item.getSublabel());
             }
 
             if (!TextUtils.isEmpty(item.getTertiaryLabel())) {
-                if (builder.length() > 0) builder.append("\n");
+                if (builder.length() > 0) builder.append(labelSeparator);
                 builder.append(item.getTertiaryLabel());
             }
 
+            if (!item.isComplete() && !TextUtils.isEmpty(item.getEditMessage())) {
+                if (builder.length() > 0) builder.append(labelSeparator);
+                String editMessage = item.getEditMessage();
+                builder.append(editMessage);
+                Object foregroundSpanner = new ForegroundColorSpan(ApiCompatibilityUtils.getColor(
+                        getContext().getResources(), R.color.google_blue_700));
+                Object sizeSpanner = new AbsoluteSizeSpan(14, true);
+                int startIndex = builder.length() - editMessage.length();
+                builder.setSpan(foregroundSpanner, startIndex, builder.length(), 0);
+                builder.setSpan(sizeSpanner, startIndex, builder.length(), 0);
+            }
+
             return builder;
         }
 
