@@ -23,6 +23,7 @@ import android.os.Handler;
 import android.support.annotation.IntDef;
 import android.support.v4.view.animation.FastOutLinearInInterpolator;
 import android.support.v4.view.animation.LinearOutSlowInInterpolator;
+import android.text.TextUtils;
 import android.text.TextUtils.TruncateAt;
 import android.view.Gravity;
 import android.view.LayoutInflater;
@@ -454,7 +455,9 @@ public class PaymentRequestUI implements DialogInterface.OnDismissListener, View
                         // Let the summary display a SELECT/ADD button for the first subsection
                         // that needs it.
                         mShippingSummarySection.setSummaryText(null, null);
-                        mShippingSummarySection.setSummaryProperties(null, false, null, false);
+                        mShippingSummarySection.setSummaryProperties(null /* leftTruncate */,
+                                false /* leftIsSingleLine */, null /* rightTruncate */,
+                                false /* rightIsSingleLine */);
 
                         PaymentRequestSection section =
                                 mShippingAddressSection.getEditButtonState() == EDIT_BUTTON_GONE
@@ -463,8 +466,9 @@ public class PaymentRequestUI implements DialogInterface.OnDismissListener, View
                     } else {
                         // Show the shipping name in the summary section.
                         mShippingSummarySection.setSummaryText(selectedShippingName, null);
-                        mShippingSummarySection.setSummaryProperties(
-                                TruncateAt.END, true, null, false);
+                        mShippingSummarySection.setSummaryProperties(TruncateAt.END,
+                                true /* leftIsSingleLine */, null /* rightTruncate */,
+                                false /* rightIsSingleLine */);
 
                         // Show the shipping address, phone and option below the summary.
                         mShippingSummarySection.setExtraTexts(new String[] {selectedShippingAddress,
@@ -477,9 +481,17 @@ public class PaymentRequestUI implements DialogInterface.OnDismissListener, View
                 }
 
                 if (mRequestContactDetails) {
+                    // Sets the summary of the contact displays in a single line.
+                    mContactDetailsSection.setSummaryProperties(TruncateAt.END,
+                            true /* leftIsSingleLine */, null /* rightTruncate */,
+                            false /* rightIsSingleLine */);
                     updateSection(TYPE_CONTACT_DETAILS, result.getContactDetails());
                 }
 
+                // Sets the summary of the payment method displays in a single line.
+                mPaymentMethodSection.setSummaryProperties(TruncateAt.END,
+                        true /* leftIsSingleLine */, null /* rightTruncate */,
+                        false /* rightIsSingleLine */);
                 updateSection(TYPE_PAYMENT_METHODS, result.getPaymentMethods());
                 updatePayButtonEnabled();
 
@@ -936,6 +948,16 @@ public class PaymentRequestUI implements DialogInterface.OnDismissListener, View
                 && !mIsClientCheckingSelection;
     }
 
+    /**
+     * Sets the observer to be called when the shipping address section gains or loses focus.
+     *
+     * @param observer The observer to notify.
+     */
+    public void setShippingAddressSectionFocusChangedObserver(
+            OptionSection.FocusChangedObserver observer) {
+        mShippingAddressSection.setOptionSectionFocusChangedObserver(observer);
+    }
+
     private void expand(PaymentRequestSection section) {
         if (!mIsShowingEditDialog) {
             // Container now takes the full height of the screen, animating towards it.
@@ -975,6 +997,14 @@ public class PaymentRequestUI implements DialogInterface.OnDismissListener, View
             // Disable all but the first button.
             updateSectionButtons();
 
+            // Sets the summary of the payment method and contact displays in multiple lines.
+            mContactDetailsSection.setSummaryProperties(null /* leftTruncate */,
+                    false /* leftIsSingleLine */, null /* rightTruncate */,
+                    false /* rightIsSingleLine */);
+            mPaymentMethodSection.setSummaryProperties(null /* leftTruncate */,
+                    false /* leftIsSingleLine */, null /* rightTruncate */,
+                    false /* rightIsSingleLine */);
+
             mIsShowingEditDialog = true;
         }
 
@@ -1070,17 +1100,23 @@ public class PaymentRequestUI implements DialogInterface.OnDismissListener, View
 
     @Override
     public String getAdditionalText(PaymentRequestSection section) {
-        if (section == mShippingAddressSection) {
-            int selectedItemIndex = mShippingAddressSectionInformation.getSelectedItemIndex();
-            boolean isNecessary = selectedItemIndex == SectionInformation.NO_SELECTION
-                    || selectedItemIndex == SectionInformation.INVALID_SELECTION;
-            return isNecessary
-                    ? mContext.getString(selectedItemIndex == SectionInformation.NO_SELECTION
-                            ? mShippingStrings.getSelectPrompt()
-                            : mShippingStrings.getUnsupported())
-                    : null;
+        if (section != mShippingAddressSection) return null;
+
+        int selectedItemIndex = mShippingAddressSectionInformation.getSelectedItemIndex();
+        if (selectedItemIndex != SectionInformation.NO_SELECTION
+                && selectedItemIndex != SectionInformation.INVALID_SELECTION) {
+            return null;
         }
-        return null;
+
+        String customErrorMessage = mShippingAddressSectionInformation.getErrorMessage();
+        if (selectedItemIndex == SectionInformation.INVALID_SELECTION
+                && !TextUtils.isEmpty(customErrorMessage)) {
+            return customErrorMessage;
+        }
+
+        return mContext.getString(selectedItemIndex == SectionInformation.NO_SELECTION
+                        ? mShippingStrings.getSelectPrompt()
+                        : mShippingStrings.getUnsupported());
     }
 
     @Override
