@@ -30,6 +30,7 @@ public class SectionInformation {
     @PaymentRequestUI.DataType private final int mDataType;
     private ArrayList<PaymentOption> mItems;
     private int mSelectedItem;
+    public String mErrorMessage;
 
     /**
      * Builds an empty section without selection.
@@ -69,6 +70,15 @@ public class SectionInformation {
         }
     }
 
+    /**
+     * Returns the data type contained in this section.
+     *
+     * @return The data type contained in this section.
+     */
+    public int getDataType() {
+        return mDataType;
+    }
+
     /**
      * Returns whether the section is empty.
      *
@@ -173,4 +183,14 @@ public class SectionInformation {
         }
         return 0;
     }
+
+    /** @param msg The optional error message to display when the selection is invalid. */
+    public void setErrorMessage(String msg) {
+        mErrorMessage = msg;
+    }
+
+    /** @return The optional error message to display when the selection is invalid. */
+    public String getErrorMessage() {
+        return mErrorMessage;
+    }
 }
