@@ -401,7 +401,6 @@ class UrlManager {
         }
 
         // Read the cache.
-        mNearbyUrls.addAll(prefs.getStringSet(PREFS_NEARBY_URLS_KEY, new HashSet<String>()));
         for (String serializedUrl : prefs.getStringSet(PREFS_ALL_URLS_KEY, new HashSet<String>())) {
             try {
                 JSONObject jsonObject = new JSONObject(serializedUrl);
@@ -412,6 +411,8 @@ class UrlManager {
                 Log.e(TAG, "Could not deserialize UrlInfo", e);
             }
         }
+        mNearbyUrls.addAll(prefs.getStringSet(PREFS_NEARBY_URLS_KEY, new HashSet<String>()));
+        mNearbyUrls.retainAll(mUrlInfoMap.keySet());
         for (String serializedPwsResult : prefs.getStringSet(PREFS_PWS_RESULTS_KEY,
                 new HashSet<String>())) {
             try {
@@ -490,7 +491,12 @@ class UrlManager {
         } else {
             mUrlsSortedByTimestamp.remove(urlInfo.getUrl());
             currentUrlInfo.setScanTimestamp(urlInfo.getScanTimestamp());
-            currentUrlInfo.setDistance(urlInfo.getDistance());
+            if (urlInfo.getDistance() > 0.0) {
+                currentUrlInfo.setDistance(urlInfo.getDistance());
+            }
+            if (urlInfo.getDeviceAddress() != null) {
+                currentUrlInfo.setDeviceAddress(urlInfo.getDeviceAddress());
+            }
         }
         mUrlsSortedByTimestamp.add(urlInfo.getUrl());
         return currentUrlInfo;
@@ -693,6 +699,9 @@ class UrlManager {
                             @Override
                             public void onSuccess(boolean alreadyStarted) {
                                 mNativePhysicalWebDataSourceAndroid = nativeInit();
+                                for (UrlInfo urlInfo : getUrls()) {
+                                    safeNotifyNativeListenersOnFound(urlInfo.getUrl());
+                                }
                             }
 
                             @Override
