@@ -10,7 +10,7 @@ import org.chromium.base.Log;
 import org.chromium.base.ThreadUtils;
 import org.chromium.base.VisibleForTesting;
 import org.chromium.base.annotations.CalledByNative;
-import org.chromium.chrome.browser.preferences.privacy.PrivacyPreferencesManager;
+import org.chromium.chrome.browser.preferences.PrefServiceBridge;
 import org.chromium.chrome.browser.sync.ProfileSyncService;
 
 import java.util.EnumSet;
@@ -46,7 +46,7 @@ public abstract class PrecacheLauncher {
      */
     private boolean mCalled = false;
     private boolean mSyncInitialized = false;
-    private boolean mPrerenderEnabled = false;
+    private boolean mNetworkPredictionsAllowed = false;
     private boolean mShouldRun = false;
 
     /** Destroy the native PrecacheLauncher, releasing the memory that it was using. */
@@ -115,13 +115,15 @@ public abstract class PrecacheLauncher {
         // thread.
         ThreadUtils.assertOnUiThread();
 
-        boolean prerenderEnabled = PrivacyPreferencesManager.getInstance().shouldPrerender();
+        boolean networkPredictionEnabledPref =
+                PrefServiceBridge.getInstance().getNetworkPredictionEnabled();
         boolean shouldRun = nativeShouldRun();
 
-        mPrerenderEnabled = prerenderEnabled;
+        mNetworkPredictionsAllowed = networkPredictionEnabledPref;
         mShouldRun = shouldRun;
 
-        PrecacheController.setIsPrecachingEnabled(context, prerenderEnabled && shouldRun);
+        PrecacheController.setIsPrecachingEnabled(
+                context, networkPredictionEnabledPref && shouldRun);
         Log.v(TAG, "updateEnabledSync complete");
     }
 
@@ -144,7 +146,7 @@ public abstract class PrecacheLauncher {
                 if (mListener == null && sync != null) {
                     mListener = new ProfileSyncService.SyncStateChangedListener() {
                         public void syncStateChanged() {
-                            if (sync.isBackendInitialized()) {
+                            if (sync.isEngineInitialized()) {
                                 mSyncInitialized = true;
                                 updateEnabledSync(context);
                             }
@@ -154,7 +156,7 @@ public abstract class PrecacheLauncher {
                 }
 
                 if (mListener != null) {
-                    // Call the listener once, in case the sync backend is already initialized.
+                    // Call the listener once, in case the sync engine is already initialized.
                     mListener.syncStateChanged();
                 }
                 Log.v(TAG, "updateEnabled complete");
@@ -179,7 +181,7 @@ public abstract class PrecacheLauncher {
         EnumSet<FailureReason> reasons = EnumSet.noneOf(FailureReason.class);
         if (!mCalled) reasons.add(FailureReason.UPDATE_PRECACHING_ENABLED_NEVER_CALLED);
         if (!mSyncInitialized) reasons.add(FailureReason.SYNC_NOT_INITIALIZED);
-        if (!mPrerenderEnabled) {
+        if (!mNetworkPredictionsAllowed) {
             reasons.add(FailureReason.PRERENDER_PRIVACY_PREFERENCE_NOT_ENABLED);
         }
         if (!mShouldRun) reasons.add(FailureReason.NATIVE_SHOULD_RUN_IS_FALSE);
