@@ -126,12 +126,16 @@ public class AccountSigninView extends FrameLayout implements ProfileDownloader.
     }
 
     /**
-     * Initializes this view with profile images and full names.
+     * Initializes this view with profile data cache, delegate and listener.
      * @param profileData ProfileDataCache that will be used to call to retrieve user account info.
+     * @param delegate    The UI object creation delegate.
+     * @param listener    The account selection event listener.
      */
-    public void init(ProfileDataCache profileData) {
+    public void init(ProfileDataCache profileData, Delegate delegate, Listener listener) {
         mProfileData = profileData;
         mProfileData.setObserver(this);
+        mDelegate = delegate;
+        mListener = listener;
         showSigninPage();
     }
 
@@ -211,29 +215,18 @@ public class AccountSigninView extends FrameLayout implements ProfileDownloader.
         mNegativeButton.setEnabled(enabled);
     }
 
-    /**
-     * Set the account selection event listener.  See {@link Listener}
-     *
-     * @param listener The listener.
-     */
-    public void setListener(Listener listener) {
-        mListener = listener;
-    }
-
-    /**
-     * Set the UI object creation delegate. See {@link Delegate}
-     * @param delegate The delegate.
-     */
-    public void setDelegate(Delegate delegate) {
-        mDelegate = delegate;
-    }
-
     /**
      * Refresh the list of available system accounts.
      */
     private void updateAccounts() {
         if (mSignedIn || mProfileData == null) return;
 
+        if (!ExternalAuthUtils.getInstance().canUseGooglePlayServices(getContext(),
+                    new UserRecoverableErrorHandler.ModalDialog(mDelegate.getActivity()))) {
+            setUpSigninButton(false);
+            return;
+        }
+
         List<String> oldAccountNames = mAccountNames;
         mAccountNames = mAccountManagerHelper.getGoogleAccountNames();
         int accountToSelect = 0;
@@ -363,11 +356,6 @@ public class AccountSigninView extends FrameLayout implements ProfileDownloader.
     }
 
     private void showConfirmSigninPageAccountTrackerServiceCheck() {
-        if (!ExternalAuthUtils.getInstance().canUseGooglePlayServices(getContext(),
-                new UserRecoverableErrorHandler.ModalDialog(mDelegate.getActivity()))) {
-            return;
-        }
-
         // Disable the buttons to prevent them being clicked again while waiting for the callbacks.
         setButtonsEnabled(false);
 
@@ -442,6 +430,11 @@ public class AccountSigninView extends FrameLayout implements ProfileDownloader.
             mPositiveButton.setOnClickListener(new OnClickListener() {
                 @Override
                 public void onClick(View v) {
+                    if (!ExternalAuthUtils.getInstance().canUseGooglePlayServices(getContext(),
+                                new UserRecoverableErrorHandler.ModalDialog(
+                                        mDelegate.getActivity()))) {
+                        return;
+                    }
                     RecordUserAction.record("Signin_AddAccountToDevice");
                     mListener.onNewAccount();
                 }
