@@ -123,18 +123,10 @@ public class NavigationPopupTest extends ChromeActivityTestCaseBase<ChromeActivi
         public void reload(boolean checkForRepost) {
         }
 
-        @Override
-        public void reloadToRefreshContent(boolean checkForRepost) {
-        }
-
         @Override
         public void reloadBypassingCache(boolean checkForRepost) {
         }
 
-        @Override
-        public void reloadDisableLoFi(boolean checkForRepost) {
-        }
-
         @Override
         public void cancelPendingReload() {
         }
@@ -221,6 +213,14 @@ public class NavigationPopupTest extends ChromeActivityTestCaseBase<ChromeActivi
         @Override
         public void copyStateFromAndPrune(NavigationController source, boolean replaceEntry) {
         }
+
+        @Override
+        public String getEntryExtraData(int index, String key) {
+            return null;
+        }
+
+        @Override
+        public void setEntryExtraData(int index, String key, String value) {}
     }
 
     @MediumTest
