@@ -12,7 +12,6 @@ import android.content.Intent;
 import android.content.IntentFilter;
 import android.content.pm.PackageInfo;
 import android.graphics.Bitmap;
-import android.os.Environment;
 import android.test.mock.MockPackageManager;
 import android.test.suitebuilder.annotation.MediumTest;
 import android.test.suitebuilder.annotation.SmallTest;
@@ -128,7 +127,7 @@ public class AppBannerManagerTest extends ChromeTabbedActivityTestBase {
     }
 
     private static class TestDataStorageFactory extends WebappDataStorage.Factory {
-        public Bitmap mSplashImage;
+        public String mSplashImage;
 
         @Override
         public WebappDataStorage create(final String webappId) {
@@ -142,7 +141,7 @@ public class AppBannerManagerTest extends ChromeTabbedActivityTestBase {
             }
 
             @Override
-            public void updateSplashScreenImage(Bitmap splashScreenImage) {
+            public void updateSplashScreenImage(String splashScreenImage) {
                 assertNull(mSplashImage);
                 mSplashImage = splashScreenImage;
             }
@@ -194,14 +193,11 @@ public class AppBannerManagerTest extends ChromeTabbedActivityTestBase {
             }
         });
 
-        AppBannerManager.disableSecureSchemeCheckForTesting();
-
         // Navigations in this test are all of type ui::PAGE_TRANSITION_LINK, i.e. indirect.
         // Force indirect navigations to be worth the same as direct for testing.
         AppBannerManager.setEngagementWeights(1, 1);
 
-        mTestServer = EmbeddedTestServer.createAndStartFileServer(
-                getInstrumentation().getContext(), Environment.getExternalStorageDirectory());
+        mTestServer = EmbeddedTestServer.createAndStartServer(getInstrumentation().getContext());
         mNativeAppUrl = mTestServer.getURL(NATIVE_APP_PATH);
         mWebAppUrl = mTestServer.getURL(WEB_APP_PATH);
     }
@@ -306,7 +302,8 @@ public class AppBannerManagerTest extends ChromeTabbedActivityTestBase {
         });
     }
 
-    public void triggerWebAppBanner(String url, String expectedTitle) throws Exception {
+    public void triggerWebAppBanner(String url, String expectedTitle, boolean installApp)
+            throws Exception {
         // Visit the site in a new tab.
         loadUrlInNewTab("about:blank");
         new TabLoadObserver(getActivity().getActivityTab()).fullyLoadUrl(url);
@@ -320,6 +317,11 @@ public class AppBannerManagerTest extends ChromeTabbedActivityTestBase {
         });
         waitUntilNoInfoBarsExist();
 
+        // Add the animation listener in.
+        InfoBarContainer container = getActivity().getActivityTab().getInfoBarContainer();
+        final InfobarListener listener = new InfobarListener();
+        container.setAnimationListener(listener);
+
         // Indicate a day has passed, then revisit the page to show the banner.
         AppBannerManager.setTimeDeltaForTesting(1);
         new TabLoadObserver(getActivity().getActivityTab()).fullyLoadUrl(url);
@@ -331,6 +333,20 @@ public class AppBannerManagerTest extends ChromeTabbedActivityTestBase {
             }
         });
         waitUntilAppBannerInfoBarAppears(expectedTitle);
+
+        if (!installApp) return;
+
+        CriteriaHelper.pollUiThread(new Criteria() {
+            @Override
+            public boolean isSatisfied() {
+                return listener.mDoneAnimating;
+            }
+        });
+
+        // Click the button to trigger the adding of the shortcut.
+        InfoBar infobar = container.getInfoBarsForTesting().get(0);
+        final Button button = (Button) infobar.getView().findViewById(R.id.button_primary);
+        TouchCommon.singleClickView(button);
     }
 
     @SmallTest
@@ -466,7 +482,7 @@ public class AppBannerManagerTest extends ChromeTabbedActivityTestBase {
     @Feature({"AppBanners"})
     @RetryOnFailure
     public void testWebAppBannerAppears() throws Exception {
-        triggerWebAppBanner(mWebAppUrl, WEB_APP_TITLE);
+        triggerWebAppBanner(mWebAppUrl, WEB_APP_TITLE, false);
     }
 
     @SmallTest
@@ -475,7 +491,7 @@ public class AppBannerManagerTest extends ChromeTabbedActivityTestBase {
     public void testBannerFallsBackToShortName() throws Exception {
         triggerWebAppBanner(WebappTestPage.urlOfPageWithServiceWorkerAndManifest(
                                     mTestServer, WEB_APP_SHORT_TITLE_MANIFEST),
-                WEB_APP_SHORT_TITLE);
+                WEB_APP_SHORT_TITLE, false);
     }
 
     @SmallTest
@@ -486,47 +502,7 @@ public class AppBannerManagerTest extends ChromeTabbedActivityTestBase {
         final TestDataStorageFactory dataStorageFactory = new TestDataStorageFactory();
         WebappDataStorage.setFactoryForTests(dataStorageFactory);
 
-        // Visit the site in a new tab.
-        loadUrlInNewTab("about:blank");
-        new TabLoadObserver(getActivity().getActivityTab()).fullyLoadUrl(mWebAppUrl);
-
-        CriteriaHelper.pollUiThread(new Criteria() {
-            @Override
-            public boolean isSatisfied() {
-                AppBannerManager manager = getActivity().getActivityTab().getAppBannerManager();
-                return !manager.isActiveForTesting();
-            }
-        });
-        waitUntilNoInfoBarsExist();
-
-        // Add the animation listener in.
-        InfoBarContainer container = getActivity().getActivityTab().getInfoBarContainer();
-        final InfobarListener listener = new InfobarListener();
-        container.setAnimationListener(listener);
-
-        // Indicate a day has passed, then revisit the page to show the banner.
-        AppBannerManager.setTimeDeltaForTesting(1);
-        new TabLoadObserver(getActivity().getActivityTab()).fullyLoadUrl(mWebAppUrl);
-        CriteriaHelper.pollUiThread(new Criteria() {
-            @Override
-            public boolean isSatisfied() {
-                AppBannerManager manager = getActivity().getActivityTab().getAppBannerManager();
-                return !manager.isActiveForTesting();
-            }
-        });
-        waitUntilAppBannerInfoBarAppears(WEB_APP_TITLE);
-        CriteriaHelper.pollUiThread(new Criteria() {
-            @Override
-            public boolean isSatisfied() {
-                return listener.mDoneAnimating;
-            }
-        });
-
-        // Click the button to trigger the adding of the shortcut.
-        InfoBar infobar = container.getInfoBarsForTesting().get(0);
-        final Button button =
-                (Button) infobar.getView().findViewById(R.id.button_primary);
-        TouchCommon.singleClickView(button);
+        triggerWebAppBanner(mWebAppUrl, WEB_APP_TITLE, true);
 
         // Make sure that the splash screen icon was downloaded.
         CriteriaHelper.pollUiThread(new Criteria() {
@@ -539,7 +515,8 @@ public class AppBannerManagerTest extends ChromeTabbedActivityTestBase {
         // Test that bitmap sizes match expectations.
         int idealSize = getActivity().getResources().getDimensionPixelSize(
                 R.dimen.webapp_splash_image_size_ideal);
-        assertEquals(idealSize, dataStorageFactory.mSplashImage.getWidth());
-        assertEquals(idealSize, dataStorageFactory.mSplashImage.getHeight());
+        Bitmap splashImage = ShortcutHelper.decodeBitmapFromString(dataStorageFactory.mSplashImage);
+        assertEquals(idealSize, splashImage.getWidth());
+        assertEquals(idealSize, splashImage.getHeight());
     }
 }
