@@ -7,6 +7,7 @@ package org.chromium.chrome.browser.contextualsearch;
 import android.content.Context;
 import android.test.suitebuilder.annotation.SmallTest;
 
+import org.chromium.base.test.util.CommandLineFlags;
 import org.chromium.base.test.util.Feature;
 import org.chromium.base.test.util.RetryOnFailure;
 import org.chromium.chrome.test.ChromeTabbedActivityTestBase;
@@ -57,6 +58,17 @@ public class ContextualSearchPolicyTest extends ChromeTabbedActivityTestBase {
         assertEquals("de", mPolicy.bestTargetLanguage(list));
     }
 
+    @SmallTest
+    @Feature({"ContextualSearch"})
+    @RetryOnFailure
+    @CommandLineFlags.Add(ContextualSearchFieldTrial.ENABLE_ENGLISH_TARGET_TRANSLATION + "=true")
+    public void testBestTargetLanguageReturnsEnglishWhenEnabled() {
+        ArrayList<String> list = new ArrayList<String>();
+        list.add("en");
+        list.add("de");
+        assertEquals("en", mPolicy.bestTargetLanguage(list));
+    }
+
     @SmallTest
     @Feature({"ContextualSearch"})
     @RetryOnFailure
