@@ -24,6 +24,7 @@ import android.graphics.drawable.ColorDrawable;
 import android.net.Uri;
 import android.os.Build;
 import android.os.Bundle;
+import android.os.SystemClock;
 import android.support.customtabs.CustomTabsCallback;
 import android.support.customtabs.CustomTabsClient;
 import android.support.customtabs.CustomTabsIntent;
@@ -47,6 +48,7 @@ import org.chromium.base.library_loader.LibraryLoader;
 import org.chromium.base.library_loader.LibraryProcessType;
 import org.chromium.base.test.util.CallbackHelper;
 import org.chromium.base.test.util.CommandLineFlags;
+import org.chromium.base.test.util.DisabledTest;
 import org.chromium.base.test.util.Restriction;
 import org.chromium.base.test.util.RetryOnFailure;
 import org.chromium.chrome.R;
@@ -64,6 +66,7 @@ import org.chromium.chrome.browser.profiles.Profile;
 import org.chromium.chrome.browser.tab.EmptyTabObserver;
 import org.chromium.chrome.browser.tab.Tab;
 import org.chromium.chrome.browser.tab.TabObserver;
+import org.chromium.chrome.browser.tab.TabTestUtils;
 import org.chromium.chrome.browser.tabmodel.EmptyTabModelObserver;
 import org.chromium.chrome.browser.tabmodel.TabModel.TabLaunchType;
 import org.chromium.chrome.browser.tabmodel.TabModelSelector;
@@ -268,11 +271,11 @@ public class CustomTabActivityTest extends CustomTabActivityTestBase {
 
     /**
      * Test the entries in the context menu shown when long clicking an image.
-     * Restricted to phone due to BUG=crbug.com/655970
+     * @SmallTest
+     * @RetryOnFailure
+     * BUG=crbug.com/655970
      */
-    @SmallTest
-    @RetryOnFailure
-    @Restriction(ChromeRestriction.RESTRICTION_TYPE_PHONE)
+    @DisabledTest
     public void testContextMenuEntriesForImage() throws InterruptedException, TimeoutException {
         startCustomTabActivityWithIntent(createMinimalCustomTabIntent());
 
@@ -302,12 +305,12 @@ public class CustomTabActivityTest extends CustomTabActivityTestBase {
     }
 
     /**
-     * Test the entries in the context menu shown when long clicking an link.
-     * Restricted to phone due to BUG=crbug.com/655970
+     * Test the entries in the context menu shown when long clicking a link.
+     * @SmallTest
+     * @RetryOnFailure
+     * BUG=crbug.com/655970
      */
-    @SmallTest
-    @RetryOnFailure
-    @Restriction(ChromeRestriction.RESTRICTION_TYPE_PHONE)
+    @DisabledTest
     public void testContextMenuEntriesForLink() throws InterruptedException, TimeoutException {
         startCustomTabActivityWithIntent(createMinimalCustomTabIntent());
 
@@ -849,13 +852,23 @@ public class CustomTabActivityTest extends CustomTabActivityTestBase {
     @RetryOnFailure
     public void testPageLoadMetricIsSent() {
         final AtomicReference<Long> firstContentfulPaintMs = new AtomicReference<>(-1L);
+        final AtomicReference<Long> activityStartTimeMs = new AtomicReference<>(-1L);
+
         CustomTabsCallback cb = new CustomTabsCallback() {
             @Override
             public void extraCallback(String callbackName, Bundle args) {
                 assertEquals(CustomTabsConnection.PAGE_LOAD_METRICS_CALLBACK, callbackName);
-                long value = args.getLong(PageLoadMetrics.FIRST_CONTENTFUL_PAINT, -1);
-                assertTrue(value > 0);
-                firstContentfulPaintMs.set(value);
+
+                long navigationStart = args.getLong(PageLoadMetrics.NAVIGATION_START, -1);
+                long current = SystemClock.uptimeMillis();
+                assertTrue(navigationStart <= current);
+                assertTrue(navigationStart >= activityStartTimeMs.get());
+
+                long firstContentfulPaint =
+                        args.getLong(PageLoadMetrics.FIRST_CONTENTFUL_PAINT, -1);
+                assertTrue(firstContentfulPaint > 0);
+                assertTrue(firstContentfulPaint <= (current - navigationStart));
+                firstContentfulPaintMs.set(firstContentfulPaint);
             }
         };
 
@@ -867,6 +880,7 @@ public class CustomTabActivityTest extends CustomTabActivityTestBase {
         intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
 
         try {
+            activityStartTimeMs.set(SystemClock.uptimeMillis());
             startCustomTabActivityWithIntent(intent);
             CriteriaHelper.pollInstrumentationThread(new Criteria() {
                 @Override
@@ -1714,7 +1728,7 @@ public class CustomTabActivityTest extends CustomTabActivityTestBase {
         assertEquals("The tab should never be hidden during the reparenting process",
                 0, tabHiddenHelper.getCallCount());
         tabToBeReparented.removeObserver(observer);
-        RewindableIterator<TabObserver> observers = tabToBeReparented.getTabObservers();
+        RewindableIterator<TabObserver> observers = TabTestUtils.getTabObservers(tabToBeReparented);
         while (observers.hasNext()) {
             assertFalse(observers.next() instanceof CustomTabObserver);
         }
