@@ -14,12 +14,13 @@ import android.os.Looper;
 import android.text.TextUtils;
 
 import org.chromium.base.ThreadUtils;
+import org.chromium.base.test.util.CallbackHelper;
 import org.chromium.chrome.browser.download.DownloadInfo;
 import org.chromium.chrome.browser.download.DownloadItem;
 import org.chromium.chrome.browser.offlinepages.downloads.OfflinePageDownloadBridge;
 import org.chromium.chrome.browser.offlinepages.downloads.OfflinePageDownloadItem;
 import org.chromium.chrome.browser.widget.selection.SelectionDelegate;
-import org.chromium.content.browser.test.util.CallbackHelper;
+import org.chromium.content_public.browser.DownloadState;
 
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
@@ -64,6 +65,9 @@ public class StubbedProvider implements BackendProvider {
             });
         }
 
+        @Override
+        public void broadcastDownloadAction(DownloadItem downloadItem, String action) {}
+
         @Override
         public void checkForExternallyRemovedDownloads(boolean isOffTheRecord) {
             checkExternalCallback.notifyCalled();
@@ -81,8 +85,7 @@ public class StubbedProvider implements BackendProvider {
         }
 
         @Override
-        public boolean isDownloadOpenableInBrowser(
-                String guid, boolean isOffTheRecord, String mimeType) {
+        public boolean isDownloadOpenableInBrowser(boolean isOffTheRecord, String mimeType) {
             return false;
         }
     }
@@ -196,8 +199,14 @@ public class StubbedProvider implements BackendProvider {
     @Override
     public void destroy() {}
 
-    /** Creates a new DownloadItem with pre-defined values. */
+    /** See {@link #createDownloadItem(int, String, boolean)}. */
     public static DownloadItem createDownloadItem(int which, String date) throws Exception {
+        return createDownloadItem(which, date, false, DownloadState.COMPLETE);
+    }
+
+    /** Creates a new DownloadItem with pre-defined values. */
+    public static DownloadItem createDownloadItem(
+            int which, String date, boolean isIncognito, int state) throws Exception {
         DownloadItem item = null;
         if (which == 0) {
             item = new DownloadItem(false, new DownloadInfo.Builder()
@@ -207,6 +216,8 @@ public class StubbedProvider implements BackendProvider {
                     .setFilePath("/storage/fake_path/Downloads/first_file.jpg")
                     .setDownloadGuid("first_guid")
                     .setMimeType("image/jpeg")
+                    .setState(state)
+                    .setIsOffTheRecord(isIncognito)
                     .build());
         } else if (which == 1) {
             item = new DownloadItem(false, new DownloadInfo.Builder()
@@ -216,6 +227,8 @@ public class StubbedProvider implements BackendProvider {
                     .setFilePath("/storage/fake_path/Downloads/second_file.gif")
                     .setDownloadGuid("second_guid")
                     .setMimeType("image/gif")
+                    .setState(state)
+                    .setIsOffTheRecord(isIncognito)
                     .build());
         } else if (which == 2) {
             item = new DownloadItem(false, new DownloadInfo.Builder()
@@ -225,6 +238,8 @@ public class StubbedProvider implements BackendProvider {
                     .setFilePath("/storage/fake_path/Downloads/third_file")
                     .setDownloadGuid("third_guid")
                     .setMimeType("text/plain")
+                    .setState(state)
+                    .setIsOffTheRecord(isIncognito)
                     .build());
         } else if (which == 3) {
             item = new DownloadItem(false, new DownloadInfo.Builder()
@@ -234,6 +249,8 @@ public class StubbedProvider implements BackendProvider {
                     .setFilePath("/storage/fake_path/Downloads/four.webm")
                     .setDownloadGuid("fourth_guid")
                     .setMimeType("video/webm")
+                    .setState(state)
+                    .setIsOffTheRecord(isIncognito)
                     .build());
         } else if (which == 4) {
             item = new DownloadItem(false, new DownloadInfo.Builder()
@@ -243,6 +260,8 @@ public class StubbedProvider implements BackendProvider {
                     .setFilePath("/storage/fake_path/Downloads/five.mp3")
                     .setDownloadGuid("fifth_guid")
                     .setMimeType("audio/mp3")
+                    .setState(state)
+                    .setIsOffTheRecord(isIncognito)
                     .build());
         } else if (which == 5) {
             item = new DownloadItem(false, new DownloadInfo.Builder()
@@ -252,6 +271,8 @@ public class StubbedProvider implements BackendProvider {
                     .setFilePath("/storage/fake_path/Downloads/six.mp3")
                     .setDownloadGuid("sixth_guid")
                     .setMimeType("audio/mp3")
+                    .setState(state)
+                    .setIsOffTheRecord(isIncognito)
                     .build());
         } else if (which == 6) {
             item = new DownloadItem(false, new DownloadInfo.Builder()
@@ -261,6 +282,7 @@ public class StubbedProvider implements BackendProvider {
                     .setFilePath("/storage/fake_path/Downloads/huge_image.png")
                     .setDownloadGuid("seventh_guid")
                     .setMimeType("image/png")
+                    .setState(state)
                     .build());
         } else if (which == 7) {
             item = new DownloadItem(false, new DownloadInfo.Builder()
@@ -270,6 +292,8 @@ public class StubbedProvider implements BackendProvider {
                     .setFilePath("/storage/fake_path/Downloads/sleep.pdf")
                     .setDownloadGuid("eighth_guid")
                     .setMimeType("application/pdf")
+                    .setState(state)
+                    .setIsOffTheRecord(isIncognito)
                     .build());
         } else if (which == 8) {
             // This is a duplicate of item 7 above.
@@ -280,6 +304,8 @@ public class StubbedProvider implements BackendProvider {
                     .setFilePath("/storage/fake_path/Downloads/sleep.pdf")
                     .setDownloadGuid("ninth_guid")
                     .setMimeType("application/pdf")
+                    .setState(state)
+                    .setIsOffTheRecord(isIncognito)
                     .build());
         } else {
             return null;
