@@ -4,6 +4,7 @@
 
 package org.chromium.chrome.browser.notifications;
 
+import android.annotation.TargetApi;
 import android.app.Notification;
 import android.app.PendingIntent;
 import android.content.Context;
@@ -12,6 +13,7 @@ import android.graphics.Bitmap;
 import android.graphics.BitmapFactory;
 import android.graphics.Color;
 import android.graphics.drawable.BitmapDrawable;
+import android.graphics.drawable.Drawable;
 import android.os.Build;
 import android.test.suitebuilder.annotation.SmallTest;
 import android.util.DisplayMetrics;
@@ -22,6 +24,7 @@ import android.widget.LinearLayout;
 import android.widget.TextView;
 
 import org.chromium.base.test.util.Feature;
+import org.chromium.base.test.util.MinAndroidSdkLevel;
 import org.chromium.chrome.R;
 import org.chromium.content.browser.test.NativeLibraryTestBase;
 
@@ -58,34 +61,31 @@ public class CustomNotificationBuilderTest extends NativeLibraryTestBase {
                 new int[] {Color.WHITE}, 1 /* width */, 1 /* height */, Bitmap.Config.ARGB_8888);
         actionIcon = actionIcon.copy(Bitmap.Config.ARGB_8888, true /* isMutable */);
 
-        Notification notification =
-                new CustomNotificationBuilder(context)
-                        .setSmallIcon(R.drawable.ic_chrome)
-                        .setLargeIcon(largeIcon)
-                        .setTitle("title")
-                        .setBody("body")
-                        .setOrigin("origin")
-                        .setTicker("ticker")
-                        .setDefaults(Notification.DEFAULT_ALL)
-                        .setVibrate(new long[] {100L})
-                        .setContentIntent(contentIntent)
-                        .setDeleteIntent(deleteIntent)
-                        .addAction(actionIcon, "button", createIntent(context, "ActionButtonOne"))
-                        .addAction(actionIcon, "button", createIntent(context, "ActionButtonTwo"))
-                        .addSettingsAction(
-                                0 /* iconId */, "settings", createIntent(context, "SettingsButton"))
-                        .build();
+        Notification notification = new CustomNotificationBuilder(context)
+                                            .setSmallIcon(R.drawable.ic_chrome)
+                                            .setLargeIcon(largeIcon)
+                                            .setTitle("title")
+                                            .setBody("body")
+                                            .setOrigin("origin")
+                                            .setTicker("ticker")
+                                            .setDefaults(Notification.DEFAULT_ALL)
+                                            .setVibrate(new long[] {100L})
+                                            .setContentIntent(contentIntent)
+                                            .setDeleteIntent(deleteIntent)
+                                            .addButtonAction(actionIcon, "button",
+                                                    createIntent(context, "ActionButtonOne"))
+                                            .addButtonAction(actionIcon, "button",
+                                                    createIntent(context, "ActionButtonTwo"))
+                                            .addSettingsAction(0 /* iconId */, "settings",
+                                                    createIntent(context, "SettingsButton"))
+                                            .build();
+
+        assertSmallNotificationIconAsExpected(context, notification, smallIcon);
+        assertLargeNotificationIconAsExpected(context, notification, largeIcon);
+
         View compactView = notification.contentView.apply(context, new LinearLayout(context));
         View bigView = notification.bigContentView.apply(context, new LinearLayout(context));
 
-        assertNotNull(((ImageView) compactView.findViewById(R.id.icon)).getDrawable());
-        assertNotNull(((ImageView) bigView.findViewById(R.id.icon)).getDrawable());
-
-        assertTrue(smallIcon.sameAs(
-                NotificationTestUtil.getSmallIconFromNotification(context, notification)));
-        assertTrue(largeIcon.sameAs(
-                NotificationTestUtil.getLargeIconFromNotification(context, notification)));
-
         assertEquals("title", getIdenticalText(R.id.title, compactView, bigView));
         assertEquals("body", getIdenticalText(R.id.body, compactView, bigView));
         assertEquals("origin", getIdenticalText(R.id.origin, compactView, bigView));
@@ -101,6 +101,14 @@ public class CustomNotificationBuilderTest extends NativeLibraryTestBase {
         assertSame(contentIntent, notification.contentIntent);
         assertSame(deleteIntent, notification.deleteIntent);
 
+        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP) {
+            // Notification.publicVersion was added in Android L.
+            assertNotNull(notification.publicVersion);
+            assertEquals("origin", Build.VERSION.SDK_INT <= Build.VERSION_CODES.M
+                            ? NotificationTestUtil.getExtraTitle(notification.publicVersion)
+                            : NotificationTestUtil.getExtraSubText(notification.publicVersion));
+        }
+
         // The regular actions and the settings action are added together in the notification
         // actions array, so they can be exposed on e.g. Wear and custom lockscreens.
         assertEquals(3, NotificationTestUtil.getActions(notification).length);
@@ -132,12 +140,12 @@ public class CustomNotificationBuilderTest extends NativeLibraryTestBase {
     public void testMaxActionButtons() {
         Context context = getInstrumentation().getTargetContext();
         NotificationBuilderBase builder = new CustomNotificationBuilder(context)
-                                                  .addAction(null /* iconBitmap */, "button",
+                                                  .addButtonAction(null /* iconBitmap */, "button",
                                                           createIntent(context, "ActionButtonOne"))
-                                                  .addAction(null /* iconBitmap */, "button",
+                                                  .addButtonAction(null /* iconBitmap */, "button",
                                                           createIntent(context, "ActionButtonTwo"));
         try {
-            builder.addAction(
+            builder.addButtonAction(
                     null /* iconBitmap */, "button", createIntent(context, "ActionButtonThree"));
             fail("This statement should not be reached as the previous statement should throw.");
         } catch (IllegalStateException e) {
@@ -168,41 +176,27 @@ public class CustomNotificationBuilderTest extends NativeLibraryTestBase {
                 new int[] {Color.RED}, 1 /* width */, 1 /* height */, Bitmap.Config.ARGB_8888);
         actionIcon = actionIcon.copy(Bitmap.Config.ARGB_8888, true /* isMutable */);
 
-        Notification notification =
-                new CustomNotificationBuilder(context)
-                        .setLargeIcon(largeIcon)
-                        .setSmallIcon(smallIcon)
-                        .addAction(actionIcon, "button", createIntent(context, "ActionButton"))
-                        .build();
+        Notification notification = new CustomNotificationBuilder(context)
+                                            .setLargeIcon(largeIcon)
+                                            .setSmallIcon(smallIcon)
+                                            .addButtonAction(actionIcon, "button",
+                                                    createIntent(context, "ActionButton"))
+                                            .build();
 
-        // The large icon should not be painted white.
-        Bitmap notificationLargeIcon =
-                NotificationTestUtil.getLargeIconFromNotification(context, notification);
-        assertNotNull(notificationLargeIcon);
-        assertEquals(Color.RED, notificationLargeIcon.getPixel(0, 0));
-
-        View bigView = notification.bigContentView.apply(context, new LinearLayout(context));
+        // The large icon should be unchanged.
+        assertLargeNotificationIconAsExpected(context, notification, largeIcon);
 
         // Small icons should be painted white.
-        // Check the small icon view's bitmap is correctly rendered.
-        int smallIconId = CustomNotificationBuilder.useMaterial() ? R.id.small_icon_overlay
-                                                                  : R.id.small_icon_footer;
-        ImageView smallIconView = (ImageView) bigView.findViewById(smallIconId);
-        Bitmap smallIconBitmap = ((BitmapDrawable) smallIconView.getDrawable()).getBitmap();
-        assertEquals(Color.WHITE, smallIconBitmap.getPixel(0, 0));
-
-        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
-            // For M+ we can also check the notification's member bitmap.
-            assertEquals(Color.WHITE,
-                    NotificationTestUtil.getBitmapFromIcon(context, notification.getSmallIcon())
-                            .getPixel(0, 0));
-        }
+        Bitmap whiteIcon = Bitmap.createBitmap(
+                new int[] {Color.WHITE}, 1 /* width */, 1 /* height */, Bitmap.Config.ARGB_8888);
+        assertSmallNotificationIconAsExpected(context, notification, whiteIcon);
 
         // Action icons should be painted white.
         assertEquals(1, NotificationTestUtil.getActions(notification).length);
+        View bigView = notification.bigContentView.apply(context, new LinearLayout(context));
         ImageView actionIconView = (ImageView) bigView.findViewById(R.id.button_icon);
         Bitmap actionIconBitmap = ((BitmapDrawable) actionIconView.getDrawable()).getBitmap();
-        assertEquals(Color.WHITE, actionIconBitmap.getPixel(0, 0));
+        assertTrue(whiteIcon.sameAs(actionIconBitmap));
     }
 
     @SmallTest
@@ -216,7 +210,7 @@ public class CustomNotificationBuilderTest extends NativeLibraryTestBase {
                         .setBody(createString('b', maxLength + 1))
                         .setOrigin(createString('c', maxLength + 1))
                         .setTicker(createString('d', maxLength + 1))
-                        .addAction(null /* iconBitmap */, createString('e', maxLength + 1),
+                        .addButtonAction(null /* iconBitmap */, createString('e', maxLength + 1),
                                 createIntent(context, "ActionButtonOne"))
                         .build();
         View compactView = notification.contentView.apply(context, new LinearLayout(context));
@@ -257,6 +251,108 @@ public class CustomNotificationBuilderTest extends NativeLibraryTestBase {
         assertEquals(0, CustomNotificationBuilder.calculateScaledPadding(1000.0f, metrics));
     }
 
+    @SmallTest
+    @Feature({"Browser", "Notifications"})
+    public void testGeneratesLargeIconFromOriginWhenNoLargeIconProvided() {
+        Context context = getInstrumentation().getTargetContext();
+        NotificationBuilderBase notificationBuilder =
+                new CustomNotificationBuilder(context).setOrigin("https://www.google.com");
+
+        Notification notification = notificationBuilder.build();
+
+        Bitmap expectedIcon = NotificationBuilderBase.createIconGenerator(context.getResources())
+                                      .generateIconForUrl("https://www.google.com");
+
+        assertLargeNotificationIconAsExpected(context, notification, expectedIcon);
+    }
+
+    @SmallTest
+    @Feature({"Browser", "Notifications"})
+    public void testGeneratesLargeIconFromOriginWhenLargeIconProvidedIsNull() {
+        Context context = getInstrumentation().getTargetContext();
+        NotificationBuilderBase notificationBuilder = new CustomNotificationBuilder(context)
+                                                              .setOrigin("https://www.chromium.org")
+                                                              .setLargeIcon(null);
+
+        Notification notification = notificationBuilder.build();
+
+        Bitmap expectedIcon = NotificationBuilderBase.createIconGenerator(context.getResources())
+                                      .generateIconForUrl("https://www.chromium.org");
+
+        assertLargeNotificationIconAsExpected(context, notification, expectedIcon);
+    }
+
+    /**
+     * Tests that adding a text action results in a notification action with a RemoteInput attached.
+     *
+     * Note that the action buttons in custom layouts will not trigger an inline reply, but we can
+     * still check the notification's action properties since these are used on Android Wear.
+     */
+    @MinAndroidSdkLevel(Build.VERSION_CODES.KITKAT_WATCH)
+    @TargetApi(Build.VERSION_CODES.KITKAT_WATCH) // RemoteInputs were only added in KITKAT_WATCH.
+    @SmallTest
+    @Feature({"Browser", "Notifications"})
+    public void testAddTextActionSetsRemoteInput() {
+        Context context = getInstrumentation().getTargetContext();
+        NotificationBuilderBase notificationBuilder = new CustomNotificationBuilder(
+                context).addTextAction(null, "Action Title", null, "Placeholder");
+
+        Notification notification = notificationBuilder.build();
+
+        assertEquals(1, notification.actions.length);
+        assertEquals("Action Title", notification.actions[0].title);
+        assertNotNull(notification.actions[0].getRemoteInputs());
+        assertEquals(1, notification.actions[0].getRemoteInputs().length);
+        assertEquals("Placeholder", notification.actions[0].getRemoteInputs()[0].getLabel());
+    }
+
+    private static void assertLargeNotificationIconAsExpected(
+            Context context, Notification notification, Bitmap expectedIcon) {
+        // 1. Check large icon property on the notification.
+
+        Bitmap icon = NotificationTestUtil.getLargeIconFromNotification(context, notification);
+        assertNotNull(icon);
+        assertTrue(expectedIcon.sameAs(icon));
+
+        // 2. Check the large icon in the custom layouts.
+
+        View compactView = notification.contentView.apply(context, new LinearLayout(context));
+        Drawable compactViewIcon = ((ImageView) compactView.findViewById(R.id.icon)).getDrawable();
+        assertNotNull(compactViewIcon);
+        assertTrue(expectedIcon.sameAs(((BitmapDrawable) compactViewIcon).getBitmap()));
+
+        View bigView = notification.bigContentView.apply(context, new LinearLayout(context));
+        Drawable bigViewIcon = ((ImageView) bigView.findViewById(R.id.icon)).getDrawable();
+        assertNotNull(bigViewIcon);
+        assertTrue(expectedIcon.sameAs(((BitmapDrawable) bigViewIcon).getBitmap()));
+    }
+
+    private static void assertSmallNotificationIconAsExpected(
+            Context context, Notification notification, Bitmap expectedIcon) {
+        // 1. Check small icon property on the notification, for M+.
+        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
+            Bitmap icon =
+                    NotificationTestUtil.getBitmapFromIcon(context, notification.getSmallIcon());
+            assertNotNull(icon);
+            assertTrue(expectedIcon.sameAs(icon));
+        }
+
+        // 2. Check the small icon in the custom layouts.
+
+        int smallIconId = CustomNotificationBuilder.useMaterial() ? R.id.small_icon_overlay
+                                                                  : R.id.small_icon_footer;
+        View compactView = notification.contentView.apply(context, new LinearLayout(context));
+        Drawable compactViewIcon =
+                ((ImageView) compactView.findViewById(smallIconId)).getDrawable();
+        assertNotNull(compactViewIcon);
+        assertTrue(expectedIcon.sameAs(((BitmapDrawable) compactViewIcon).getBitmap()));
+
+        View bigView = notification.bigContentView.apply(context, new LinearLayout(context));
+        Drawable bigViewIcon = ((ImageView) bigView.findViewById(smallIconId)).getDrawable();
+        assertNotNull(bigViewIcon);
+        assertTrue(expectedIcon.sameAs(((BitmapDrawable) bigViewIcon).getBitmap()));
+    }
+
     /**
      * Finds a TextView with the given id in each of the given views, and checks that they all
      * contain the same text.
