@@ -35,6 +35,7 @@ import java.io.OutputStreamWriter;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Properties;
+import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.Semaphore;
 import java.util.concurrent.TimeUnit;
 
@@ -88,16 +89,14 @@ public class OfflinePageSavePageLaterEvaluationTest
     private OfflinePageEvaluationBridge mBridge;
     private OfflinePageEvaluationObserver mObserver;
 
-    private Semaphore mDoneSemaphore;
+    private CountDownLatch mCompletionLatch;
     private List<String> mUrls;
     private int mCount;
     private boolean mIsUserRequested;
     private boolean mUseTestScheduler;
+    private int mScheduleBatchSize;
 
     private LongSparseArray<RequestMetadata> mRequestMetadata;
-    // TODO(romax): Use actual policy to determine the timeout.
-    private Long mTimeoutPerUrlInSeconds = 0L;
-    private OutputStreamWriter mLogOutput;
 
     public OfflinePageSavePageLaterEvaluationTest() {
         super(ChromeActivity.class);
@@ -139,6 +138,7 @@ public class OfflinePageSavePageLaterEvaluationTest
         });
         checkTrue(mClearingSemaphore.tryAcquire(REMOVE_REQUESTS_TIMEOUT_MS, TimeUnit.MILLISECONDS),
                 "Timed out when clearing remaining requests!");
+        mBridge.closeLog();
         super.tearDown();
     }
 
@@ -179,33 +179,24 @@ public class OfflinePageSavePageLaterEvaluationTest
                     for (String file : files) {
                         File currentFile = new File(externalArchiveDir.getPath(), file);
                         if (!currentFile.delete()) {
-                            logError(file + " cannot be deleted when clearing previous archives.");
+                            log(file + " cannot be deleted when clearing previous archives.");
                         }
                     }
                 }
-            }
-            if (!externalArchiveDir.mkdir()) {
-                logError("Cannot create directory on external storage to store saved pages.");
+            } else if (!externalArchiveDir.mkdir()) {
+                log("Cannot create directory on external storage to store saved pages.");
             }
         } catch (SecurityException e) {
-            logError("Failed to delete or create external archive folder!");
+            log("Failed to delete or create external archive folder!");
         }
         return externalArchiveDir;
     }
 
     /**
-     * Logs error in both console and output file.
+     * Print log message in output file through evaluation bridge.
      */
-    private void logError(String error) {
-        Log.e(TAG, error);
-        if (mLogOutput != null) {
-            try {
-                mLogOutput.write(error + NEW_LINE);
-                mLogOutput.flush();
-            } catch (Exception e) {
-                Log.e(TAG, e.getMessage(), e);
-            }
-        }
+    private void log(String message) {
+        mBridge.log(TAG, message);
     }
 
     /**
@@ -213,14 +204,7 @@ public class OfflinePageSavePageLaterEvaluationTest
      */
     private void checkTrue(boolean condition, String message) {
         if (!condition) {
-            logError(message);
-            if (mLogOutput != null) {
-                try {
-                    mLogOutput.close();
-                } catch (IOException e) {
-                    Log.e(TAG, e.getMessage(), e);
-                }
-            }
+            log(message);
             fail();
         }
     }
@@ -239,7 +223,7 @@ public class OfflinePageSavePageLaterEvaluationTest
                 Profile profile = Profile.getLastUsedProfile();
                 mBridge = OfflinePageEvaluationBridge.getForProfile(profile, useTestingScheduler);
                 if (mBridge == null) {
-                    logError("OfflinePageEvaluationBridge initialization failed!");
+                    fail("OfflinePageEvaluationBridge initialization failed!");
                     return;
                 }
                 if (mBridge.isOfflinePageModelLoaded()) {
@@ -265,21 +249,18 @@ public class OfflinePageSavePageLaterEvaluationTest
      *                           will be used. False otherwise.
      */
     protected void setUpIOAndBridge(final boolean useCustomScheduler) throws InterruptedException {
-        try {
-            mLogOutput = getOutputStream(LOG_OUTPUT_FILE_PATH);
-        } catch (IOException e) {
-            Log.wtf(TAG, "Cannot set output file!");
-            Log.wtf(TAG, e.getMessage(), e);
-        }
         try {
             getUrlListFromInputFile(INPUT_FILE_PATH);
         } catch (IOException e) {
-            Log.wtf(TAG, "Cannot read input file!");
-            Log.wtf(TAG, e.getMessage(), e);
+            Log.wtf(TAG, "Cannot read input file!", e);
         }
         checkTrue(mUrls != null, "URLs weren't loaded.");
         checkTrue(mUrls.size() > 0, "No valid URLs in the input file.");
 
+        if (mScheduleBatchSize == 0) {
+            mScheduleBatchSize = mUrls.size();
+        }
+
         initializeBridgeForProfile(useCustomScheduler);
         mObserver = new OfflinePageEvaluationObserver() {
             public void savePageRequestAdded(SavePageRequest request) {
@@ -297,16 +278,27 @@ public class OfflinePageSavePageLaterEvaluationTest
                 metadata.mTimeDelta.setEndTime(System.currentTimeMillis());
                 if (metadata.mStatus == -1) {
                     mCount++;
+                } else {
+                    log("The request for url: " + metadata.mUrl
+                            + " has more than one completion callbacks!");
+                    log("Previous status: " + metadata.mStatus + ". Current: " + status);
                 }
                 metadata.mStatus = status;
-                if (mCount == mUrls.size()) {
-                    mDoneSemaphore.release();
+                if (mCount == mUrls.size() || mCount % mScheduleBatchSize == 0) {
+                    mCompletionLatch.countDown();
                     return;
                 }
             }
             public void savePageRequestChanged(SavePageRequest request) {}
         };
         mBridge.addObserver(mObserver);
+        try {
+            File logOutputFile =
+                    new File(Environment.getExternalStorageDirectory(), LOG_OUTPUT_FILE_PATH);
+            mBridge.setLogOutputFile(logOutputFile);
+        } catch (IOException e) {
+            Log.wtf(TAG, "Cannot set log output file!", e);
+        }
     }
 
     /**
@@ -326,19 +318,20 @@ public class OfflinePageSavePageLaterEvaluationTest
 
     private void processUrls(List<String> urls) throws InterruptedException, IOException {
         if (mBridge == null) {
-            logError("Test initialization error, aborting. No results would be written.");
+            fail("Test initialization error, aborting. No results would be written.");
             return;
         }
-        mDoneSemaphore = new Semaphore(0);
-        for (String url : mUrls) {
-            savePageLater(url, NAMESPACE);
-        }
-
-        if (!mDoneSemaphore.tryAcquire(urls.size() * mTimeoutPerUrlInSeconds, TimeUnit.SECONDS)) {
-            writeResults(false);
-        } else {
-            writeResults(true);
+        int count = 0;
+        for (int i = 0; i < mUrls.size(); i++) {
+            savePageLater(mUrls.get(i), NAMESPACE);
+            count++;
+            if (count == mScheduleBatchSize || i == mUrls.size() - 1) {
+                count = 0;
+                mCompletionLatch = new CountDownLatch(1);
+                mCompletionLatch.await();
+            }
         }
+        writeResults();
     }
 
     private void getUrlListFromInputFile(String inputFilePath)
@@ -369,10 +362,10 @@ public class OfflinePageSavePageLaterEvaluationTest
         switch (status) {
             case BackgroundSavePageResult.SUCCESS:
                 return "SUCCESS";
-            case BackgroundSavePageResult.PRERENDER_FAILURE:
-                return "PRERENDER_FAILURE";
-            case BackgroundSavePageResult.PRERENDER_CANCELED:
-                return "PRERENDER_CANCELED";
+            case BackgroundSavePageResult.LOADING_FAILURE:
+                return "LOADING_FAILURE";
+            case BackgroundSavePageResult.LOADING_CANCELED:
+                return "LOADING_CANCELED";
             case BackgroundSavePageResult.FOREGROUND_CANCELED:
                 return "FOREGROUND_CANCELED";
             case BackgroundSavePageResult.SAVE_FAILED:
@@ -426,13 +419,13 @@ public class OfflinePageSavePageLaterEvaluationTest
      * At the end of the file there will be a summary:
      * Total requested URLs: XX, Completed: XX, Failed: XX, Failure Rate: XX.XX%
      */
-    private void writeResults(boolean completed) throws IOException, InterruptedException {
+    private void writeResults() throws IOException, InterruptedException {
         loadSavedPages();
         OutputStreamWriter output = getOutputStream(RESULT_OUTPUT_FILE_PATH);
         try {
             int failedCount = 0;
-            if (!completed) {
-                logError("Test terminated before all requests completed.");
+            if (mCount < mUrls.size()) {
+                log("Test terminated before all requests completed.");
             }
             File externalArchiveDir = getExternalArchiveDir();
             for (int i = 0; i < mRequestMetadata.size(); i++) {
@@ -455,7 +448,7 @@ public class OfflinePageSavePageLaterEvaluationTest
                 File originalPage = new File(page.getFilePath());
                 File externalPage = new File(externalArchiveDir, originalPage.getName());
                 if (!OfflinePageUtils.copyToShareableLocation(originalPage, externalPage)) {
-                    logError("Saved page for url " + page.getUrl() + " cannot be moved.");
+                    log("Saved page for url " + page.getUrl() + " cannot be moved.");
                 }
             }
             output.write(String.format(
@@ -468,9 +461,6 @@ public class OfflinePageSavePageLaterEvaluationTest
             if (output != null) {
                 output.close();
             }
-            if (mLogOutput != null) {
-                mLogOutput.close();
-            }
         }
     }
 
@@ -485,9 +475,8 @@ public class OfflinePageSavePageLaterEvaluationTest
             inputStream = new FileInputStream(configFile);
             properties.load(inputStream);
             mIsUserRequested = Boolean.parseBoolean(properties.getProperty("IsUserRequested"));
-            mTimeoutPerUrlInSeconds =
-                    Long.parseLong(properties.getProperty("TimeoutPerUrlInSeconds"));
             mUseTestScheduler = Boolean.parseBoolean(properties.getProperty("UseTestScheduler"));
+            mScheduleBatchSize = Integer.parseInt(properties.getProperty("ScheduleBatchSize"));
         } catch (FileNotFoundException e) {
             Log.e(TAG, e.getMessage(), e);
             fail(String.format(
@@ -504,7 +493,7 @@ public class OfflinePageSavePageLaterEvaluationTest
      * It is encouraged to use run_offline_page_evaluation_test.py to run this test.
      */
     @Manual
-    public void testFailureRateWithTimeout() throws IOException, InterruptedException {
+    public void testFailureRate() throws IOException, InterruptedException {
         parseConfigFile();
         setUpIOAndBridge(mUseTestScheduler);
         processUrls(mUrls);
