@@ -6,6 +6,7 @@ package org.chromium.chrome.browser.payments;
 
 import android.test.suitebuilder.annotation.MediumTest;
 
+import org.chromium.base.test.util.CommandLineFlags;
 import org.chromium.base.test.util.Feature;
 import org.chromium.chrome.R;
 import org.chromium.chrome.browser.autofill.AutofillTestHelper;
@@ -18,6 +19,7 @@ import java.util.concurrent.TimeoutException;
  * A payment integration test for checking whether user can make a payment via either payment
  * app or a credit card. This user does not have a complete credit card on file.
  */
+@CommandLineFlags.Add("enable-blink-features=CanMakePayment")
 public class PaymentRequestCanMakePaymentQueryNoCardTest extends PaymentRequestTestBase {
     public PaymentRequestCanMakePaymentQueryNoCardTest() {
         super("payment_request_can_make_payment_query_test.html");
@@ -29,15 +31,15 @@ public class PaymentRequestCanMakePaymentQueryNoCardTest extends PaymentRequestT
         // The user has an incomplete credit card on file. This is not sufficient for
         // canMakePayment() to return true.
         new AutofillTestHelper().setCreditCard(new CreditCard("", "https://example.com", true, true,
-                "" /* nameOnCard */, "4111111111111111", "1111", "12", "2050", "visa",
-                R.drawable.pr_visa, "" /* billingAddressId */, "" /* serverId */));
+                "Jon Doe", "4111111111111111", "1111", "12", "2050", "visa", R.drawable.pr_visa,
+                "" /* billingAddressId */, "" /* serverId */));
     }
 
     @MediumTest
     @Feature({"Payments"})
     public void testNoBobPayInstalled() throws InterruptedException, ExecutionException,
             TimeoutException {
-        triggerUIAndWait(mCanMakePaymentQueryResponded);
+        openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
         expectResultContains(new String[]{"false"});
     }
 
@@ -46,7 +48,7 @@ public class PaymentRequestCanMakePaymentQueryNoCardTest extends PaymentRequestT
     public void testNoInstrumentsInFastBobPay() throws InterruptedException, ExecutionException,
             TimeoutException {
         installPaymentApp(NO_INSTRUMENTS, IMMEDIATE_RESPONSE);
-        triggerUIAndWait(mCanMakePaymentQueryResponded);
+        openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
         expectResultContains(new String[]{"false"});
     }
 
@@ -55,7 +57,7 @@ public class PaymentRequestCanMakePaymentQueryNoCardTest extends PaymentRequestT
     public void testNoInstrumentsInSlowBobPay() throws InterruptedException, ExecutionException,
             TimeoutException {
         installPaymentApp(NO_INSTRUMENTS, DELAYED_RESPONSE);
-        triggerUIAndWait(mCanMakePaymentQueryResponded);
+        openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
         expectResultContains(new String[]{"false"});
     }
 
@@ -64,7 +66,7 @@ public class PaymentRequestCanMakePaymentQueryNoCardTest extends PaymentRequestT
     public void testPayViaFastBobPay() throws InterruptedException, ExecutionException,
             TimeoutException {
         installPaymentApp(HAVE_INSTRUMENTS, IMMEDIATE_RESPONSE);
-        triggerUIAndWait(mCanMakePaymentQueryResponded);
+        openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
         expectResultContains(new String[]{"true"});
     }
 
@@ -73,7 +75,7 @@ public class PaymentRequestCanMakePaymentQueryNoCardTest extends PaymentRequestT
     public void testPayViaSlowBobPay() throws InterruptedException, ExecutionException,
             TimeoutException {
         installPaymentApp(HAVE_INSTRUMENTS, DELAYED_RESPONSE);
-        triggerUIAndWait(mCanMakePaymentQueryResponded);
+        openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
         expectResultContains(new String[]{"true"});
     }
 }
