@@ -65,12 +65,28 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
     /** Flag for installing a slow payment app. */
     protected static final int DELAYED_RESPONSE = 1;
 
+    /** Flag for immediately installing a payment app. */
+    protected static final int IMMEDIATE_CREATION = 0;
+
+    /** Flag for installing a payment app with a delay. */
+    protected static final int DELAYED_CREATION = 1;
+
+    /** The expiration month dropdown index for December. */
+    protected static final int DECEMBER = 11;
+
+    /** The expiration year dropdown index for the next year. */
+    protected static final int NEXT_YEAR = 1;
+
+    /** The billing address dropdown index for the first billing address. */
+    protected static final int FIRST_BILLING_ADDRESS = 0;
+
     protected final PaymentsCallbackHelper<PaymentRequestUI> mReadyForInput;
     protected final PaymentsCallbackHelper<PaymentRequestUI> mReadyToPay;
     protected final PaymentsCallbackHelper<PaymentRequestUI> mSelectionChecked;
     protected final PaymentsCallbackHelper<PaymentRequestUI> mResultReady;
     protected final PaymentsCallbackHelper<CardUnmaskPrompt> mReadyForUnmaskInput;
     protected final PaymentsCallbackHelper<CardUnmaskPrompt> mReadyToUnmask;
+    protected final PaymentsCallbackHelper<CardUnmaskPrompt> mUnmaskValidationDone;
     protected final CallbackHelper mReadyToEdit;
     protected final CallbackHelper mEditorValidationError;
     protected final CallbackHelper mEditorTextUpdate;
@@ -95,6 +111,7 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
         mResultReady = new PaymentsCallbackHelper<>();
         mReadyForUnmaskInput = new PaymentsCallbackHelper<>();
         mReadyToUnmask = new PaymentsCallbackHelper<>();
+        mUnmaskValidationDone = new PaymentsCallbackHelper<>();
         mReadyToEdit = new CallbackHelper();
         mEditorValidationError = new CallbackHelper();
         mEditorTextUpdate = new CallbackHelper();
@@ -111,31 +128,32 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
     }
 
     @Override
-    public void startMainActivity() throws InterruptedException {}
+    public void startMainActivity() throws InterruptedException {
+        startMainActivityWithURL(mTestFilePath);
+    }
 
     protected abstract void onMainActivityStarted()
             throws InterruptedException, ExecutionException, TimeoutException;
 
     protected void triggerUIAndWait(PaymentsCallbackHelper<PaymentRequestUI> helper)
             throws InterruptedException, ExecutionException, TimeoutException {
-        triggerUIAndWait("buy", (CallbackHelper) helper);
+        openPageAndClickNodeAndWait("buy", helper);
         mUI = helper.getTarget();
     }
 
-    protected void triggerUIAndWait(CallbackHelper helper)
+    protected void openPageAndClickBuyAndWait(CallbackHelper helper)
             throws InterruptedException, ExecutionException, TimeoutException {
-        triggerUIAndWait("buy", helper);
+        openPageAndClickNodeAndWait("buy", helper);
     }
 
     protected void triggerUIAndWait(String nodeId, PaymentsCallbackHelper<PaymentRequestUI> helper)
             throws InterruptedException, ExecutionException, TimeoutException {
-        triggerUIAndWait(nodeId, (CallbackHelper) helper);
+        openPageAndClickNodeAndWait(nodeId, helper);
         mUI = helper.getTarget();
     }
 
-    protected void triggerUIAndWait(String nodeId, CallbackHelper helper)
+    protected void openPageAndClickNodeAndWait(String nodeId, CallbackHelper helper)
             throws InterruptedException, ExecutionException, TimeoutException {
-        startMainActivityWithURL(mTestFilePath);
         onMainActivityStarted();
         ThreadUtils.runOnUiThreadBlocking(new Runnable() {
             @Override
@@ -310,7 +328,7 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
         });
     }
 
-    /**  Returns the the number of payment instruments. */
+    /**  Returns the number of payment instruments. */
     protected int getNumberOfPaymentInstruments() throws ExecutionException {
         return ThreadUtils.runOnUiThreadBlocking(new Callable<Integer>() {
             @Override
@@ -321,7 +339,7 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
         });
     }
 
-    /**  Returns the the number of contact detail suggestions. */
+    /**  Returns the number of contact detail suggestions. */
     protected int getNumberOfContactDetailSuggestions() throws ExecutionException {
         return ThreadUtils.runOnUiThreadBlocking(new Callable<Integer>() {
             @Override
@@ -434,6 +452,11 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
         });
     }
 
+    /** Returns the error message visible to the user in the credit card unmask prompt. */
+    protected String getUnmaskPromptErrorMessage() {
+        return mCardUnmaskPrompt.getErrorMessage();
+    }
+
     /** Selects the spinner value in the editor UI for credit cards. */
     protected void setSpinnerSelectionsInCardEditorAndWait(final int[] selections,
             CallbackHelper helper) throws InterruptedException, TimeoutException {
@@ -520,8 +543,10 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
         ThreadUtils.runOnUiThreadBlocking(new Runnable() {
             @Override
             public void run() {
-                ((EditText) mCardUnmaskPrompt.getDialogForTest().findViewById(resourceId))
-                        .setText(input);
+                EditText editText =
+                        ((EditText) mCardUnmaskPrompt.getDialogForTest().findViewById(resourceId));
+                editText.setText(input);
+                editText.getOnFocusChangeListener().onFocusChange(null, false);
             }
         });
         helper.waitForCallback(callCount);
@@ -537,8 +562,10 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
             @Override
             public void run() {
                 for (int i = 0; i < resourceIds.length; ++i) {
-                    ((EditText) mCardUnmaskPrompt.getDialogForTest().findViewById(resourceIds[i]))
-                            .setText(values[i]);
+                    EditText editText = ((EditText) mCardUnmaskPrompt.getDialogForTest()
+                            .findViewById(resourceIds[i]));
+                    editText.setText(values[i]);
+                    editText.getOnFocusChangeListener().onFocusChange(null, false);
                 }
             }
         });
@@ -575,6 +602,57 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
         });
     }
 
+    /**  Will fail if the OptionRow at |index| is not selected in Contact Details.*/
+    protected void expectContactDetailsRowIsSelected(final int index)
+            throws ExecutionException, InterruptedException {
+        CriteriaHelper.pollInstrumentationThread(new Criteria() {
+            @Override
+            public boolean isSatisfied() {
+                boolean isSelected = ((OptionSection) mUI.getContactDetailsSectionForTest())
+                                             .getOptionRowAtIndex(index)
+                                             .isChecked();
+                if (!isSelected) {
+                    updateFailureReason("Contact Details row at " + index + " was not selected.");
+                }
+                return isSelected;
+            }
+        });
+    }
+
+    /**  Will fail if the OptionRow at |index| is not selected in Shipping Address section.*/
+    protected void expectShippingAddressRowIsSelected(final int index)
+            throws ExecutionException, InterruptedException {
+        CriteriaHelper.pollInstrumentationThread(new Criteria() {
+            @Override
+            public boolean isSatisfied() {
+                boolean isSelected = ((OptionSection) mUI.getShippingAddressSectionForTest())
+                                             .getOptionRowAtIndex(index)
+                                             .isChecked();
+                if (!isSelected) {
+                    updateFailureReason("Shipping Address row at " + index + " was not selected.");
+                }
+                return isSelected;
+            }
+        });
+    }
+
+    /**  Will fail if the OptionRow at |index| is not selected in PaymentMethod section.*/
+    protected void expectPaymentMethodRowIsSelected(final int index)
+            throws ExecutionException, InterruptedException {
+        CriteriaHelper.pollInstrumentationThread(new Criteria() {
+            @Override
+            public boolean isSatisfied() {
+                boolean isSelected = ((OptionSection) mUI.getPaymentMethodSectionForTest())
+                                             .getOptionRowAtIndex(index)
+                                             .isChecked();
+                if (!isSelected) {
+                    updateFailureReason("Payment Method row at " + index + " was not selected.");
+                }
+                return isSelected;
+            }
+        });
+    }
+
     @Override
     public void onPaymentRequestReadyForInput(PaymentRequestUI ui) {
         ThreadUtils.assertOnUiThread();
@@ -666,6 +744,12 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
         mReadyToUnmask.notifyCalled(prompt);
     }
 
+    @Override
+    public void onCardUnmaskPromptValidationDone(CardUnmaskPrompt prompt) {
+        ThreadUtils.assertOnUiThread();
+        mUnmaskValidationDone.notifyCalled(prompt);
+    }
+
     /**
      * Listens for UI notifications.
      */
@@ -699,7 +783,7 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
      * @param instrumentPresence Whether the app has any payment instruments. Either NO_INSTRUMENTS
      *                           or HAVE_INSTRUMENTS.
      * @param responseSpeed      How quickly the app will respond to "get instruments" query. Either
-     *                           IMMEDIATE_RESPONSE, DELAYED_RESPONSE, or NO_RESPONSE.
+     *                           IMMEDIATE_RESPONSE or DELAYED_RESPONSE.
      * @return The installed payment app.
      */
     protected TestPay installPaymentApp(final int instrumentPresence, final int responseSpeed) {
@@ -713,18 +797,45 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
      * @param instrumentPresence Whether the app has any payment instruments. Either NO_INSTRUMENTS
      *                           or HAVE_INSTRUMENTS.
      * @param responseSpeed      How quickly the app will respond to "get instruments" query. Either
-     *                           IMMEDIATE_RESPONSE, DELAYED_RESPONSE, or NO_RESPONSE.
+     *                           IMMEDIATE_RESPONSE or DELAYED_RESPONSE.
      * @return The installed payment app.
      */
     protected TestPay installPaymentApp(final String methodName, final int instrumentPresence,
             final int responseSpeed) {
+        return installPaymentApp(methodName, instrumentPresence, responseSpeed, IMMEDIATE_CREATION);
+    }
+
+    /**
+     * Installs a payment app for testing.
+     *
+     * @param methodName         The name of the payment method used in the payment app.
+     * @param instrumentPresence Whether the app has any payment instruments. Either NO_INSTRUMENTS
+     *                           or HAVE_INSTRUMENTS.
+     * @param responseSpeed      How quickly the app will respond to "get instruments" query. Either
+     *                           IMMEDIATE_RESPONSE or DELAYED_RESPONSE.
+     * @param creationSpeed      How quickly the app factory will create this app. Either
+     *                           IMMEDIATE_CREATION or DELAYED_CREATION.
+     * @return The installed payment app.
+     */
+    protected TestPay installPaymentApp(final String methodName, final int instrumentPresence,
+            final int responseSpeed, final int creationSpeed) {
         final TestPay app = new TestPay(methodName, instrumentPresence, responseSpeed);
-        PaymentAppFactory.setAdditionalFactory(new PaymentAppFactoryAddition() {
+        PaymentAppFactory.getInstance().addAdditionalFactory(new PaymentAppFactoryAddition() {
             @Override
-            public List<PaymentApp> create(Context context, WebContents webContents) {
-                List<PaymentApp> additionalApps = new ArrayList<>();
-                additionalApps.add(app);
-                return additionalApps;
+            public void create(Context context, WebContents webContents,
+                    final PaymentAppFactory.PaymentAppCreatedCallback callback) {
+                if (creationSpeed == IMMEDIATE_CREATION) {
+                    callback.onPaymentAppCreated(app);
+                    callback.onAllPaymentAppsCreated();
+                } else {
+                    new Handler().postDelayed(new Runnable() {
+                        @Override
+                        public void run() {
+                            callback.onPaymentAppCreated(app);
+                            callback.onAllPaymentAppsCreated();
+                        }
+                    }, 100);
+                }
             }
         });
         return app;
@@ -776,6 +887,12 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
             return methodNames;
         }
 
+        @Override
+        public boolean supportsMethodsAndData(Map<String, PaymentMethodData> methodsAndData) {
+            assert methodsAndData != null;
+            return methodsAndData.containsKey(mMethodName);
+        }
+
         @Override
         public String getAppIdentifier() {
             return mMethodName;
@@ -792,13 +909,15 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
         }
 
         @Override
-        public String getInstrumentMethodName() {
-            return mMethodName;
+        public Set<String> getInstrumentMethodNames() {
+            Set<String> result = new HashSet<>();
+            result.add(mMethodName);
+            return result;
         }
 
         @Override
-        public void getInstrumentDetails(String merchantName, String origin, PaymentItem total,
-                List<PaymentItem> cart, PaymentMethodData details,
+        public void invokePaymentApp(String merchantName, String origin, PaymentItem total,
+                List<PaymentItem> cart, Map<String, PaymentMethodData> methodData,
                 InstrumentDetailsCallback detailsCallback) {
             detailsCallback.onInstrumentDetailsReady(
                     mMethodName, "{\"transaction\": 1337}");
