@@ -5,6 +5,7 @@
 package org.chromium.chrome.browser.physicalweb;
 
 import android.app.Instrumentation.ActivityMonitor;
+import android.bluetooth.BluetoothDevice;
 import android.content.ComponentName;
 import android.content.Context;
 import android.content.ContextWrapper;
@@ -82,7 +83,8 @@ public class ListUrlsActivityTest extends InstrumentationTestCase {
         assertTrue(prefsManager.isPhysicalWebEnabled());
 
         // Add URLs.
-        addUrl(URL, TITLE, DESC);
+        String deviceAddress = "00:11:22:33:AA:BB";
+        addUrl(new UrlInfo(URL).setDeviceAddress(deviceAddress), TITLE, DESC);
 
         // Launch the Activity.
         ListUrlsActivity listActivity = launchActivity();
@@ -101,7 +103,11 @@ public class ListUrlsActivityTest extends InstrumentationTestCase {
 
         // Test the fired intent.
         assertEquals(1, testContextWrapper.startedIntents.size());
-        assertEquals(URL, testContextWrapper.startedIntents.get(0).getDataString());
+        Intent intent = testContextWrapper.startedIntents.get(0);
+        assertEquals(URL, intent.getDataString());
+        assertTrue(intent.hasExtra(BluetoothDevice.EXTRA_DEVICE));
+        BluetoothDevice device = intent.getParcelableExtra(BluetoothDevice.EXTRA_DEVICE);
+        assertEquals(deviceAddress, device.getAddress());
     }
 
     @SmallTest
@@ -239,12 +245,16 @@ public class ListUrlsActivityTest extends InstrumentationTestCase {
         assertEquals(0, entries.size());
     }
 
-    public void addUrl(String url, String title, String desc) {
+    private void addUrl(String url, String title, String desc) {
+        addUrl(new UrlInfo(url), title, desc);
+    }
+
+    private void addUrl(UrlInfo urlInfo, String title, String desc) {
         ArrayList<PwsResult> results = new ArrayList<>();
-        results.add(new PwsResult(url, url, null, title, desc, null));
+        results.add(new PwsResult(urlInfo.getUrl(), urlInfo.getUrl(), null, title, desc, null));
         mMockPwsClient.addPwsResults(results);
         mMockPwsClient.addPwsResults(results);
-        UrlManager.getInstance().addUrl(new UrlInfo(url));
+        UrlManager.getInstance().addUrl(urlInfo);
         getInstrumentation().waitForIdleSync();
     }
 
