@@ -262,6 +262,30 @@ public class UrlManagerTest extends InstrumentationTestCase {
         assertTrue(mUrlManager.containsInAnyCache(URL2));
     }
 
+    @SmallTest
+    public void testAddUrlUpdatesCache() throws Exception {
+        addEmptyPwsResult();
+        addEmptyPwsResult();
+
+        UrlInfo urlInfo = new UrlInfo(URL1);
+        mUrlManager.addUrl(urlInfo);
+        List<UrlInfo> urls = mUrlManager.getUrls(true);
+        assertEquals(1, urls.size());
+        assertEquals(urlInfo.getDistance(), urls.get(0).getDistance());
+        assertEquals(urlInfo.getDeviceAddress(), urls.get(0).getDeviceAddress());
+        assertEquals(urlInfo.getScanTimestamp(), urls.get(0).getScanTimestamp());
+
+        urlInfo = new UrlInfo(URL1)
+                .setDistance(100.0)
+                .setDeviceAddress("00:11:22:33:AA:BB");
+        mUrlManager.addUrl(urlInfo);
+        urls = mUrlManager.getUrls(true);
+        assertEquals(1, urls.size());
+        assertEquals(urlInfo.getDistance(), urls.get(0).getDistance());
+        assertEquals(urlInfo.getDeviceAddress(), urls.get(0).getDeviceAddress());
+        assertEquals(urlInfo.getScanTimestamp(), urls.get(0).getScanTimestamp());
+    }
+
     @SmallTest
     @RetryOnFailure
     public void testAddUrlTwiceWorks() throws Exception {
@@ -408,6 +432,31 @@ public class UrlManagerTest extends InstrumentationTestCase {
         assertEquals(URL1, urlInfos.get(2).getUrl());
     }
 
+    @SmallTest
+    public void testSerializationWorksWithPoorlySerializedResult() throws Exception {
+        addPwsResult1();
+        addPwsResult2();
+        long curTime = System.currentTimeMillis();
+        mUrlManager.addUrl(new UrlInfo(URL1, 99.5, curTime + 42));
+        mUrlManager.addUrl(new UrlInfo(URL2, 100.5, curTime + 43));
+        getInstrumentation().waitForIdleSync();
+
+        // Create an invalid serialization.
+        Set<String> serializedUrls = new HashSet<>();
+        serializedUrls.add(new UrlInfo(URL1, 99.5, curTime + 42).jsonSerialize().toString());
+        serializedUrls.add("{\"not_a_value\": \"This is totally not a serialized UrlInfo.\"}");
+        mSharedPreferences.edit()
+                .putStringSet("physicalweb_all_urls", serializedUrls)
+                .apply();
+
+        // Make sure only the properly serialized URL is restored.
+        Context context = getInstrumentation().getTargetContext().getApplicationContext();
+        UrlManager urlManager = new UrlManager(context);
+        List<UrlInfo> urlInfos = urlManager.getUrls();
+        assertEquals(1, urlInfos.size());
+        assertEquals(URL1, urlInfos.get(0).getUrl());
+    }
+
     @SmallTest
     @RetryOnFailure
     public void testSerializationWorksWithoutGarbageCollection() throws Exception {
