@@ -89,7 +89,7 @@ public class PasswordViewingTypeTest extends NativeLibraryTestBase {
             }
 
             @Override
-            public boolean isBackendInitialized() {
+            public boolean isEngineInitialized() {
                 return true;
             }
         }
@@ -133,7 +133,7 @@ public class PasswordViewingTypeTest extends NativeLibraryTestBase {
         ThreadUtils.runOnUiThreadBlocking(new Runnable() {
             @Override
             public void run() {
-                assertTrue(ProfileSyncService.get().isBackendInitialized());
+                assertTrue(ProfileSyncService.get().isEngineInitialized());
                 assertFalse(ProfileSyncService.get().isUsingSecondaryPassphrase());
             }
         });
