@@ -9,9 +9,12 @@ import android.test.suitebuilder.annotation.SmallTest;
 
 import org.chromium.base.ThreadUtils;
 import org.chromium.base.test.util.Feature;
+import org.chromium.base.test.util.Restriction;
+import org.chromium.base.test.util.RetryOnFailure;
 import org.chromium.chrome.browser.search_engines.TemplateUrlService.LoadListener;
 import org.chromium.chrome.browser.search_engines.TemplateUrlService.TemplateUrl;
 import org.chromium.chrome.test.util.ApplicationData;
+import org.chromium.chrome.test.util.ChromeRestriction;
 import org.chromium.content.browser.test.NativeLibraryTestBase;
 import org.chromium.content.browser.test.util.Criteria;
 import org.chromium.content.browser.test.util.CriteriaHelper;
@@ -48,6 +51,7 @@ public class TemplateUrlServiceTest extends NativeLibraryTestBase {
 
     @SmallTest
     @Feature({"ContextualSearch"})
+    @RetryOnFailure
     public void testUrlForContextualSearchQueryValid()
             throws InterruptedException, ExecutionException {
         waitForTemplateUrlServiceToLoad();
@@ -90,6 +94,8 @@ public class TemplateUrlServiceTest extends NativeLibraryTestBase {
 
     @SmallTest
     @Feature({"SearchEngines"})
+    @RetryOnFailure
+    @Restriction(ChromeRestriction.RESTRICTION_TYPE_PHONE) // see crbug.com/581268
     public void testLoadUrlService() throws InterruptedException {
         assertFalse(ThreadUtils.runOnUiThreadBlockingNoException(new Callable<Boolean>() {
             @Override
@@ -113,35 +119,40 @@ public class TemplateUrlServiceTest extends NativeLibraryTestBase {
     public void testSetAndGetSearchEngine() throws InterruptedException {
         final TemplateUrlService templateUrlService = waitForTemplateUrlServiceToLoad();
 
-        // Ensure known state of default search index before running test.
-        int searchEngineIndex = ThreadUtils.runOnUiThreadBlockingNoException(
-                new Callable<Integer>() {
+        List<TemplateUrl> searchEngines =
+                ThreadUtils.runOnUiThreadBlockingNoException(new Callable<List<TemplateUrl>>() {
                     @Override
-                    public Integer call() throws Exception {
-                        return templateUrlService.getDefaultSearchEngineIndex();
+                    public List<TemplateUrl> call() throws Exception {
+                        return templateUrlService.getSearchEngines();
                     }
                 });
-        assertEquals(0, searchEngineIndex);
+        // Ensure known state of default search index before running test.
+        String searchEngineKeyword =
+                ThreadUtils.runOnUiThreadBlockingNoException(new Callable<String>() {
+                    @Override
+                    public String call() throws Exception {
+                        return templateUrlService.getDefaultSearchEngineTemplateUrl().getKeyword();
+                    }
+                });
+        assertEquals(searchEngines.get(0).getKeyword(), searchEngineKeyword);
 
         // Set search engine index and verified it stuck.
         ThreadUtils.runOnUiThreadBlocking(new Runnable() {
             @Override
             public void run() {
-                List<TemplateUrl> searchEngines =
-                        templateUrlService.getLocalizedSearchEngines();
+                List<TemplateUrl> searchEngines = templateUrlService.getSearchEngines();
                 assertTrue("There must be more than one search engine to change searchEngines",
                         searchEngines.size() > 1);
-                templateUrlService.setSearchEngine(1);
+                templateUrlService.setSearchEngine(searchEngines.get(1).getKeyword());
             }
         });
-        searchEngineIndex = ThreadUtils.runOnUiThreadBlockingNoException(
-                new Callable<Integer>() {
-                    @Override
-                    public Integer call() throws Exception {
-                        return templateUrlService.getDefaultSearchEngineIndex();
-                    }
-                });
-        assertEquals(1, searchEngineIndex);
+        searchEngineKeyword = ThreadUtils.runOnUiThreadBlockingNoException(new Callable<String>() {
+            @Override
+            public String call() throws Exception {
+                return templateUrlService.getDefaultSearchEngineTemplateUrl().getKeyword();
+            }
+        });
+        assertEquals(searchEngines.get(1).getKeyword(), searchEngineKeyword);
     }
 
     private TemplateUrlService waitForTemplateUrlServiceToLoad() throws InterruptedException {
