@@ -4,7 +4,6 @@
 
 package org.chromium.chrome.browser.video;
 
-import android.os.Environment;
 import android.test.suitebuilder.annotation.LargeTest;
 
 import org.chromium.base.test.util.DisableIf;
@@ -33,8 +32,8 @@ public class VideoTest extends ChromeActivityTestCaseBase<ChromeActivity> {
     @LargeTest
     @RetryOnFailure
     public void testLoadMediaUrl() throws InterruptedException, TimeoutException {
-        EmbeddedTestServer testServer = EmbeddedTestServer.createAndStartFileServer(
-                getInstrumentation().getContext(), Environment.getExternalStorageDirectory());
+        EmbeddedTestServer testServer = EmbeddedTestServer.createAndStartServer(
+                getInstrumentation().getContext());
         try {
             Tab tab = getActivity().getActivityTab();
             TabTitleObserver titleObserver = new TabTitleObserver(tab, "ready_to_play");
