@@ -17,7 +17,9 @@
 #include "base/debug/leak_annotations.h"
 #include "base/format_macros.h"
 #include "chrome/common/chrome_result_codes.h"
+#include "chrome/install_static/install_details.h"
 #include "chrome/install_static/install_util.h"
+#include "chrome/install_static/user_data_dir.h"
 #include "components/crash/content/app/crashpad.h"
 #include "components/crash/core/common/crash_keys.h"
 
@@ -46,6 +48,18 @@ constexpr char kGPUPixelShaderVersion[] = "gpu-psver";
 constexpr char kGPUVertexShaderVersion[] = "gpu-vsver";
 
 constexpr char kHungAudioThreadDetails[] = "hung-audio-thread-details";
+constexpr char kHungRendererOutstandingAckCount[] = "hung-outstanding-acks";
+constexpr char kHungRendererOutstandingEventType[] =
+    "hung-outstanding-event-type";
+constexpr char kHungRendererLastEventType[] = "hung-last-event-type";
+constexpr char kHungRendererReason[] = "hung-reason";
+constexpr char kInputEventFilterSendFailure[] =
+    "input-event-filter-send-failure";
+
+constexpr char kThirdPartyModulesLoaded[] = "third-party-modules-loaded";
+constexpr char kThirdPartyModulesNotLoaded[] = "third-party-modules-not-loaded";
+
+constexpr char kEnrolledToDomain[] = "enrolled-to-domain";
 
 constexpr char kViewCount[] = "view-count";
 constexpr char kZeroEncodeDetails[] = "zero-encode-details";
@@ -89,16 +103,27 @@ size_t RegisterCrashKeysHelper() {
       {kGPUPixelShaderVersion, kSmallSize},
       {kGPUVertexShaderVersion, kSmallSize},
 
+      // browser/:
+      {kThirdPartyModulesLoaded, kSmallSize},
+      {kThirdPartyModulesNotLoaded, kSmallSize},
+      {kEnrolledToDomain, kSmallSize},
+
       // content/:
       {"bad_message_reason", kSmallSize},
       {"discardable-memory-allocated", kSmallSize},
       {"discardable-memory-free", kSmallSize},
       {kFontKeyName, kSmallSize},
+      { "mojo-message-error", kMediumSize },
       {"ppapi_path", kMediumSize},
       {"subresource_url", kLargeSize},
       {"total-discardable-memory-allocated", kSmallSize},
       {kBug464926CrashKey, kSmallSize},
       {kViewCount, kSmallSize},
+      {kHungRendererOutstandingAckCount, kSmallSize},
+      {kHungRendererOutstandingEventType, kSmallSize},
+      {kHungRendererLastEventType, kSmallSize},
+      {kHungRendererReason, kSmallSize},
+      {kInputEventFilterSendFailure, kSmallSize},
 
       // media/:
       {kHungAudioThreadDetails, kSmallSize},
@@ -172,13 +197,13 @@ size_t RegisterCrashKeysHelper() {
       {"swdh_register_cannot_scope_url", crash_keys::kLargeSize},
       {"swdh_register_cannot_script_url", crash_keys::kLargeSize},
 
-      // Temporary for https://crbug.com/619294.
-      {"swdh_unregister_cannot_host_url", crash_keys::kLargeSize},
-      {"swdh_unregister_cannot_scope_url", crash_keys::kLargeSize},
-
       // Temporary for https://crbug.com/630496.
       {"swdh_get_registration_cannot_host_url", crash_keys::kLargeSize},
       {"swdh_get_registration_cannot_document_url", crash_keys::kLargeSize},
+
+      // Temporary for https://crbug.com/668633.
+      {"swdh_set_hosted_version_worker_pid", crash_keys::kSmallSize},
+      {"swdh_set_hosted_version_host_pid", crash_keys::kSmallSize},
   };
 
   // This dynamic set of keys is used for sets of key value pairs when gathering
@@ -232,12 +257,12 @@ void ChromeCrashReporterClient::InitializeCrashReportingForProcess() {
   instance = new ChromeCrashReporterClient();
   ANNOTATE_LEAKING_OBJECT_PTR(instance);
 
-  std::string process_type = install_static::GetSwitchValueFromCommandLine(
-      ::GetCommandLineA(), install_static::kProcessType);
+  std::wstring process_type = install_static::GetSwitchValueFromCommandLine(
+      ::GetCommandLine(), install_static::kProcessType);
   if (process_type != install_static::kCrashpadHandler) {
     crash_reporter::SetCrashReporterClient(instance);
-    crash_reporter::InitializeCrashpadWithEmbeddedHandler(process_type.empty(),
-                                                          process_type);
+    crash_reporter::InitializeCrashpadWithEmbeddedHandler(
+        process_type.empty(), install_static::UTF16ToUTF8(process_type));
   }
 }
 #endif  // NACL_WIN64
@@ -307,23 +332,20 @@ bool ChromeCrashReporterClient::GetDeferredUploadsSupported(
   return false;
 }
 
+// TODO(grt): Remove |exe_path| from crash_reporter::CrashReporterClient.
 bool ChromeCrashReporterClient::GetIsPerUserInstall(
     const base::string16& exe_path) {
-  return !install_static::IsSystemInstall(exe_path.c_str());
+  return !install_static::InstallDetails::Get().system_level();
 }
 
+// TODO(grt): Remove |is_per_user_install| from
+// crash_reporter::CrashReporterClient.
 bool ChromeCrashReporterClient::GetShouldDumpLargerDumps(
     bool is_per_user_install) {
-  base::string16 channel_name;
-  install_static::GetChromeChannelName(is_per_user_install,
-                                       false, // !add_modifier
-                                       &channel_name);
-  // Capture more detail in crash dumps for Beta, Dev, Canary channels and
-  // if channel is unknown (e.g. Chromium or developer builds).
-  return (channel_name == install_static::kChromeChannelBeta ||
-          channel_name == install_static::kChromeChannelDev ||
-          channel_name == install_static::kChromeChannelCanary ||
-          channel_name == install_static::kChromeChannelUnknown);
+  // Capture larger dumps for Google Chrome "beta", "dev", and "canary"
+  // channels. Stable channel and Chromium builds are on channel "", and use
+  // smaller dumps.
+  return !install_static::InstallDetails::Get().channel().empty();
 }
 
 int ChromeCrashReporterClient::GetResultCodeRespawnFailed() {
@@ -353,14 +375,13 @@ bool ChromeCrashReporterClient::GetCrashDumpLocation(
   if (GetAlternativeCrashDumpLocation(crash_dir))
     return true;
 
-  // TODO(scottmg): Consider supporting --user-data-dir. See
-  // https://crbug.com/565446.
-  return install_static::GetDefaultCrashDumpLocation(crash_dir);
+  *crash_dir = install_static::GetCrashDumpLocation();
+  return true;
 }
 
 bool ChromeCrashReporterClient::GetCrashMetricsLocation(
     base::string16* metrics_dir) {
-  return install_static::GetDefaultUserDataDirectory(metrics_dir);
+  return install_static::GetUserDataDirectory(metrics_dir, nullptr);
 }
 
 // TODO(ananta)
@@ -384,7 +405,7 @@ bool ChromeCrashReporterClient::GetCollectStatsInSample() {
 
 bool ChromeCrashReporterClient::EnableBreakpadForProcess(
     const std::string& process_type) {
-  return process_type == install_static::kRendererProcess ||
-         process_type == install_static::kPpapiPluginProcess ||
-         process_type == install_static::kGpuProcess;
+  // This is not used by Crashpad (at least on Windows).
+  NOTREACHED();
+  return true;
 }
