@@ -5,6 +5,8 @@
 #include "chrome/app/mash/mash_runner.h"
 
 #include "base/at_exit.h"
+#include "base/base_paths.h"
+#include "base/base_switches.h"
 #include "base/bind.h"
 #include "base/command_line.h"
 #include "base/debug/debugger.h"
@@ -13,8 +15,12 @@
 #include "base/logging.h"
 #include "base/memory/ptr_util.h"
 #include "base/message_loop/message_loop.h"
+#include "base/path_service.h"
 #include "base/process/launch.h"
+#include "base/process/process.h"
 #include "base/run_loop.h"
+#include "base/task_scheduler/task_scheduler.h"
+#include "base/threading/sequenced_worker_pool.h"
 #include "base/trace_event/trace_event.h"
 #include "components/tracing/common/trace_to_console.h"
 #include "components/tracing/common/tracing_switches.h"
@@ -30,11 +36,12 @@
 #include "services/service_manager/public/cpp/identity.h"
 #include "services/service_manager/public/cpp/service.h"
 #include "services/service_manager/public/cpp/service_context.h"
+#include "services/service_manager/public/cpp/standalone_service/standalone_service.h"
 #include "services/service_manager/public/interfaces/service_factory.mojom.h"
+#include "services/service_manager/runner/common/client_util.h"
 #include "services/service_manager/runner/common/switches.h"
-#include "services/service_manager/runner/host/child_process.h"
-#include "services/service_manager/runner/host/child_process_base.h"
 #include "services/service_manager/runner/init.h"
+#include "services/service_manager/standalone/context.h"
 #include "ui/base/resource/resource_bundle.h"
 #include "ui/base/ui_base_paths.h"
 #include "ui/base/ui_base_switches.h"
@@ -90,6 +97,12 @@ class NativeRunnerDelegateImpl : public service_manager::NativeRunnerDelegate {
   void AdjustCommandLineArgumentsForTarget(
       const service_manager::Identity& target,
       base::CommandLine* command_line) override {
+    if (target.name() == kChromeMashServiceName ||
+        target.name() == content::mojom::kBrowserServiceName) {
+      base::FilePath exe_path;
+      base::PathService::Get(base::FILE_EXE, &exe_path);
+      command_line->SetProgram(exe_path);
+    }
     if (target.name() != content::mojom::kBrowserServiceName) {
       // If running anything other than the browser process, launch a mash
       // child process. The new process will execute MashRunner::RunChild().
@@ -102,12 +115,13 @@ class NativeRunnerDelegateImpl : public service_manager::NativeRunnerDelegate {
 
     // When launching the browser process, ensure that we don't inherit the
     // --mash flag so it proceeds with the normal content/browser startup path.
-    base::CommandLine::StringVector argv(command_line->argv());
-    auto iter =
-        std::find(argv.begin(), argv.end(), FILE_PATH_LITERAL("--mash"));
-    if (iter != argv.end())
-      argv.erase(iter);
-    *command_line = base::CommandLine(argv);
+    // Eliminate all copies in case the developer passed more than one.
+    base::CommandLine::StringVector new_argv;
+    for (const base::CommandLine::StringType& arg : command_line->argv()) {
+      if (arg != FILE_PATH_LITERAL("--mash"))
+        new_argv.push_back(arg);
+    }
+    *command_line = base::CommandLine(new_argv);
   }
 
   DISALLOW_COPY_AND_ASSIGN(NativeRunnerDelegateImpl);
@@ -127,6 +141,10 @@ int MashRunner::Run() {
 }
 
 void MashRunner::RunMain() {
+  base::TaskScheduler::CreateAndSetSimpleTaskScheduler(
+      service_manager::kThreadPoolMaxThreads);
+  base::SequencedWorkerPool::EnableWithRedirectionToTaskSchedulerForProcess();
+
   // TODO(sky): refactor BackgroundServiceManager so can supply own context, we
   // shouldn't we using context as it has a lot of stuff we don't really want
   // in chrome.
@@ -169,19 +187,21 @@ void MashRunner::RunMain() {
   // Ping mash_session to ensure an instance is brought up
   context_->connector()->Connect("mash_session");
   base::RunLoop().Run();
+
+  base::TaskScheduler::GetInstance()->Shutdown();
 }
 
 int MashRunner::RunChild() {
-  base::FilePath path =
-      base::CommandLine::ForCurrentProcess()->GetSwitchValuePath(
-          switches::kChildProcess);
-  if (base::PathExists(path))
-    return service_manager::ChildProcessMain();
+  // TODO(fdoray): Add TaskScheduler initialization code in
+  // service_manager::ServiceRunner. TaskScheduler can't be initialized here
+  // because it wouldn't be visible to the service's dynamic library.
+  // https://crbug.com/664996
+
+  service_manager::WaitForDebuggerIfNecessary();
 
-  // If the path doesn't exist - try launching this as a packaged service.
   base::i18n::InitializeICU();
   InitializeResources();
-  service_manager::ChildProcessMainWithCallback(
+  service_manager::RunStandaloneService(
       base::Bind(&MashRunner::StartChildApp, base::Unretained(this)));
   return 0;
 }
@@ -225,3 +245,23 @@ int MashMain() {
   MashRunner mash_runner;
   return mash_runner.Run();
 }
+
+void WaitForMashDebuggerIfNecessary() {
+  if (!service_manager::ServiceManagerIsRemote())
+    return;
+
+  const base::CommandLine* command_line =
+      base::CommandLine::ForCurrentProcess();
+  const std::string service_name =
+      command_line->GetSwitchValueASCII(switches::kProcessServiceName);
+  if (service_name !=
+      command_line->GetSwitchValueASCII(switches::kWaitForDebugger)) {
+    return;
+  }
+
+  // Include the pid as logging may not have been initialized yet (the pid
+  // printed out by logging is wrong).
+  LOG(WARNING) << "waiting for debugger to attach for service " << service_name
+               << " pid=" << base::Process::Current().Pid();
+  base::debug::WaitForDebugger(120, true);
+}
