@@ -2,10 +2,11 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#include <utility>
-
 #include "chrome/browser/android/banners/app_banner_manager_android.h"
 
+#include <memory>
+#include <utility>
+
 #include "base/android/jni_android.h"
 #include "base/android/jni_string.h"
 #include "base/memory/ptr_util.h"
@@ -16,9 +17,9 @@
 #include "chrome/browser/android/webapk/webapk_metrics.h"
 #include "chrome/browser/android/webapk/webapk_web_manifest_checker.h"
 #include "chrome/browser/banners/app_banner_metrics.h"
+#include "chrome/browser/banners/app_banner_settings_helper.h"
 #include "chrome/browser/manifest/manifest_icon_downloader.h"
 #include "chrome/browser/manifest/manifest_icon_selector.h"
-#include "chrome/common/chrome_constants.h"
 #include "content/public/browser/web_contents.h"
 #include "content/public/common/frame_navigate_params.h"
 #include "jni/AppBannerManager_jni.h"
@@ -43,7 +44,7 @@ std::unique_ptr<ShortcutInfo> CreateShortcutInfo(
   if (!manifest.IsEmpty()) {
     shortcut_info->UpdateFromManifest(manifest);
     shortcut_info->manifest_url = manifest_url;
-    shortcut_info->icon_url = icon_url;
+    shortcut_info->best_icon_url = icon_url;
     shortcut_info->UpdateSource(ShortcutInfo::SOURCE_APP_BANNER);
   }
   return shortcut_info;
@@ -128,7 +129,7 @@ std::string AppBannerManagerAndroid::GetAppIdentifier() {
 
 std::string AppBannerManagerAndroid::GetBannerType() {
   return native_app_data_.is_null() ? AppBannerManager::GetBannerType()
-                                    : "android";
+                                    : "play";
 }
 
 int AppBannerManagerAndroid::GetIdealIconSizeInDp() {
@@ -199,7 +200,6 @@ void AppBannerManagerAndroid::ShowBanner() {
             contents, GetWeakPtr(), app_title_,
             CreateShortcutInfo(manifest_url_, manifest_, icon_url_),
             std::move(icon_), event_request_id(),
-            ChromeWebApkHost::AreWebApkEnabled(),
             webapk::INSTALL_SOURCE_BANNER)) {
       RecordDidShowBanner("AppBanner.WebApp.Shown");
       TrackDisplayEvent(DISPLAY_EVENT_WEB_APP_BANNER_CREATED);
@@ -288,6 +288,13 @@ bool AppBannerManagerAndroid::Register(JNIEnv* env) {
   return RegisterNativesImpl(env);
 }
 
+// static
+jint GetHomescreenLanguageOption(JNIEnv* env,
+                                 const JavaParamRef<jclass>& clazz) {
+  return AppBannerSettingsHelper::GetHomescreenLanguageOption();
+}
+
+
 // static
 ScopedJavaLocalRef<jobject> GetJavaBannerManagerForWebContents(
     JNIEnv* env,
@@ -299,12 +306,6 @@ ScopedJavaLocalRef<jobject> GetJavaBannerManagerForWebContents(
                 : ScopedJavaLocalRef<jobject>();
 }
 
-// static
-void DisableSecureSchemeCheckForTesting(JNIEnv* env,
-                                        const JavaParamRef<jclass>& clazz) {
-  AppBannerManager::DisableSecureSchemeCheckForTesting();
-}
-
 // static
 void SetEngagementWeights(JNIEnv* env,
                           const JavaParamRef<jclass>& clazz,
