@@ -14,7 +14,7 @@
 #include "chrome/common/chrome_features.h"
 #include "components/autofill/core/browser/autofill_experiments.h"
 #include "components/ntp_snippets/features.h"
-#include "components/offline_pages/offline_page_feature.h"
+#include "components/offline_pages/core/offline_page_feature.h"
 #include "components/password_manager/core/common/password_manager_features.h"
 #include "content/public/common/content_features.h"
 #include "jni/ChromeFeatureList_jni.h"
@@ -34,6 +34,7 @@ const base::Feature* kFeaturesExposedToJava[] = {
     &autofill::kAutofillScanCardholderName,
     &features::kConsistentOmniboxGeolocation,
     &features::kCredentialManagementAPI,
+    &features::kServiceWorkerPaymentApps,
     &features::kSimplifiedFullscreenUI,
     &features::kVrShell,
     &features::kWebPayments,
@@ -53,6 +54,7 @@ const base::Feature* kFeaturesExposedToJava[] = {
     &kSpecialLocaleWrapper,
     &kTabReparenting,
     &kWebApks,
+    &kWebPaymentsModifiers,
     &ntp_snippets::kContentSuggestionsFeature,
     &ntp_snippets::kIncreasedVisibility,
     &ntp_snippets::kForeignSessionsSuggestionsFeature,
@@ -92,12 +94,12 @@ const base::Feature kImportantSitesInCBD{"ImportantSitesInCBD",
 const base::Feature kNoCreditCardAbort{"NoCreditCardAbort",
                                        base::FEATURE_DISABLED_BY_DEFAULT};
 
-const base::Feature kNTPOfflinePagesFeature{"NTPOfflinePages",
-                                            base::FEATURE_ENABLED_BY_DEFAULT};
-
 const base::Feature kNTPFakeOmniboxTextFeature{
     "NTPFakeOmniboxText", base::FEATURE_DISABLED_BY_DEFAULT};
 
+const base::Feature kNTPOfflinePagesFeature{"NTPOfflinePages",
+                                            base::FEATURE_ENABLED_BY_DEFAULT};
+
 const base::Feature kPhysicalWebFeature{"PhysicalWeb",
                                         base::FEATURE_ENABLED_BY_DEFAULT};
 
@@ -120,6 +122,9 @@ const base::Feature kUserMediaScreenCapturing{
 // URL which opens Chrome in fullscreen.
 const base::Feature kWebApks{"WebApks", base::FEATURE_DISABLED_BY_DEFAULT};
 
+const base::Feature kWebPaymentsModifiers{"WebPaymentsModifiers",
+                                          base::FEATURE_DISABLED_BY_DEFAULT};
+
 static jboolean IsEnabled(JNIEnv* env,
                           const JavaParamRef<jclass>& clazz,
                           const JavaParamRef<jstring>& jfeature_name) {
