@@ -11,7 +11,6 @@
 #include "chrome/browser/android/compositor/layer/layer.h"
 
 namespace cc {
-class ImageLayer;
 class Layer;
 class NinePatchLayer;
 class SolidColorLayer;
@@ -26,8 +25,6 @@ namespace ui {
 class ResourceManager;
 }
 
-class SkBitmap;
-
 namespace android {
 
 class ContentLayer;
