@@ -17,11 +17,6 @@ MockDownloadController::MockDownloadController()
 
 MockDownloadController::~MockDownloadController() {}
 
-void MockDownloadController::CreateGETDownload(
-    const content::ResourceRequestInfo::WebContentsGetter& wc_getter,
-    bool must_download, const DownloadInfo& info) {
-}
-
 void MockDownloadController::OnDownloadStarted(
     content::DownloadItem* download_item) {
 }
@@ -32,11 +27,6 @@ void MockDownloadController::StartContextMenuDownload(
     bool is_link, const std::string& extra_headers) {
 }
 
-void MockDownloadController::DangerousDownloadValidated(
-    content::WebContents* web_contents,
-    const std::string& download_guid,
-    bool accept) {}
-
 void MockDownloadController::AcquireFileAccessPermission(
     content::WebContents* web_contents,
     const DownloadControllerBase::AcquireFileAccessPermissionCallback& cb) {
