@@ -15,9 +15,11 @@
 #include "base/memory/ptr_util.h"
 #include "chrome/browser/android/ntp/popular_sites.h"
 #include "chrome/browser/browser_process.h"
+#include "chrome/browser/favicon/favicon_service_factory.h"
 #include "chrome/browser/history/top_sites_factory.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/profiles/profile_android.h"
+#include "chrome/browser/search/suggestions/image_decoder_impl.h"
 #include "chrome/browser/search/suggestions/suggestions_service_factory.h"
 #include "chrome/browser/search_engines/template_url_service_factory.h"
 #include "chrome/browser/supervised_user/supervised_user_service.h"
@@ -25,7 +27,11 @@
 #include "chrome/browser/supervised_user/supervised_user_url_filter.h"
 #include "chrome/browser/thumbnails/thumbnail_list_source.h"
 #include "components/history/core/browser/top_sites.h"
+#include "components/image_fetcher/image_fetcher_impl.h"
+#include "components/ntp_tiles/icon_cacher.h"
+#include "components/ntp_tiles/metrics.h"
 #include "components/ntp_tiles/popular_sites.h"
+#include "components/rappor/rappor_service_impl.h"
 #include "components/safe_json/safe_json_parser.h"
 #include "content/public/browser/browser_thread.h"
 #include "content/public/browser/url_data_source.h"
@@ -35,12 +41,15 @@
 
 using base::android::AttachCurrentThread;
 using base::android::ConvertJavaStringToUTF8;
+using base::android::ConvertUTF8ToJavaString;
 using base::android::JavaParamRef;
 using base::android::ScopedJavaGlobalRef;
 using base::android::ScopedJavaLocalRef;
 using base::android::ToJavaArrayOfStrings;
 using base::android::ToJavaIntArray;
 using content::BrowserThread;
+using ntp_tiles::metrics::MostVisitedTileType;
+using ntp_tiles::metrics::TileImpression;
 using ntp_tiles::MostVisitedSites;
 using ntp_tiles::MostVisitedSitesSupervisor;
 using ntp_tiles::NTPTileSource;
@@ -102,8 +111,7 @@ class MostVisitedSitesBridge::JavaObserver : public MostVisitedSites::Observer {
 
   void OnMostVisitedURLsAvailable(const NTPTilesVector& tiles) override;
 
-  void OnPopularURLsAvailable(
-      const MostVisitedSites::PopularSitesVector& sites) override;
+  void OnIconMadeAvailable(const GURL& site_url) override;
 
  private:
   ScopedJavaGlobalRef<jobject> observer_;
@@ -141,21 +149,11 @@ void MostVisitedSitesBridge::JavaObserver::OnMostVisitedURLsAvailable(
       ToJavaIntArray(env, sources));
 }
 
-void MostVisitedSitesBridge::JavaObserver::OnPopularURLsAvailable(
-    const MostVisitedSites::PopularSitesVector& sites) {
+void MostVisitedSitesBridge::JavaObserver::OnIconMadeAvailable(
+    const GURL& site_url) {
   JNIEnv* env = AttachCurrentThread();
-  std::vector<std::string> urls;
-  std::vector<std::string> favicon_urls;
-  std::vector<std::string> large_icon_urls;
-  for (const auto& site : sites) {
-    urls.emplace_back(site.url.spec());
-    favicon_urls.emplace_back(site.favicon_url.spec());
-    large_icon_urls.emplace_back(site.large_icon_url.spec());
-  }
-  Java_MostVisitedURLsObserver_onPopularURLsAvailable(
-      env, observer_, ToJavaArrayOfStrings(env, urls),
-      ToJavaArrayOfStrings(env, favicon_urls),
-      ToJavaArrayOfStrings(env, large_icon_urls));
+  Java_MostVisitedURLsObserver_onIconMadeAvailable(
+      env, observer_, ConvertUTF8ToJavaString(env, site_url.spec()));
 }
 
 MostVisitedSitesBridge::MostVisitedSitesBridge(Profile* profile)
@@ -163,18 +161,19 @@ MostVisitedSitesBridge::MostVisitedSitesBridge(Profile* profile)
       most_visited_(profile->GetPrefs(),
                     TopSitesFactory::GetForProfile(profile),
                     SuggestionsServiceFactory::GetForProfile(profile),
-                    base::MakeUnique<ntp_tiles::PopularSites>(
-                        BrowserThread::GetBlockingPool(),
-                        profile->GetPrefs(),
-                        TemplateURLServiceFactory::GetForProfile(profile),
-                        g_browser_process->variations_service(),
-                        profile->GetRequestContext(),
-                        ChromePopularSites::GetDirectory(),
-                        base::Bind(safe_json::SafeJsonParser::Parse)),
+                    ChromePopularSites::NewForProfile(profile),
+                    base::MakeUnique<ntp_tiles::IconCacher>(
+                        FaviconServiceFactory::GetForProfile(
+                            profile,
+                            ServiceAccessType::IMPLICIT_ACCESS),
+                        base::MakeUnique<image_fetcher::ImageFetcherImpl>(
+                            base::MakeUnique<suggestions::ImageDecoderImpl>(),
+                            profile->GetRequestContext())),
                     &supervisor_) {
   // Register the thumbnails debugging page.
   // TODO(sfiera): find thumbnails a home. They don't belong here.
   content::URLDataSource::Add(profile, new ThumbnailListSource(profile));
+  DCHECK(!profile->IsOffTheRecord());
 }
 
 MostVisitedSitesBridge::~MostVisitedSitesBridge() {}
@@ -202,27 +201,33 @@ void MostVisitedSitesBridge::AddOrRemoveBlacklistedUrl(
   most_visited_.AddOrRemoveBlacklistedUrl(url, add_url);
 }
 
-void MostVisitedSitesBridge::RecordTileTypeMetrics(
+void MostVisitedSitesBridge::RecordPageImpression(
     JNIEnv* env,
     const JavaParamRef<jobject>& obj,
     const JavaParamRef<jintArray>& jtile_types,
-    const JavaParamRef<jintArray>& jsources) {
-  std::vector<int> int_tile_types;
-  base::android::JavaIntArrayToIntVector(env, jtile_types, &int_tile_types);
-  std::vector<MostVisitedSites::MostVisitedTileType> tile_types;
-  for (int source : int_tile_types) {
-    tile_types.push_back(
-        static_cast<MostVisitedSites::MostVisitedTileType>(source));
-  }
-
+    const JavaParamRef<jintArray>& jsources,
+    const JavaParamRef<jobjectArray>& jtile_urls) {
   std::vector<int> int_sources;
   base::android::JavaIntArrayToIntVector(env, jsources, &int_sources);
-  std::vector<NTPTileSource> sources;
-  for (int source : int_sources) {
-    sources.push_back(static_cast<NTPTileSource>(source));
-  }
+  std::vector<int> int_tile_types;
+  base::android::JavaIntArrayToIntVector(env, jtile_types, &int_tile_types);
+  std::vector<std::string> string_tile_urls;
+  base::android::AppendJavaStringArrayToStringVector(env, jtile_urls,
+                                                     &string_tile_urls);
 
-  most_visited_.RecordTileTypeMetrics(tile_types, sources);
+  DCHECK_EQ(int_sources.size(), int_tile_types.size());
+  DCHECK_EQ(int_sources.size(), string_tile_urls.size());
+
+  std::vector<TileImpression> tiles;
+  for (size_t i = 0; i < int_sources.size(); i++) {
+    NTPTileSource source = static_cast<NTPTileSource>(int_sources[i]);
+    MostVisitedTileType tile_type =
+        static_cast<MostVisitedTileType>(int_tile_types[i]);
+
+    tiles.emplace_back(source, tile_type, GURL(string_tile_urls[i]));
+  }
+  ntp_tiles::metrics::RecordPageImpression(tiles,
+                                           g_browser_process->rappor_service());
 }
 
 void MostVisitedSitesBridge::RecordOpenedMostVisitedItem(
@@ -231,9 +236,9 @@ void MostVisitedSitesBridge::RecordOpenedMostVisitedItem(
     jint index,
     jint tile_type,
     jint source) {
-  most_visited_.RecordOpenedMostVisitedItem(
-      index, static_cast<MostVisitedSites::MostVisitedTileType>(tile_type),
-      static_cast<NTPTileSource>(source));
+  ntp_tiles::metrics::RecordTileClick(
+      index, static_cast<NTPTileSource>(source),
+      static_cast<MostVisitedTileType>(tile_type));
 }
 
 // static
