@@ -40,11 +40,12 @@ class MostVisitedSitesBridge {
       const base::android::JavaParamRef<jobject>& obj,
       const base::android::JavaParamRef<jstring>& j_url,
       jboolean add_url);
-  void RecordTileTypeMetrics(
+  void RecordPageImpression(
       JNIEnv* env,
       const base::android::JavaParamRef<jobject>& obj,
       const base::android::JavaParamRef<jintArray>& jtile_types,
-      const base::android::JavaParamRef<jintArray>& jsources);
+      const base::android::JavaParamRef<jintArray>& jsources,
+      const base::android::JavaParamRef<jobjectArray>& jtile_urls);
   void RecordOpenedMostVisitedItem(
       JNIEnv* env,
       const base::android::JavaParamRef<jobject>& obj,
