@@ -46,52 +46,45 @@ using ntp_snippets::ContentSuggestion;
 
 namespace {
 
-// TODO(treib): Move this into the Time class itself.
-base::Time TimeFromJavaTime(jlong timestamp_ms) {
-  return base::Time::UnixEpoch() +
-         base::TimeDelta::FromMilliseconds(timestamp_ms);
-}
-
 // Converts a vector of ContentSuggestions to its Java equivalent.
 ScopedJavaLocalRef<jobject> ToJavaSuggestionList(
     JNIEnv* env,
     const Category& category,
-    const CategoryInfo& info,
     const std::vector<ContentSuggestion>& suggestions) {
   ScopedJavaLocalRef<jobject> result =
       Java_SnippetsBridge_createSuggestionList(env);
   for (const ContentSuggestion& suggestion : suggestions) {
-    Java_SnippetsBridge_addSuggestion(
-        env, result, category.id(),
-        ConvertUTF8ToJavaString(env, suggestion.id().id_within_category()),
-        ConvertUTF16ToJavaString(env, suggestion.title()),
-        ConvertUTF16ToJavaString(env, suggestion.publisher_name()),
-        ConvertUTF16ToJavaString(env, suggestion.snippet_text()),
-        ConvertUTF8ToJavaString(env, suggestion.url().spec()),
-        ConvertUTF8ToJavaString(env, suggestion.amp_url().spec()),
-        suggestion.publish_date().ToJavaTime(), suggestion.score(),
-        static_cast<int>(info.card_layout()));
+    ScopedJavaLocalRef<jobject> java_suggestion =
+        Java_SnippetsBridge_addSuggestion(
+            env, result, category.id(),
+            ConvertUTF8ToJavaString(env, suggestion.id().id_within_category()),
+            ConvertUTF16ToJavaString(env, suggestion.title()),
+            ConvertUTF16ToJavaString(env, suggestion.publisher_name()),
+            ConvertUTF16ToJavaString(env, suggestion.snippet_text()),
+            ConvertUTF8ToJavaString(env, suggestion.url().spec()),
+            ConvertUTF8ToJavaString(env, suggestion.amp_url().spec()),
+            suggestion.publish_date().ToJavaTime(), suggestion.score());
     if (suggestion.id().category().IsKnownCategory(
             KnownCategories::DOWNLOADS) &&
         suggestion.download_suggestion_extra() != nullptr) {
       if (suggestion.download_suggestion_extra()->is_download_asset) {
-        Java_SnippetsBridge_setDownloadAssetDataForLastSuggestion(
-            env, result,
+        Java_SnippetsBridge_setAssetDownloadDataForSuggestion(
+            env, java_suggestion,
             ConvertUTF8ToJavaString(env, suggestion.download_suggestion_extra()
                                              ->target_file_path.value()),
             ConvertUTF8ToJavaString(
                 env, suggestion.download_suggestion_extra()->mime_type));
       } else {
-        Java_SnippetsBridge_setDownloadOfflinePageDataForLastSuggestion(
-            env, result,
+        Java_SnippetsBridge_setOfflinePageDownloadDataForSuggestion(
+            env, java_suggestion,
             suggestion.download_suggestion_extra()->offline_page_id);
       }
     }
     if (suggestion.id().category().IsKnownCategory(
             KnownCategories::RECENT_TABS) &&
         suggestion.recent_tab_suggestion_extra() != nullptr) {
-      Java_SnippetsBridge_setRecentTabDataForLastSuggestion(
-          env, result,
+      Java_SnippetsBridge_setRecentTabDataForSuggestion(
+          env, java_suggestion,
           ConvertUTF8ToJavaString(
               env, suggestion.recent_tab_suggestion_extra()->tab_id),
           suggestion.recent_tab_suggestion_extra()->offline_page_id);
@@ -101,6 +94,17 @@ ScopedJavaLocalRef<jobject> ToJavaSuggestionList(
   return result;
 }
 
+ntp_snippets::RemoteSuggestionsProvider* GetRemoteSuggestionsProvider() {
+  ntp_snippets::ContentSuggestionsService* content_suggestions_service =
+      ContentSuggestionsServiceFactory::GetForProfile(
+          ProfileManager::GetLastUsedProfile());
+  // Can maybe be null in some cases? (Incognito profile?) crbug.com/647920
+  if (!content_suggestions_service) {
+    return nullptr;
+  }
+  return content_suggestions_service->ntp_snippets_service();
+}
+
 }  // namespace
 
 static jlong Init(JNIEnv* env,
@@ -110,29 +114,29 @@ static jlong Init(JNIEnv* env,
   return reinterpret_cast<intptr_t>(snippets_bridge);
 }
 
-static void FetchSnippets(JNIEnv* env,
-                          const JavaParamRef<jclass>& caller,
-                          jboolean j_force_request) {
-  Profile* profile = ProfileManager::GetLastUsedProfile();
-  // Temporary check while investigating crbug.com/647920.
-  CHECK(profile);
-
-  ntp_snippets::ContentSuggestionsService* content_suggestions_service =
-      ContentSuggestionsServiceFactory::GetForProfile(profile);
-
-  // Can maybe be null in some cases? (Incognito profile?) crbug.com/647920
-  if (!content_suggestions_service)
-    return;
-
-  ntp_snippets::RemoteSuggestionsProvider* service =
-      content_suggestions_service->ntp_snippets_service();
-
+static void FetchRemoteSuggestions(JNIEnv* env,
+                                   const JavaParamRef<jclass>& caller) {
+  ntp_snippets::RemoteSuggestionsProvider* remote_suggestions_provider =
+      GetRemoteSuggestionsProvider();
   // Can be null if the feature has been disabled but the scheduler has not been
   // unregistered yet. The next start should unregister it.
-  if (!service)
+  if (!remote_suggestions_provider) {
     return;
+  }
+  remote_suggestions_provider->FetchSnippetsForAllCategories();
+}
 
-  service->FetchSnippets(j_force_request);
+static void FetchRemoteSuggestionsInTheBackground(
+    JNIEnv* env,
+    const JavaParamRef<jclass>& caller) {
+  ntp_snippets::RemoteSuggestionsProvider* remote_suggestions_provider =
+      GetRemoteSuggestionsProvider();
+  // Can be null if the feature has been disabled but the scheduler has not been
+  // unregistered yet. The next start should unregister it.
+  if (!remote_suggestions_provider) {
+    return;
+  }
+  remote_suggestions_provider->FetchSnippetsInTheBackground();
 }
 
 // Reschedules the fetching of snippets. If tasks are already scheduled, they
@@ -147,16 +151,18 @@ static void RescheduleFetching(JNIEnv* env,
       ContentSuggestionsServiceFactory::GetForProfile(profile);
 
   // Can maybe be null in some cases? (Incognito profile?) crbug.com/647920
-  if (!content_suggestions_service)
+  if (!content_suggestions_service) {
     return;
+  }
 
   ntp_snippets::RemoteSuggestionsProvider* service =
       content_suggestions_service->ntp_snippets_service();
 
   // Can be null if the feature has been disabled but the scheduler has not been
   // unregistered yet. The next start should unregister it.
-  if (!service)
+  if (!service) {
     return;
+  }
 
   service->RescheduleFetching(/*force=*/true);
 }
@@ -220,8 +226,9 @@ base::android::ScopedJavaLocalRef<jobject> NTPSnippetsBridge::GetCategoryInfo(
   base::Optional<CategoryInfo> info =
       content_suggestions_service_->GetCategoryInfo(
           CategoryFromIDValue(j_category_id));
-  if (!info)
+  if (!info) {
     return base::android::ScopedJavaLocalRef<jobject>(env, nullptr);
+  }
   return Java_SnippetsBridge_createSuggestionsCategoryInfo(
       env, j_category_id, ConvertUTF16ToJavaString(env, info->title()),
       static_cast<int>(info->card_layout()), info->has_more_action(),
@@ -235,11 +242,8 @@ ScopedJavaLocalRef<jobject> NTPSnippetsBridge::GetSuggestionsForCategory(
     const base::android::JavaParamRef<jobject>& obj,
     jint j_category_id) {
   Category category = CategoryFromIDValue(j_category_id);
-  base::Optional<CategoryInfo> info =
-      content_suggestions_service_->GetCategoryInfo(category);
-  DCHECK(info);
   return ToJavaSuggestionList(
-      env, category, *info,
+      env, category,
       content_suggestions_service_->GetSuggestionsForCategory(category));
 }
 
@@ -348,7 +352,7 @@ void NTPSnippetsBridge::OnSuggestionShown(JNIEnv* env,
                                           jfloat score) {
   ntp_snippets::metrics::OnSuggestionShown(
       global_position, CategoryFromIDValue(j_category_id), category_position,
-      TimeFromJavaTime(publish_timestamp_ms), score);
+      base::Time::FromJavaTime(publish_timestamp_ms), score);
   if (global_position == 0) {
     content_suggestions_service_->user_classifier()->OnEvent(
         ntp_snippets::UserClassifier::Metric::SUGGESTIONS_SHOWN);
@@ -365,7 +369,7 @@ void NTPSnippetsBridge::OnSuggestionOpened(JNIEnv* env,
                                            int windowOpenDisposition) {
   ntp_snippets::metrics::OnSuggestionOpened(
       global_position, CategoryFromIDValue(j_category_id), category_position,
-      TimeFromJavaTime(publish_timestamp_ms), score,
+      base::Time::FromJavaTime(publish_timestamp_ms), score,
       static_cast<WindowOpenDisposition>(windowOpenDisposition));
   content_suggestions_service_->user_classifier()->OnEvent(
       ntp_snippets::UserClassifier::Metric::SUGGESTIONS_USED);
@@ -380,7 +384,7 @@ void NTPSnippetsBridge::OnSuggestionMenuOpened(JNIEnv* env,
                                                jfloat score) {
   ntp_snippets::metrics::OnSuggestionMenuOpened(
       global_position, CategoryFromIDValue(j_category_id), category_position,
-      TimeFromJavaTime(publish_timestamp_ms), score);
+      base::Time::FromJavaTime(publish_timestamp_ms), score);
 }
 
 void NTPSnippetsBridge::OnMoreButtonShown(JNIEnv* env,
@@ -404,8 +408,9 @@ void NTPSnippetsBridge::OnMoreButtonClicked(JNIEnv* env,
 NTPSnippetsBridge::~NTPSnippetsBridge() {}
 
 void NTPSnippetsBridge::OnNewSuggestions(Category category) {
-  if (observer_.is_null())
+  if (observer_.is_null()) {
     return;
+  }
 
   JNIEnv* env = base::android::AttachCurrentThread();
   Java_SnippetsBridge_onNewSuggestions(env, observer_,
@@ -414,8 +419,9 @@ void NTPSnippetsBridge::OnNewSuggestions(Category category) {
 
 void NTPSnippetsBridge::OnCategoryStatusChanged(Category category,
                                                 CategoryStatus new_status) {
-  if (observer_.is_null())
+  if (observer_.is_null()) {
     return;
+  }
 
   JNIEnv* env = base::android::AttachCurrentThread();
   Java_SnippetsBridge_onCategoryStatusChanged(env, observer_,
@@ -425,8 +431,9 @@ void NTPSnippetsBridge::OnCategoryStatusChanged(Category category,
 
 void NTPSnippetsBridge::OnSuggestionInvalidated(
     const ContentSuggestion::ID& suggestion_id) {
-  if (observer_.is_null())
+  if (observer_.is_null()) {
     return;
+  }
 
   JNIEnv* env = base::android::AttachCurrentThread();
   Java_SnippetsBridge_onSuggestionInvalidated(
@@ -434,6 +441,15 @@ void NTPSnippetsBridge::OnSuggestionInvalidated(
       ConvertUTF8ToJavaString(env, suggestion_id.id_within_category()).obj());
 }
 
+void NTPSnippetsBridge::OnFullRefreshRequired() {
+  if (observer_.is_null()) {
+    return;
+  }
+
+  JNIEnv* env = base::android::AttachCurrentThread();
+  Java_SnippetsBridge_onFullRefreshRequired(env, observer_.obj());
+}
+
 void NTPSnippetsBridge::ContentSuggestionsServiceShutdown() {
   observer_.Reset();
   content_suggestions_service_observer_.Remove(content_suggestions_service_);
@@ -442,9 +458,9 @@ void NTPSnippetsBridge::ContentSuggestionsServiceShutdown() {
 void NTPSnippetsBridge::OnImageFetched(ScopedJavaGlobalRef<jobject> callback,
                                        const gfx::Image& image) {
   ScopedJavaLocalRef<jobject> j_bitmap;
-  if (!image.IsEmpty())
+  if (!image.IsEmpty()) {
     j_bitmap = gfx::ConvertToJavaBitmap(image.ToSkBitmap());
-
+  }
   base::android::RunCallbackAndroid(callback, j_bitmap);
 }
 
@@ -454,15 +470,9 @@ void NTPSnippetsBridge::OnSuggestionsFetched(
     std::vector<ContentSuggestion> suggestions) {
   // TODO(fhorschig, dgn): Allow refetch or show notification acc. to status.
   JNIEnv* env = AttachCurrentThread();
-  // It's possible that the category has been dismissed in the meantime, and
-  // so info is nullopt. In that case, don't update the UI.
-  base::Optional<CategoryInfo> info =
-      content_suggestions_service_->GetCategoryInfo(category);
-  if (info) {
-    Java_SnippetsBridge_onMoreSuggestions(
-        env, observer_, category.id(),
-        ToJavaSuggestionList(env, category, *info, suggestions));
-  }
+  Java_SnippetsBridge_onMoreSuggestions(
+      env, observer_, category.id(),
+      ToJavaSuggestionList(env, category, suggestions));
 }
 
 Category NTPSnippetsBridge::CategoryFromIDValue(jint id) {
