@@ -5,14 +5,10 @@
 #ifndef CHROME_BROWSER_ANDROID_OFFLINE_PAGES_BACKGROUND_SCHEDULER_BRIDGE_H_
 #define CHROME_BROWSER_ANDROID_OFFLINE_PAGES_BACKGROUND_SCHEDULER_BRIDGE_H_
 
-#include "components/offline_pages/background/scheduler.h"
+#include "components/offline_pages/core/background/scheduler.h"
 
 #include "base/android/jni_android.h"
 
-namespace content {
-class BrowserContext;
-}
-
 namespace offline_pages {
 namespace android {
 
