@@ -5,9 +5,12 @@
 #ifndef CHROME_BROWSER_ANDROID_OFFLINE_PAGES_EVALUATION_EVALUATION_TEST_SCHEDULER_H_
 #define CHROME_BROWSER_ANDROID_OFFLINE_PAGES_EVALUATION_EVALUATION_TEST_SCHEDULER_H_
 
-#include "components/offline_pages/background/scheduler.h"
+#include "components/offline_pages/core/background/scheduler.h"
 
 namespace offline_pages {
+
+class RequestCoordinator;
+
 namespace android {
 
 class EvaluationTestScheduler : public Scheduler {
@@ -20,6 +23,9 @@ class EvaluationTestScheduler : public Scheduler {
 
   // Callback used by user request.
   void ImmediateScheduleCallback(bool result);
+
+ private:
+  RequestCoordinator* coordinator_;
 };
 
 }  // namespace android
