@@ -21,17 +21,17 @@
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/profiles/profile_android.h"
 #include "chrome/common/chrome_constants.h"
-#include "components/offline_pages/background/offliner_factory.h"
-#include "components/offline_pages/background/offliner_policy.h"
-#include "components/offline_pages/background/request_coordinator.h"
-#include "components/offline_pages/background/request_notifier.h"
-#include "components/offline_pages/background/request_queue.h"
-#include "components/offline_pages/background/request_queue_store.h"
-#include "components/offline_pages/background/request_queue_store_sql.h"
-#include "components/offline_pages/background/save_page_request.h"
-#include "components/offline_pages/downloads/download_notifying_observer.h"
-#include "components/offline_pages/offline_page_item.h"
-#include "components/offline_pages/offline_page_model.h"
+#include "components/offline_pages/core/background/offliner_factory.h"
+#include "components/offline_pages/core/background/offliner_policy.h"
+#include "components/offline_pages/core/background/request_coordinator.h"
+#include "components/offline_pages/core/background/request_notifier.h"
+#include "components/offline_pages/core/background/request_queue.h"
+#include "components/offline_pages/core/background/request_queue_store.h"
+#include "components/offline_pages/core/background/request_queue_store_sql.h"
+#include "components/offline_pages/core/background/save_page_request.h"
+#include "components/offline_pages/core/downloads/download_notifying_observer.h"
+#include "components/offline_pages/core/offline_page_item.h"
+#include "components/offline_pages/core/offline_page_model.h"
 #include "content/public/browser/browser_context.h"
 #include "content/public/browser/browser_thread.h"
 #include "jni/OfflinePageEvaluationBridge_jni.h"
@@ -47,12 +47,7 @@ namespace offline_pages {
 namespace android {
 
 namespace {
-const bool kPreferUntriedRequest = false;
-const bool kPreferEarlierRequest = true;
-const bool kPreferRetryCountOverRecency = false;
-const int kMaxStartedTries = 4;
-const int kMaxCompletedTries = 1;
-const int kImmediateRequestExpirationTimeInSeconds = 3600;
+const char kNativeTag[] = "OPNative";
 
 void ToJavaOfflinePageList(JNIEnv* env,
                            jobject j_result_obj,
@@ -170,12 +165,7 @@ bool OfflinePageEvaluationBridge::Register(JNIEnv* env) {
 std::unique_ptr<KeyedService>
 OfflinePageEvaluationBridge::GetTestingRequestCoordinator(
     content::BrowserContext* context) {
-  // Create a new OfflinerPolicy with a larger background processing
-  // budget (3600 sec). Other values are the same with default ones.
-  std::unique_ptr<OfflinerPolicy> policy(new OfflinerPolicy(
-      kPreferUntriedRequest, kPreferEarlierRequest,
-      kPreferRetryCountOverRecency, kMaxStartedTries, kMaxCompletedTries,
-      kImmediateRequestExpirationTimeInSeconds));
+  std::unique_ptr<OfflinerPolicy> policy(new OfflinerPolicy());
   std::unique_ptr<OfflinerFactory> prerenderer_offliner(
       new PrerenderingOfflinerFactory(context));
 
@@ -225,6 +215,8 @@ OfflinePageEvaluationBridge::OfflinePageEvaluationBridge(
   NotifyIfDoneLoading();
   offline_page_model_->AddObserver(this);
   request_coordinator_->AddObserver(this);
+  offline_page_model_->GetLogger()->SetClient(this);
+  request_coordinator_->GetLogger()->SetClient(this);
 }
 
 OfflinePageEvaluationBridge::~OfflinePageEvaluationBridge() {
@@ -240,8 +232,9 @@ void OfflinePageEvaluationBridge::OfflinePageModelLoaded(
   NotifyIfDoneLoading();
 }
 
-void OfflinePageEvaluationBridge::OfflinePageModelChanged(
-    OfflinePageModel* model) {}
+void OfflinePageEvaluationBridge::OfflinePageAdded(
+    OfflinePageModel* model,
+    const OfflinePageItem& added_page) {}
 
 void OfflinePageEvaluationBridge::OfflinePageDeleted(
     int64_t offline_id,
@@ -269,6 +262,13 @@ void OfflinePageEvaluationBridge::OnChanged(const SavePageRequest& request) {
       env, java_ref_, ToJavaSavePageRequest(env, request));
 }
 
+void OfflinePageEvaluationBridge::CustomLog(const std::string& message) {
+  JNIEnv* env = base::android::AttachCurrentThread();
+  Java_OfflinePageEvaluationBridge_log(env, java_ref_,
+                                       ConvertUTF8ToJavaString(env, kNativeTag),
+                                       ConvertUTF8ToJavaString(env, message));
+}
+
 void OfflinePageEvaluationBridge::GetAllPages(
     JNIEnv* env,
     const JavaParamRef<jobject>& obj,
