@@ -9,7 +9,7 @@
 #include "base/memory/ptr_util.h"
 #include "chrome/browser/android/offline_pages/offline_page_request_job.h"
 #include "chrome/browser/android/offline_pages/offline_page_utils.h"
-#include "components/offline_pages/offline_page_item.h"
+#include "components/offline_pages/core/offline_page_item.h"
 #include "content/public/browser/browser_thread.h"
 #include "content/public/browser/navigation_controller.h"
 #include "content/public/browser/navigation_entry.h"
@@ -22,9 +22,19 @@ DEFINE_WEB_CONTENTS_USER_DATA_KEY(offline_pages::OfflinePageTabHelper);
 
 namespace offline_pages {
 
+OfflinePageTabHelper::LoadedOfflinePageInfo::LoadedOfflinePageInfo()
+    : is_showing_offline_preview(false) {}
+
+OfflinePageTabHelper::LoadedOfflinePageInfo::~LoadedOfflinePageInfo() {}
+
+void OfflinePageTabHelper::LoadedOfflinePageInfo::Clear() {
+  offline_page.reset();
+  offline_header.Clear();
+  is_showing_offline_preview = false;
+}
+
 OfflinePageTabHelper::OfflinePageTabHelper(content::WebContents* web_contents)
     : content::WebContentsObserver(web_contents),
-      is_offline_preview_(false),
       weak_ptr_factory_(this) {
   DCHECK(content::BrowserThread::CurrentlyOn(content::BrowserThread::UI));
 }
@@ -40,12 +50,15 @@ void OfflinePageTabHelper::DidStartNavigation(
   // This is a new navigation so we can invalidate any previously scheduled
   // operations.
   weak_ptr_factory_.InvalidateWeakPtrs();
-
-  // Since this is a new navigation, we will reset the cached offline page,
-  offline_page_ = nullptr;
-  is_offline_preview_ = false;
-
   reloading_url_on_net_error_ = false;
+
+  // The provisional offline info can be cleared no matter how.
+  provisional_offline_info_.Clear();
+
+  // If not a fragment navigation, clear the cached offline info.
+  if (offline_info_.offline_page.get() && !navigation_handle->IsSamePage()) {
+    offline_info_.Clear();
+  }
 }
 
 void OfflinePageTabHelper::DidFinishNavigation(
@@ -54,6 +67,35 @@ void OfflinePageTabHelper::DidFinishNavigation(
   if (!navigation_handle->IsInMainFrame())
     return;
 
+  if (!navigation_handle->HasCommitted())
+    return;
+
+  if (navigation_handle->IsSamePage())
+    return;
+
+  GURL navigated_url = navigation_handle->GetURL();
+  if (navigation_handle->IsErrorPage()) {
+    offline_info_.Clear();
+  } else {
+    // The provisional offline info can now be committed if the navigation is
+    // done without error.
+    DCHECK(!provisional_offline_info_.offline_page ||
+           OfflinePageUtils::EqualsIgnoringFragment(
+               navigated_url,
+               provisional_offline_info_.offline_page->url));
+    offline_info_.offline_page =
+        std::move(provisional_offline_info_.offline_page);
+    offline_info_.offline_header = provisional_offline_info_.offline_header;
+    offline_info_.is_showing_offline_preview =
+        provisional_offline_info_.is_showing_offline_preview;
+  }
+  provisional_offline_info_.Clear();
+
+  // If the offline page has been loaded successfully, nothing more to do.
+  net::Error error_code = navigation_handle->GetNetErrorCode();
+  if (error_code == net::OK)
+    return;
+
   // We might be reloading the URL in order to fetch the offline page.
   // * If successful, nothing to do.
   // * Otherwise, we're hitting error again. Bail out to avoid loop.
@@ -67,7 +109,6 @@ void OfflinePageTabHelper::DidFinishNavigation(
   // eventually fail. To handle this, we will reload the page to force the
   // offline interception if the error code matches the following list.
   // Otherwise, the error page will be shown.
-  net::Error error_code = navigation_handle->GetNetErrorCode();
   if (error_code != net::ERR_INTERNET_DISCONNECTED &&
       error_code != net::ERR_NAME_NOT_RESOLVED &&
       error_code != net::ERR_ADDRESS_UNREACHABLE &&
@@ -90,15 +131,16 @@ void OfflinePageTabHelper::DidFinishNavigation(
     return;
   }
 
-  OfflinePageUtils::SelectPageForOnlineURL(
+  OfflinePageUtils::SelectPageForURL(
       web_contents()->GetBrowserContext(),
-      navigation_handle->GetURL(),
+      navigated_url,
+      OfflinePageModel::URLSearchMode::SEARCH_BY_ALL_URLS,
       tab_id,
-      base::Bind(&OfflinePageTabHelper::SelectPageForOnlineURLDone,
+      base::Bind(&OfflinePageTabHelper::SelectPageForURLDone,
                  weak_ptr_factory_.GetWeakPtr()));
 }
 
-void OfflinePageTabHelper::SelectPageForOnlineURLDone(
+void OfflinePageTabHelper::SelectPageForURLDone(
     const OfflinePageItem* offline_page) {
   // Bails out if no offline page is found.
   if (!offline_page) {
@@ -113,18 +155,33 @@ void OfflinePageTabHelper::SelectPageForOnlineURLDone(
   // Reloads the page with extra header set to force loading the offline page.
   content::NavigationController::LoadURLParams load_params(offline_page->url);
   load_params.transition_type = ui::PAGE_TRANSITION_RELOAD;
-  load_params.extra_headers = kOfflinePageHeader;
-  load_params.extra_headers += ":";
-  load_params.extra_headers += kOfflinePageHeaderReasonKey;
-  load_params.extra_headers += "=";
-  load_params.extra_headers += kOfflinePageHeaderReasonValueDueToNetError;
+  OfflinePageHeader offline_header;
+  offline_header.reason = OfflinePageHeader::Reason::NET_ERROR;
+  load_params.extra_headers = offline_header.GetCompleteHeaderString();
   web_contents()->GetController().LoadURLWithParams(load_params);
 }
 
-void OfflinePageTabHelper::SetOfflinePage(const OfflinePageItem& offline_page,
-                                          bool is_offline_preview) {
-  offline_page_ = base::MakeUnique<OfflinePageItem>(offline_page);
-  is_offline_preview_ = is_offline_preview;
+// This is a callback from network request interceptor. It happens between
+// DidStartNavigation and DidFinishNavigation calls on this tab helper.
+void OfflinePageTabHelper::SetOfflinePage(
+    const OfflinePageItem& offline_page,
+    const OfflinePageHeader& offline_header,
+    bool is_offline_preview) {
+  provisional_offline_info_.offline_page =
+      base::MakeUnique<OfflinePageItem>(offline_page);
+  provisional_offline_info_.offline_header = offline_header;
+  provisional_offline_info_.is_showing_offline_preview = is_offline_preview;
+}
+
+const OfflinePageItem* OfflinePageTabHelper::GetOfflinePageForTest() const {
+  return provisional_offline_info_.offline_page.get();
+}
+
+bool OfflinePageTabHelper::IsShowingOfflinePreview() const {
+  // TODO(ryansturm): Change this once offline pages infrastructure uses
+  // NavigationHandle instead of a back channel. crbug.com/658899
+  return provisional_offline_info_.is_showing_offline_preview ||
+         offline_info_.is_showing_offline_preview;
 }
 
 }  // namespace offline_pages
