@@ -8,9 +8,14 @@
 #include <stdint.h>
 
 #include "base/callback.h"
+#include "components/offline_pages/core/offline_page_model.h"
 
 class GURL;
 
+namespace base {
+class Time;
+}
+
 namespace content {
 class BrowserContext;
 class WebContents;
@@ -20,16 +25,24 @@ namespace offline_pages {
 struct OfflinePageHeader;
 struct OfflinePageItem;
 
+// Callback used for checking if specific |pages_exist| and what is the
+// |latest_saved_time| for those pages. The former being a basic return type,
+// while the latter is meant to be used as a helper to report UMA.
+using PagesExistCallback =
+    base::Callback<void(bool /* pages_exist */,
+                        const base::Time& /* latest_saved_time */)>;
+
 class OfflinePageUtils {
  public:
-  // Returns via callback an offline page saved for |online_url|, if any. The
+  // Returns via callback an offline page related to |url|, if any. The
   // page is chosen based on creation date; a more recently created offline
   // page will be preferred over an older one. The offline page captured from
   // last visit in the tab will not be considered if its tab id does not match
   // the provided |tab_id|.
-  static void SelectPageForOnlineURL(
+  static void SelectPageForURL(
       content::BrowserContext* browser_context,
-      const GURL& online_url,
+      const GURL& url,
+      OfflinePageModel::URLSearchMode url_search_mode,
       int tab_id,
       const base::Callback<void(const OfflinePageItem*)>& callback);
 
@@ -44,22 +57,35 @@ class OfflinePageUtils {
   static const OfflinePageHeader* GetOfflineHeaderFromWebContents(
       content::WebContents* web_contents);
 
+  // Returns true if the offline page is shown for previewing purpose.
+  static bool IsShowingOfflinePreview(content::WebContents* web_contents);
+
   // Gets an Android Tab ID from a tab containing |web_contents|. Returns false,
   // when tab is not available. Returns true otherwise and sets |tab_id| to the
   // ID of the tab.
   static bool GetTabId(content::WebContents* web_contents, int* tab_id);
 
+  // Performs a check, whether pages with specified |url| and |name_space|
+  // already exist. Result is returned in a |callback|, where first parameter
+  // indicates whether offline pages exist, while second is a helper value to
+  // report UMA, indicating the time the latest existing page with such
+  // parameters was saved.
   static void CheckExistenceOfPagesWithURL(
       content::BrowserContext* browser_context,
       const std::string name_space,
-      const GURL& offline_url,
-      const base::Callback<void(bool)>& callback);
+      const GURL& url,
+      const PagesExistCallback& callback);
 
+  // Performs a check, whether requests with specified |url| and |name_space|
+  // already exist. Result is returned in a |callback|, where first parameter
+  // indicates whether requests exist, while second is a helper value to report
+  // UMA, indicating the time the latest existing request with such parameters
+  // was created.
   static void CheckExistenceOfRequestsWithURL(
       content::BrowserContext* browser_context,
       const std::string name_space,
-      const GURL& offline_page_url,
-      const base::Callback<void(bool)>& callback);
+      const GURL& url,
+      const PagesExistCallback& callback);
 
   static bool EqualsIgnoringFragment(const GURL& lhs, const GURL& rhs);
 };
