@@ -9,23 +9,29 @@
 
 #include "base/callback.h"
 #include "base/command_line.h"
-#include "base/feature_list.h"
 #include "base/files/file.h"
 #include "base/files/file_path.h"
 #include "base/files/file_util.h"
+#include "base/run_loop.h"
 #include "base/strings/string16.h"
-#include "base/test/test_simple_task_runner.h"
+#include "base/test/scoped_feature_list.h"
 #include "base/threading/thread_task_runner_handle.h"
+#include "base/time/time.h"
 #include "chrome/browser/android/offline_pages/offline_page_model_factory.h"
+#include "chrome/browser/android/offline_pages/request_coordinator_factory.h"
 #include "chrome/browser/android/offline_pages/test_offline_page_model_builder.h"
+#include "chrome/browser/android/offline_pages/test_request_coordinator_builder.h"
 #include "chrome/common/chrome_constants.h"
 #include "chrome/test/base/testing_profile.h"
-#include "components/offline_pages/client_namespace_constants.h"
-#include "components/offline_pages/offline_page_feature.h"
-#include "components/offline_pages/offline_page_model.h"
-#include "components/offline_pages/offline_page_test_archiver.h"
-#include "components/offline_pages/offline_page_test_store.h"
-#include "components/offline_pages/offline_page_types.h"
+#include "components/offline_pages/core/background/network_quality_provider_stub.h"
+#include "components/offline_pages/core/background/request_coordinator.h"
+#include "components/offline_pages/core/client_namespace_constants.h"
+#include "components/offline_pages/core/offline_page_feature.h"
+#include "components/offline_pages/core/offline_page_model.h"
+#include "components/offline_pages/core/offline_page_test_archiver.h"
+#include "components/offline_pages/core/offline_page_test_store.h"
+#include "components/offline_pages/core/offline_page_types.h"
+#include "content/public/test/test_browser_thread_bundle.h"
 #include "net/base/filename_util.h"
 #include "testing/gtest/include/gtest/gtest.h"
 #include "url/gurl.h"
@@ -40,11 +46,16 @@ const GURL kTestPage4Url("http://test.org/page4");
 const int64_t kTestFileSize = 876543LL;
 const char* kTestPage1ClientId = "1234";
 const char* kTestPage2ClientId = "5678";
-const char* kTestPage4ClientId = "9876";
+const char* kTestPage3ClientId = "7890";
 
-void BoolCallback(bool* actual_result, bool call_result) {
-  DCHECK(actual_result);
-  *actual_result = call_result;
+void HasDuplicatesCallback(bool* out_has_duplicates,
+                           base::Time* out_latest_saved_time,
+                           bool has_duplicates,
+                           const base::Time& latest_saved_time) {
+  DCHECK(out_has_duplicates);
+  DCHECK(out_latest_saved_time);
+  *out_has_duplicates = has_duplicates;
+  *out_latest_saved_time = latest_saved_time;
 }
 
 }  // namespace
@@ -60,6 +71,10 @@ class OfflinePageUtilsTest
   void SetUp() override;
   void RunUntilIdle();
 
+  void SavePage(const GURL& url,
+                const ClientId& client_id,
+                std::unique_ptr<OfflinePageArchiver> archiver);
+
   // Necessary callbacks for the offline page model.
   void OnSavePageDone(SavePageResult result, int64_t offlineId);
   void OnClearAllDone();
@@ -75,45 +90,60 @@ class OfflinePageUtilsTest
 
  private:
   void CreateOfflinePages();
+  void CreateRequests();
   std::unique_ptr<OfflinePageTestArchiver> BuildArchiver(
       const GURL& url,
       const base::FilePath& file_name);
 
+  content::TestBrowserThreadBundle browser_thread_bundle_;
   int64_t offline_id_;
   GURL url_;
-
-  scoped_refptr<base::TestSimpleTaskRunner> task_runner_;
-  base::ThreadTaskRunnerHandle task_runner_handle_;
   TestingProfile profile_;
+  base::test::ScopedFeatureList scoped_feature_list_;
 };
 
-OfflinePageUtilsTest::OfflinePageUtilsTest()
-    : task_runner_(new base::TestSimpleTaskRunner),
-      task_runner_handle_(task_runner_) {}
+OfflinePageUtilsTest::OfflinePageUtilsTest() = default;
 
 OfflinePageUtilsTest::~OfflinePageUtilsTest() {}
 
 void OfflinePageUtilsTest::SetUp() {
   // Enables offline pages feature.
   // TODO(jianli): Remove this once the feature is completely enabled.
-  base::FeatureList::ClearInstanceForTesting();
-  std::unique_ptr<base::FeatureList> feature_list(new base::FeatureList);
-  feature_list->InitializeFromCommandLine(
-      offline_pages::kOfflineBookmarksFeature.name, "");
-  base::FeatureList::SetInstance(std::move(feature_list));
+  scoped_feature_list_.InitAndEnableFeature(
+      offline_pages::kOfflineBookmarksFeature);
 
   // Set up the factory for testing.
   OfflinePageModelFactory::GetInstance()->SetTestingFactoryAndUse(
       &profile_, BuildTestOfflinePageModel);
   RunUntilIdle();
 
-  // Make sure the store contains the right offline pages before the load
-  // happens.
+  NetworkQualityProviderStub::SetUserData(&profile_,
+                                          new NetworkQualityProviderStub());
+  RequestCoordinatorFactory::GetInstance()->SetTestingFactoryAndUse(
+      &profile_, BuildTestRequestCoordinator);
+  RunUntilIdle();
+
+  // Make sure to create offline pages and requests.
   CreateOfflinePages();
+  CreateRequests();
 }
 
 void OfflinePageUtilsTest::RunUntilIdle() {
-  task_runner_->RunUntilIdle();
+  base::RunLoop().RunUntilIdle();
+}
+
+void OfflinePageUtilsTest::SavePage(
+    const GURL& url,
+    const ClientId& client_id,
+    std::unique_ptr<OfflinePageArchiver> archiver) {
+  OfflinePageModel::SavePageParams save_page_params;
+  save_page_params.url = url;
+  save_page_params.client_id = client_id;
+  OfflinePageModelFactory::GetForBrowserContext(profile())->SavePage(
+      save_page_params,
+      std::move(archiver),
+      base::Bind(&OfflinePageUtilsTest::OnSavePageDone, AsWeakPtr()));
+  RunUntilIdle();
 }
 
 void OfflinePageUtilsTest::OnSavePageDone(SavePageResult result,
@@ -137,40 +167,31 @@ void OfflinePageUtilsTest::SetLastPathCreatedByArchiver(
     const base::FilePath& file_path) {}
 
 void OfflinePageUtilsTest::CreateOfflinePages() {
-  OfflinePageModel* model =
-      OfflinePageModelFactory::GetForBrowserContext(profile());
-
   // Create page 1.
   std::unique_ptr<OfflinePageTestArchiver> archiver(BuildArchiver(
       kTestPage1Url, base::FilePath(FILE_PATH_LITERAL("page1.mhtml"))));
   offline_pages::ClientId client_id;
   client_id.name_space = kDownloadNamespace;
   client_id.id = kTestPage1ClientId;
-  model->SavePage(
-      kTestPage1Url, client_id, 0l, std::move(archiver),
-      base::Bind(&OfflinePageUtilsTest::OnSavePageDone, AsWeakPtr()));
-  RunUntilIdle();
+  SavePage(kTestPage1Url, client_id, std::move(archiver));
 
   // Create page 2.
   archiver = BuildArchiver(kTestPage2Url,
                            base::FilePath(FILE_PATH_LITERAL("page2.mhtml")));
   client_id.id = kTestPage2ClientId;
-  model->SavePage(
-      kTestPage2Url, client_id, 0l, std::move(archiver),
-      base::Bind(&OfflinePageUtilsTest::OnSavePageDone, AsWeakPtr()));
-  RunUntilIdle();
+  SavePage(kTestPage2Url, client_id, std::move(archiver));
+}
 
-  // Create page 4 - expired page.
-  archiver = BuildArchiver(kTestPage4Url,
-                           base::FilePath(FILE_PATH_LITERAL("page4.mhtml")));
-  client_id.id = kTestPage4ClientId;
-  model->SavePage(
-      kTestPage4Url, client_id, 0l, std::move(archiver),
-      base::Bind(&OfflinePageUtilsTest::OnSavePageDone, AsWeakPtr()));
-  RunUntilIdle();
-  model->ExpirePages(
-      std::vector<int64_t>({offline_id()}), base::Time::Now(),
-      base::Bind(&OfflinePageUtilsTest::OnExpirePageDone, AsWeakPtr()));
+void OfflinePageUtilsTest::CreateRequests() {
+  RequestCoordinator* request_coordinator =
+      RequestCoordinatorFactory::GetForBrowserContext(profile());
+
+  offline_pages::ClientId client_id;
+  client_id.name_space = kDownloadNamespace;
+  client_id.id = kTestPage3ClientId;
+  request_coordinator->SavePageLater(
+      kTestPage3Url, client_id, true,
+      RequestCoordinator::RequestAvailability::ENABLED_FOR_OFFLINER);
   RunUntilIdle();
 }
 
@@ -185,19 +206,45 @@ std::unique_ptr<OfflinePageTestArchiver> OfflinePageUtilsTest::BuildArchiver(
 }
 
 TEST_F(OfflinePageUtilsTest, CheckExistenceOfPagesWithURL) {
-  bool page_exists = false;
+  bool has_duplicates = false;
+  base::Time latest_saved_time;
   // This page should be available.
   OfflinePageUtils::CheckExistenceOfPagesWithURL(
       profile(), kDownloadNamespace, kTestPage1Url,
-      base::Bind(&BoolCallback, base::Unretained(&page_exists)));
+      base::Bind(&HasDuplicatesCallback, base::Unretained(&has_duplicates),
+                 base::Unretained(&latest_saved_time)));
   RunUntilIdle();
-  EXPECT_TRUE(page_exists);
+  EXPECT_TRUE(has_duplicates);
+  EXPECT_FALSE(latest_saved_time.is_null());
   // This one should be missing
   OfflinePageUtils::CheckExistenceOfPagesWithURL(
       profile(), kDownloadNamespace, kTestPage3Url,
-      base::Bind(&BoolCallback, base::Unretained(&page_exists)));
+      base::Bind(&HasDuplicatesCallback, base::Unretained(&has_duplicates),
+                 base::Unretained(&latest_saved_time)));
   RunUntilIdle();
-  EXPECT_FALSE(page_exists);
+  EXPECT_FALSE(has_duplicates);
+  EXPECT_TRUE(latest_saved_time.is_null());
+}
+
+TEST_F(OfflinePageUtilsTest, CheckExistenceOfRequestsWithURL) {
+  bool has_duplicates = false;
+  base::Time latest_saved_time;
+  // This page should be available.
+  OfflinePageUtils::CheckExistenceOfRequestsWithURL(
+      profile(), kDownloadNamespace, kTestPage3Url,
+      base::Bind(&HasDuplicatesCallback, base::Unretained(&has_duplicates),
+                 base::Unretained(&latest_saved_time)));
+  RunUntilIdle();
+  EXPECT_TRUE(has_duplicates);
+  EXPECT_FALSE(latest_saved_time.is_null());
+  // This one should be missing
+  OfflinePageUtils::CheckExistenceOfRequestsWithURL(
+      profile(), kDownloadNamespace, kTestPage1Url,
+      base::Bind(&HasDuplicatesCallback, base::Unretained(&has_duplicates),
+                 base::Unretained(&latest_saved_time)));
+  RunUntilIdle();
+  EXPECT_FALSE(has_duplicates);
+  EXPECT_TRUE(latest_saved_time.is_null());
 }
 
 TEST_F(OfflinePageUtilsTest, EqualsIgnoringFragment) {
