@@ -34,8 +34,9 @@ Offliner* PrerenderingOfflinerFactory::GetOffliner(
     // Get a pointer to the (unowned) offline page model.
     OfflinePageModel* model =
         OfflinePageModelFactory::GetInstance()->GetForBrowserContext(context_);
-
-    offliner_ = new PrerenderingOffliner(policy, nullptr, model);
+    // Ensure we do have a model for saving a page if we prerender it.
+    DCHECK(model) << "No OfflinePageModel for offliner";
+    offliner_ = new PrerenderingOffliner(context_, policy, model);
   }
 
   return offliner_;
