@@ -20,11 +20,11 @@
 #include "chrome/browser/android/offline_pages/offline_page_model_factory.h"
 #include "chrome/browser/android/offline_pages/offline_page_utils.h"
 #include "chrome/browser/android/offline_pages/request_coordinator_factory.h"
-#include "components/offline_pages/background/request_coordinator.h"
-#include "components/offline_pages/client_namespace_constants.h"
-#include "components/offline_pages/offline_page_feature.h"
-#include "components/offline_pages/offline_page_item.h"
-#include "components/offline_pages/offline_page_model.h"
+#include "components/offline_pages/core/background/request_coordinator.h"
+#include "components/offline_pages/core/client_namespace_constants.h"
+#include "components/offline_pages/core/offline_page_feature.h"
+#include "components/offline_pages/core/offline_page_item.h"
+#include "components/offline_pages/core/offline_page_model.h"
 #include "content/public/browser/browser_context.h"
 #include "content/public/browser/browser_thread.h"
 #include "content/public/browser/navigation_entry.h"
@@ -59,6 +59,7 @@ RecentTabHelper::RecentTabHelper(content::WebContents* web_contents)
       page_model_(nullptr),
       snapshots_enabled_(false),
       is_page_ready_for_snapshot_(false),
+      previous_request_id_for_load_(OfflinePageModel::kInvalidOfflineId),
       delegate_(new DefaultDelegate()),
       weak_ptr_factory_(this) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
@@ -91,10 +92,12 @@ void RecentTabHelper::ObserveAndDownloadCurrentPage(
     return;
 
   // If snapshot already happened and we missed it, go ahead and snapshot now.
+  OfflinePageModel::SavePageParams save_page_params;
+  save_page_params.url = web_contents()->GetLastCommittedURL();
+  save_page_params.client_id = client_id;
+  save_page_params.proposed_offline_id = request_id;
   page_model_->SavePage(
-      web_contents()->GetLastCommittedURL(),
-      client_id,
-      request_id,
+      save_page_params,
       delegate_->CreatePageArchiver(web_contents()),
       base::Bind(&RecentTabHelper::SavePageCallback,
                  weak_ptr_factory_.GetWeakPtr()));
@@ -150,14 +153,14 @@ void RecentTabHelper::DidFinishNavigation(
   }
 
   if (offline_pages::IsOffliningRecentPagesEnabled()) {
-    int64_t proposed_id = OfflinePageModel::kInvalidOfflineId;
     download_info_ = base::MakeUnique<DownloadPageInfo>(
-        GetRecentPagesClientId(), proposed_id);
+        GetRecentPagesClientId(), OfflinePageModel::kInvalidOfflineId);
   } else {
     download_info_.reset();
   }
 
   is_page_ready_for_snapshot_ = false;
+  previous_request_id_for_load_ = OfflinePageModel::kInvalidOfflineId;
 
   // New navigation, new snapshot session.
   snapshot_url_ = web_contents()->GetLastCommittedURL();
@@ -223,9 +226,17 @@ void RecentTabHelper::ContinueSnapshotWithIdsToPurge(
   if (!download_info_)
     return;
 
-  // Also remove the download page if this is not a first snapshot.
   std::vector<int64_t> ids(page_ids);
+  // Also remove the download page if this is not a first snapshot.
   ids.push_back(download_info_->request_id_);
+  // Do not delete a previous save from the same page load right now as it's
+  // unknown at this point in time if this snapshot will succeed.
+  for (auto it = ids.begin(); it != ids.end(); ++it) {
+    if (*it == previous_request_id_for_load_) {
+      ids.erase(it);
+      break;
+    }
+  }
 
   page_model_->DeletePagesByOfflineId(
       ids, base::Bind(&RecentTabHelper::ContinueSnapshotAfterPurge,
@@ -241,9 +252,11 @@ void RecentTabHelper::ContinueSnapshotAfterPurge(
     return;
   }
 
-  page_model_->SavePage(snapshot_url_,
-                        download_info_->client_id_,
-                        download_info_->request_id_,
+  OfflinePageModel::SavePageParams save_page_params;
+  save_page_params.url = snapshot_url_;
+  save_page_params.client_id = download_info_->client_id_;
+  save_page_params.proposed_offline_id = download_info_->request_id_;
+  page_model_->SavePage(save_page_params,
                         delegate_->CreatePageArchiver(web_contents()),
                         base::Bind(&RecentTabHelper::SavePageCallback,
                                    weak_ptr_factory_.GetWeakPtr()));
@@ -255,6 +268,30 @@ void RecentTabHelper::SavePageCallback(OfflinePageModel::SavePageResult result,
     return;
   download_info_->page_snapshot_completed_ =
       (result == SavePageResult::SUCCESS);
+
+  if (download_info_->page_snapshot_completed_) {
+    int64_t previous_request_id = previous_request_id_for_load_;
+    previous_request_id_for_load_ = offline_id;
+
+    // If there is a previous snapshot saved during the same page load it must
+    // be deleted before finishing the snapshot process.
+    if (previous_request_id != OfflinePageModel::kInvalidOfflineId) {
+      std::vector<int64_t> page_id = {previous_request_id};
+      page_model_->DeletePagesByOfflineId(
+          page_id, base::Bind(&RecentTabHelper::PreviousSaveWasPurged,
+                              weak_ptr_factory_.GetWeakPtr()));
+      return;
+    }
+  }
+
+  ReportSnapshotCompleted();
+}
+
+void RecentTabHelper::PreviousSaveWasPurged(
+    OfflinePageModel::DeletePageResult result) {
+  if (!download_info_)
+    return;
+
   ReportSnapshotCompleted();
 }
 
@@ -283,7 +320,8 @@ void RecentTabHelper::ReportDownloadStatusToRequestCoordinator() {
   if (download_info_->page_snapshot_completed_)
     request_coordinator->MarkRequestCompleted(download_info_->request_id_);
   else
-    request_coordinator->EnableForOffliner(download_info_->request_id_);
+    request_coordinator->EnableForOffliner(download_info_->request_id_,
+                                           download_info_->client_id_);
 }
 
 bool RecentTabHelper::IsSamePage() const {
