@@ -9,15 +9,14 @@
 #include <vector>
 
 #include "base/memory/weak_ptr.h"
-#include "components/offline_pages/downloads/download_ui_item.h"
-#include "components/offline_pages/offline_page_model.h"
-#include "components/offline_pages/snapshot_controller.h"
+#include "components/offline_pages/core/downloads/download_ui_item.h"
+#include "components/offline_pages/core/offline_page_model.h"
+#include "components/offline_pages/core/snapshot_controller.h"
 #include "content/public/browser/web_contents_observer.h"
 #include "content/public/browser/web_contents_user_data.h"
 #include "url/gurl.h"
 
 namespace content {
-class NavigationEntry;
 class NavigationHandle;
 }
 
@@ -99,6 +98,7 @@ class RecentTabHelper
   void ContinueSnapshotAfterPurge(OfflinePageModel::DeletePageResult result);
   void SavePageCallback(OfflinePageModel::SavePageResult result,
                         int64_t offline_id);
+  void PreviousSaveWasPurged(OfflinePageModel::DeletePageResult result);
   void ReportSnapshotCompleted();
   void ReportDownloadStatusToRequestCoordinator();
   bool IsSamePage() const;
@@ -120,6 +120,10 @@ class RecentTabHelper
   // current page.
   std::unique_ptr<DownloadPageInfo> download_info_;
 
+  // Stores the request/offline ID of successful snapshots that happened during
+  // a single ongoing page load.
+  int64_t previous_request_id_for_load_;
+
   // If empty, the tab does not have AndroidId and can not capture pages.
   std::string tab_id_;
 
