@@ -7,18 +7,15 @@
 #include <cmath>
 
 #include "base/logging.h"
-#include "chrome/browser/android/vr_shell/vr_gesture.h"
-#include "third_party/WebKit/public/web/WebInputEvent.h"
+#include "base/time/time.h"
 #include "third_party/gvr-android-sdk/src/ndk/include/vr/gvr/capi/include/gvr.h"
 #include "third_party/gvr-android-sdk/src/ndk/include/vr/gvr/capi/include/gvr_controller.h"
 
-using blink::WebInputEvent;
-
 namespace vr_shell {
 
 namespace {
 
-constexpr float kDisplacementScaleFactor = 800.0f;
+constexpr float kDisplacementScaleFactor = 300.0f;
 
 // A slop represents a small rectangular region around the first touch point of
 // a gesture.
@@ -113,19 +110,19 @@ const gvr::Quatf VrController::Orientation() {
   return controller_state_->GetOrientation();
 }
 
-bool VrController::IsTouchDown() {
+bool VrController::TouchDownHappened() {
   return controller_state_->GetTouchDown();
 }
 
-bool VrController::IsTouchUp() {
+bool VrController::TouchUpHappened() {
   return controller_state_->GetTouchUp();
 }
 
-bool VrController::IsButtonDown(gvr::ControllerButton button) {
+bool VrController::ButtonDownHappened(gvr::ControllerButton button) {
   return controller_state_->GetButtonDown(button);
 }
 
-bool VrController::IsButtonUp(gvr::ControllerButton button) {
+bool VrController::ButtonUpHappened(gvr::ControllerButton button) {
   return controller_state_->GetButtonUp(button);
 }
 
@@ -152,15 +149,15 @@ void VrController::UpdateTouchInfo() {
   gvr::Vec2f position;
   position.x = TouchPosX();
   position.y = TouchPosY();
-  touch_info_->touch_up = IsTouchUp();
-  touch_info_->touch_down = IsTouchDown();
+  touch_info_->touch_up = TouchUpHappened();
+  touch_info_->touch_down = TouchDownHappened();
   touch_info_->is_touching = IsTouching();
   touch_info_->touch_point.position = position;
   Vector::ClampTouchpadPosition(&touch_info_->touch_point.position);
   touch_info_->touch_point.timestamp =
       gvr::GvrApi::GetTimePointNow().monotonic_system_time_nanos;
   if (controller_state_->GetLastTouchTimestamp() == last_touch_timestamp_) {
-    // fill the touch_info
+    // Fill the touch_info
     float duration =
         (gvr::GvrApi::GetTimePointNow().monotonic_system_time_nanos -
          last_timestamp_nanos_) /
@@ -188,41 +185,54 @@ void VrController::Initialize(gvr_context* gvr_context) {
   controller_api_->Resume();
 }
 
-std::unique_ptr<VrGesture> VrController::DetectGesture() {
-  std::unique_ptr<VrGesture> gesture(new VrGesture());
+std::vector<std::unique_ptr<WebGestureEvent>> VrController::DetectGestures() {
+  std::vector<std::unique_ptr<WebGestureEvent>> gesture_list;
+  std::unique_ptr<WebGestureEvent> gesture(new WebGestureEvent());
+
   if (controller_state_->GetConnectionState() != gvr::kControllerConnected) {
-    return gesture;
+    gesture_list.push_back(std::move(gesture));
+    return gesture_list;
   }
   UpdateTouchInfo();
   UpdateGestureFromTouchInfo(gesture.get());
 
-  if (gesture->type == WebInputEvent::GestureScrollBegin ||
-      gesture->type == WebInputEvent::GestureScrollUpdate ||
-      gesture->type == WebInputEvent::GestureScrollEnd) {
-    return gesture;
+  if (gesture->type == WebInputEvent::Undefined &&
+      ButtonUpHappened(gvr::kControllerButtonClick)) {
+    gesture->type = WebInputEvent::GestureTapDown;
+    gesture->x = 0;
+    gesture->y = 0;
+  }
+  gesture->sourceDevice = blink::WebGestureDeviceTouchpad;
+  gesture_list.push_back(std::move(gesture));
+
+  if (gesture_list.back()->type == WebInputEvent::GestureScrollEnd) {
+    if (!ButtonDownHappened(gvr::kControllerButtonClick)) {
+      std::unique_ptr<WebGestureEvent> fling(new WebGestureEvent());
+      fling->timeStampSeconds = gesture_list.back()->timeStampSeconds;
+      fling->sourceDevice = blink::WebGestureDeviceTouchpad;
+      fling->type = WebInputEvent::GestureFlingStart;
+      if (IsHorizontalGesture()) {
+        fling->data.flingStart.velocityX =
+            overall_velocity_.x * kDisplacementScaleFactor;
+      } else {
+        fling->data.flingStart.velocityY =
+            overall_velocity_.y * kDisplacementScaleFactor;
+      }
+      gesture_list.push_back(std::move(fling));
+    }
+    Reset();
   }
 
-  if (IsButtonDown(gvr::kControllerButtonClick)) {
-    gesture->type = WebInputEvent::GestureTap;
-    gesture->details.buttons.down = 1;
-    gesture->details.buttons.up = 0;
-    gesture->details.buttons.pos.x = 0;
-    gesture->details.buttons.pos.y = 0;
-    return gesture;
-  }
-
-  return gesture;
+  return gesture_list;
 }
 
-void VrController::UpdateGestureFromTouchInfo(VrGesture* gesture) {
-  gesture->start_time =
-      gvr::GvrApi::GetTimePointNow().monotonic_system_time_nanos;
-  gesture->end_time =
-      gvr::GvrApi::GetTimePointNow().monotonic_system_time_nanos;
+void VrController::UpdateGestureFromTouchInfo(WebGestureEvent* gesture) {
+  gesture->timeStampSeconds =
+      (base::TimeTicks::Now() - base::TimeTicks()).InSecondsF();
   switch (state_) {
     // User has not put finger on touch pad.
     case WAITING:
-      HandleWaitingState();
+      HandleWaitingState(gesture);
       break;
     // User has not started a gesture (by moving out of slop).
     case TOUCHING:
@@ -238,7 +248,7 @@ void VrController::UpdateGestureFromTouchInfo(VrGesture* gesture) {
   }
 }
 
-void VrController::HandleWaitingState() {
+void VrController::HandleWaitingState(WebGestureEvent* gesture) {
   // User puts finger on touch pad (or when the touch down for current gesture
   // is missed, initiate gesture from current touch point).
   if (touch_info_->touch_down || touch_info_->is_touching) {
@@ -247,53 +257,60 @@ void VrController::HandleWaitingState() {
     // update current touchpoint
     *cur_touch_point_ = touch_info_->touch_point;
     state_ = TOUCHING;
+
+    gesture->type = WebInputEvent::GestureFlingCancel;
+    gesture->data.flingCancel.preventBoosting = false;
   }
 }
 
-void VrController::HandleDetectingState(VrGesture* gesture) {
+void VrController::HandleDetectingState(WebGestureEvent* gesture) {
   // User lifts up finger from touch pad.
   if (touch_info_->touch_up || !(touch_info_->is_touching)) {
     Reset();
     return;
   }
 
-  // Touch position is changed and the touch point moves outside of slop.
+  // Touch position is changed, the touch point moves outside of slop,
+  // and the Controller's button is not down.
   if (UpdateCurrentTouchpoint() && touch_info_->is_touching &&
-      !InSlop(touch_info_->touch_point.position)) {
+      !InSlop(touch_info_->touch_point.position) &&
+      !ButtonDownHappened(gvr::kControllerButtonClick)) {
     state_ = SCROLLING;
     gesture->type = WebInputEvent::GestureScrollBegin;
     UpdateGesture(gesture);
-    gesture->details.scroll.delta.x =
-        gesture->displacement.x * kDisplacementScaleFactor;
-    gesture->details.scroll.delta.y =
-        gesture->displacement.y * kDisplacementScaleFactor;
-    gesture->details.scroll.stop_fling = 0;
+    gesture->data.scrollBegin.deltaXHint =
+        displacement_.x * kDisplacementScaleFactor;
+    gesture->data.scrollBegin.deltaYHint =
+        displacement_.y * kDisplacementScaleFactor;
   }
 }
 
-void VrController::HandleScrollingState(VrGesture* gesture) {
+void VrController::HandleScrollingState(WebGestureEvent* gesture) {
   // Update current touch point.
   bool touch_position_changed = UpdateCurrentTouchpoint();
-  if (touch_info_->touch_up || !(touch_info_->is_touching)) {
+  if (touch_info_->touch_up || !(touch_info_->is_touching) ||
+      ButtonDownHappened(gvr::kControllerButtonClick)) {
     // Gesture ends.
     gesture->type = WebInputEvent::GestureScrollEnd;
     UpdateGesture(gesture);
-    gesture->details.scroll.delta.x = 0;
-    gesture->details.scroll.delta.y = 0;
-    gesture->details.scroll.stop_fling = 0;
-    Reset();
   } else if (touch_position_changed) {
     // User continues scrolling and there is a change in touch position.
     gesture->type = WebInputEvent::GestureScrollUpdate;
     UpdateGesture(gesture);
-    gesture->details.scroll.delta.x =
-        gesture->displacement.x * kDisplacementScaleFactor;
-    gesture->details.scroll.delta.y =
-        gesture->displacement.y * kDisplacementScaleFactor;
-    gesture->details.scroll.stop_fling = 0;
+    if (IsHorizontalGesture()) {
+      gesture->data.scrollUpdate.deltaX =
+          displacement_.x * kDisplacementScaleFactor;
+    } else {
+      gesture->data.scrollUpdate.deltaY =
+          displacement_.y * kDisplacementScaleFactor;
+    }
   }
 }
 
+bool VrController::IsHorizontalGesture() {
+  return std::abs(overall_velocity_.x) > std::abs(overall_velocity_.y);
+}
+
 bool VrController::InSlop(const gvr::Vec2f touch_position) {
   return (std::abs(touch_position.x - init_touch_point_->position.x) <
           kSlopHorizontal) &&
@@ -313,11 +330,10 @@ void VrController::Reset() {
   Vector::SetZero(&overall_velocity_);
 }
 
-void VrController::UpdateGesture(VrGesture* gesture) {
+void VrController::UpdateGesture(WebGestureEvent* gesture) {
   if (!gesture)
     LOG(ERROR) << "The gesture pointer is not initiated properly.";
-  gesture->velocity = overall_velocity_;
-  gesture->displacement =
+  displacement_ =
       Vector::Subtract(cur_touch_point_->position, prev_touch_point_->position);
 }
 
