@@ -9,20 +9,21 @@
 #include "base/android/jni_string.h"
 #include "base/android/path_utils.h"
 #include "base/bind.h"
+#include "base/command_line.h"
 #include "base/files/file_path.h"
 #include "base/files/file_util.h"
 #include "base/memory/ref_counted.h"
+#include "base/strings/string_number_conversions.h"
 #include "base/strings/string_util.h"
 #include "base/strings/stringprintf.h"
 #include "base/strings/utf_string_conversions.h"
 #include "base/task_runner_util.h"
 #include "base/threading/sequenced_worker_pool.h"
-#include "chrome/browser/android/chrome_feature_list.h"
 #include "chrome/browser/android/shortcut_helper.h"
 #include "chrome/browser/android/webapk/webapk.pb.h"
 #include "chrome/browser/android/webapk/webapk_icon_hasher.h"
 #include "chrome/browser/profiles/profile.h"
-#include "components/variations/variations_associated_data.h"
+#include "chrome/common/chrome_switches.h"
 #include "components/version_info/version_info.h"
 #include "content/public/browser/browser_thread.h"
 #include "content/public/common/manifest_util.h"
@@ -36,10 +37,7 @@ namespace {
 
 // The default WebAPK server URL.
 const char kDefaultServerUrl[] =
-    "https://webapk.googleapis.com/v1alpha/webApks/?alt=proto";
-
-// Flag for setting the WebAPK server URL.
-const char kServerUrlVariationsParamKey[] = "ServerUrl";
+    "https://webapk.googleapis.com/v1/webApks/?alt=proto&key=AIzaSyAoI6v-F31-3t9NunLYEiKcPIqgTJIUZBw";
 
 // The MIME type of the POST data sent to the server.
 const char kProtoMimeType[] = "application/x-protobuf";
@@ -56,12 +54,13 @@ const int kWorldReadableFilePermission = base::FILE_PERMISSION_READ_BY_USER |
                                          base::FILE_PERMISSION_READ_BY_GROUP |
                                          base::FILE_PERMISSION_READ_BY_OTHERS;
 
-// Returns the WebAPK server URL based on the command line flags and the
-// currently active field trials.
+// Returns the WebAPK server URL based on the command line.
 GURL GetServerUrl() {
-  GURL server_url(variations::GetVariationParamValueByFeature(
-      chrome::android::kWebApks, kServerUrlVariationsParamKey));
-  return server_url.is_valid() ? server_url : GURL(kDefaultServerUrl);
+  base::CommandLine* command_line = base::CommandLine::ForCurrentProcess();
+  GURL command_line_url(
+      command_line->GetSwitchValueASCII(switches::kWebApkServerUrl));
+  return command_line_url.is_valid() ? command_line_url
+                                     : GURL(kDefaultServerUrl);
 }
 
 // Returns the scope from |info| if it is specified. Otherwise, returns the
@@ -122,6 +121,11 @@ std::unique_ptr<webapk::WebApk> BuildWebApkProtoInBackground(
   webapk->set_requester_application_version(version_info::GetVersionNumber());
   webapk->set_android_abi(getCurrentAbi());
 
+  // TODO(hanxi): crbug.com/665078. Add a flag in WebAPK's proto to indicate
+  // that the Web Manifest data in the proto might be stale.
+  if (shortcut_icon_murmur2_hash.empty())
+    return webapk;
+
   webapk::WebAppManifest* web_app_manifest = webapk->mutable_manifest();
   web_app_manifest->set_name(base::UTF16ToUTF8(shortcut_info.name));
   web_app_manifest->set_short_name(
@@ -138,12 +142,20 @@ std::unique_ptr<webapk::WebApk> BuildWebApkProtoInBackground(
 
   std::string* scope = web_app_manifest->add_scopes();
   scope->assign(GetScope(shortcut_info).spec());
-  webapk::Image* image = web_app_manifest->add_icons();
-  image->set_src(shortcut_info.icon_url.spec());
-  image->set_hash(shortcut_icon_murmur2_hash);
+
+  webapk::Image* best_image = web_app_manifest->add_icons();
+  best_image->set_src(shortcut_info.best_icon_url.spec());
+  best_image->set_hash(shortcut_icon_murmur2_hash);
   std::vector<unsigned char> png_bytes;
   gfx::PNGCodec::EncodeBGRASkBitmap(shortcut_icon, false, &png_bytes);
-  image->set_image_data(&png_bytes.front(), png_bytes.size());
+  best_image->set_image_data(&png_bytes.front(), png_bytes.size());
+
+  for (const std::string& icon_url : shortcut_info.icon_urls) {
+    if (icon_url == shortcut_info.best_icon_url.spec())
+      continue;
+    webapk::Image* image = web_app_manifest->add_icons();
+    image->set_src(icon_url);
+  }
 
   return webapk;
 }
@@ -304,6 +316,39 @@ bool WebApkInstaller::StartUpdateUsingDownloadedWebApk(
       env, java_ref_, java_file_path);
 }
 
+bool WebApkInstaller::HasGooglePlayWebApkInstallDelegate() {
+  JNIEnv* env = base::android::AttachCurrentThread();
+  return Java_WebApkInstaller_hasGooglePlayWebApkInstallDelegate(
+      env, java_ref_);
+}
+
+bool WebApkInstaller::InstallOrUpdateWebApkFromGooglePlay(
+    const std::string& package_name,
+    int version,
+    const std::string& token) {
+  webapk_package_ = package_name;
+
+  JNIEnv* env = base::android::AttachCurrentThread();
+  base::android::ScopedJavaLocalRef<jstring> java_webapk_package =
+      base::android::ConvertUTF8ToJavaString(env, webapk_package_);
+  base::android::ScopedJavaLocalRef<jstring> java_title =
+      base::android::ConvertUTF16ToJavaString(env, shortcut_info_.user_title);
+  base::android::ScopedJavaLocalRef<jstring> java_token =
+      base::android::ConvertUTF8ToJavaString(env, token);
+  base::android::ScopedJavaLocalRef<jstring> java_url =
+      base::android::ConvertUTF8ToJavaString(env, shortcut_info_.url.spec());
+
+  if (task_type_ == WebApkInstaller::INSTALL) {
+    return Java_WebApkInstaller_installWebApkFromGooglePlayAsync(
+        env, java_ref_, java_webapk_package, version, java_title, java_token,
+        java_url);
+  } else {
+    return Java_WebApkInstaller_updateAsyncFromGooglePlay(
+        env, java_ref_, java_webapk_package, version, java_title, java_token,
+        java_url);
+  }
+}
+
 void WebApkInstaller::OnURLFetchComplete(const net::URLFetcher* source) {
   timer_.Stop();
 
@@ -328,12 +373,23 @@ void WebApkInstaller::OnURLFetchComplete(const net::URLFetcher* source) {
     OnFailure();
     return;
   }
+
+  if (HasGooglePlayWebApkInstallDelegate()) {
+    int version = 1;
+    base::StringToInt(response->version(), &version);
+    if (!InstallOrUpdateWebApkFromGooglePlay(
+        response->package_name(), version, response->token())) {
+      OnFailure();
+    }
+    return;
+  }
+
   OnGotWebApkDownloadUrl(signed_download_url, response->package_name());
 }
 
 void WebApkInstaller::DownloadAppIconAndComputeMurmur2Hash() {
   // Safeguard. WebApkIconHasher crashes if asked to fetch an invalid URL.
-  if (!shortcut_info_.icon_url.is_valid()) {
+  if (!shortcut_info_.best_icon_url.is_valid()) {
     OnFailure();
     return;
   }
@@ -344,7 +400,7 @@ void WebApkInstaller::DownloadAppIconAndComputeMurmur2Hash() {
 
   icon_hasher_.reset(new WebApkIconHasher());
   icon_hasher_->DownloadAndComputeMurmur2Hash(
-      request_context_getter_, shortcut_info_.icon_url,
+      request_context_getter_, shortcut_info_.best_icon_url,
       base::Bind(&WebApkInstaller::OnGotIconMurmur2Hash,
                  weak_ptr_factory_.GetWeakPtr()));
 }
