@@ -8,23 +8,18 @@
 #include <memory>
 #include <string>
 
-#include "base/android/field_trial_list.h"
 #include "base/android/scoped_java_ref.h"
 #include "base/bind.h"
 #include "base/callback_forward.h"
-#include "base/feature_list.h"
+#include "base/command_line.h"
 #include "base/files/file_path.h"
-#include "base/memory/ptr_util.h"
 #include "base/memory/ref_counted.h"
 #include "base/run_loop.h"
 #include "base/single_thread_task_runner.h"
-#include "base/test/scoped_feature_list.h"
 #include "base/threading/thread_task_runner_handle.h"
-#include "chrome/browser/android/chrome_feature_list.h"
 #include "chrome/browser/android/shortcut_info.h"
 #include "chrome/browser/android/webapk/webapk.pb.h"
 #include "chrome/common/chrome_switches.h"
-#include "components/variations/variations_associated_data.h"
 #include "content/public/browser/browser_thread.h"
 #include "content/public/test/test_browser_thread_bundle.h"
 #include "net/test/embedded_test_server/embedded_test_server.h"
@@ -40,17 +35,13 @@ namespace {
 const base::FilePath::CharType kTestDataDir[] =
     FILE_PATH_LITERAL("chrome/test/data");
 
-// Mock field trial name and field trial group to use for "WebApks" feature.
-const char kFieldTrialName[] = "MockFieldTrial";
-const char kFieldTrialGroup[] = "MockFieldTrialGroup";
-
 // URL of mock WebAPK server.
 const char* kServerUrl = "/webapkserver/";
 
-// Icon URL from Web Manifest. We use a random file in the test data directory.
-// Since WebApkInstaller does not try to decode the file as an image it is OK
-// that the file is not an image.
-const char* kIconUrl = "/simple.html";
+// The best icon URL from Web Manifest. We use a random file in the test data
+// directory. Since WebApkInstaller does not try to decode the file as an image
+// it is OK that the file is not an image.
+const char* kBestIconUrl = "/simple.html";
 
 // URL of file to download from the WebAPK server. We use a random file in the
 // test data directory.
@@ -61,12 +52,17 @@ const char* kDownloadedWebApkPackageName = "party.unicode";
 
 // WebApkInstaller subclass where
 // WebApkInstaller::StartInstallingDownloadedWebApk() and
-// WebApkInstaller::StartUpdateUsingDownloadedWebApk() are stubbed out.
+// WebApkInstaller::StartUpdateUsingDownloadedWebApk() and
+// WebApkInstaller::HasGooglePlayWebApkInstallDelegate() and
+// WebApkInstaller::InstallOrUpdateWebApkFromGooglePlay() are stubbed out.
 class TestWebApkInstaller : public WebApkInstaller {
  public:
   TestWebApkInstaller(const ShortcutInfo& shortcut_info,
-                      const SkBitmap& shortcut_icon)
-      : WebApkInstaller(shortcut_info, shortcut_icon) {}
+                      const SkBitmap& shortcut_icon,
+                      bool has_google_play_webapk_install_delegate)
+      : WebApkInstaller(shortcut_info, shortcut_icon),
+        has_google_play_webapk_install_delegate_(
+            has_google_play_webapk_install_delegate) {}
 
   bool StartInstallingDownloadedWebApk(
       JNIEnv* env,
@@ -82,6 +78,17 @@ class TestWebApkInstaller : public WebApkInstaller {
     return true;
   }
 
+  bool HasGooglePlayWebApkInstallDelegate() override {
+    return has_google_play_webapk_install_delegate_;
+  }
+
+  bool InstallOrUpdateWebApkFromGooglePlay(const std::string& package_name,
+                                           int version,
+                                           const std::string& token) override {
+    PostTaskToRunSuccessCallback();
+    return true;
+  }
+
   void PostTaskToRunSuccessCallback() {
     base::ThreadTaskRunnerHandle::Get()->PostTask(
         FROM_HERE,
@@ -89,18 +96,27 @@ class TestWebApkInstaller : public WebApkInstaller {
   }
 
  private:
+  // Whether the Google Play install delegate is available.
+  bool has_google_play_webapk_install_delegate_;
+
   DISALLOW_COPY_AND_ASSIGN(TestWebApkInstaller);
 };
 
 // Runs the WebApkInstaller installation process/update and blocks till done.
 class WebApkInstallerRunner {
  public:
-  explicit WebApkInstallerRunner(const GURL& icon_url)
+  explicit WebApkInstallerRunner(const GURL& best_icon_url)
       : url_request_context_getter_(new net::TestURLRequestContextGetter(
             base::ThreadTaskRunnerHandle::Get())),
-        icon_url_(icon_url) {}
+        best_icon_url_(best_icon_url),
+        has_google_play_webapk_install_delegate_(false) {}
+
   ~WebApkInstallerRunner() {}
 
+  void SetHasGooglePlayWebApkInstallDelegate(bool has_delegate) {
+    has_google_play_webapk_install_delegate_ = has_delegate;
+  }
+
   void RunInstallWebApk() {
     WebApkInstaller* installer = CreateWebApkInstaller();
 
@@ -129,10 +145,11 @@ class WebApkInstallerRunner {
 
   WebApkInstaller* CreateWebApkInstaller() {
     ShortcutInfo info(GURL::EmptyGURL());
-    info.icon_url = icon_url_;
+    info.best_icon_url = best_icon_url_;
 
     // WebApkInstaller owns itself.
-    WebApkInstaller* installer = new TestWebApkInstaller(info, SkBitmap());
+    WebApkInstaller* installer = new TestWebApkInstaller(
+        info, SkBitmap(), has_google_play_webapk_install_delegate_);
     installer->SetTimeoutMs(100);
     return installer;
   }
@@ -155,7 +172,7 @@ class WebApkInstallerRunner {
       url_request_context_getter_;
 
   // The Web Manifest's icon URL.
-  const GURL icon_url_;
+  const GURL best_icon_url_;
 
   // Called after the installation process has succeeded or failed.
   base::Closure on_completed_callback_;
@@ -163,6 +180,9 @@ class WebApkInstallerRunner {
   // Whether the installation process succeeded.
   bool success_;
 
+  // Whether the Google Play install delegate is available.
+  bool has_google_play_webapk_install_delegate_;
+
   DISALLOW_COPY_AND_ASSIGN(WebApkInstallerRunner);
 };
 
@@ -193,9 +213,7 @@ class WebApkInstallerTest : public ::testing::Test {
 
   WebApkInstallerTest()
       : thread_bundle_(content::TestBrowserThreadBundle::IO_MAINLOOP) {}
-  ~WebApkInstallerTest() override {
-    variations::testing::ClearAllVariationParams();
-  }
+  ~WebApkInstallerTest() override {}
 
   void SetUp() override {
     test_server_.AddDefaultHandlers(base::FilePath(kTestDataDir));
@@ -204,30 +222,19 @@ class WebApkInstallerTest : public ::testing::Test {
                    base::Unretained(this)));
     ASSERT_TRUE(test_server_.Start());
 
-    field_trial_list_.reset(new base::FieldTrialList(nullptr));
-    base::FieldTrial* field_trial = base::FieldTrialList::CreateFieldTrial(
-        kFieldTrialName, kFieldTrialGroup);
-    std::unique_ptr<base::FeatureList> feature_list =
-        base::MakeUnique<base::FeatureList>();
-    feature_list->RegisterFieldTrialOverride(
-        chrome::android::kWebApks.name,
-        base::FeatureList::OVERRIDE_ENABLE_FEATURE, field_trial);
-    scoped_feature_list_.InitWithFeatureList(std::move(feature_list));
-
     SetDefaults();
   }
 
-  // Sets the Web Manifest's icon URL.
-  void SetIconUrl(const GURL& icon_url) { icon_url_ = icon_url; }
+  // Sets the best Web Manifest's icon URL.
+  void SetBestIconUrl(const GURL& best_icon_url) {
+    best_icon_url_ = best_icon_url;
+  }
 
   // Sets the URL to send the webapk::CreateWebApkRequest to. WebApkInstaller
   // should fail if the URL is not |kServerUrl|.
   void SetWebApkServerUrl(const GURL& server_url) {
-    variations::testing::ClearAllVariationParams();
-    std::map<std::string, std::string> params;
-    params["ServerUrl"] = server_url.spec();
-    ASSERT_TRUE(variations::AssociateVariationParams(kFieldTrialName,
-                                                     kFieldTrialGroup, params));
+    base::CommandLine::ForCurrentProcess()->AppendSwitchASCII(
+        switches::kWebApkServerUrl, server_url.spec());
   }
 
   // Sets the function that should be used to build the response to the
@@ -238,7 +245,7 @@ class WebApkInstallerTest : public ::testing::Test {
 
   std::unique_ptr<WebApkInstallerRunner> CreateWebApkInstallerRunner() {
     return std::unique_ptr<WebApkInstallerRunner>(
-        new WebApkInstallerRunner(icon_url_));
+        new WebApkInstallerRunner(best_icon_url_));
   }
 
   net::test_server::EmbeddedTestServer* test_server() { return &test_server_; }
@@ -246,8 +253,8 @@ class WebApkInstallerTest : public ::testing::Test {
  private:
   // Sets default configuration for running WebApkInstaller.
   void SetDefaults() {
-    GURL icon_url = test_server_.GetURL(kIconUrl);
-    SetIconUrl(icon_url);
+    GURL best_icon_url = test_server_.GetURL(kBestIconUrl);
+    SetBestIconUrl(best_icon_url);
     GURL server_url = test_server_.GetURL(kServerUrl);
     SetWebApkServerUrl(server_url);
     GURL download_url = test_server_.GetURL(kDownloadUrl);
@@ -265,11 +272,8 @@ class WebApkInstallerTest : public ::testing::Test {
   content::TestBrowserThreadBundle thread_bundle_;
   net::EmbeddedTestServer test_server_;
 
-  std::unique_ptr<base::FieldTrialList> field_trial_list_;
-  base::test::ScopedFeatureList scoped_feature_list_;
-
   // Web Manifest's icon URL.
-  GURL icon_url_;
+  GURL best_icon_url_;
 
   // Builds response to the WebAPK creation request.
   WebApkResponseBuilder webapk_response_builder_;
@@ -284,12 +288,12 @@ TEST_F(WebApkInstallerTest, Success) {
   EXPECT_TRUE(runner->success());
 }
 
-// Test that installation fails if fetching the bitmap at the icon URL times
-// out. In a perfect world the fetch would never time out because the bitmap at
-// the icon URL should be in the HTTP cache.
-TEST_F(WebApkInstallerTest, IconUrlDownloadTimesOut) {
-  GURL icon_url = test_server()->GetURL("/slow?1000");
-  SetIconUrl(icon_url);
+// Test that installation fails if fetching the bitmap at the best icon URL
+// times out. In a perfect world the fetch would never time out because the
+// bitmap at the best icon URL should be in the HTTP cache.
+TEST_F(WebApkInstallerTest, BestIconUrlDownloadTimesOut) {
+  GURL best_icon_url = test_server()->GetURL("/slow?1000");
+  SetBestIconUrl(best_icon_url);
 
   std::unique_ptr<WebApkInstallerRunner> runner = CreateWebApkInstallerRunner();
   runner->RunInstallWebApk();
@@ -356,3 +360,11 @@ TEST_F(WebApkInstallerTest, UpdateSuccess) {
   runner->RunUpdateWebApk();
   EXPECT_TRUE(runner->success());
 }
+
+// Test installation succeeds using Google Play.
+TEST_F(WebApkInstallerTest, InstallFromGooglePlaySuccess) {
+  std::unique_ptr<WebApkInstallerRunner> runner = CreateWebApkInstallerRunner();
+  runner->SetHasGooglePlayWebApkInstallDelegate(true);
+  runner->RunInstallWebApk();
+  EXPECT_TRUE(runner->success());
+}
