@@ -6,6 +6,7 @@
 
 #include <jni.h>
 
+#include "base/android/jni_array.h"
 #include "base/android/jni_string.h"
 #include "base/bind.h"
 #include "chrome/browser/android/webapk/webapk_installer.h"
@@ -43,23 +44,25 @@ void WebApkUpdateManager::OnBuiltWebApk(const std::string& id,
 }
 
 // static JNI method.
-static void UpdateAsync(JNIEnv* env,
-                        const JavaParamRef<jclass>& clazz,
-                        const JavaParamRef<jstring>& java_id,
-                        const JavaParamRef<jstring>& java_start_url,
-                        const JavaParamRef<jstring>& java_scope,
-                        const JavaParamRef<jstring>& java_name,
-                        const JavaParamRef<jstring>& java_short_name,
-                        const JavaParamRef<jstring>& java_icon_url,
-                        const JavaParamRef<jstring>& java_icon_murmur2_hash,
-                        const JavaParamRef<jobject>& java_icon_bitmap,
-                        jint java_display_mode,
-                        jint java_orientation,
-                        jlong java_theme_color,
-                        jlong java_background_color,
-                        const JavaParamRef<jstring>& java_web_manifest_url,
-                        const JavaParamRef<jstring>& java_webapk_package,
-                        jint java_webapk_version) {
+static void UpdateAsync(
+    JNIEnv* env,
+    const JavaParamRef<jclass>& clazz,
+    const JavaParamRef<jstring>& java_id,
+    const JavaParamRef<jstring>& java_start_url,
+    const JavaParamRef<jstring>& java_scope,
+    const JavaParamRef<jstring>& java_name,
+    const JavaParamRef<jstring>& java_short_name,
+    const JavaParamRef<jstring>& java_best_icon_url,
+    const JavaParamRef<jstring>& java_best_icon_murmur2_hash,
+    const JavaParamRef<jobject>& java_best_icon_bitmap,
+    const JavaParamRef<jobjectArray>& java_icon_urls,
+    jint java_display_mode,
+    jint java_orientation,
+    jlong java_theme_color,
+    jlong java_background_color,
+    const JavaParamRef<jstring>& java_web_manifest_url,
+    const JavaParamRef<jstring>& java_webapk_package,
+    jint java_webapk_version) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
 
   Profile* profile = ProfileManager::GetLastUsedProfile();
@@ -72,7 +75,7 @@ static void UpdateAsync(JNIEnv* env,
   GURL start_url(ConvertJavaStringToUTF8(env, java_start_url));
   GURL scope(ConvertJavaStringToUTF8(env, java_scope));
   GURL web_manifest_url(ConvertJavaStringToUTF8(env, java_web_manifest_url));
-  GURL icon_url(ConvertJavaStringToUTF8(env, java_icon_url));
+  GURL best_icon_url(ConvertJavaStringToUTF8(env, java_best_icon_url));
   ShortcutInfo info(start_url);
   info.scope = scope;
   info.name = ConvertJavaStringToUTF16(env, java_name);
@@ -82,22 +85,27 @@ static void UpdateAsync(JNIEnv* env,
       static_cast<blink::WebScreenOrientationLockType>(java_orientation);
   info.theme_color = (long)java_theme_color;
   info.background_color = (long)java_background_color;
-  info.icon_url = icon_url;
+  info.best_icon_url = best_icon_url;
   info.manifest_url = web_manifest_url;
 
-  gfx::JavaBitmap java_bitmap_lock(java_icon_bitmap);
-  SkBitmap icon_bitmap = gfx::CreateSkBitmapFromJavaBitmap(java_bitmap_lock);
-  icon_bitmap.setImmutable();
+  base::android::AppendJavaStringArrayToStringVector(
+      env, java_icon_urls.obj(), &info.icon_urls);
 
-  std::string icon_murmur2_hash;
-  ConvertJavaStringToUTF8(env, java_icon_murmur2_hash, &icon_murmur2_hash);
+  gfx::JavaBitmap java_bitmap_lock(java_best_icon_bitmap);
+  SkBitmap best_icon_bitmap =
+      gfx::CreateSkBitmapFromJavaBitmap(java_bitmap_lock);
+  best_icon_bitmap.setImmutable();
+
+  std::string best_icon_murmur2_hash;
+  ConvertJavaStringToUTF8(env, java_best_icon_murmur2_hash,
+                          &best_icon_murmur2_hash);
 
   std::string webapk_package;
   ConvertJavaStringToUTF8(env, java_webapk_package, &webapk_package);
 
-  WebApkInstaller* installer = new WebApkInstaller(info, icon_bitmap);
+  WebApkInstaller* installer = new WebApkInstaller(info, best_icon_bitmap);
   installer->UpdateAsync(
       profile,
       base::Bind(&WebApkUpdateManager::OnBuiltWebApk, id),
-      icon_murmur2_hash, webapk_package, java_webapk_version);
+      best_icon_murmur2_hash, webapk_package, java_webapk_version);
 }
