@@ -21,16 +21,16 @@
 #include "chrome/browser/browser_process.h"
 #include "chrome/common/chrome_paths.h"
 #include "chrome/common/chrome_switches.h"
-#include "chrome/common/chrome_version_info.h"
 #include "chrome/common/mac/app_mode_common.h"
+#include "components/version_info/version_info.h"
 
 using content::BrowserThread;
 
 namespace {
 
-void CreateAppShimHost(const IPC::ChannelHandle& handle) {
+void CreateAppShimHost(mojo::edk::ScopedPlatformHandle handle) {
   // AppShimHost takes ownership of itself.
-  (new AppShimHost)->ServeChannel(handle);
+  (new AppShimHost)->ServeChannel(std::move(handle));
 }
 
 base::FilePath GetDirectoryInTmpTemplate(const base::FilePath& user_data_dir) {
@@ -140,7 +140,7 @@ void AppShimHostManager::InitOnFileThread() {
   base::FilePath version_path =
       user_data_dir.Append(app_mode::kRunningChromeVersionSymlinkName);
   base::DeleteFile(version_path, false);
-  base::CreateSymbolicLink(base::FilePath(chrome::VersionInfo().Version()),
+  base::CreateSymbolicLink(base::FilePath(version_info::GetVersionNumber()),
                            version_path);
 
   BrowserThread::PostTask(
@@ -158,11 +158,11 @@ void AppShimHostManager::ListenOnIOThread() {
 }
 
 void AppShimHostManager::OnClientConnected(
-    const IPC::ChannelHandle& handle) {
+    mojo::edk::ScopedPlatformHandle handle) {
   DCHECK_CURRENTLY_ON(BrowserThread::IO);
   BrowserThread::PostTask(
       BrowserThread::UI, FROM_HERE,
-      base::Bind(&CreateAppShimHost, handle));
+      base::Bind(&CreateAppShimHost, base::Passed(&handle)));
 }
 
 void AppShimHostManager::OnListenError() {
