@@ -8,6 +8,7 @@
 #include "build/build_config.h"
 #include "chrome/browser/apps/app_browsertest_util.h"
 #include "chrome/browser/chrome_notification_types.h"
+#include "chrome/browser/prerender/prerender_manager.h"
 #include "chrome/browser/ui/browser_navigator_params.h"
 #include "chrome/browser/ui/tabs/tab_strip_model.h"
 #include "chrome/common/chrome_switches.h"
@@ -23,6 +24,7 @@ namespace extensions {
 class PlatformAppUrlRedirectorBrowserTest : public PlatformAppBrowserTest {
  public:
   void SetUpCommandLine(base::CommandLine* command_line) override;
+  void SetUpOnMainThread() override;
 
  protected:
   // Performs the following sequence:
@@ -118,8 +120,12 @@ void PlatformAppUrlRedirectorBrowserTest::SetUpCommandLine(
     base::CommandLine* command_line) {
   PlatformAppBrowserTest::SetUpCommandLine(command_line);
   command_line->AppendSwitch(::switches::kDisablePopupBlocking);
-  command_line->AppendSwitchASCII(::switches::kPrerenderMode,
-                                  ::switches::kPrerenderModeSwitchValueEnabled);
+}
+
+void PlatformAppUrlRedirectorBrowserTest::SetUpOnMainThread() {
+  PlatformAppBrowserTest::SetUpOnMainThread();
+  prerender::PrerenderManager::SetMode(
+      prerender::PrerenderManager::PRERENDER_MODE_ENABLED);
 }
 
 // TODO(sergeygs): Factor out common functionality from TestXyz,
