@@ -28,16 +28,19 @@ const char kFieldTrialGroup[] = "GroupA";
 
 class TestBackgroundSyncControllerImpl : public BackgroundSyncControllerImpl {
  public:
-  TestBackgroundSyncControllerImpl(Profile* profile,
-                                   rappor::TestRapporService* rappor_service)
+  TestBackgroundSyncControllerImpl(
+      Profile* profile,
+      rappor::TestRapporServiceImpl* rappor_service)
       : BackgroundSyncControllerImpl(profile),
         rappor_service_(rappor_service) {}
 
  protected:
-  rappor::RapporService* GetRapporService() override { return rappor_service_; }
+  rappor::RapporServiceImpl* GetRapporServiceImpl() override {
+    return rappor_service_;
+  }
 
  private:
-  rappor::TestRapporService* rappor_service_;
+  rappor::TestRapporServiceImpl* rappor_service_;
 
   DISALLOW_COPY_AND_ASSIGN(TestBackgroundSyncControllerImpl);
 };
@@ -65,7 +68,7 @@ class BackgroundSyncControllerImplTest : public testing::Test {
 
   content::TestBrowserThreadBundle thread_bundle_;
   TestingProfile profile_;
-  rappor::TestRapporService rappor_service_;
+  rappor::TestRapporServiceImpl rappor_service_;
   std::unique_ptr<TestBackgroundSyncControllerImpl> controller_;
   std::unique_ptr<base::FieldTrialList> field_trial_list_;
 
