@@ -24,7 +24,8 @@
 #include "chrome/common/chrome_switches.h"
 #include "components/content_settings/core/browser/host_content_settings_map.h"
 #include "components/content_settings/core/common/content_settings_pattern.h"
-#include "components/rappor/rappor_utils.h"
+#include "components/rappor/public/rappor_utils.h"
+#include "components/rappor/rappor_service_impl.h"
 #include "components/variations/variations_associated_data.h"
 #include "content/public/browser/web_contents.h"
 #include "net/base/escape.h"
@@ -81,6 +82,7 @@ const char kBannerParamsEngagementTotalKey[] = "site_engagement_total";
 const char kBannerParamsDaysAfterBannerDismissedKey[] = "days_after_dismiss";
 const char kBannerParamsDaysAfterBannerIgnoredKey[] = "days_after_ignore";
 const char kBannerSiteEngagementParamsKey[] = "use_site_engagement";
+const char kBannerParamsLanguageKey[] = "language_option";
 
 // Engagement weight assigned to direct and indirect navigations.
 // By default, a direct navigation is a page visit via ui::PAGE_TRANSITION_TYPED
@@ -353,7 +355,7 @@ void AppBannerSettingsHelper::RecordBannerCouldShowEvent(
   // the times are converted to local dates.
   base::Time date = BucketTimeToResolution(time, gMinimumMinutesBetweenVisits);
   for (auto it = could_show_list->begin(); it != could_show_list->end();) {
-    if ((*it)->IsType(base::Value::TYPE_DICTIONARY)) {
+    if ((*it)->IsType(base::Value::Type::DICTIONARY)) {
       base::DictionaryValue* internal_value;
       double internal_date;
       (*it)->GetAsDictionary(&internal_value);
@@ -495,7 +497,7 @@ AppBannerSettingsHelper::GetCouldShowBannerEvents(
     return result;
 
   for (const auto& value : *could_show_list) {
-    if (value->IsType(base::Value::TYPE_DICTIONARY)) {
+    if (value->IsType(base::Value::Type::DICTIONARY)) {
       base::DictionaryValue* internal_value;
       double internal_date = 0;
       value->GetAsDictionary(&internal_value);
@@ -580,7 +582,7 @@ bool AppBannerSettingsHelper::WasLaunchedRecently(Profile* profile,
   // homescreen recently, return true.
   for (base::DictionaryValue::Iterator it(*origin_dict); !it.IsAtEnd();
        it.Advance()) {
-    if (it.value().IsType(base::Value::TYPE_DICTIONARY)) {
+    if (it.value().IsType(base::Value::Type::DICTIONARY)) {
       const base::DictionaryValue* value;
       it.value().GetAsDictionary(&value);
 
@@ -674,6 +676,21 @@ void AppBannerSettingsHelper::UpdateFromFieldTrial() {
   }
 }
 
+AppBannerSettingsHelper::LanguageOption
+AppBannerSettingsHelper::GetHomescreenLanguageOption() {
+  std::string param = variations::GetVariationParamValue(
+      kBannerParamsKey, kBannerParamsLanguageKey);
+  unsigned int language_option = 0;
+
+  if (param.empty() || !base::StringToUint(param, &language_option) ||
+      language_option < LANGUAGE_OPTION_MIN ||
+      language_option > LANGUAGE_OPTION_MAX) {
+    return LANGUAGE_OPTION_DEFAULT;
+  }
+
+  return static_cast<LanguageOption>(language_option);
+}
+
 bool AppBannerSettingsHelper::ShouldUseSiteEngagementScore() {
   if (base::CommandLine::ForCurrentProcess()->HasSwitch(
           switches::kEnableSiteEngagementAppBanner)) {
