@@ -29,6 +29,8 @@
 #include "chrome/browser/history/web_history_service_factory.h"
 #include "chrome/browser/io_thread.h"
 #include "chrome/browser/media/media_device_id_salt.h"
+#include "chrome/browser/net/nqe/ui_network_quality_estimator_service.h"
+#include "chrome/browser/net/nqe/ui_network_quality_estimator_service_factory.h"
 #include "chrome/browser/net/predictor.h"
 #include "chrome/browser/net/spdyproxy/data_reduction_proxy_chrome_settings.h"
 #include "chrome/browser/net/spdyproxy/data_reduction_proxy_chrome_settings_factory.h"
@@ -63,8 +65,6 @@
 #include "components/ntp_snippets/content_suggestions_service.h"
 #include "components/omnibox/browser/omnibox_pref_names.h"
 #include "components/password_manager/core/browser/password_store.h"
-#include "components/power/origin_power_map.h"
-#include "components/power/origin_power_map_factory.h"
 #include "components/prefs/pref_service.h"
 #include "components/previews/core/previews_ui_service.h"
 #include "components/search_engines/template_url_service.h"
@@ -77,6 +77,8 @@
 #include "content/public/browser/ssl_host_state_delegate.h"
 #include "content/public/browser/storage_partition.h"
 #include "content/public/browser/user_metrics.h"
+#include "extensions/features/features.h"
+#include "media/media_features.h"
 #include "net/base/net_errors.h"
 #include "net/cookies/cookie_store.h"
 #include "net/http/http_network_session.h"
@@ -86,6 +88,7 @@
 #include "net/ssl/channel_id_store.h"
 #include "net/url_request/url_request_context.h"
 #include "net/url_request/url_request_context_getter.h"
+#include "ppapi/features/features.h"
 #include "storage/browser/quota/special_storage_policy.h"
 #include "url/origin.h"
 
@@ -93,21 +96,21 @@
 #include "chrome/browser/android/offline_pages/offline_page_model_factory.h"
 #include "chrome/browser/android/webapps/webapp_registry.h"
 #include "chrome/browser/precache/precache_manager_factory.h"
-#include "components/offline_pages/offline_page_feature.h"
-#include "components/offline_pages/offline_page_model.h"
+#include "components/offline_pages/core/offline_page_feature.h"
+#include "components/offline_pages/core/offline_page_model.h"
 #include "components/precache/content/precache_manager.h"
 #endif
 
-#if defined(ENABLE_EXTENSIONS)
+#if BUILDFLAG(ENABLE_EXTENSIONS)
 #include "chrome/browser/extensions/activity_log/activity_log.h"
 #include "extensions/browser/extension_prefs.h"
 #endif
 
-#if defined(ENABLE_PLUGINS)
+#if BUILDFLAG(ENABLE_PLUGINS)
 #include "chrome/browser/browsing_data/browsing_data_flash_lso_helper.h"
 #endif
 
-#if defined(ENABLE_SESSION_SERVICE)
+#if BUILDFLAG(ENABLE_SESSION_SERVICE)
 #include "chrome/browser/sessions/session_service.h"
 #include "chrome/browser/sessions/session_service_factory.h"
 #endif
@@ -121,7 +124,7 @@
 #include "components/user_manager/user.h"
 #endif
 
-#if defined(ENABLE_WEBRTC)
+#if BUILDFLAG(ENABLE_WEBRTC)
 #include "chrome/browser/media/webrtc/webrtc_log_list.h"
 #include "chrome/browser/media/webrtc/webrtc_log_util.h"
 #endif
@@ -320,7 +323,7 @@ BrowsingDataRemover::BrowsingDataRemover(
       remove_mask_(-1),
       origin_type_mask_(-1),
       is_removing_(false),
-#if defined(ENABLE_PLUGINS)
+#if BUILDFLAG(ENABLE_PLUGINS)
       flash_lso_helper_(BrowsingDataFlashLSOHelper::Create(profile_)),
 #endif
 #if BUILDFLAG(ANDROID_JAVA_UI)
@@ -532,7 +535,7 @@ void BrowsingDataRemover::RemoveImpl(
                                                 filter);
     }
 
-#if defined(ENABLE_EXTENSIONS)
+#if BUILDFLAG(ENABLE_EXTENSIONS)
     // The extension activity log contains details of which websites extensions
     // were active on. It therefore indirectly stores details of websites a
     // user has visited so best clean from here as well.
@@ -552,13 +555,6 @@ void BrowsingDataRemover::RemoveImpl(
     }
 #endif
 
-    // The power consumption history by origin contains details of websites
-    // that were visited.
-    power::OriginPowerMap* origin_power_map =
-        power::OriginPowerMapFactory::GetForBrowserContext(profile_);
-    if (origin_power_map)
-      origin_power_map->ClearOriginMap(nullable_filter);
-
     // Need to clear the host cache and accumulated speculative data, as it also
     // reveals some history. We have no mechanism to track when these items were
     // created, so we'll not honor the time range.
@@ -629,7 +625,7 @@ void BrowsingDataRemover::RemoveImpl(
         tab_service->DeleteLastSession();
       }
 
-#if defined(ENABLE_SESSION_SERVICE)
+#if BUILDFLAG(ENABLE_SESSION_SERVICE)
       // We also delete the last session when we delete the history.
       SessionService* session_service =
           SessionServiceFactory::GetForProfile(profile_);
@@ -662,7 +658,7 @@ void BrowsingDataRemover::RemoveImpl(
         data_manager->Refresh();
     }
 
-#if defined(ENABLE_WEBRTC)
+#if BUILDFLAG(ENABLE_WEBRTC)
     waiting_for_clear_webrtc_logs_ = true;
     BrowserThread::PostTaskAndReply(
         BrowserThread::FILE, FROM_HERE,
@@ -702,13 +698,8 @@ void BrowsingDataRemover::RemoveImpl(
     }
 
     // Clear the history information (last launch time and origin URL) of any
-    // registered webapps. The webapp_registry makes a JNI call into a Java-side
-    // AsyncTask, so don't wait for the reply.
-    waiting_for_clear_webapp_history_ = true;
-    webapp_registry_->ClearWebappHistoryForUrls(
-        filter,
-        base::Bind(&BrowsingDataRemover::OnClearedWebappHistory,
-                   weak_ptr_factory_.GetWeakPtr()));
+    // registered webapps.
+    webapp_registry_->ClearWebappHistoryForUrls(filter);
 #endif
 
     data_reduction_proxy::DataReductionProxySettings*
@@ -852,7 +843,7 @@ void BrowsingDataRemover::RemoveImpl(
         content::StoragePartition::REMOVE_DATA_MASK_FILE_SYSTEMS;
   }
 
-#if defined(ENABLE_PLUGINS)
+#if BUILDFLAG(ENABLE_PLUGINS)
   // Plugin is data not separated for protected and unprotected web origins. We
   // check the origin_type_mask_ to prevent unintended deletion.
   if (remove_mask & REMOVE_PLUGIN_DATA &&
@@ -1038,6 +1029,20 @@ void BrowsingDataRemover::RemoveImpl(
         ContentSuggestionsServiceFactory::GetForProfileIfExists(profile_);
     if (content_suggestions_service)
       content_suggestions_service->ClearAllCachedSuggestions();
+
+    // |ui_nqe_service| may be null if |profile_| is not a regular profile.
+    UINetworkQualityEstimatorService* ui_nqe_service =
+        UINetworkQualityEstimatorServiceFactory::GetForProfile(profile_);
+    DCHECK(profile_->GetProfileType() !=
+               Profile::ProfileType::REGULAR_PROFILE ||
+           ui_nqe_service != nullptr);
+    if (ui_nqe_service) {
+      // Network Quality Estimator (NQE) stores the quality (RTT, bandwidth
+      // etc.) of different networks in prefs. The stored quality is not
+      // broken down by URLs or timestamps, so clearing the cache should
+      // completely clear the prefs.
+      ui_nqe_service->ClearPrefs();
+    }
   }
 
   if (remove_mask & REMOVE_COOKIES || remove_mask & REMOVE_PASSWORDS) {
@@ -1104,7 +1109,7 @@ void BrowsingDataRemover::RemoveImpl(
     content::RecordAction(
         UserMetricsAction("ClearBrowsingData_ContentLicenses"));
 
-#if defined(ENABLE_PLUGINS)
+#if BUILDFLAG(ENABLE_PLUGINS)
     waiting_for_clear_flash_content_licenses_ = true;
     if (!pepper_flash_settings_manager_.get()) {
       pepper_flash_settings_manager_.reset(
@@ -1130,7 +1135,7 @@ void BrowsingDataRemover::RemoveImpl(
       waiting_for_clear_platform_keys_ = true;
     }
 #endif  // defined(OS_CHROMEOS)
-#endif  // defined(ENABLE_PLUGINS)
+#endif  // BUILDFLAG(ENABLE_PLUGINS)
   }
 
   // Remove omnibox zero-suggest cache results. Filtering is not supported.
@@ -1160,15 +1165,9 @@ void BrowsingDataRemover::RemoveImpl(
   }
 
 #if BUILDFLAG(ANDROID_JAVA_UI)
-  if (remove_mask & REMOVE_WEBAPP_DATA) {
-    // Clear all data associated with registered webapps. The webapp_registry
-    // makes a JNI call into a Java-side AsyncTask, so don't wait for the reply.
-    waiting_for_clear_webapp_data_ = true;
-    webapp_registry_->UnregisterWebappsForUrls(
-        filter,
-        base::Bind(&BrowsingDataRemover::OnClearedWebappData,
-                   weak_ptr_factory_.GetWeakPtr()));
-  }
+  // Clear all data associated with registered webapps.
+  if (remove_mask & REMOVE_WEBAPP_DATA)
+    webapp_registry_->UnregisterWebappsForUrls(filter);
 
   // For now we're considering offline pages as cache, so if we're removing
   // cache we should remove offline pages as well.
@@ -1220,7 +1219,7 @@ void BrowsingDataRemover::OverrideWebappRegistryForTesting(
 }
 #endif
 
-#if defined(ENABLE_PLUGINS)
+#if BUILDFLAG(ENABLE_PLUGINS)
 void BrowsingDataRemover::OverrideFlashLSOHelperForTesting(
     scoped_refptr<BrowsingDataFlashLSOHelper> flash_lso_helper) {
   flash_lso_helper_ = flash_lso_helper;
@@ -1276,11 +1275,9 @@ bool BrowsingDataRemover::AllDone() {
          !waiting_for_clear_pnacl_cache_ &&
 #if BUILDFLAG(ANDROID_JAVA_UI)
          !waiting_for_clear_precache_history_ &&
-         !waiting_for_clear_webapp_data_ &&
-         !waiting_for_clear_webapp_history_ &&
          !waiting_for_clear_offline_page_data_ &&
 #endif
-#if defined(ENABLE_WEBRTC)
+#if BUILDFLAG(ENABLE_WEBRTC)
          !waiting_for_clear_webrtc_logs_ &&
 #endif
          !waiting_for_clear_storage_partition_data_ &&
@@ -1405,7 +1402,7 @@ void BrowsingDataRemover::ClearedPnaclCache() {
 }
 #endif
 
-#if defined(ENABLE_PLUGINS)
+#if BUILDFLAG(ENABLE_PLUGINS)
 void BrowsingDataRemover::OnWaitableEventSignaled(
     base::WaitableEvent* waitable_event) {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
@@ -1521,7 +1518,7 @@ void BrowsingDataRemover::OnClearedStoragePartitionData() {
   NotifyIfDone();
 }
 
-#if defined(ENABLE_WEBRTC)
+#if BUILDFLAG(ENABLE_WEBRTC)
 void BrowsingDataRemover::OnClearedWebRtcLogs() {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
   waiting_for_clear_webrtc_logs_ = false;
@@ -1536,18 +1533,6 @@ void BrowsingDataRemover::OnClearedPrecacheHistory() {
   NotifyIfDone();
 }
 
-void BrowsingDataRemover::OnClearedWebappData() {
-  DCHECK_CURRENTLY_ON(BrowserThread::UI);
-  waiting_for_clear_webapp_data_ = false;
-  NotifyIfDone();
-}
-
-void BrowsingDataRemover::OnClearedWebappHistory() {
-  DCHECK_CURRENTLY_ON(BrowserThread::UI);
-  waiting_for_clear_webapp_history_ = false;
-  NotifyIfDone();
-}
-
 void BrowsingDataRemover::OnClearedOfflinePageData(
     offline_pages::OfflinePageModel::DeletePageResult result) {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
