@@ -26,8 +26,8 @@ namespace {
 const char kDatabaseUMAName[] = "BudgetManager";
 
 // The default amount of time during which a budget will be valid.
-// This is 10 days = 240 hours.
-constexpr double kBudgetDurationInHours = 240;
+// This is 4 days = 96 hours.
+constexpr double kBudgetDurationInHours = 96;
 
 }  // namespace
 
@@ -130,7 +130,7 @@ void BudgetDatabase::AddToCache(
 void BudgetDatabase::GetBudgetAfterSync(const url::Origin& origin,
                                         const GetBudgetCallback& callback,
                                         bool success) {
-  mojo::Array<blink::mojom::BudgetStatePtr> predictions;
+  std::vector<blink::mojom::BudgetStatePtr> predictions;
 
   // If the database wasn't able to read the information, return the
   // failure and an empty predictions array.
@@ -181,7 +181,7 @@ void BudgetDatabase::SpendBudgetAfterSync(const url::Origin& origin,
 
   // Get the current SES score, to generate UMA.
   SiteEngagementService* service = SiteEngagementService::Get(profile_);
-  double score = service->GetScore(GURL(origin.Serialize()));
+  double score = service->GetScore(origin.GetURL());
 
   // Walk the list of budget chunks to see if the origin has enough budget.
   double total = 0;
@@ -305,7 +305,7 @@ void BudgetDatabase::SyncLoadedCache(const url::Origin& origin,
 void BudgetDatabase::AddEngagementBudget(const url::Origin& origin) {
   // Get the current SES score, which we'll use to set a new budget.
   SiteEngagementService* service = SiteEngagementService::Get(profile_);
-  double score = service->GetScore(GURL(origin.Serialize()));
+  double score = service->GetScore(origin.GetURL());
 
   // By default we award the "full" award. Then that ratio is decreased if
   // there have been other awards recently.
