@@ -7,8 +7,6 @@
 #include <stddef.h>
 #include <stdint.h>
 
-#include <algorithm>
-#include <map>
 #include <set>
 #include <string>
 #include <utility>
@@ -32,17 +30,10 @@
 #include "base/run_loop.h"
 #include "base/strings/string16.h"
 #include "base/strings/string_number_conversions.h"
-#include "base/strings/string_piece.h"
-#include "base/strings/string_split.h"
 #include "base/strings/sys_string_conversions.h"
 #include "base/strings/utf_string_conversions.h"
 #include "base/sys_info.h"
-#include "base/task_scheduler/scheduler_worker_pool_params.h"
-#include "base/task_scheduler/switches.h"
-#include "base/task_scheduler/task_scheduler.h"
-#include "base/task_scheduler/task_traits.h"
 #include "base/threading/platform_thread.h"
-#include "base/threading/sequenced_worker_pool.h"
 #include "base/time/default_tick_clock.h"
 #include "base/time/time.h"
 #include "base/trace_event/trace_event.h"
@@ -80,9 +71,8 @@
 #include "chrome/browser/net/crl_set_fetcher.h"
 #include "chrome/browser/performance_monitor/performance_monitor.h"
 #include "chrome/browser/plugins/plugin_prefs.h"
-#include "chrome/browser/power/process_power_collector.h"
+#include "chrome/browser/prefs/chrome_command_line_pref_store.h"
 #include "chrome/browser/prefs/chrome_pref_service_factory.h"
-#include "chrome/browser/prefs/command_line_pref_store.h"
 #include "chrome/browser/prefs/incognito_mode_prefs.h"
 #include "chrome/browser/prefs/pref_metrics_service.h"
 #include "chrome/browser/printing/cloud_print/cloud_print_proxy_service.h"
@@ -120,7 +110,7 @@
 #include "chrome/common/net/net_resource_provider.h"
 #include "chrome/common/pref_names.h"
 #include "chrome/common/profiling.h"
-#include "chrome/common/variations/variations_util.h"
+#include "chrome/common/stack_sampling_configuration.h"
 #include "chrome/grit/generated_resources.h"
 #include "chrome/installer/util/google_update_settings.h"
 #include "components/component_updater/component_updater_service.h"
@@ -140,11 +130,12 @@
 #include "components/prefs/pref_service.h"
 #include "components/prefs/pref_value_store.h"
 #include "components/prefs/scoped_user_pref_update.h"
-#include "components/rappor/rappor_service.h"
+#include "components/rappor/rappor_service_impl.h"
 #include "components/signin/core/common/profile_management_switches.h"
 #include "components/startup_metric_utils/browser/startup_metric_utils.h"
 #include "components/tracing/common/tracing_switches.h"
 #include "components/translate/core/browser/translate_download_manager.h"
+#include "components/variations/field_trial_config/field_trial_util.h"
 #include "components/variations/pref_names.h"
 #include "components/variations/service/variations_service.h"
 #include "components/variations/variations_associated_data.h"
@@ -156,7 +147,6 @@
 #include "content/public/browser/notification_registrar.h"
 #include "content/public/browser/notification_service.h"
 #include "content/public/browser/notification_types.h"
-#include "content/public/browser/power_usage_monitor.h"
 #include "content/public/browser/site_instance.h"
 #include "content/public/common/content_client.h"
 #include "content/public/common/content_features.h"
@@ -164,12 +154,15 @@
 #include "content/public/common/main_function_params.h"
 #include "device/geolocation/geolocation_delegate.h"
 #include "device/geolocation/geolocation_provider.h"
+#include "extensions/features/features.h"
 #include "media/base/media_resources.h"
+#include "media/media_features.h"
 #include "net/base/net_module.h"
 #include "net/cookies/cookie_monster.h"
 #include "net/http/http_network_layer.h"
 #include "net/http/http_stream_factory.h"
 #include "net/url_request/url_request.h"
+#include "printing/features/features.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/base/layout.h"
 #include "ui/base/material_design/material_design_controller.h"
@@ -180,7 +173,9 @@
 #include "chrome/browser/metrics/thread_watcher_android.h"
 #include "ui/base/resource/resource_bundle_android.h"
 #else
+#include "chrome/browser/features.h"
 #include "chrome/browser/feedback/feedback_profile_observer.h"
+#include "chrome/browser/lifetime/application_lifetime.h"
 #endif  // defined(OS_ANDROID)
 
 #if defined(OS_LINUX) && !defined(OS_CHROMEOS)
@@ -240,25 +235,25 @@
 #include "chrome/browser/background/background_mode_manager.h"
 #endif  // BUILDFLAG(ENABLE_BACKGROUND)
 
-#if defined(ENABLE_EXTENSIONS)
+#if BUILDFLAG(ENABLE_EXTENSIONS)
 #include "chrome/browser/extensions/startup_helper.h"
 #include "extensions/browser/extension_protocols.h"
 #include "extensions/common/features/feature_provider.h"
 #include "extensions/components/javascript_dialog_extensions_client/javascript_dialog_extension_client_impl.h"
-#endif  // defined(ENABLE_EXTENSIONS)
+#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
 
-#if defined(ENABLE_PRINT_PREVIEW) && !defined(OFFICIAL_BUILD)
+#if BUILDFLAG(ENABLE_PRINT_PREVIEW) && !defined(OFFICIAL_BUILD)
 #include "printing/printed_document.h"
-#endif  // defined(ENABLE_PRINT_PREVIEW) && !defined(OFFICIAL_BUILD)
+#endif  // BUILDFLAG(ENABLE_PRINT_PREVIEW) && !defined(OFFICIAL_BUILD)
 
 #if defined(ENABLE_RLZ)
 #include "chrome/browser/rlz/chrome_rlz_tracker_delegate.h"
 #include "components/rlz/rlz_tracker.h"
 #endif  // defined(ENABLE_RLZ)
 
-#if defined(ENABLE_WEBRTC)
+#if BUILDFLAG(ENABLE_WEBRTC)
 #include "chrome/browser/media/webrtc/webrtc_log_util.h"
-#endif  // defined(ENABLE_WEBRTC)
+#endif  // BUILDFLAG(ENABLE_WEBRTC)
 
 #if defined(USE_AURA)
 #include "ui/aura/env.h"
@@ -271,7 +266,7 @@
 #if defined(USE_AURA)
 #include "chrome/browser/lifetime/application_lifetime.h"
 #include "content/public/common/service_manager_connection.h"
-#include "services/shell/runner/common/client_util.h"
+#include "services/service_manager/runner/common/client_util.h"
 #endif
 
 #if defined(OS_WIN) || defined(OS_MACOSX) || \
@@ -317,144 +312,6 @@ void AddFirstRunNewTabs(StartupBrowserCreator* browser_creator,
 }
 #endif  // !defined(OS_ANDROID) && !defined(OS_CHROMEOS)
 
-enum WorkerPoolType : size_t {
-  BACKGROUND_WORKER_POOL = 0,
-  BACKGROUND_FILE_IO_WORKER_POOL,
-  FOREGROUND_WORKER_POOL,
-  FOREGROUND_FILE_IO_WORKER_POOL,
-  WORKER_POOL_COUNT  // Always last.
-};
-
-struct WorkerPoolVariationValues {
-  int threads = 0;
-  base::TimeDelta detach_period;
-};
-
-// Converts |pool_descriptor| to a WorkerPoolVariationValues. Returns a default
-// WorkerPoolVariationValues on failure.
-//
-// |pool_descriptor| is a semi-colon separated value string with the following
-// items:
-// 1. Minimum Thread Count (int)
-// 2. Maximum Thread Count (int)
-// 3. Thread Count Multiplier (double)
-// 4. Thread Count Offset (int)
-// 5. Detach Time in Milliseconds (milliseconds)
-// Additional values may appear as necessary and will be ignored.
-WorkerPoolVariationValues StringToWorkerPoolVariationValues(
-    const base::StringPiece pool_descriptor) {
-  const std::vector<std::string> tokens =
-      SplitString(pool_descriptor, ";",
-                  base::KEEP_WHITESPACE, base::SPLIT_WANT_NONEMPTY);
-  int minimum;
-  int maximum;
-  double multiplier;
-  int offset;
-  int detach_milliseconds;
-  // Checking for a size greater than the expected amount allows us to be
-  // forward compatible if we add more variation values.
-  if (tokens.size() >= 5 &&
-      base::StringToInt(tokens[0], &minimum) &&
-      base::StringToInt(tokens[1], &maximum) &&
-      base::StringToDouble(tokens[2], &multiplier) &&
-      base::StringToInt(tokens[3], &offset) &&
-      base::StringToInt(tokens[4], &detach_milliseconds)) {
-    const int num_of_cores = base::SysInfo::NumberOfProcessors();
-    const int threads = std::ceil<int>(num_of_cores * multiplier) + offset;
-    WorkerPoolVariationValues values;
-    values.threads = std::min(maximum, std::max(minimum, threads));
-    values.detach_period =
-        base::TimeDelta::FromMilliseconds(detach_milliseconds);
-    return values;
-  }
-  DLOG(ERROR) << "Invalid Worker Pool Descriptor: " << pool_descriptor;
-  return WorkerPoolVariationValues();
-}
-
-// Returns the worker pool index for |traits| defaulting to
-// FOREGROUND_WORKER_POOL or FOREGROUND_FILE_IO_WORKER_POOL on unknown
-// priorities.
-size_t WorkerPoolIndexForTraits(const base::TaskTraits& traits) {
-  const bool is_background =
-      traits.priority() == base::TaskPriority::BACKGROUND;
-  if (traits.with_file_io()) {
-    return is_background ? BACKGROUND_FILE_IO_WORKER_POOL
-                         : FOREGROUND_FILE_IO_WORKER_POOL;
-  }
-  return is_background ? BACKGROUND_WORKER_POOL : FOREGROUND_WORKER_POOL;
-}
-
-// Initializes the Default Browser Task Scheduler if there is a valid variation
-// parameter for the field trial.
-void MaybeInitializeTaskScheduler() {
-  static constexpr char kFieldTrialName[] = "BrowserScheduler";
-  std::map<std::string, std::string> variation_params;
-  if (!variations::GetVariationParams(kFieldTrialName, &variation_params)) {
-    DCHECK(!base::CommandLine::ForCurrentProcess()->HasSwitch(
-        switches::kEnableBrowserTaskScheduler))
-        << "The Browser Task Scheduler remains disabled with "
-        << switches::kEnableBrowserTaskScheduler
-        << " because there is no available variation param for this build or "
-           " the task scheduler is disabled in chrome://flags.";
-    return;
-  }
-
-  using ThreadPriority = base::ThreadPriority;
-  using IORestriction = base::SchedulerWorkerPoolParams::IORestriction;
-  struct SchedulerWorkerPoolPredefinedParams {
-    const char* name;
-    ThreadPriority priority_hint;
-    IORestriction io_restriction;
-  };
-  static const SchedulerWorkerPoolPredefinedParams kAllPredefinedParams[] = {
-    {"Background", ThreadPriority::BACKGROUND, IORestriction::DISALLOWED},
-    {"BackgroundFileIO", ThreadPriority::BACKGROUND, IORestriction::ALLOWED},
-    {"Foreground", ThreadPriority::NORMAL, IORestriction::DISALLOWED},
-    {"ForegroundFileIO", ThreadPriority::NORMAL, IORestriction::ALLOWED},
-  };
-  static_assert(arraysize(kAllPredefinedParams) == WORKER_POOL_COUNT,
-                "Mismatched Worker Pool Types and Predefined Parameters");
-
-  std::vector<base::SchedulerWorkerPoolParams> params_vector;
-  for (const auto& predefined_params : kAllPredefinedParams) {
-    const auto pair = variation_params.find(predefined_params.name);
-    if (pair == variation_params.end()) {
-      DLOG(ERROR) << "Missing Worker Pool Configuration: "
-                  << predefined_params.name;
-      return;
-    }
-
-    const WorkerPoolVariationValues variation_values =
-        StringToWorkerPoolVariationValues(pair->second);
-
-    if (variation_values.threads <= 0 ||
-        variation_values.detach_period.is_zero()) {
-      DLOG(ERROR) << "Invalid Worker Pool Configuration: " <<
-          predefined_params.name << " [" << pair->second << "]";
-      return;
-    }
-
-    params_vector.emplace_back(predefined_params.name,
-                               predefined_params.priority_hint,
-                               predefined_params.io_restriction,
-                               variation_values.threads,
-                               variation_values.detach_period);
-  }
-
-  DCHECK_EQ(WORKER_POOL_COUNT, params_vector.size());
-
-  base::TaskScheduler::CreateAndSetDefaultTaskScheduler(
-      params_vector, base::Bind(WorkerPoolIndexForTraits));
-
-  // TODO(gab): Remove this when http://crbug.com/622400 concludes.
-  const auto sequenced_worker_pool_param =
-      variation_params.find("RedirectSequencedWorkerPools");
-  if (sequenced_worker_pool_param != variation_params.end() &&
-      sequenced_worker_pool_param->second == "true") {
-    base::SequencedWorkerPool::RedirectToTaskSchedulerForProcess();
-  }
-}
-
 // Returns the new local state object, guaranteed non-NULL.
 // |local_state_task_runner| must be a shutdown-blocking task runner.
 PrefService* InitializeLocalState(
@@ -582,9 +439,9 @@ Profile* CreatePrimaryProfile(const content::MainFunctionParams& parameters,
     profile = GetFallbackStartupProfile();
 
   if (!profile) {
-    ProfileErrorType error_type = profile_dir_specified ?
-                                  PROFILE_ERROR_CREATE_FAILURE_SPECIFIED :
-                                  PROFILE_ERROR_CREATE_FAILURE_ALL;
+    ProfileErrorType error_type =
+        profile_dir_specified ? ProfileErrorType::CREATE_FAILURE_SPECIFIED
+                              : ProfileErrorType::CREATE_FAILURE_ALL;
 
     // TODO(lwchkg): What diagnostics do you want to include in the feedback
     // report when an error occurs?
@@ -613,12 +470,16 @@ void RegisterComponentsForUpdate() {
   // Registration can be before or after cus->Start() so it is ok to post
   // a task to the UI thread to do registration once you done the necessary
   // file IO to know you existing component version.
-#if !defined(OS_CHROMEOS) && !defined(OS_ANDROID)
+#if !defined(OS_ANDROID)
+#if !defined(OS_CHROMEOS)
   RegisterRecoveryComponent(cus, g_browser_process->local_state());
+#endif  // !defined(OS_CHROMEOS)
   RegisterPepperFlashComponent(cus);
+#if !defined(OS_CHROMEOS)
   RegisterSwiftShaderComponent(cus);
   RegisterWidevineCdmComponent(cus);
-#endif  // !defined(OS_CHROMEOS) && !defined(OS_ANDROID)
+#endif  // !defined(OS_CHROMEOS)
+#endif  // !defined(OS_ANDROID)
 
 #if !defined(DISABLE_NACL) && !defined(OS_ANDROID)
 #if defined(OS_CHROMEOS)
@@ -761,10 +622,10 @@ ChromeBrowserMainParts::ChromeBrowserMainParts(
       result_code_(content::RESULT_CODE_NORMAL_EXIT),
       startup_watcher_(new StartupTimeBomb()),
       shutdown_watcher_(new ShutdownWatcherHelper()),
-      browser_field_trials_(parameters.command_line),
       sampling_profiler_(
           base::PlatformThread::CurrentId(),
-          sampling_profiler_config_.GetSamplingParams(),
+          StackSamplingConfiguration::Get()->
+              GetSamplingParamsForCurrentProcess(),
           metrics::CallStackProfileMetricsProvider::GetProfilerCallback(
               metrics::CallStackProfileParams(
                   metrics::CallStackProfileParams::BROWSER_PROCESS,
@@ -774,7 +635,7 @@ ChromeBrowserMainParts::ChromeBrowserMainParts(
       profile_(NULL),
       run_message_loop_(true),
       local_state_(NULL) {
-  if (sampling_profiler_config_.IsProfilerEnabled())
+  if (StackSamplingConfiguration::Get()->IsProfilerEnabledForCurrentProcess())
     sampling_profiler_.Start();
 
   // If we're running tests (ui_task is non-null).
@@ -811,10 +672,12 @@ void ChromeBrowserMainParts::SetupFieldTrials() {
     base::FieldTrial::EnableBenchmarking();
   }
 
-  if (command_line->HasSwitch(switches::kForceFieldTrialParams)) {
-    bool result = chrome_variations::AssociateParamsFromString(
-        command_line->GetSwitchValueASCII(switches::kForceFieldTrialParams));
-    CHECK(result) << "Invalid --" << switches::kForceFieldTrialParams
+  if (command_line->HasSwitch(variations::switches::kForceFieldTrialParams)) {
+    bool result = variations::AssociateParamsFromString(
+        command_line->GetSwitchValueASCII(
+            variations::switches::kForceFieldTrialParams));
+    CHECK(result) << "Invalid --"
+                  << variations::switches::kForceFieldTrialParams
                   << " list specified.";
   }
 
@@ -858,10 +721,11 @@ void ChromeBrowserMainParts::SetupFieldTrials() {
       command_line->GetSwitchValueASCII(switches::kDisableFeatures));
 
 #if defined(FIELDTRIAL_TESTING_ENABLED)
-  if (!command_line->HasSwitch(switches::kDisableFieldTrialTestingConfig) &&
+  if (!command_line->HasSwitch(
+          variations::switches::kDisableFieldTrialTestingConfig) &&
       !command_line->HasSwitch(switches::kForceFieldTrials) &&
       !command_line->HasSwitch(variations::switches::kVariationsServerURL)) {
-    chrome_variations::AssociateDefaultFieldTrialConfig(feature_list.get());
+    variations::AssociateDefaultFieldTrialConfig(feature_list.get());
   }
 #endif  // defined(FIELDTRIAL_TESTING_ENABLED)
 
@@ -942,8 +806,8 @@ void ChromeBrowserMainParts::StartMetricsRecording() {
   // Register a synthetic field trial for the sampling profiler configuration
   // that was already chosen.
   std::string trial_name, group_name;
-  if (sampling_profiler_config_.GetSyntheticFieldTrial(&trial_name,
-                                                       &group_name)) {
+  if (StackSamplingConfiguration::Get()->GetSyntheticFieldTrial(&trial_name,
+                                                                &group_name)) {
     ChromeMetricsServiceAccessor::RegisterSyntheticFieldTrial(trial_name,
                                                               group_name);
   }
@@ -1063,6 +927,11 @@ void ChromeBrowserMainParts::PostMainMessageLoopStart() {
 }
 
 int ChromeBrowserMainParts::PreCreateThreads() {
+  // IMPORTANT
+  // Calls in this function should not post tasks or create threads as
+  // components used to handle those tasks are not yet available. This work
+  // should be deferred to PreMainMessageLoopRunImpl.
+
   TRACE_EVENT0("startup", "ChromeBrowserMainParts::PreCreateThreads");
   result_code_ = PreCreateThreadsImpl();
 
@@ -1188,7 +1057,7 @@ int ChromeBrowserMainParts::PreCreateThreadsImpl() {
 #endif  // OS_WIN
 
   local_state_->UpdateCommandLinePrefStore(
-      new CommandLinePrefStore(base::CommandLine::ForCurrentProcess()));
+      new ChromeCommandLinePrefStore(base::CommandLine::ForCurrentProcess()));
 
   // Reset the command line in the crash report details, since we may have
   // just changed it to include experiments.
@@ -1333,30 +1202,13 @@ int ChromeBrowserMainParts::PreCreateThreadsImpl() {
   device::GeolocationProvider::SetGeolocationDelegate(
       new ChromeGeolocationDelegate());
 
-  // IMPORTANT
-  // Do not add anything below this line until you've verified your new code
-  // does not interfere with the critical initialization order below. Some of
-  // the calls below end up implicitly creating threads and as such new calls
-  // typically either belong before them or in a later startup phase.
-
   // Now that the command line has been mutated based on about:flags, we can
-  // initialize field trials and setup metrics. The field trials are needed by
-  // IOThread's initialization which happens in BrowserProcess:PreCreateThreads.
+  // initialize field trials. The field trials are needed by IOThread's
+  // initialization which happens in BrowserProcess:PreCreateThreads. Metrics
+  // initialization is handled in PreMainMessageLoopRunImpl since it posts
+  // tasks.
   SetupFieldTrials();
 
-  // Task Scheduler initialization needs to be here for the following reasons:
-  //   * After |SetupFieldTrials()|: Initialization uses variations.
-  //   * Before |SetupMetrics()|: |SetupMetrics()| uses the blocking pool. The
-  //         Task Scheduler must do any necessary redirection before then.
-  //   * Near the end of |PreCreateThreads()|: The TaskScheduler needs to be
-  //         created before any other threads are (by contract) but it creates
-  //         threads itself so instantiating it earlier is also incorrect.
-  // To maintain scoping symmetry, if this line is moved, the corresponding
-  // shutdown call may also need to be moved.
-  MaybeInitializeTaskScheduler();
-
-  SetupMetrics();
-
   // ChromeOS needs ResourceBundle::InitSharedInstance to be called before this.
   // This also instantiates the IOThread which requests the metrics service and
   // must be after |SetupMetrics()|.
@@ -1374,7 +1226,7 @@ void ChromeBrowserMainParts::ServiceManagerConnectionStarted(
 void ChromeBrowserMainParts::PreMainMessageLoopRun() {
 #if defined(USE_AURA)
   if (content::ServiceManagerConnection::GetForProcess() &&
-      shell::ShellIsRemote()) {
+      service_manager::ServiceManagerIsRemote()) {
     content::ServiceManagerConnection::GetForProcess()->
         SetConnectionLostClosure(base::Bind(&chrome::SessionEnding));
   }
@@ -1413,9 +1265,9 @@ void ChromeBrowserMainParts::PreProfileInit() {
   g_browser_process->profile_manager()->CleanUpEphemeralProfiles();
 #endif  // !defined(OS_ANDROID)
 
-#if defined(ENABLE_EXTENSIONS)
+#if BUILDFLAG(ENABLE_EXTENSIONS)
   javascript_dialog_extensions_client::InstallClient();
-#endif  // defined(ENABLE_EXTENSIONS)
+#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
 
   InstallChromeJavaScriptNativeDialogFactory();
 }
@@ -1518,7 +1370,7 @@ void ChromeBrowserMainParts::PostBrowserStart() {
   // Allow ProcessSingleton to process messages.
   process_singleton_->Unlock();
 #endif  // !defined(OS_ANDROID)
-#if defined(ENABLE_WEBRTC)
+#if BUILDFLAG(ENABLE_WEBRTC)
   // Set up a task to delete old WebRTC log files for all profiles. Use a delay
   // to reduce the impact on startup time.
   BrowserThread::PostDelayedTask(
@@ -1526,7 +1378,7 @@ void ChromeBrowserMainParts::PostBrowserStart() {
       FROM_HERE,
       base::Bind(&WebRtcLogUtil::DeleteOldWebRtcLogFilesForAllProfiles),
       base::TimeDelta::FromMinutes(1));
-#endif  // defined(ENABLE_WEBRTC)
+#endif  // BUILDFLAG(ENABLE_WEBRTC)
 
 #if !defined(OS_ANDROID)
   if (base::FeatureList::IsEnabled(features::kWebUsb)) {
@@ -1552,13 +1404,17 @@ int ChromeBrowserMainParts::PreMainMessageLoopRunImpl() {
   SCOPED_UMA_HISTOGRAM_LONG_TIMER("Startup.PreMainMessageLoopRunImplLongTime");
   const base::TimeTicks start_time_step1 = base::TimeTicks::Now();
 
+  // This must occur at PreMainMessageLoopRun because |SetupMetrics()| uses the
+  // blocking pool, which is disabled until the CreateThreads phase of startup.
+  SetupMetrics();
+
 #if defined(OS_WIN)
   // Windows parental controls calls can be slow, so we do an early init here
   // that calculates this value off of the UI thread.
   IncognitoModePrefs::InitializePlatformParentalControls();
 #endif
 
-#if defined(ENABLE_EXTENSIONS)
+#if BUILDFLAG(ENABLE_EXTENSIONS)
   if (!variations::GetVariationParamValue(
       "LightSpeed", "EarlyInitStartup").empty()) {
     // Try to compute this early on another thread so that we don't spend time
@@ -1647,6 +1503,9 @@ int ChromeBrowserMainParts::PreMainMessageLoopRunImpl() {
   // 20 seconds to respond. Note that this needs to be done before we attempt
   // to read the profile.
   notify_result_ = process_singleton_->NotifyOtherProcessOrCreate();
+  UMA_HISTOGRAM_ENUMERATION("Chrome.ProcessSingleton.NotifyResult",
+                            notify_result_,
+                            ProcessSingleton::kNumNotifyResults);
   switch (notify_result_) {
     case ProcessSingleton::PROCESS_NONE:
       // No process already running, fall through to starting a new one.
@@ -1679,9 +1538,6 @@ int ChromeBrowserMainParts::PreMainMessageLoopRunImpl() {
                     "opening a new window in the existing process. Aborting "
                     "now to avoid profile corruption.";
       return chrome::RESULT_CODE_PROFILE_IN_USE;
-
-    default:
-      NOTREACHED();
   }
 #endif  // !defined(OS_ANDROID)
 
@@ -1889,13 +1745,13 @@ int ChromeBrowserMainParts::PreMainMessageLoopRunImpl() {
   // needs to read prefs that get set after that runs.
   browser_process_->intranet_redirect_detector();
 
-#if defined(ENABLE_PRINT_PREVIEW) && !defined(OFFICIAL_BUILD)
+#if BUILDFLAG(ENABLE_PRINT_PREVIEW) && !defined(OFFICIAL_BUILD)
   if (parsed_command_line().HasSwitch(switches::kDebugPrint)) {
     base::FilePath path =
         parsed_command_line().GetSwitchValuePath(switches::kDebugPrint);
     printing::PrintedDocument::set_debug_dump_path(path);
   }
-#endif  // defined(ENABLE_PRINT_PREVIEW) && !defined(OFFICIAL_BUILD)
+#endif  // BUILDFLAG(ENABLE_PRINT_PREVIEW) && !defined(OFFICIAL_BUILD)
 
   HandleTestParameters(parsed_command_line());
   browser_process_->metrics_service()->RecordBreakpadHasDebugger(
@@ -1922,7 +1778,7 @@ int ChromeBrowserMainParts::PreMainMessageLoopRunImpl() {
   browser_process_->metrics_service()->LogNeedForCleanShutdown();
 #endif  // !defined(OS_ANDROID)
 
-#if defined(ENABLE_PRINT_PREVIEW)
+#if BUILDFLAG(ENABLE_PRINT_PREVIEW)
   // Create the instance of the cloud print proxy service so that it can launch
   // the service process if needed. This is needed because the service process
   // might have shutdown because an update was available.
@@ -1930,7 +1786,7 @@ int ChromeBrowserMainParts::PreMainMessageLoopRunImpl() {
   // BrowserContextKeyedServiceFactory::ServiceIsCreatedWithBrowserContext()
   // instead?
   CloudPrintProxyServiceFactory::GetForProfile(profile_);
-#endif  // defined(ENABLE_PRINT_PREVIEW)
+#endif  // BUILDFLAG(ENABLE_PRINT_PREVIEW)
 
   // Start watching all browser threads for responsiveness.
   metrics::MetricsService::SetExecutionPhase(
@@ -2046,12 +1902,13 @@ int ChromeBrowserMainParts::PreMainMessageLoopRunImpl() {
   run_message_loop_ = started;
   browser_creator_.reset();
 
-#if !defined(OS_LINUX) || defined(OS_CHROMEOS)  // http://crbug.com/426393
-  content::StartPowerUsageMonitor();
+#if !defined(OS_LINUX) || defined(OS_CHROMEOS)
+  // Collects power-related UMA stats for Windows, Mac, and ChromeOS.
+  // Linux is not supported (crbug.com/426393).
+  power_usage_monitor_.reset(new PowerUsageMonitor());
+  power_usage_monitor_->Start();
 #endif  // !defined(OS_LINUX) || defined(OS_CHROMEOS)
 
-  process_power_collector_.reset(new ProcessPowerCollector);
-  process_power_collector_->Initialize();
 #endif  // !defined(OS_ANDROID)
 
   PostBrowserStart();
@@ -2115,6 +1972,12 @@ bool ChromeBrowserMainParts::MainMessageLoopRun(int* result_code) {
       g_browser_process->local_state());
   run_loop.Run();
 
+  if (base::FeatureList::IsEnabled(features::kDesktopFastShutdown)) {
+    // Experiment to determine the impact of always taking the quick exit path.
+    // There is no returning from this call as it terminates the process.
+    chrome::SessionEnding();
+  }
+
   return true;
 #endif  // defined(OS_ANDROID)
 }
@@ -2136,10 +1999,6 @@ void ChromeBrowserMainParts::PostMainMessageLoopRun() {
   // Disarm the startup hang detector time bomb if it is still Arm'ed.
   startup_watcher_->Disarm();
 
-  // Remove observers attached to D-Bus clients before DbusThreadManager is
-  // shut down.
-  process_power_collector_.reset();
-
   web_usb_detector_.reset();
 
   for (size_t i = 0; i < chrome_extra_parts_.size(); ++i)
@@ -2203,13 +2062,6 @@ void ChromeBrowserMainParts::PostDestroyThreads() {
   // release it.
   ignore_result(browser_process_.release());
 
-  // The TaskScheduler was initialized before invoking
-  // |browser_process_->PreCreateThreads()|. To maintain scoping symmetry,
-  // perform the shutdown after |browser_process_->PostDestroyThreads()|.
-  base::TaskScheduler* task_scheduler = base::TaskScheduler::GetInstance();
-  if (task_scheduler)
-    task_scheduler->Shutdown();
-
   browser_shutdown::ShutdownPostThreadsStop(restart_flags);
   master_prefs_.reset();
   process_singleton_.reset();
