@@ -6,6 +6,7 @@
 #define CHROME_BROWSER_CHROME_BROWSER_MAIN_H_
 
 #include <memory>
+#include <vector>
 
 #include "base/macros.h"
 #include "base/metrics/field_trial.h"
@@ -15,6 +16,7 @@
 #include "chrome/browser/chrome_browser_field_trials.h"
 #include "chrome/browser/chrome_process_singleton.h"
 #include "chrome/browser/first_run/first_run.h"
+#include "chrome/browser/power_usage_monitor/power_usage_monitor.h"
 #include "chrome/browser/process_singleton.h"
 #include "chrome/browser/ui/startup/startup_browser_creator.h"
 #include "chrome/common/stack_sampling_configuration.h"
@@ -24,9 +26,7 @@
 class BrowserProcessImpl;
 class ChromeBrowserMainExtraParts;
 class FieldTrialSynchronizer;
-class MetricsService;
 class PrefService;
-class ProcessPowerCollector;
 class Profile;
 class StartupBrowserCreator;
 class StartupTimeBomb;
@@ -146,9 +146,6 @@ class ChromeBrowserMainParts : public content::BrowserMainParts {
   ChromeBrowserFieldTrials browser_field_trials_;
 
 #if !defined(OS_ANDROID) && !defined(OS_IOS)
-  // A monitor for attributing power consumption to origins.
-  std::unique_ptr<ProcessPowerCollector> process_power_collector_;
-
   std::unique_ptr<WebUsbDetector> web_usb_detector_;
 #endif
 
@@ -156,9 +153,6 @@ class ChromeBrowserMainParts : public content::BrowserMainParts {
   // Parts are deleted in the inverse order they are added.
   std::vector<ChromeBrowserMainExtraParts*> chrome_extra_parts_;
 
-  // The configuration to use for the stack sampling profiler below.
-  StackSamplingConfiguration sampling_profiler_config_;
-
   // A profiler that periodically samples stack traces. Used to sample startup
   // behavior.
   base::StackSamplingProfiler sampling_profiler_;
@@ -176,6 +170,10 @@ class ChromeBrowserMainParts : public content::BrowserMainParts {
   // ProcessSingleton.
   std::unique_ptr<ChromeProcessSingleton> process_singleton_;
 
+#if !defined(OS_LINUX) || defined(OS_CHROMEOS)  // http://crbug.com/426393
+  std::unique_ptr<PowerUsageMonitor> power_usage_monitor_;
+#endif  // !defined(OS_LINUX) || defined(OS_CHROMEOS)
+
   // Android's first run is done in Java instead of native.
   std::unique_ptr<first_run::MasterPrefs> master_prefs_;
 
