@@ -6,6 +6,7 @@
 #define CHROME_BROWSER_CHROME_BROWSER_MAIN_ANDROID_H_
 
 #include "base/macros.h"
+#include "chrome/browser/android/chrome_backup_watcher.h"
 #include "chrome/browser/chrome_browser_main.h"
 
 namespace breakpad {
@@ -30,6 +31,7 @@ class ChromeBrowserMainPartsAndroid : public ChromeBrowserMainParts {
  private:
   std::unique_ptr<base::MessageLoop> main_message_loop_;
   std::unique_ptr<breakpad::CrashDumpManager> crash_dump_manager_;
+  std::unique_ptr<chrome::android::ChromeBackupWatcher> backup_watcher_;
 
   DISALLOW_COPY_AND_ASSIGN(ChromeBrowserMainPartsAndroid);
 };
