@@ -43,6 +43,7 @@
 #include "chrome/common/chrome_result_codes.h"
 #include "chrome/common/chrome_switches.h"
 #include "chrome/common/chrome_utility_messages.h"
+#include "chrome/common/crash_keys.h"
 #include "chrome/common/env_vars.h"
 #include "chrome/grit/chromium_strings.h"
 #include "chrome/grit/generated_resources.h"
@@ -289,6 +290,11 @@ void ChromeBrowserMainPartsWin::PreMainMessageLoopStart() {
 }
 
 int ChromeBrowserMainPartsWin::PreCreateThreads() {
+// Record whether the machine is domain joined in a crash key. This will be used
+// to better identify whether crashes are from enterprise users.
+  base::debug::SetCrashKeyValue(crash_keys::kEnrolledToDomain,
+                                base::win::IsEnrolledToDomain() ? "yes" : "no");
+
   int rv = ChromeBrowserMainParts::PreCreateThreads();
 
   // TODO(viettrungluu): why don't we run this earlier?
