@@ -25,6 +25,15 @@ data_use_measurement::ChromeDataUseAscriber* InitOnIOThread(
   return io_thread->globals()->data_use_ascriber.get();
 }
 
+// Returns the top most parent of |render_frame_host|.
+content::RenderFrameHost* GetMainFrame(
+    content::RenderFrameHost* render_frame_host) {
+  content::RenderFrameHost* render_main_frame_host = render_frame_host;
+  while (render_main_frame_host->GetParent())
+    render_main_frame_host = render_main_frame_host->GetParent();
+  return render_main_frame_host;
+}
+
 }  // namespace
 
 namespace data_use_measurement {
@@ -64,20 +73,21 @@ void ChromeDataUseAscriberService::RenderFrameCreated(
   if (!ascriber_)
     return;
 
-  int parent_render_process_id = -1;
-  int parent_render_frame_id = -1;
-  if (render_frame_host->GetParent()) {
-    parent_render_process_id =
-        render_frame_host->GetParent()->GetProcess()->GetID();
-    parent_render_frame_id = render_frame_host->GetParent()->GetRoutingID();
+  int main_render_process_id = -1;
+  int main_render_frame_id = -1;
+  content::RenderFrameHost* main_frame = GetMainFrame(render_frame_host);
+  if (main_frame != render_frame_host) {
+    main_render_process_id = main_frame->GetProcess()->GetID();
+    main_render_frame_id = main_frame->GetRoutingID();
   }
+
   content::BrowserThread::PostTask(
       content::BrowserThread::IO, FROM_HERE,
       base::Bind(&ChromeDataUseAscriber::RenderFrameCreated,
                  base::Unretained(ascriber_),
                  render_frame_host->GetProcess()->GetID(),
-                 render_frame_host->GetRoutingID(), parent_render_process_id,
-                 parent_render_frame_id));
+                 render_frame_host->GetRoutingID(), main_render_process_id,
+                 main_render_frame_id));
 }
 
 void ChromeDataUseAscriberService::RenderFrameDeleted(
@@ -95,38 +105,31 @@ void ChromeDataUseAscriberService::RenderFrameDeleted(
   if (!ascriber_)
     return;
 
-  int parent_render_frame_id = -1;
-  int parent_render_process_id = -1;
-
-  if (render_frame_host->GetParent()) {
-    parent_render_process_id =
-        render_frame_host->GetParent()->GetProcess()->GetID();
-    parent_render_frame_id = render_frame_host->GetParent()->GetRoutingID();
+  int main_render_process_id = -1;
+  int main_render_frame_id = -1;
+  content::RenderFrameHost* main_frame = GetMainFrame(render_frame_host);
+  if (main_frame != render_frame_host) {
+    main_render_process_id = main_frame->GetProcess()->GetID();
+    main_render_frame_id = main_frame->GetRoutingID();
   }
+
   content::BrowserThread::PostTask(
       content::BrowserThread::IO, FROM_HERE,
       base::Bind(&ChromeDataUseAscriber::RenderFrameDeleted,
                  base::Unretained(ascriber_),
                  render_frame_host->GetProcess()->GetID(),
-                 render_frame_host->GetRoutingID(), parent_render_process_id,
-                 parent_render_frame_id));
+                 render_frame_host->GetRoutingID(), main_render_process_id,
+                 main_render_frame_id));
 }
 
 void ChromeDataUseAscriberService::DidStartNavigation(
     content::NavigationHandle* navigation_handle) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
-
   if (!navigation_handle->IsInMainFrame())
     return;
 
-  if (!is_initialized_) {
-    pending_navigations_queue_.push_back(navigation_handle);
-    return;
-  }
-
   if (!ascriber_)
     return;
-
   content::WebContents* web_contents = navigation_handle->GetWebContents();
   content::BrowserThread::PostTask(
       content::BrowserThread::IO, FROM_HERE,
@@ -137,21 +140,13 @@ void ChromeDataUseAscriberService::DidStartNavigation(
                  navigation_handle));
 }
 
-void ChromeDataUseAscriberService::DidFinishNavigation(
+void ChromeDataUseAscriberService::ReadyToCommitNavigation(
     content::NavigationHandle* navigation_handle) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
 
   if (!navigation_handle->IsInMainFrame())
     return;
 
-  if (!is_initialized_) {
-    // While remove() is a O(n) operation, the pending queue is not expected
-    // to have a significant number of elements.
-    DCHECK_GE(50u, pending_navigations_queue_.size());
-    pending_navigations_queue_.remove(navigation_handle);
-    return;
-  }
-
   if (!ascriber_)
     return;
 
@@ -159,34 +154,15 @@ void ChromeDataUseAscriberService::DidFinishNavigation(
   content::BrowserThread::PostTask(
       content::BrowserThread::IO, FROM_HERE,
       base::Bind(
-          &ChromeDataUseAscriber::DidFinishMainFrameNavigation,
+          &ChromeDataUseAscriber::ReadyToCommitMainFrameNavigation,
           base::Unretained(ascriber_), navigation_handle->GetURL(),
+          navigation_handle->GetGlobalRequestID(),
           web_contents->GetRenderProcessHost()->GetID(),
           web_contents->GetMainFrame()->GetRoutingID(),
           !navigation_handle->HasCommitted() || navigation_handle->IsSamePage(),
           navigation_handle));
 }
 
-void ChromeDataUseAscriberService::DidRedirectNavigation(
-    content::NavigationHandle* navigation_handle) {
-  DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
-
-  if (!is_initialized_ || !navigation_handle->IsInMainFrame())
-    return;
-
-  if (!ascriber_)
-    return;
-
-  content::WebContents* web_contents = navigation_handle->GetWebContents();
-  content::BrowserThread::PostTask(
-      content::BrowserThread::IO, FROM_HERE,
-      base::Bind(&ChromeDataUseAscriber::DidRedirectMainFrameNavigation,
-                 base::Unretained(ascriber_), navigation_handle->GetURL(),
-                 web_contents->GetRenderProcessHost()->GetID(),
-                 web_contents->GetMainFrame()->GetRoutingID(),
-                 navigation_handle));
-}
-
 void ChromeDataUseAscriberService::SetDataUseAscriber(
     ChromeDataUseAscriber* ascriber) {
   DCHECK(!is_initialized_);
@@ -199,11 +175,6 @@ void ChromeDataUseAscriberService::SetDataUseAscriber(
     RenderFrameCreated(it);
   }
   pending_frames_queue_.clear();
-
-  for (auto& it : pending_navigations_queue_) {
-    DidStartNavigation(it);
-  }
-  pending_navigations_queue_.clear();
 }
 
 }  // namespace data_use_measurement
