@@ -26,7 +26,6 @@
 #include "extensions/browser/extension_host.h"
 #include "extensions/browser/extension_registry.h"
 #include "extensions/browser/process_manager.h"
-#include "net/base/host_port_pair.h"
 #include "ui/base/resource/resource_bundle.h"
 
 using content::DevToolsAgentHost;
@@ -39,11 +38,28 @@ char kLocationsParam[] = "locations";
 char kHostParam[] = "host";
 char kPortParam[] = "port";
 
+class ChromeDevToolsManagerDelegate::HostData {
+ public:
+  HostData() {}
+  ~HostData() {}
+
+  RemoteLocations& remote_locations() { return remote_locations_; }
+
+  void set_remote_locations(RemoteLocations& locations) {
+    remote_locations_.swap(locations);
+  }
+
+ private:
+  RemoteLocations remote_locations_;
+};
+
 ChromeDevToolsManagerDelegate::ChromeDevToolsManagerDelegate()
     : network_protocol_handler_(new DevToolsNetworkProtocolHandler()) {
+  content::DevToolsAgentHost::AddObserver(this);
 }
 
 ChromeDevToolsManagerDelegate::~ChromeDevToolsManagerDelegate() {
+  content::DevToolsAgentHost::RemoveObserver(this);
 }
 
 void ChromeDevToolsManagerDelegate::Inspect(
@@ -51,39 +67,6 @@ void ChromeDevToolsManagerDelegate::Inspect(
   DevToolsWindow::OpenDevToolsWindow(agent_host, nullptr);
 }
 
-void ChromeDevToolsManagerDelegate::DevicesAvailable(
-    const DevToolsAgentHost::DiscoveryCallback& callback,
-    const DevToolsAndroidBridge::CompleteDevices& devices) {
-  DevToolsAgentHost::List result = DevToolsAgentHost::GetOrCreateAll();
-  for (const auto& complete : devices) {
-    for (const auto& browser : complete.second->browsers()) {
-      for (const auto& page : browser->pages())
-        result.push_back(page->CreateTarget());
-    }
-  }
-  callback.Run(std::move(result));
-}
-
-bool ChromeDevToolsManagerDelegate::DiscoverTargets(
-    const DevToolsAgentHost::DiscoveryCallback& callback) {
-  if (!tcp_locations_.size())
-    return false;
-
-  if (!device_manager_)
-    device_manager_ = AndroidDeviceManager::Create();
-
-  AndroidDeviceManager::DeviceProviders providers;
-  providers.push_back(new TCPDeviceProvider(tcp_locations_));
-  device_manager_->SetDeviceProviders(providers);
-
-  DevToolsAndroidBridge::QueryCompleteDevices(
-      device_manager_.get(),
-      base::Bind(&ChromeDevToolsManagerDelegate::DevicesAvailable,
-                 base::Unretained(this),
-                 callback));
-  return true;
-}
-
 base::DictionaryValue* ChromeDevToolsManagerDelegate::HandleCommand(
     DevToolsAgentHost* agent_host,
     base::DictionaryValue* command_dict) {
@@ -94,7 +77,7 @@ base::DictionaryValue* ChromeDevToolsManagerDelegate::HandleCommand(
   if (!DevToolsProtocol::ParseCommand(command_dict, &id, &method, &params))
     return nullptr;
 
-  if (method == chrome::devtools::Browser::setRemoteLocations::kName)
+  if (method == chrome::devtools::Target::setRemoteLocations::kName)
     return SetRemoteLocations(agent_host, id, params).release();
 
   return network_protocol_handler_->HandleCommand(agent_host, command_dict);
@@ -184,10 +167,76 @@ std::string ChromeDevToolsManagerDelegate::GetFrontendResource(
   return content::DevToolsFrontendHost::GetFrontendResource(path).as_string();
 }
 
-void ChromeDevToolsManagerDelegate::DevToolsAgentStateChanged(
-    DevToolsAgentHost* agent_host,
-    bool attached) {
-  network_protocol_handler_->DevToolsAgentStateChanged(agent_host, attached);
+void ChromeDevToolsManagerDelegate::DevToolsAgentHostAttached(
+    content::DevToolsAgentHost* agent_host) {
+  network_protocol_handler_->DevToolsAgentStateChanged(agent_host, true);
+
+  DCHECK(host_data_.find(agent_host) == host_data_.end());
+  host_data_[agent_host].reset(new ChromeDevToolsManagerDelegate::HostData());
+}
+
+void ChromeDevToolsManagerDelegate::DevToolsAgentHostDetached(
+    content::DevToolsAgentHost* agent_host) {
+  network_protocol_handler_->DevToolsAgentStateChanged(agent_host, false);
+  // This class is created lazily, so it may not know about some attached hosts.
+  if (host_data_.find(agent_host) != host_data_.end()) {
+    host_data_.erase(agent_host);
+    UpdateDeviceDiscovery();
+  }
+}
+
+void ChromeDevToolsManagerDelegate::DevicesAvailable(
+    const DevToolsDeviceDiscovery::CompleteDevices& devices) {
+  DevToolsAgentHost::List remote_targets;
+  for (const auto& complete : devices) {
+    for (const auto& browser : complete.second->browsers()) {
+      for (const auto& page : browser->pages())
+        remote_targets.push_back(page->CreateTarget());
+    }
+  }
+  remote_agent_hosts_.swap(remote_targets);
+}
+
+void ChromeDevToolsManagerDelegate::UpdateDeviceDiscovery() {
+  RemoteLocations remote_locations;
+  for (const auto& pair : host_data_) {
+    RemoteLocations& locations = pair.second->remote_locations();
+    remote_locations.insert(locations.begin(), locations.end());
+  }
+
+  bool equals = remote_locations.size() == remote_locations_.size();
+  if (equals) {
+    RemoteLocations::iterator it1 = remote_locations.begin();
+    RemoteLocations::iterator it2 = remote_locations_.begin();
+    while (it1 != remote_locations.end()) {
+      DCHECK(it2 != remote_locations_.end());
+      if (!(*it1).Equals(*it2))
+        equals = false;
+      ++it1;
+      ++it2;
+    }
+    DCHECK(it2 == remote_locations_.end());
+  }
+
+  if (equals)
+    return;
+
+  if (remote_locations.empty()) {
+    device_discovery_.reset();
+    remote_agent_hosts_.clear();
+  } else {
+    if (!device_manager_)
+      device_manager_ = AndroidDeviceManager::Create();
+
+    AndroidDeviceManager::DeviceProviders providers;
+    providers.push_back(new TCPDeviceProvider(remote_locations));
+    device_manager_->SetDeviceProviders(providers);
+
+    device_discovery_.reset(new DevToolsDeviceDiscovery(device_manager_.get(),
+        base::Bind(&ChromeDevToolsManagerDelegate::DevicesAvailable,
+                   base::Unretained(this))));
+  }
+  remote_locations_.swap(remote_locations);
 }
 
 std::unique_ptr<base::DictionaryValue>
@@ -195,14 +244,18 @@ ChromeDevToolsManagerDelegate::SetRemoteLocations(
     content::DevToolsAgentHost* agent_host,
     int command_id,
     base::DictionaryValue* params) {
-  tcp_locations_.clear();
+  if (host_data_.find(agent_host) == host_data_.end()) {
+      return DevToolsProtocol::CreateInvalidParamsResponse(
+          command_id, "Cannot find agent host");
+  }
 
+  std::set<net::HostPortPair> tcp_locations;
   base::ListValue* locations;
   if (!params->GetList(kLocationsParam, &locations))
     return DevToolsProtocol::CreateInvalidParamsResponse(command_id,
                                                          kLocationsParam);
   for (const auto& item : *locations) {
-    if (!item->IsType(base::Value::TYPE_DICTIONARY)) {
+    if (!item->IsType(base::Value::Type::DICTIONARY)) {
       return DevToolsProtocol::CreateInvalidParamsResponse(command_id,
                                                            kLocationsParam);
     }
@@ -218,8 +271,12 @@ ChromeDevToolsManagerDelegate::SetRemoteLocations(
       return DevToolsProtocol::CreateInvalidParamsResponse(command_id,
                                                            kLocationsParam);
     }
-    tcp_locations_.insert(net::HostPortPair(host, port));
+    tcp_locations.insert(net::HostPortPair(host, port));
   }
+
+  host_data_[agent_host]->set_remote_locations(tcp_locations);
+  UpdateDeviceDiscovery();
+
   std::unique_ptr<base::DictionaryValue> result(
       base::MakeUnique<base::DictionaryValue>());
   return DevToolsProtocol::CreateSuccessResponse(command_id, std::move(result));
