@@ -18,10 +18,6 @@
 #include "net/log/net_log_with_source.h"
 #include "net/socket/stream_socket.h"
 
-namespace base {
-class MessageLoop;
-}
-
 class AndroidUsbSocket : public net::StreamSocket,
                          public base::NonThreadSafe {
  public:
