@@ -29,7 +29,6 @@ class Profile;
 class PortForwardingStatusSerializer;
 
 namespace content {
-class NavigationHandle;
 class WebContents;
 }
 
@@ -43,9 +42,6 @@ class DevToolsUIBindings : public DevToolsEmbedderMessageDispatcher::Delegate,
   static DevToolsUIBindings* ForWebContents(
       content::WebContents* web_contents);
 
-  static GURL SanitizeFrontendURL(const GURL& url);
-  static bool IsValidFrontendURL(const GURL& url);
-
   class Delegate {
    public:
     virtual ~Delegate() {}
@@ -202,7 +198,6 @@ class DevToolsUIBindings : public DevToolsEmbedderMessageDispatcher::Delegate,
   typedef base::Callback<void(bool)> InfoBarCallback;
   void ShowDevToolsConfirmInfoBar(const base::string16& message,
                                   const InfoBarCallback& callback);
-  void UpdateFrontendHost(content::NavigationHandle* navigation_handle);
 
   // Extensions support.
   void AddDevToolsExtensionsToClient();
