@@ -36,6 +36,10 @@
 #include "content/public/browser/web_contents.h"
 #include "url/gurl.h"
 
+#if defined(OS_ANDROID)
+#include "chrome/browser/engagement/site_engagement_service_android.h"
+#endif
+
 namespace {
 
 const int FOUR_WEEKS_IN_DAYS = 28;
@@ -87,19 +91,6 @@ double SiteEngagementService::GetMaxPoints() {
 
 // static
 bool SiteEngagementService::IsEnabled() {
-  // If the engagement service or any of its dependencies are force-enabled,
-  // return true immediately.
-  if (base::CommandLine::ForCurrentProcess()->HasSwitch(
-          switches::kEnableSiteEngagementService) ||
-      SiteEngagementEvictionPolicy::IsEnabled() ||
-      AppBannerSettingsHelper::ShouldUseSiteEngagementScore()) {
-    return true;
-  }
-
-  if (base::CommandLine::ForCurrentProcess()->HasSwitch(
-          switches::kDisableSiteEngagementService)) {
-    return false;
-  }
   const std::string group_name =
       base::FieldTrialList::FindFullName(kEngagementParams);
   return !base::StartsWith(group_name, "Disabled",
@@ -251,6 +242,17 @@ double SiteEngagementService::GetTotalEngagementPoints() const {
   return total_score;
 }
 
+#if defined(OS_ANDROID)
+SiteEngagementServiceAndroid* SiteEngagementService::GetAndroidService() const {
+  return android_service_.get();
+}
+
+void SiteEngagementService::SetAndroidService(
+    std::unique_ptr<SiteEngagementServiceAndroid> android_service) {
+  android_service_ = std::move(android_service);
+}
+#endif
+
 SiteEngagementService::SiteEngagementService(Profile* profile,
                                              std::unique_ptr<base::Clock> clock)
     : profile_(profile), clock_(std::move(clock)), weak_factory_(this) {
@@ -401,6 +403,10 @@ void SiteEngagementService::RecordMetrics() {
       percent_origins_with_max_engagement);
 }
 
+bool SiteEngagementService::ShouldRecordEngagement(const GURL& url) const {
+  return url.SchemeIsHTTPOrHTTPS();
+}
+
 base::Time SiteEngagementService::GetLastEngagementTime() const {
   return base::Time::FromInternalValue(
       profile_->GetPrefs()->GetInt64(prefs::kSiteEngagementLastUpdateTime));
@@ -448,7 +454,10 @@ double SiteEngagementService::GetMedianEngagement(
 void SiteEngagementService::HandleMediaPlaying(
     content::WebContents* web_contents,
     bool is_hidden) {
-  const GURL& url = web_contents->GetVisibleURL();
+  const GURL& url = web_contents->GetLastCommittedURL();
+  if (!ShouldRecordEngagement(url))
+    return;
+
   SiteEngagementMetrics::RecordEngagement(
       is_hidden ? SiteEngagementMetrics::ENGAGEMENT_MEDIA_HIDDEN
                 : SiteEngagementMetrics::ENGAGEMENT_MEDIA_VISIBLE);
@@ -456,37 +465,38 @@ void SiteEngagementService::HandleMediaPlaying(
                            : SiteEngagementScore::GetVisibleMediaPoints());
 
   RecordMetrics();
-  FOR_EACH_OBSERVER(
-      SiteEngagementObserver, observer_list_,
-      OnEngagementIncreased(web_contents, url, GetScore(url)));
+  for (SiteEngagementObserver& observer : observer_list_)
+    observer.OnEngagementIncreased(web_contents, url, GetScore(url));
 }
 
 void SiteEngagementService::HandleNavigation(content::WebContents* web_contents,
                                              ui::PageTransition transition) {
-  if (IsEngagementNavigation(transition)) {
-    const GURL& url = web_contents->GetLastCommittedURL();
-    SiteEngagementMetrics::RecordEngagement(
-        SiteEngagementMetrics::ENGAGEMENT_NAVIGATION);
-    AddPoints(url, SiteEngagementScore::GetNavigationPoints());
+  const GURL& url = web_contents->GetLastCommittedURL();
+  if (!IsEngagementNavigation(transition) || !ShouldRecordEngagement(url))
+    return;
 
-    RecordMetrics();
-    FOR_EACH_OBSERVER(
-        SiteEngagementObserver, observer_list_,
-        OnEngagementIncreased(web_contents, url, GetScore(url)));
-  }
+  SiteEngagementMetrics::RecordEngagement(
+      SiteEngagementMetrics::ENGAGEMENT_NAVIGATION);
+  AddPoints(url, SiteEngagementScore::GetNavigationPoints());
+
+  RecordMetrics();
+  for (SiteEngagementObserver& observer : observer_list_)
+    observer.OnEngagementIncreased(web_contents, url, GetScore(url));
 }
 
 void SiteEngagementService::HandleUserInput(
     content::WebContents* web_contents,
     SiteEngagementMetrics::EngagementType type) {
-  const GURL& url = web_contents->GetVisibleURL();
+  const GURL& url = web_contents->GetLastCommittedURL();
+  if (!ShouldRecordEngagement(url))
+    return;
+
   SiteEngagementMetrics::RecordEngagement(type);
   AddPoints(url, SiteEngagementScore::GetUserInputPoints());
 
   RecordMetrics();
-  FOR_EACH_OBSERVER(
-      SiteEngagementObserver, observer_list_,
-      OnEngagementIncreased(web_contents, url, GetScore(url)));
+  for (SiteEngagementObserver& observer : observer_list_)
+    observer.OnEngagementIncreased(web_contents, url, GetScore(url));
 }
 
 bool SiteEngagementService::IsLastEngagementStale() const {
