@@ -14,6 +14,7 @@
 #include "base/memory/weak_ptr.h"
 #include "base/observer_list.h"
 #include "base/time/time.h"
+#include "build/build_config.h"
 #include "chrome/browser/engagement/site_engagement_metrics.h"
 #include "chrome/browser/engagement/site_engagement_observer.h"
 #include "components/history/core/browser/history_service_observer.h"
@@ -21,7 +22,6 @@
 #include "ui/base/page_transition_types.h"
 
 namespace base {
-class DictionaryValue;
 class Clock;
 }
 
@@ -38,6 +38,10 @@ class HostContentSettingsMap;
 class Profile;
 class SiteEngagementScore;
 
+#if defined(OS_ANDROID)
+class SiteEngagementServiceAndroid;
+#endif
+
 class SiteEngagementScoreProvider {
  public:
   // Returns a non-negative integer representing the engagement score of the
@@ -135,6 +139,7 @@ class SiteEngagementService : public KeyedService,
 
  private:
   friend class SiteEngagementObserver;
+  friend class SiteEngagementServiceAndroid;
   FRIEND_TEST_ALL_PREFIXES(SiteEngagementServiceTest, CheckHistograms);
   FRIEND_TEST_ALL_PREFIXES(SiteEngagementServiceTest, CleanupEngagementScores);
   FRIEND_TEST_ALL_PREFIXES(SiteEngagementServiceTest,
@@ -147,6 +152,7 @@ class SiteEngagementService : public KeyedService,
   FRIEND_TEST_ALL_PREFIXES(SiteEngagementServiceTest, GetMedianEngagement);
   FRIEND_TEST_ALL_PREFIXES(SiteEngagementServiceTest, GetTotalNavigationPoints);
   FRIEND_TEST_ALL_PREFIXES(SiteEngagementServiceTest, GetTotalUserInputPoints);
+  FRIEND_TEST_ALL_PREFIXES(SiteEngagementServiceTest, RestrictedToHTTPAndHTTPS);
   FRIEND_TEST_ALL_PREFIXES(SiteEngagementServiceTest, LastShortcutLaunch);
   FRIEND_TEST_ALL_PREFIXES(SiteEngagementServiceTest,
                            CleanupOriginsOnHistoryDeletion);
@@ -160,6 +166,13 @@ class SiteEngagementService : public KeyedService,
   FRIEND_TEST_ALL_PREFIXES(SiteEngagementServiceTest, GetScoreFromSettings);
   FRIEND_TEST_ALL_PREFIXES(AppBannerSettingsHelperTest, SiteEngagementTrigger);
 
+#if defined(OS_ANDROID)
+  // Shim class to expose the service to Java.
+  SiteEngagementServiceAndroid* GetAndroidService() const;
+  void SetAndroidService(
+      std::unique_ptr<SiteEngagementServiceAndroid> android_service);
+#endif
+
   // Only used in tests.
   SiteEngagementService(Profile* profile, std::unique_ptr<base::Clock> clock);
 
@@ -187,6 +200,10 @@ class SiteEngagementService : public KeyedService,
   // Records UMA metrics.
   void RecordMetrics();
 
+  // Returns true if we should record engagement for this URL. Currently,
+  // engagement is only earned for HTTP and HTTPS.
+  bool ShouldRecordEngagement(const GURL& url) const;
+
   // Get and set the last engagement time from prefs.
   base::Time GetLastEngagementTime() const;
   void SetLastEngagementTime(base::Time last_engagement_time) const;
@@ -249,6 +266,10 @@ class SiteEngagementService : public KeyedService,
   // The clock used to vend times.
   std::unique_ptr<base::Clock> clock_;
 
+#if defined(OS_ANDROID)
+  std::unique_ptr<SiteEngagementServiceAndroid> android_service_;
+#endif
+
   // Metrics are recorded at non-incognito browser startup, and then
   // approximately once per hour thereafter. Store the local time at which
   // metrics were previously uploaded: the first event which affects any
