@@ -33,7 +33,7 @@
 #include "url/url_util.h"
 
 #if defined(OS_CHROMEOS)
-#include "chrome/browser/chromeos/arc/arc_auth_service.h"
+#include "chrome/browser/chromeos/arc/arc_session_manager.h"
 #endif  // defined(OS_CHROMEOS)
 
 #if defined(OS_WIN)
@@ -153,7 +153,7 @@ void FeedbackPrivateAPI::RequestFeedbackForFlow(
 // static
 base::Closure* FeedbackPrivateGetStringsFunction::test_callback_ = NULL;
 
-bool FeedbackPrivateGetStringsFunction::RunSync() {
+ExtensionFunction::ResponseAction FeedbackPrivateGetStringsFunction::Run() {
   std::unique_ptr<base::DictionaryValue> dict(new base::DictionaryValue());
 
 #define SET_STRING(id, idr) \
@@ -164,8 +164,9 @@ bool FeedbackPrivateGetStringsFunction::RunSync() {
   SET_STRING("screenshot", IDS_FEEDBACK_SCREENSHOT_LABEL);
   SET_STRING("user-email", IDS_FEEDBACK_USER_EMAIL_LABEL);
 #if defined(OS_CHROMEOS)
-  const arc::ArcAuthService* auth_service = arc::ArcAuthService::Get();
-  if (auth_service && auth_service->IsArcEnabled()) {
+  const arc::ArcSessionManager* arc_session_manager =
+      arc::ArcSessionManager::Get();
+  if (arc_session_manager && arc_session_manager->IsArcEnabled()) {
     SET_STRING("sys-info",
                IDS_FEEDBACK_INCLUDE_SYSTEM_INFORMATION_AND_METRICS_CHKBOX_ARC);
   } else {
@@ -204,21 +205,19 @@ bool FeedbackPrivateGetStringsFunction::RunSync() {
   const std::string& app_locale = g_browser_process->GetApplicationLocale();
   webui::SetLoadTimeDataDefaults(app_locale, dict.get());
 
-  SetResult(std::move(dict));
 
   if (test_callback_ && !test_callback_->is_null())
     test_callback_->Run();
 
-  return true;
+  return RespondNow(OneArgument(std::move(dict)));
 }
 
-bool FeedbackPrivateGetUserEmailFunction::RunSync() {
-  SigninManagerBase* signin_manager =
-      SigninManagerFactory::GetForProfile(GetProfile());
-  SetResult(base::MakeUnique<base::StringValue>(
+ExtensionFunction::ResponseAction FeedbackPrivateGetUserEmailFunction::Run() {
+  SigninManagerBase* signin_manager = SigninManagerFactory::GetForProfile(
+      Profile::FromBrowserContext(browser_context()));
+  return RespondNow(OneArgument(base::MakeUnique<base::StringValue>(
       signin_manager ? signin_manager->GetAuthenticatedAccountInfo().email
-                     : std::string()));
-  return true;
+                     : std::string())));
 }
 
 bool FeedbackPrivateGetSystemInformationFunction::RunAsync() {
