@@ -8,6 +8,7 @@
 
 #include <stddef.h>
 
+#include <memory>
 #include <set>
 #include <string>
 #include <utility>
@@ -40,6 +41,7 @@
 #include "chrome/common/pref_names.h"
 #include "chrome/grit/generated_resources.h"
 #include "components/storage_monitor/storage_info.h"
+#include "components/web_modal/web_contents_modal_dialog_manager.h"
 #include "content/public/browser/blob_handle.h"
 #include "content/public/browser/browser_context.h"
 #include "content/public/browser/browser_thread.h"
@@ -48,6 +50,8 @@
 #include "content/public/browser/render_process_host.h"
 #include "content/public/browser/render_view_host.h"
 #include "content/public/browser/web_contents.h"
+#include "extensions/browser/app_window/app_window.h"
+#include "extensions/browser/app_window/app_window_registry.h"
 #include "extensions/browser/blob_holder.h"
 #include "extensions/browser/extension_prefs.h"
 #include "extensions/browser/extension_system.h"
@@ -185,7 +189,7 @@ base::ListValue* ConstructFileSystemList(
     file_system_dict_value->SetBooleanWithoutPathExpansion(
         kIsAvailableKey, true);
 
-    list->Append(file_system_dict_value.release());
+    list->Append(std::move(file_system_dict_value));
 
     if (filesystems[i].path.empty())
       continue;
@@ -261,6 +265,30 @@ class SelectDirectoryDialog : public ui::SelectFileDialog::Listener,
   DISALLOW_COPY_AND_ASSIGN(SelectDirectoryDialog);
 };
 
+// Returns a web contents to use as the source for a prompt showing to the user.
+// The web contents has to support modal dialogs, so it can't be the app's
+// background page.
+content::WebContents* GetWebContentsForPrompt(
+    content::WebContents* sender_web_contents,
+    content::BrowserContext* browser_context,
+    const std::string& app_id) {
+  // Check if the sender web contents supports modal dialogs.
+  if (sender_web_contents &&
+      web_modal::WebContentsModalDialogManager::FromWebContents(
+          sender_web_contents)) {
+    return sender_web_contents;
+  }
+  // Otherwise, check for the current app window for the app (app windows
+  // support modal dialogs).
+  if (!app_id.empty()) {
+    AppWindow* window = AppWindowRegistry::Get(browser_context)
+                            ->GetCurrentAppWindowForApp(app_id);
+    if (window)
+      return window->web_contents();
+  }
+  return nullptr;
+}
+
 }  // namespace
 
 MediaGalleriesEventRouter::MediaGalleriesEventRouter(
@@ -437,14 +465,16 @@ void MediaGalleriesGetMediaFileSystemsFunction::ReturnGalleries(
   }
 
   // The custom JS binding will use this list to create DOMFileSystem objects.
-  SetResult(list.release());
+  SetResult(std::move(list));
   SendResponse(true);
 }
 
 void MediaGalleriesGetMediaFileSystemsFunction::ShowDialog() {
   media_galleries::UsageCount(media_galleries::SHOW_DIALOG);
   WebContents* contents =
-      ChromeExtensionFunctionDetails(this).GetOriginWebContents();
+      GetWebContentsForPrompt(GetSenderWebContents(),
+                              browser_context(),
+                              extension()->id());
   if (!contents) {
     SendResponse(false);
     return;
@@ -481,10 +511,11 @@ bool MediaGalleriesAddUserSelectedFolderFunction::RunAsync() {
 }
 
 void MediaGalleriesAddUserSelectedFolderFunction::OnPreferencesInit() {
-  Profile* profile = GetProfile();
   const std::string& app_id = extension()->id();
   WebContents* contents =
-      ChromeExtensionFunctionDetails(this).GetOriginWebContents();
+      GetWebContentsForPrompt(GetSenderWebContents(),
+                              browser_context(),
+                              app_id);
   if (!contents) {
     SendResponse(false);
     return;
@@ -497,7 +528,7 @@ void MediaGalleriesAddUserSelectedFolderFunction::OnPreferencesInit() {
 
   base::FilePath last_used_path =
       extensions::file_system_api::GetLastChooseEntryDirectory(
-          extensions::ExtensionPrefs::Get(profile), app_id);
+          extensions::ExtensionPrefs::Get(browser_context()), app_id);
   SelectDirectoryDialog::Callback callback = base::Bind(
       &MediaGalleriesAddUserSelectedFolderFunction::OnDirectorySelected, this);
   scoped_refptr<SelectDirectoryDialog> select_directory_dialog =
@@ -553,10 +584,10 @@ void MediaGalleriesAddUserSelectedFolderFunction::ReturnGalleriesAndId(
       }
     }
   }
-  base::DictionaryValue* results = new base::DictionaryValue;
+  std::unique_ptr<base::DictionaryValue> results(new base::DictionaryValue);
   results->SetWithoutPathExpansion("mediaFileSystems", list.release());
   results->SetIntegerWithoutPathExpansion("selectedFileSystemIndex", index);
-  SetResult(results);
+  SetResult(std::move(results));
   SendResponse(true);
 }
 
@@ -631,9 +662,10 @@ void MediaGalleriesGetMetadataFunction::GetMetadata(
     MediaGalleries::MediaMetadata metadata;
     metadata.mime_type = mime_type;
 
-    base::DictionaryValue* result_dictionary = new base::DictionaryValue;
+    std::unique_ptr<base::DictionaryValue> result_dictionary(
+        new base::DictionaryValue);
     result_dictionary->Set(kMetadataKey, metadata.ToValue().release());
-    SetResult(result_dictionary);
+    SetResult(std::move(result_dictionary));
     SendResponse(true);
     return;
   }
@@ -671,7 +703,7 @@ void MediaGalleriesGetMetadataFunction::OnSafeMediaMetadataParserDone(
   result_dictionary->Set(kMetadataKey, metadata_dictionary.release());
 
   if (attached_images->empty()) {
-    SetResult(result_dictionary.release());
+    SetResult(std::move(result_dictionary));
     SendResponse(true);
     return;
   }
@@ -709,14 +741,15 @@ void MediaGalleriesGetMetadataFunction::ConstructNextBlob(
 
   metadata::AttachedImage* current_image =
       &(*attached_images)[blob_uuids->size()];
-  base::DictionaryValue* attached_image = new base::DictionaryValue;
+  std::unique_ptr<base::DictionaryValue> attached_image(
+      new base::DictionaryValue);
   attached_image->Set(kBlobUUIDKey, new base::StringValue(
       current_blob->GetUUID()));
   attached_image->Set(kTypeKey, new base::StringValue(
       current_image->type));
   attached_image->Set(kSizeKey, new base::FundamentalValue(
       base::checked_cast<int>(current_image->data.size())));
-  attached_images_list->Append(attached_image);
+  attached_images_list->Append(std::move(attached_image));
 
   blob_uuids->push_back(current_blob->GetUUID());
   extensions::BlobHolder* holder =
@@ -739,7 +772,7 @@ void MediaGalleriesGetMetadataFunction::ConstructNextBlob(
   }
 
   // All Blobs have been constructed. The renderer will take ownership.
-  SetResult(result_dictionary.release());
+  SetResult(std::move(result_dictionary));
   SetTransferredBlobUUIDs(*blob_uuids);
   SendResponse(true);
 }
@@ -785,7 +818,7 @@ void MediaGalleriesAddGalleryWatchFunction::OnPreferencesInit(
     error_ = kInvalidGalleryIdMsg;
     result.gallery_id = kInvalidGalleryId;
     result.success = false;
-    SetResult(result.ToValue().release());
+    SetResult(result.ToValue());
     SendResponse(false);
     return;
   }
@@ -812,14 +845,14 @@ void MediaGalleriesAddGalleryWatchFunction::HandleResponse(
 
   if (!api->ExtensionHasGalleryChangeListener(extension()->id())) {
     result.success = false;
-    SetResult(result.ToValue().release());
+    SetResult(result.ToValue());
     error_ = kMissingEventListener;
     SendResponse(false);
     return;
   }
 
   result.success = error.empty();
-  SetResult(result.ToValue().release());
+  SetResult(result.ToValue());
   if (error.empty()) {
     SendResponse(true);
   } else {
