@@ -9,8 +9,10 @@
 #include <utility>
 
 #include "base/callback.h"
+#include "base/feature_list.h"
 #include "base/guid.h"
 #include "base/macros.h"
+#include "base/memory/ptr_util.h"
 #include "base/metrics/histogram_macros.h"
 #include "base/rand_util.h"
 #include "base/strings/string_number_conversions.h"
@@ -30,6 +32,9 @@
 #include "content/public/browser/render_process_host.h"
 #include "content/public/browser/render_view_host.h"
 #include "content/public/browser/web_contents.h"
+#include "extensions/browser/app_window/app_window.h"
+#include "extensions/browser/app_window/app_window_registry.h"
+#include "extensions/browser/app_window/native_app_window.h"
 #include "extensions/browser/event_router.h"
 #include "extensions/browser/extension_system_provider.h"
 #include "extensions/browser/extensions_browser_client.h"
@@ -45,10 +50,16 @@
 #include "ui/message_center/notifier_settings.h"
 #include "url/gurl.h"
 
+using message_center::NotifierId;
+
 namespace extensions {
 
 namespace notifications = api::notifications;
 
+const base::Feature kAllowFullscreenAppNotificationsFeature{
+  "FSNotificationsApp", base::FEATURE_DISABLED_BY_DEFAULT
+};
+
 namespace {
 
 const char kMissingRequiredPropertiesForCreateNotification[] =
@@ -157,7 +168,7 @@ class NotificationsApiDelegate : public NotificationDelegate {
         by_user ? EventRouter::USER_GESTURE_ENABLED
                 : EventRouter::USER_GESTURE_NOT_ENABLED;
     std::unique_ptr<base::ListValue> args(CreateBaseEventArgs());
-    args->Append(new base::FundamentalValue(by_user));
+    args->AppendBoolean(by_user);
     SendEvent(events::NOTIFICATIONS_ON_CLOSED,
               notifications::OnClosed::kEventName, gesture, std::move(args));
   }
@@ -179,7 +190,7 @@ class NotificationsApiDelegate : public NotificationDelegate {
 
   void ButtonClick(int index) override {
     std::unique_ptr<base::ListValue> args(CreateBaseEventArgs());
-    args->Append(new base::FundamentalValue(index));
+    args->AppendInteger(index);
     SendEvent(events::NOTIFICATIONS_ON_BUTTON_CLICKED,
               notifications::OnButtonClicked::kEventName,
               EventRouter::USER_GESTURE_ENABLED, std::move(args));
@@ -187,6 +198,34 @@ class NotificationsApiDelegate : public NotificationDelegate {
 
   std::string id() const override { return scoped_id_; }
 
+  // Should only display when fullscreen if this app is the source of the
+  // fullscreen window.
+  bool ShouldDisplayOverFullscreen() const override {
+    AppWindowRegistry::AppWindowList windows = AppWindowRegistry::Get(
+        api_function_->GetProfile())->GetAppWindowsForApp(extension_id_);
+    for (const auto& window : windows) {
+      // Window must be fullscreen and visible
+      if (window->IsFullscreen() && window->GetBaseWindow()->IsActive()) {
+        bool enabled = base::FeatureList::IsEnabled(
+            kAllowFullscreenAppNotificationsFeature);
+        if (enabled) {
+          UMA_HISTOGRAM_ENUMERATION("Notifications.Display_Fullscreen.Shown",
+                                    NotifierId::APPLICATION,
+                                    NotifierId::SIZE);
+        } else {
+          UMA_HISTOGRAM_ENUMERATION(
+              "Notifications.Display_Fullscreen.Suppressed",
+              NotifierId::APPLICATION,
+              NotifierId::SIZE);
+
+        }
+        return enabled;
+      }
+    }
+
+    return false;
+  }
+
  private:
   ~NotificationsApiDelegate() override {}
 
@@ -210,7 +249,7 @@ class NotificationsApiDelegate : public NotificationDelegate {
 
   std::unique_ptr<base::ListValue> CreateBaseEventArgs() {
     std::unique_ptr<base::ListValue> args(new base::ListValue());
-    args->Append(new base::StringValue(id_));
+    args->AppendString(id_);
     return args;
   }
 
@@ -606,7 +645,7 @@ bool NotificationsCreateFunction::RunNotificationsApi() {
       notification_id = base::RandBytesAsString(16);
   }
 
-  SetResult(new base::StringValue(notification_id));
+  SetResult(base::MakeUnique<base::StringValue>(notification_id));
 
   // TODO(dewittj): Add more human-readable error strings if this fails.
   if (!CreateNotification(notification_id, &params_->options))
@@ -634,7 +673,7 @@ bool NotificationsUpdateFunction::RunNotificationsApi() {
           CreateScopedIdentifier(extension_->id(), params_->notification_id),
           NotificationUIManager::GetProfileID(GetProfile()));
   if (!matched_notification) {
-    SetResult(new base::FundamentalValue(false));
+    SetResult(base::MakeUnique<base::FundamentalValue>(false));
     SendResponse(true);
     return true;
   }
@@ -648,7 +687,8 @@ bool NotificationsUpdateFunction::RunNotificationsApi() {
   // TODO(dewittj): Add more human-readable error strings if this fails.
   bool could_update_notification = UpdateNotification(
       params_->notification_id, &params_->options, &notification);
-  SetResult(new base::FundamentalValue(could_update_notification));
+  SetResult(
+      base::MakeUnique<base::FundamentalValue>(could_update_notification));
   if (!could_update_notification)
     return false;
 
@@ -672,7 +712,7 @@ bool NotificationsClearFunction::RunNotificationsApi() {
       CreateScopedIdentifier(extension_->id(), params_->notification_id),
       NotificationUIManager::GetProfileID(GetProfile()));
 
-  SetResult(new base::FundamentalValue(cancel_result));
+  SetResult(base::MakeUnique<base::FundamentalValue>(cancel_result));
   SendResponse(true);
 
   return true;
@@ -697,7 +737,7 @@ bool NotificationsGetAllFunction::RunNotificationsApi() {
         StripScopeFromIdentifier(extension_->id(), *iter), true);
   }
 
-  SetResult(result.release());
+  SetResult(std::move(result));
   SendResponse(true);
 
   return true;
@@ -719,7 +759,8 @@ bool NotificationsGetPermissionLevelFunction::RunNotificationsApi() {
           ? api::notifications::PERMISSION_LEVEL_GRANTED
           : api::notifications::PERMISSION_LEVEL_DENIED;
 
-  SetResult(new base::StringValue(api::notifications::ToString(result)));
+  SetResult(base::MakeUnique<base::StringValue>(
+      api::notifications::ToString(result)));
   SendResponse(true);
 
   return true;
