@@ -149,7 +149,7 @@ IN_PROC_BROWSER_TEST_F(OmniboxApiTest, DISABLED_Basic) {
     OmniboxView* omnibox_view = location_bar->GetOmniboxView();
     omnibox_view->OnBeforePossibleChange();
     omnibox_view->SetUserText(ASCIIToUTF16("keyword command"));
-    omnibox_view->OnAfterPossibleChange();
+    omnibox_view->OnAfterPossibleChange(true);
     location_bar->AcceptInput();
     // This checks that the keyword provider (via javascript)
     // gets told to navigate to the string "command".
@@ -171,20 +171,20 @@ IN_PROC_BROWSER_TEST_F(OmniboxApiTest, OnInputEntered) {
       GetAutocompleteController(browser());
   omnibox_view->OnBeforePossibleChange();
   omnibox_view->SetUserText(ASCIIToUTF16("keyword command"));
-  omnibox_view->OnAfterPossibleChange();
+  omnibox_view->OnAfterPossibleChange(true);
 
   autocomplete_controller->Start(AutocompleteInput(
       ASCIIToUTF16("keyword command"), base::string16::npos, std::string(),
       GURL(), OmniboxEventProto::NTP, true, false, true, true, false,
       ChromeAutocompleteSchemeClassifier(profile)));
-  omnibox_view->model()->AcceptInput(CURRENT_TAB, false);
+  omnibox_view->model()->AcceptInput(WindowOpenDisposition::CURRENT_TAB, false);
   WaitForAutocompleteDone(autocomplete_controller);
   EXPECT_TRUE(autocomplete_controller->done());
   EXPECT_TRUE(catcher.GetNextResult()) << catcher.message();
 
   omnibox_view->OnBeforePossibleChange();
   omnibox_view->SetUserText(ASCIIToUTF16("keyword newtab"));
-  omnibox_view->OnAfterPossibleChange();
+  omnibox_view->OnAfterPossibleChange(true);
   WaitForAutocompleteDone(autocomplete_controller);
   EXPECT_TRUE(autocomplete_controller->done());
 
@@ -192,7 +192,8 @@ IN_PROC_BROWSER_TEST_F(OmniboxApiTest, OnInputEntered) {
       ASCIIToUTF16("keyword newtab"), base::string16::npos, std::string(),
       GURL(), OmniboxEventProto::NTP, true, false, true, true, false,
       ChromeAutocompleteSchemeClassifier(profile)));
-  omnibox_view->model()->AcceptInput(NEW_FOREGROUND_TAB, false);
+  omnibox_view->model()->AcceptInput(WindowOpenDisposition::NEW_FOREGROUND_TAB,
+                                     false);
   WaitForAutocompleteDone(autocomplete_controller);
   EXPECT_TRUE(autocomplete_controller->done());
   EXPECT_TRUE(catcher.GetNextResult()) << catcher.message();
