@@ -23,7 +23,6 @@
 #include "base/strings/string16.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/string_util.h"
-#include "base/strings/stringprintf.h"
 #include "base/strings/utf_string_conversions.h"
 #include "base/threading/thread_task_runner_handle.h"
 #include "chrome/browser/browser_process.h"
@@ -225,9 +224,7 @@ bool IsValidStateForWindowsCreateFunction(
 
   bool has_bound = create_data->left || create_data->top ||
                    create_data->width || create_data->height;
-  bool is_panel =
-      create_data->type == windows::CreateType::CREATE_TYPE_PANEL ||
-      create_data->type == windows::CreateType::CREATE_TYPE_DETACHED_PANEL;
+  bool is_panel = create_data->type == windows::CreateType::CREATE_TYPE_PANEL;
 
   switch (create_data->state) {
     case windows::WINDOW_STATE_MINIMIZED:
@@ -500,8 +497,7 @@ ExtensionFunction::ResponseAction WindowsCreateFunction::Run() {
         extension_id = extension()->id();
         break;
 
-      case windows::CREATE_TYPE_PANEL:
-      case windows::CREATE_TYPE_DETACHED_PANEL: {
+      case windows::CREATE_TYPE_PANEL: {
         extension_id = extension()->id();
 #if defined(USE_ASH)
       // Only ChromeOS' version of chrome.windows.create would create a panel
@@ -1180,11 +1176,17 @@ bool TabsUpdateFunction::RunAsync() {
 
   int tab_index = -1;
   TabStripModel* tab_strip = NULL;
-  if (!GetTabById(tab_id, browser_context(), include_incognito(), NULL,
+  Browser* browser = nullptr;
+  if (!GetTabById(tab_id, browser_context(), include_incognito(), &browser,
                   &tab_strip, &contents, &tab_index, &error_)) {
     return false;
   }
 
+  if (!ExtensionTabUtil::BrowserSupportsTabs(browser)) {
+    error_ = keys::kNoCurrentWindowError;
+    return false;
+  }
+
   web_contents_ = contents;
 
   // TODO(rafaelw): handle setting remaining tab properties:
