@@ -23,7 +23,6 @@ class Profile;
 
 namespace extensions {
 
-class ExtensionPrefs;
 class ExtensionRegistry;
 
 class ExtensionMessageBubbleController : public chrome::BrowserListObserver {
@@ -151,10 +150,6 @@ class ExtensionMessageBubbleController : public chrome::BrowserListObserver {
   // Obtains a list of all extensions (by id) the controller knows about.
   const ExtensionIdList& GetExtensionIdList();
 
-  // Checks if each extension entry is installed, and if not, removes it from
-  // the list.
-  void UpdateExtensionIdList();
-
   // Whether to close the bubble when it loses focus.
   bool CloseOnDeactivate();
 
