@@ -4,6 +4,8 @@
 
 #include "chrome/browser/extensions/extension_util.h"
 
+#include <vector>
+
 #include "base/command_line.h"
 #include "base/logging.h"
 #include "base/metrics/field_trial.h"
@@ -44,10 +46,6 @@ namespace extensions {
 namespace util {
 
 namespace {
-
-const char kSupervisedUserExtensionPermissionIncreaseFieldTrialName[] =
-    "SupervisedUserExtensionPermissionIncrease";
-
 // The entry into the prefs used to flag an extension as installed by custodian.
 // It is relevant only for supervised users.
 const char kWasInstalledByCustodianPrefName[] = "was_installed_by_custodian";
@@ -55,7 +53,7 @@ const char kWasInstalledByCustodianPrefName[] = "was_installed_by_custodian";
 // Returns true if |extension| should always be enabled in incognito mode.
 bool IsWhitelistedForIncognito(const Extension* extension) {
   const Feature* feature = FeatureProvider::GetBehaviorFeature(
-      BehaviorFeature::kWhitelistedForIncognito);
+      behavior_feature::kWhitelistedForIncognito);
   return feature && feature->IsAvailableToExtension(extension).is_available();
 }
 
@@ -356,17 +354,5 @@ bool IsExtensionSupervised(const Extension* extension, Profile* profile) {
          profile->IsSupervised();
 }
 
-bool NeedCustodianApprovalForPermissionIncrease(const Profile* profile) {
-  if (!profile->IsSupervised())
-    return false;
-  // Query the trial group name first, to make sure it's properly initialized.
-  base::FieldTrialList::FindFullName(
-      kSupervisedUserExtensionPermissionIncreaseFieldTrialName);
-  std::string value = variations::GetVariationParamValue(
-      kSupervisedUserExtensionPermissionIncreaseFieldTrialName,
-      profile->IsChild() ? "child_account" : "legacy_supervised_user");
-  return value == "true";
-}
-
 }  // namespace util
 }  // namespace extensions
