@@ -9,11 +9,8 @@
 #include <vector>
 
 #include "base/macros.h"
-#include "base/strings/string16.h"
 #include "components/favicon/core/fallback_icon_client.h"
 
-class GURL;
-
 // ChromeFallbackIconClient implements the FallbackIconClient interface.
 class ChromeFallbackIconClient : public favicon::FallbackIconClient {
  public:
@@ -23,8 +20,6 @@ class ChromeFallbackIconClient : public favicon::FallbackIconClient {
   // FallbackIconClient implementation:
   const std::vector<std::string>& GetFontNameList() const override;
 
-  base::string16 GetFallbackIconText(const GURL& url) const override;
-
  private:
   std::vector<std::string> font_list_;
 
