@@ -12,7 +12,7 @@
 #include "chrome/browser/sync/profile_sync_service_factory.h"
 #include "chrome/common/channel_info.h"
 #include "chrome/common/pref_names.h"
-#include "components/browser_sync/browser/profile_sync_service.h"
+#include "components/browser_sync/profile_sync_service.h"
 #include "components/prefs/pref_service.h"
 #include "components/sync/driver/about_sync_util.h"
 #include "content/public/browser/browser_thread.h"
@@ -140,15 +140,15 @@ void ChromeInternalLogSource::PopulateSyncLogs(SystemLogsResponse* response) {
       !ProfileSyncServiceFactory::GetInstance()->HasProfileSyncService(profile))
     return;
 
-  ProfileSyncService* service =
+  browser_sync::ProfileSyncService* service =
       ProfileSyncServiceFactory::GetInstance()->GetForProfile(profile);
   std::unique_ptr<base::DictionaryValue> sync_logs(
-      sync_driver::sync_ui_util::ConstructAboutInformation(
+      syncer::sync_ui_util::ConstructAboutInformation(
           service, service->signin(), chrome::GetChannel()));
 
   // Remove identity section.
   base::ListValue* details = NULL;
-  sync_logs->GetList(sync_driver::sync_ui_util::kDetailsKey, &details);
+  sync_logs->GetList(syncer::sync_ui_util::kDetailsKey, &details);
   if (!details)
     return;
   for (base::ListValue::iterator it = details->begin();
@@ -157,7 +157,7 @@ void ChromeInternalLogSource::PopulateSyncLogs(SystemLogsResponse* response) {
     if ((*it)->GetAsDictionary(&dict)) {
       std::string title;
       dict->GetString("title", &title);
-      if (title == sync_driver::sync_ui_util::kIdentityTitle) {
+      if (title == syncer::sync_ui_util::kIdentityTitle) {
         details->Erase(it, NULL);
         break;
       }
