@@ -78,7 +78,6 @@ class CookieStore;
 class CTLogVerifier;
 class HostMappingRules;
 class HostResolver;
-class HttpAuthHandlerRegistryFactory;
 class HttpAuthPreferences;
 class HttpServerProperties;
 class HttpTransactionFactory;
@@ -240,7 +239,7 @@ class IOThread : public content::BrowserThreadDelegate {
   base::TimeTicks creation_time() const;
 
   // Returns the callback for updating data use prefs.
-  const metrics::UpdateUsagePrefCallbackType& GetMetricsDataUseForwarder();
+  metrics::UpdateUsagePrefCallbackType GetMetricsDataUseForwarder();
 
   // Registers the |observer| for new STH notifications.
   void RegisterSTHObserver(net::ct::STHObserver* observer);
@@ -400,10 +399,6 @@ class IOThread : public content::BrowserThreadDelegate {
 
   const base::TimeTicks creation_time_;
 
-  // Callback for updating data use prefs which needs to be initialized on UI
-  // thread and passed to |DataUseNetworkDelegate|.
-  metrics::UpdateUsagePrefCallbackType metrics_data_use_forwarder_;
-
   base::WeakPtrFactory<IOThread> weak_factory_;
 
   DISALLOW_COPY_AND_ASSIGN(IOThread);
