@@ -48,7 +48,8 @@
 #include "components/data_reduction_proxy/core/browser/data_reduction_proxy_io_data.h"
 #include "components/google/core/browser/google_util.h"
 #include "components/policy/core/common/cloud/policy_header_io_helper.h"
-#include "components/rappor/rappor_utils.h"
+#include "components/rappor/public/rappor_utils.h"
+#include "components/rappor/rappor_service_impl.h"
 #include "components/search_engines/template_url_service.h"
 #include "components/variations/net/variations_http_headers.h"
 #include "content/public/browser/browser_thread.h"
@@ -242,12 +243,16 @@ void LaunchURL(
   // If the URL is in whitelist, we launch it without asking the user and
   // without any additional security checks. Since the URL is whitelisted,
   // we assume it can be executed.
+  // TODO(davidsac): External protocol handling needs to be
+  // fixed for OOPIFs.  See https://crbug.com/668289.
   if (is_whitelisted) {
     ExternalProtocolHandler::LaunchUrlWithoutSecurityCheck(
-        url, render_process_id, web_contents->GetRoutingID());
+        url, render_process_id,
+        web_contents->GetRenderViewHost()->GetRoutingID());
   } else {
     ExternalProtocolHandler::LaunchUrlWithDelegate(
-        url, render_process_id, web_contents->GetRoutingID(), page_transition,
+        url, render_process_id,
+        web_contents->GetRenderViewHost()->GetRoutingID(), page_transition,
         has_user_gesture, g_external_protocol_handler_delegate);
   }
 }
@@ -508,7 +513,7 @@ void ChromeResourceDispatcherHostDelegate::RequestBeginning(
 
   if (io_data->resource_prefetch_predictor_observer()) {
     io_data->resource_prefetch_predictor_observer()->OnRequestStarted(
-        request, resource_type, info->GetChildID(), info->GetRenderFrameID());
+        request, resource_type, info->GetWebContentsGetterForRequest());
   }
 }
 
@@ -623,11 +628,11 @@ void ChromeResourceDispatcherHostDelegate::AppendStandardResourceThrottles(
     throttles->push_back(first_throttle);
 
 #if BUILDFLAG(ENABLE_SUPERVISED_USERS)
-  bool is_subresource_request =
-      resource_type != content::RESOURCE_TYPE_MAIN_FRAME;
-  throttles->push_back(new SupervisedUserResourceThrottle(
-        request, !is_subresource_request,
-        io_data->supervised_user_url_filter()));
+  std::unique_ptr<content::ResourceThrottle> supervised_user_throttle =
+      SupervisedUserResourceThrottle::MaybeCreate(
+          request, resource_type, io_data->supervised_user_url_filter());
+  if (supervised_user_throttle)
+    throttles->push_back(supervised_user_throttle.release());
 #endif
 
 #if BUILDFLAG(ENABLE_EXTENSIONS)
@@ -774,7 +779,8 @@ void ChromeResourceDispatcherHostDelegate::OnResponseStarted(
 #endif
 
   if (io_data->resource_prefetch_predictor_observer())
-    io_data->resource_prefetch_predictor_observer()->OnResponseStarted(request);
+    io_data->resource_prefetch_predictor_observer()->OnResponseStarted(
+        request, info->GetWebContentsGetterForRequest());
 
   mod_pagespeed::RecordMetrics(info->GetResourceType(), request->url(),
                                request->response_headers());
@@ -800,7 +806,7 @@ void ChromeResourceDispatcherHostDelegate::OnRequestRedirected(
 
   if (io_data->resource_prefetch_predictor_observer()) {
     io_data->resource_prefetch_predictor_observer()->OnRequestRedirected(
-        redirect_url, request);
+        request, redirect_url, info->GetWebContentsGetterForRequest());
   }
 
   if (io_data->policy_header_helper())
