@@ -7,6 +7,7 @@
 #include <iterator>
 #include <utility>
 
+#include "base/debug/alias.h"
 #include "base/logging.h"
 #include "base/metrics/histogram_macros.h"
 #include "base/trace_event/trace_event.h"
@@ -20,7 +21,6 @@
 #include "components/subresource_filter/content/browser/content_subresource_filter_driver_factory.h"
 #include "content/public/browser/browser_thread.h"
 #include "content/public/browser/render_frame_host.h"
-#include "content/public/browser/resource_controller.h"
 #include "content/public/browser/resource_request_info.h"
 #include "content/public/browser/web_contents.h"
 #include "net/base/load_flags.h"
@@ -93,14 +93,15 @@ SafeBrowsingResourceThrottle::SafeBrowsingResourceThrottle(
     : state_(STATE_NONE),
       defer_state_(DEFERRED_NONE),
       threat_type_(safe_browsing::SB_THREAT_TYPE_SAFE),
-      database_manager_(sb_service->database_manager()),
+      database_manager_(safe_browsing::V4FeatureList::IsV4HybridEnabled()
+                            ? sb_service->v4_local_database_manager()
+                            : sb_service->database_manager()),
       ui_manager_(sb_service->ui_manager()),
       request_(request),
       resource_type_(resource_type),
       net_log_with_source_(
           net::NetLogWithSource::Make(request->net_log().net_log(),
-                                      NetLogSourceType::SAFE_BROWSING)),
-      v4_local_database_manager_(sb_service->v4_local_database_manager()) {}
+                                      NetLogSourceType::SAFE_BROWSING)) {}
 
 SafeBrowsingResourceThrottle::~SafeBrowsingResourceThrottle() {
   if (defer_state_ != DEFERRED_NONE) {
@@ -109,10 +110,6 @@ SafeBrowsingResourceThrottle::~SafeBrowsingResourceThrottle() {
 
   if (state_ == STATE_CHECKING_URL) {
     database_manager_->CancelCheck(this);
-    if (safe_browsing::V4FeatureList::IsParallelCheckEnabled()) {
-      v4_local_database_manager_->CancelCheck(this);
-    }
-
     EndNetLogEvent(NetLogEventType::SAFE_BROWSING_CHECKING_URL, "result",
                    "request_canceled");
   }
@@ -236,7 +233,17 @@ void SafeBrowsingResourceThrottle::OnCheckBrowseUrlResult(
     safe_browsing::SBThreatType threat_type,
     const safe_browsing::ThreatMetadata& metadata) {
   CHECK_EQ(state_, STATE_CHECKING_URL);
-  CHECK_EQ(url, url_being_checked_);
+  // TODO(vakh): The following base::debug::Alias() and CHECK calls should be
+  // removed after http://crbug.com/660293 is fixed.
+  CHECK(url.is_valid());
+  CHECK(url_being_checked_.is_valid());
+  if (url != url_being_checked_) {
+    char buf[2000];
+    snprintf(buf, sizeof(buf), "sbtr::ocbur:%s -- %s\n", url.spec().c_str(),
+             url_being_checked_.spec().c_str());
+    base::debug::Alias(buf);
+    CHECK(false) << "buf: " << buf;
+  }
 
   timer_.Stop();  // Cancel the timeout timer.
   threat_type_ = threat_type;
@@ -262,7 +269,7 @@ void SafeBrowsingResourceThrottle::OnCheckBrowseUrlResult(
 
   if (request_->load_flags() & net::LOAD_PREFETCH) {
     // Don't prefetch resources that fail safe browsing, disallow them.
-    controller()->Cancel();
+    Cancel();
     UMA_HISTOGRAM_ENUMERATION("SB2.ResourceTypes2.UnsafePrefetchCanceled",
                               resource_type_, content::RESOURCE_TYPE_LAST_TYPE);
     return;
@@ -274,7 +281,7 @@ void SafeBrowsingResourceThrottle::OnCheckBrowseUrlResult(
   const content::ResourceRequestInfo* info =
       content::ResourceRequestInfo::ForRequest(request_);
 
-  SafeBrowsingUIManager::UnsafeResource resource;
+  security_interstitials::UnsafeResource resource;
   resource.url = url;
   resource.original_url = request_->original_url();
   resource.redirect_urls = redirect_urls_;
@@ -300,7 +307,7 @@ void SafeBrowsingResourceThrottle::OnCheckBrowseUrlResult(
 void SafeBrowsingResourceThrottle::StartDisplayingBlockingPage(
     const base::WeakPtr<SafeBrowsingResourceThrottle>& throttle,
     scoped_refptr<SafeBrowsingUIManager> ui_manager,
-    const SafeBrowsingUIManager::UnsafeResource& resource) {
+    const security_interstitials::UnsafeResource& resource) {
   content::WebContents* web_contents = resource.web_contents_getter.Run();
   if (web_contents) {
     prerender::PrerenderContents* prerender_contents =
@@ -344,10 +351,6 @@ void SafeBrowsingResourceThrottle::StartDisplayingBlockingPage(
       base::Bind(&SafeBrowsingResourceThrottle::Cancel, throttle));
 }
 
-void SafeBrowsingResourceThrottle::Cancel() {
-  controller()->Cancel();
-}
-
 // SafeBrowsingService::UrlCheckCallback implementation, called on the IO
 // thread when the user has decided to proceed with the current request, or
 // go back.
@@ -361,7 +364,7 @@ void SafeBrowsingResourceThrottle::OnBlockingPageComplete(bool proceed) {
       ResumeRequest();
     }
   } else {
-    controller()->Cancel();
+    Cancel();
   }
 }
 
@@ -372,21 +375,19 @@ bool SafeBrowsingResourceThrottle::CheckUrl(const GURL& url) {
   // To reduce aggregate latency on mobile, check only the most dangerous
   // resource types.
   if (!database_manager_->CanCheckResourceType(resource_type_)) {
+    // TODO(vakh): Consider changing this metric to SafeBrowsing.V4ResourceType
+    // to be consistent with the other PVer4 metrics.
     UMA_HISTOGRAM_ENUMERATION("SB2.ResourceTypes2.Skipped", resource_type_,
                               content::RESOURCE_TYPE_LAST_TYPE);
     return true;
   }
 
-  bool succeeded_synchronously = database_manager_->CheckBrowseUrl(url, this);
+  // TODO(vakh): Consider changing this metric to SafeBrowsing.V4ResourceType to
+  // be consistent with the other PVer4 metrics.
   UMA_HISTOGRAM_ENUMERATION("SB2.ResourceTypes2.Checked", resource_type_,
                             content::RESOURCE_TYPE_LAST_TYPE);
 
-  if (safe_browsing::V4FeatureList::IsParallelCheckEnabled() &&
-      v4_local_database_manager_->CanCheckResourceType(resource_type_)) {
-    v4_local_database_manager_->CheckBrowseUrl(url, this);
-  }
-
-  if (succeeded_synchronously) {
+  if (database_manager_->CheckBrowseUrl(url, this)) {
     threat_type_ = safe_browsing::SB_THREAT_TYPE_SAFE;
     ui_manager_->LogPauseDelay(base::TimeDelta());  // No delay.
     return true;
@@ -411,9 +412,7 @@ void SafeBrowsingResourceThrottle::OnCheckUrlTimeout() {
   CHECK_EQ(state_, STATE_CHECKING_URL);
 
   database_manager_->CancelCheck(this);
-  if (safe_browsing::V4FeatureList::IsParallelCheckEnabled()) {
-    v4_local_database_manager_->CancelCheck(this);
-  }
+
   OnCheckBrowseUrlResult(url_being_checked_, safe_browsing::SB_THREAT_TYPE_SAFE,
                          safe_browsing::ThreatMetadata());
 }
@@ -438,6 +437,6 @@ void SafeBrowsingResourceThrottle::ResumeRequest() {
 
   if (resume) {
     defer_state_ = DEFERRED_NONE;
-    controller()->Resume();
+    Resume();
   }
 }
