@@ -5,7 +5,6 @@
 #ifndef CHROME_BROWSER_LOADER_SAFE_BROWSING_RESOURCE_THROTTLE_H_
 #define CHROME_BROWSER_LOADER_SAFE_BROWSING_RESOURCE_THROTTLE_H_
 
-#include <set>
 #include <string>
 #include <vector>
 
@@ -22,16 +21,10 @@
 #include "net/log/net_log_with_source.h"
 #include "url/gurl.h"
 
-class ResourceDispatcherHost;
-
 namespace net {
 class URLRequest;
 }
 
-namespace safe_browsing {
-class V4LocalDatabaseManager;
-}
-
 // SafeBrowsingResourceThrottle checks that URLs are "safe" before
 // navigating to them. To be considered "safe", a URL must not appear in the
 // malware/phishing blacklists (see SafeBrowsingService for details).
@@ -139,11 +132,7 @@ class SafeBrowsingResourceThrottle
   static void StartDisplayingBlockingPage(
       const base::WeakPtr<SafeBrowsingResourceThrottle>& throttle,
       scoped_refptr<safe_browsing::SafeBrowsingUIManager> ui_manager,
-      const safe_browsing::SafeBrowsingUIManager::UnsafeResource& resource);
-
-  // Called on the IO thread if the request turned out to be for a prerendered
-  // page.
-  void Cancel();
+      const security_interstitials::UnsafeResource& resource);
 
   // Resumes the request, by continuing the deferred action (either starting the
   // request, or following a redirect).
@@ -185,11 +174,6 @@ class SafeBrowsingResourceThrottle
   const content::ResourceType resource_type_;
   net::NetLogWithSource net_log_with_source_;
 
-  // TODO(vakh): The following set should be removed after fixing
-  // http://crbug.com/660293
-  // URLs that timed out waiting for a SafeBrowsing reputation check.
-  std::set<GURL> timed_out_urls_;
-
   DISALLOW_COPY_AND_ASSIGN(SafeBrowsingResourceThrottle);
 };
 
