@@ -16,7 +16,6 @@
 #include "base/logging.h"
 #include "base/memory/ptr_util.h"
 #include "base/memory/scoped_vector.h"
-#include "base/strings/stringprintf.h"
 #include "chrome/browser/android/tab_android.h"
 #include "chrome/browser/media/router/media_routes_observer.h"
 #include "chrome/browser/media/router/media_sinks_observer.h"
@@ -101,11 +100,9 @@ void MediaRouterAndroid::CreateRoute(
   bool is_incognito = web_contents
       && web_contents->GetBrowserContext()->IsOffTheRecord();
 
-  MediaRouteRequest* request = new MediaRouteRequest(
-      MediaSource(source_id),
-      presentation_id,
-      callbacks);
-  int route_request_id = route_requests_.Add(request);
+  int route_request_id =
+      route_requests_.Add(base::MakeUnique<MediaRouteRequest>(
+          MediaSource(source_id), presentation_id, callbacks));
 
   JNIEnv* env = base::android::AttachCurrentThread();
   ScopedJavaLocalRef<jstring> jsource_id =
@@ -159,11 +156,8 @@ void MediaRouterAndroid::JoinRoute(
   DVLOG(2) << "JoinRoute: " << source_id << ", " << presentation_id << ", "
            << origin.spec() << ", " << tab_id;
 
-  MediaRouteRequest* request = new MediaRouteRequest(
-      MediaSource(source_id),
-      presentation_id,
-      callbacks);
-  int request_id = route_requests_.Add(request);
+  int request_id = route_requests_.Add(base::MakeUnique<MediaRouteRequest>(
+      MediaSource(source_id), presentation_id, callbacks));
 
   JNIEnv* env = base::android::AttachCurrentThread();
   ScopedJavaLocalRef<jstring> jsource_id =
@@ -190,7 +184,7 @@ void MediaRouterAndroid::SendRouteMessage(
     const std::string& message,
     const SendRouteMessageCallback& callback) {
   int callback_id = message_callbacks_.Add(
-      new SendRouteMessageCallback(callback));
+      base::MakeUnique<SendRouteMessageCallback>(callback));
   JNIEnv* env = base::android::AttachCurrentThread();
   ScopedJavaLocalRef<jstring> jroute_id =
           base::android::ConvertUTF8ToJavaString(env, route_id);
@@ -204,8 +198,8 @@ void MediaRouterAndroid::SendRouteBinaryMessage(
     const MediaRoute::Id& route_id,
     std::unique_ptr<std::vector<uint8_t>> data,
     const SendRouteMessageCallback& callback) {
-  int callback_id =
-      message_callbacks_.Add(new SendRouteMessageCallback(callback));
+  int callback_id = message_callbacks_.Add(
+      base::MakeUnique<SendRouteMessageCallback>(callback));
   JNIEnv* env = base::android::AttachCurrentThread();
   ScopedJavaLocalRef<jstring> jroute_id =
       base::android::ConvertUTF8ToJavaString(env, route_id);
@@ -355,8 +349,8 @@ void MediaRouterAndroid::OnSinksReceived(
   auto it = sinks_observers_.find(source_urn);
   if (it != sinks_observers_.end()) {
     // TODO(imcheng): Pass origins to OnSinksUpdated (crbug.com/594858).
-    FOR_EACH_OBSERVER(MediaSinksObserver, *it->second,
-                      OnSinksUpdated(sinks_converted, std::vector<GURL>()));
+    for (auto& observer : *it->second)
+      observer.OnSinksUpdated(sinks_converted, std::vector<GURL>());
   }
 }
 
@@ -385,8 +379,8 @@ void MediaRouterAndroid::OnRouteCreated(
   route_requests_.Remove(jroute_request_id);
 
   active_routes_.push_back(route);
-  FOR_EACH_OBSERVER(MediaRoutesObserver, routes_observers_,
-      OnRoutesUpdated(active_routes_, std::vector<MediaRoute::Id>()));
+  for (auto& observer : routes_observers_)
+    observer.OnRoutesUpdated(active_routes_, std::vector<MediaRoute::Id>());
 }
 
 void MediaRouterAndroid::OnRouteRequestError(
@@ -419,8 +413,8 @@ void MediaRouterAndroid::OnRouteClosed(
       break;
     }
 
-  FOR_EACH_OBSERVER(MediaRoutesObserver, routes_observers_,
-      OnRoutesUpdated(active_routes_, std::vector<MediaRoute::Id>()));
+  for (auto& observer : routes_observers_)
+    observer.OnRoutesUpdated(active_routes_, std::vector<MediaRoute::Id>());
   NotifyPresentationConnectionStateChange(
       route_id, content::PRESENTATION_CONNECTION_STATE_TERMINATED);
 }
@@ -462,8 +456,8 @@ void MediaRouterAndroid::OnMessage(JNIEnv* env,
   std::vector<RouteMessage> messages(1);
   messages.front().type = RouteMessage::TEXT;
   messages.front().text = ConvertJavaStringToUTF8(env, jmessage);
-  FOR_EACH_OBSERVER(RouteMessageObserver, *observer_list,
-                    OnMessagesReceived(messages));
+  for (auto& observer : *observer_list)
+    observer.OnMessagesReceived(messages);
 }
 
 }  // namespace media_router
