@@ -8,16 +8,19 @@
 #include "content/public/browser/render_frame_host.h"
 #include "media/mojo/interfaces/output_protection.mojom.h"
 
+namespace chrome {
+class OutputProtectionProxy;
+}
+
 // Implements media::mojom::OutputProtection to check display links and
 // their statuses. On all platforms we'll check the network links. On ChromeOS
 // we'll also check the hardware links. Can only be used on the UI thread.
 class OutputProtectionImpl : public media::mojom::OutputProtection {
  public:
-  static void Create(
-      content::RenderFrameHost* render_frame_host,
-      mojo::InterfaceRequest<media::mojom::OutputProtection> request);
+  static void Create(content::RenderFrameHost* render_frame_host,
+                     media::mojom::OutputProtectionRequest request);
 
-  explicit OutputProtectionImpl(content::RenderFrameHost* render_frame_host);
+  OutputProtectionImpl(int render_process_id, int render_frame_id);
   ~OutputProtectionImpl() final;
 
   // media::mojom::OutputProtection implementation.
@@ -26,7 +29,23 @@ class OutputProtectionImpl : public media::mojom::OutputProtection {
                         const EnableProtectionCallback& callback) final;
 
  private:
-  content::RenderFrameHost* const render_frame_host_;
+  // Callbacks for QueryStatus and EnableProtection results.
+  // Note: These are bound using weak pointers so that we won't fire |callback|
+  // after the binding is destroyed.
+  void OnQueryStatusResult(const QueryStatusCallback& callback,
+                           bool success,
+                           uint32_t link_mask,
+                           uint32_t protection_mask);
+  void OnEnableProtectionResult(const EnableProtectionCallback& callback,
+                                bool success);
+
+  // Helper function to lazily create the |proxy_| and return it.
+  chrome::OutputProtectionProxy* GetProxy();
+
+  const int render_process_id_;
+  const int render_frame_id_;
+
+  std::unique_ptr<chrome::OutputProtectionProxy> proxy_;
 
   base::WeakPtrFactory<OutputProtectionImpl> weak_factory_;
 };
