@@ -6,15 +6,13 @@
 
 #include <string>
 
-#include "url/gurl.h"
-
 namespace media_router {
 
 MediaSource::MediaSource(const MediaSource::Id& source_id) : id_(source_id) {
 }
 
 MediaSource::MediaSource(const GURL& presentation_url)
-    : id_(presentation_url.spec()) {}
+    : id_(presentation_url.spec()), url_(presentation_url) {}
 
 MediaSource::~MediaSource() {}
 
@@ -22,6 +20,10 @@ MediaSource::Id MediaSource::id() const {
   return id_;
 }
 
+GURL MediaSource::url() const {
+  return url_;
+}
+
 bool MediaSource::operator==(const MediaSource& other) const {
   return id_ == other.id();
 }
