@@ -24,28 +24,28 @@
 #include "content/public/browser/web_contents_user_data.h"
 
 namespace content {
-class RenderFrameHost;
 class PresentationScreenAvailabilityListener;
 class WebContents;
 struct PresentationSessionInfo;
 struct PresentationSessionMessage;
 }  // namespace content
 
+namespace url {
+class Origin;
+}  // namespace url
+
 namespace media_router {
 
 class MediaRoute;
-class MediaSinksObserver;
 class PresentationFrameManager;
 class RouteRequestResult;
 
-// Implementation of PresentationServiceDelegate that interfaces an
-// instance of WebContents with the Chrome Media Router. It uses the Media
-// Router to handle presentation API calls forwarded from
-// PresentationServiceImpl. In addition, it also
-// provides default presentation URL that is required for creating
-// browser-initiated sessions.
-// It is scoped to the lifetime of a WebContents, and is managed by the
-// associated WebContents.
+// Implementation of PresentationServiceDelegate that interfaces an instance of
+// WebContents with the Chrome Media Router. It uses the Media Router to handle
+// presentation API calls forwarded from PresentationServiceImpl. In addition,
+// it also provides default presentation URL that is required for creating
+// browser-initiated sessions.  It is scoped to the lifetime of a WebContents,
+// and is managed by the associated WebContents.
 class PresentationServiceDelegateImpl
     : public content::WebContentsUserData<PresentationServiceDelegateImpl>,
       public content::PresentationServiceDelegate {
@@ -93,18 +93,18 @@ class PresentationServiceDelegateImpl
   void SetDefaultPresentationUrls(
       int render_process_id,
       int render_frame_id,
-      const std::vector<std::string>& default_presentation_urls,
+      const std::vector<GURL>& default_presentation_urls,
       const content::PresentationSessionStartedCallback& callback) override;
   void StartSession(
       int render_process_id,
       int render_frame_id,
-      const std::vector<std::string>& presentation_urls,
+      const std::vector<GURL>& presentation_urls,
       const content::PresentationSessionStartedCallback& success_cb,
       const content::PresentationSessionErrorCallback& error_cb) override;
   void JoinSession(
       int render_process_id,
       int render_frame_id,
-      const std::vector<std::string>& presentation_urls,
+      const std::vector<GURL>& presentation_urls,
       const std::string& presentation_id,
       const content::PresentationSessionStartedCallback& success_cb,
       const content::PresentationSessionErrorCallback& error_cb) override;
@@ -185,7 +185,8 @@ class PresentationServiceDelegateImpl
   void OnJoinRouteResponse(
       int render_process_id,
       int render_frame_id,
-      const content::PresentationSessionInfo& session,
+      const GURL& presentation_url,
+      const std::string& presentation_id,
       const content::PresentationSessionStartedCallback& success_cb,
       const content::PresentationSessionErrorCallback& error_cb,
       const RouteRequestResult& result);
@@ -195,7 +196,12 @@ class PresentationServiceDelegateImpl
       int render_frame_id,
       const content::PresentationSessionStartedCallback& success_cb,
       const content::PresentationSessionInfo& new_session,
-      const MediaRoute::Id& route_id);
+      const MediaRoute& route);
+
+#if !defined(OS_ANDROID)
+  // Returns true if auto-join requests should be cancelled for |origin|.
+  bool ShouldCancelAutoJoinForOrigin(const url::Origin& origin) const;
+#endif
 
   // References to the WebContents that owns this instance, and associated
   // browser profile's MediaRouter instance.
