@@ -36,6 +36,7 @@
 
 #if defined(OS_CHROMEOS)
 #include "ash/shell.h"
+#include "chrome/browser/media/public_session_media_access_handler.h"
 #endif  // defined(OS_CHROMEOS)
 
 #if BUILDFLAG(ENABLE_EXTENSIONS)
@@ -84,7 +85,12 @@ MediaCaptureDevicesDispatcher::MediaCaptureDevicesDispatcher()
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
 
 #if BUILDFLAG(ENABLE_EXTENSIONS)
+#if defined(OS_CHROMEOS)
+  // Wrapper around ExtensionMediaAccessHandler used in Public Sessions.
+  media_access_handlers_.push_back(new PublicSessionMediaAccessHandler());
+#else
   media_access_handlers_.push_back(new ExtensionMediaAccessHandler());
+#endif
   media_access_handlers_.push_back(new DesktopCaptureAccessHandler());
   media_access_handlers_.push_back(new TabCaptureAccessHandler());
 #endif
