@@ -17,6 +17,7 @@
 #include "base/macros.h"
 #include "build/build_config.h"
 #include "chrome/browser/media/webrtc/rtp_dump_type.h"
+#include "chrome/browser/media/webrtc/webrtc_event_log_handler.h"
 #include "chrome/browser/media/webrtc/webrtc_rtp_dump_handler.h"
 #include "chrome/browser/media/webrtc/webrtc_text_log_handler.h"
 #include "content/public/browser/browser_message_filter.h"
@@ -118,6 +119,24 @@ class WebRtcLoggingHandlerHost : public content::BrowserMessageFilter {
                    size_t packet_length,
                    bool incoming);
 
+  // Starts an RTC event log for each peerconnection on this RenderProcessHost.
+  // The call writes the most recent events and all future events for |duration|
+  // seconds to a file. After |duration|, recording stops and |callback| is
+  // invoked. If |duration| is zero, |callback| is run immediately and the
+  // logging will continue until StopWebRtcEventLogging() is explicitly invoked.
+  // Must be called on the UI thread.
+  void StartWebRtcEventLogging(
+      base::TimeDelta duration,
+      const WebRtcEventLogHandler::RecordingDoneCallback& callback,
+      const WebRtcEventLogHandler::RecordingErrorCallback& error_callback);
+
+  // Stops the RTC event logs. Must be called on the UI thread.
+  // |callback| is invoked once recording stops. If no recording was in
+  // progress, |error_callback| is invoked instead of |callback|.
+  void StopWebRtcEventLogging(
+      const WebRtcEventLogHandler::RecordingDoneCallback& callback,
+      const WebRtcEventLogHandler::RecordingErrorCallback& error_callback);
+
  private:
   friend class content::BrowserThread;
   friend class base::DeleteHelper<WebRtcLoggingHandlerHost>;
@@ -191,6 +210,10 @@ class WebRtcLoggingHandlerHost : public content::BrowserMessageFilter {
   // Only accessed on the IO thread.
   bool upload_log_on_render_close_;
 
+  // The event log handler provides an interface for starting and stopping
+  // the WebRTC event log. It is a scoped_refptr to allow posting tasks.
+  scoped_refptr<WebRtcEventLogHandler> event_log_handler_;
+
   // The text log handler owns the WebRtcLogBuffer object and keeps track of
   // the logging state. It is a scoped_refptr to allow posting tasks.
   scoped_refptr<WebRtcTextLogHandler> text_log_handler_;
@@ -205,7 +228,6 @@ class WebRtcLoggingHandlerHost : public content::BrowserMessageFilter {
   // Ownership lies with the browser process.
   WebRtcLogUploader* const log_uploader_;
 
-
   DISALLOW_COPY_AND_ASSIGN(WebRtcLoggingHandlerHost);
 };
 
