@@ -27,6 +27,7 @@
 #include "base/time/time.h"
 #include "chrome/browser/chromeos/arc/process/arc_process.h"
 #include "chrome/browser/chromeos/arc/process/arc_process_service.h"
+#include "chrome/browser/memory/memory_kills_monitor.h"
 #include "chrome/browser/memory/tab_stats.h"
 #include "chrome/browser/ui/browser.h"
 #include "chrome/browser/ui/browser_list.h"
@@ -35,8 +36,8 @@
 #include "chrome/common/chrome_features.h"
 #include "chromeos/dbus/dbus_thread_manager.h"
 #include "components/arc/arc_bridge_service.h"
+#include "components/arc/arc_service_manager.h"
 #include "components/arc/common/process.mojom.h"
-#include "components/arc/metrics/oom_kills_histogram.h"
 #include "components/exo/shell_surface.h"
 #include "content/public/browser/browser_thread.h"
 #include "content/public/browser/notification_service.h"
@@ -73,7 +74,7 @@ aura::client::ActivationClient* GetActivationClient() {
 
 // Checks if a window renders ARC apps.
 bool IsArcWindow(aura::Window* window) {
-  if (!window || window->name() != kExoShellSurfaceWindowName)
+  if (!window || window->GetName() != kExoShellSurfaceWindowName)
     return false;
   std::string application_id = exo::ShellSurface::GetApplicationId(window);
   return base::StartsWith(application_id, kArcProcessNamePrefix,
@@ -250,24 +251,16 @@ int TabManagerDelegate::MemoryStat::LowMemoryMarginKB() {
 int TabManagerDelegate::MemoryStat::TargetMemoryToFreeKB() {
   static const int kRamVsSwapWeight = 4;
   static const char kMinFilelistConfig[] = "/proc/sys/vm/min_filelist_kbytes";
-  static const char kMinFreeKbytes[] = "/proc/sys/vm/min_free_kbytes";
 
   base::SystemMemoryInfoKB system_mem;
   base::GetSystemMemoryInfo(&system_mem);
   const int file_mem_kb = system_mem.active_file + system_mem.inactive_file;
   const int min_filelist_kb = ReadIntFromFile(kMinFilelistConfig, 0);
-  const int min_free_kb = ReadIntFromFile(kMinFreeKbytes, 0);
   // Calculate current available memory in system.
   // File-backed memory should be easy to reclaim, unless they're dirty.
-  // TODO(cylee): On ChromeOS, kernel reports low memory condition when
-  // available memory is low. The following formula duplicates the logic in
-  // kernel to calculate how much memory should be released. In the future,
-  // kernel should try to report the amount of memory to release directly to
-  // eliminate the duplication here.
   const int available_mem_kb = system_mem.free +
       file_mem_kb - system_mem.dirty - min_filelist_kb +
-      system_mem.swap_free / kRamVsSwapWeight -
-      min_free_kb;
+      system_mem.swap_free / kRamVsSwapWeight;
 
   return LowMemoryMarginKB() - available_mem_kb;
 }
@@ -281,36 +274,6 @@ int TabManagerDelegate::MemoryStat::EstimatedMemoryFreedKB(
   return mem_usage.priv;
 }
 
-class TabManagerDelegate::UmaReporter {
- public:
-  UmaReporter() : total_kills_(0) {}
-  ~UmaReporter() {}
-
-  void ReportKill(const int memory_freed);
-
- private:
-  base::Time last_kill_time_;
-  int total_kills_;
-};
-
-void TabManagerDelegate::UmaReporter::ReportKill(const int memory_freed) {
-  base::Time now = base::Time::Now();
-  const TimeDelta time_delta =
-      last_kill_time_.is_null() ?
-      TimeDelta::FromSeconds(arc::kMaxOomMemoryKillTimeDeltaSecs) :
-      (now - last_kill_time_);
-  UMA_HISTOGRAM_OOM_KILL_TIME_INTERVAL(
-            "Arc.LowMemoryKiller.TimeDelta", time_delta);
-  last_kill_time_ = now;
-
-  ++total_kills_;
-  UMA_HISTOGRAM_CUSTOM_COUNTS(
-      "Arc.LowMemoryKiller.Count", total_kills_, 1, 1000, 1001);
-
-  UMA_HISTOGRAM_MEMORY_KB("Arc.LowMemoryKiller.FreedSize",
-                          memory_freed);
-}
-
 TabManagerDelegate::TabManagerDelegate(
     const base::WeakPtr<TabManager>& tab_manager)
   : TabManagerDelegate(tab_manager, new MemoryStat()) {
@@ -322,7 +285,6 @@ TabManagerDelegate::TabManagerDelegate(
     : tab_manager_(tab_manager),
       focused_process_(new FocusedProcess()),
       mem_stat_(mem_stat),
-      uma_(new UmaReporter()),
       weak_ptr_factory_(this) {
   registrar_.Add(this, content::NOTIFICATION_RENDERER_PROCESS_CLOSED,
                  content::NotificationService::AllBrowserContextsAndSources());
@@ -584,13 +546,14 @@ TabManagerDelegate::GetSortedCandidates(
 }
 
 bool TabManagerDelegate::KillArcProcess(const int nspid) {
-  auto* arc_bridge_service = arc::ArcBridgeService::Get();
-  if (!arc_bridge_service)
+  auto* arc_service_manager = arc::ArcServiceManager::Get();
+  if (!arc_service_manager)
     return false;
 
   auto* arc_process_instance =
-      arc_bridge_service->process()->GetInstanceForMethod(
-          "KillProcess", kMinVersionForKillProcess);
+      arc_service_manager->arc_bridge_service()
+          ->process()
+          ->GetInstanceForMethod("KillProcess", kMinVersionForKillProcess);
   if (!arc_process_instance)
     return false;
 
@@ -614,8 +577,7 @@ void TabManagerDelegate::LowMemoryKillImpl(
     const TabStatsList& tab_list,
     const std::vector<arc::ArcProcess>& arc_processes) {
 
-  VLOG(2) << "LowMemoryKillImpl";
-
+  VLOG(2) << "LowMemoryKilleImpl";
   const std::vector<TabManagerDelegate::Candidate> candidates =
       GetSortedCandidates(tab_list, arc_processes);
 
@@ -640,7 +602,7 @@ void TabManagerDelegate::LowMemoryKillImpl(
           mem_stat_->EstimatedMemoryFreedKB(it->app()->pid());
       if (KillArcProcess(it->app()->nspid())) {
         target_memory_to_free_kb -= estimated_memory_freed_kb;
-        uma_->ReportKill(estimated_memory_freed_kb);
+        MemoryKillsMonitor::LogLowMemoryKill("APP", estimated_memory_freed_kb);
         VLOG(2) << "Killed " << *it;
       }
     } else {
@@ -652,7 +614,7 @@ void TabManagerDelegate::LowMemoryKillImpl(
           mem_stat_->EstimatedMemoryFreedKB(it->tab()->renderer_handle);
       if (KillTab(tab_id)) {
         target_memory_to_free_kb -= estimated_memory_freed_kb;
-        uma_->ReportKill(estimated_memory_freed_kb);
+        MemoryKillsMonitor::LogLowMemoryKill("TAB", estimated_memory_freed_kb);
         VLOG(2) << "Killed " << *it;
       }
     }
