@@ -20,7 +20,7 @@
 #include "components/metrics/enabled_state_provider.h"
 #include "components/metrics/metrics_state_manager.h"
 #include "components/prefs/pref_service.h"
-#include "components/rappor/rappor_service.h"
+#include "components/rappor/rappor_service_impl.h"
 #include "components/variations/service/variations_service.h"
 #include "components/variations/variations_associated_data.h"
 #include "components/version_info/version_info.h"
@@ -188,18 +188,18 @@ bool ChromeMetricsServicesManagerClient::GetSamplingRatePerMille(int* rate) {
   return true;
 }
 
-std::unique_ptr<rappor::RapporService>
-ChromeMetricsServicesManagerClient::CreateRapporService() {
+std::unique_ptr<rappor::RapporServiceImpl>
+ChromeMetricsServicesManagerClient::CreateRapporServiceImpl() {
   DCHECK(thread_checker_.CalledOnValidThread());
-  return base::WrapUnique(new rappor::RapporService(
-      local_state_, base::Bind(&chrome::IsIncognitoSessionActive)));
+  return base::MakeUnique<rappor::RapporServiceImpl>(
+      local_state_, base::Bind(&chrome::IsIncognitoSessionActive));
 }
 
 std::unique_ptr<variations::VariationsService>
 ChromeMetricsServicesManagerClient::CreateVariationsService() {
   DCHECK(thread_checker_.CalledOnValidThread());
   return variations::VariationsService::Create(
-      base::WrapUnique(new ChromeVariationsServiceClient()), local_state_,
+      base::MakeUnique<ChromeVariationsServiceClient>(), local_state_,
       GetMetricsStateManager(), switches::kDisableBackgroundNetworking,
       chrome_variations::CreateUIStringOverrider());
 }
@@ -210,6 +210,11 @@ ChromeMetricsServicesManagerClient::CreateMetricsServiceClient() {
   return ChromeMetricsServiceClient::Create(GetMetricsStateManager());
 }
 
+std::unique_ptr<const base::FieldTrial::EntropyProvider>
+ChromeMetricsServicesManagerClient::CreateEntropyProvider() {
+  return GetMetricsStateManager()->CreateDefaultEntropyProvider();
+}
+
 net::URLRequestContextGetter*
 ChromeMetricsServicesManagerClient::GetURLRequestContext() {
   return g_browser_process->system_request_context();
