@@ -56,10 +56,11 @@ class LeakDetectorControllerTest : public ::testing::Test {
 // initializes class LeakDetector, which can only be initialized once, enforced
 // by an internal CHECK. Multiple initializations of LeakDetectorController in
 // the same process will result in multiple initializations of class
-// LeakDetector.
+// LeakDetector. It has to be Leaky as running its destructor will otherwise
+// DCHECK when called outside the scope of a TestBrowserThreadBundle.
 //
 // See src/components/metrics/leak_detector/leak_detector.h for more info.
-base::LazyInstance<TestLeakDetectorController> g_instance =
+base::LazyInstance<TestLeakDetectorController>::Leaky g_instance =
     LAZY_INSTANCE_INITIALIZER;
 
 TEST_F(LeakDetectorControllerTest, SingleReport) {
