@@ -361,11 +361,11 @@ void ChromeNetworkDelegate::OnResponseStarted(net::URLRequest* request,
 
 void ChromeNetworkDelegate::OnNetworkBytesReceived(net::URLRequest* request,
                                                    int64_t bytes_received) {
-#if defined(ENABLE_TASK_MANAGER)
+#if !defined(OS_ANDROID)
   // Note: Currently, OnNetworkBytesReceived is only implemented for HTTP jobs,
   // not FTP or other types, so those kinds of bytes will not be reported here.
   task_manager::TaskManagerInterface::OnRawBytesRead(*request, bytes_received);
-#endif  // defined(ENABLE_TASK_MANAGER)
+#endif  // !defined(OS_ANDROID)
 
   ReportDataUsageStats(request, 0 /* tx_bytes */, bytes_received);
 }
@@ -542,10 +542,11 @@ bool ChromeNetworkDelegate::OnCanEnablePrivacyMode(
   if (!cookie_settings_.get())
     return false;
 
-  bool reading_cookie_allowed = cookie_settings_->IsReadingCookieAllowed(
-      url, first_party_for_cookies);
-  bool setting_cookie_allowed = cookie_settings_->IsSettingCookieAllowed(
-      url, first_party_for_cookies);
+  bool reading_cookie_allowed = false;
+  bool setting_cookie_allowed = false;
+  cookie_settings_->GetReadingAndSettingCookieAllowed(
+      url, first_party_for_cookies, &reading_cookie_allowed,
+      &setting_cookie_allowed);
   bool privacy_mode = !(reading_cookie_allowed && setting_cookie_allowed);
   return privacy_mode;
 }
