@@ -27,12 +27,10 @@
 #include "url/gurl.h"
 
 #if BUILDFLAG(ANDROID_JAVA_UI)
-#include "chrome/browser/android/offline_pages/offline_page_model_factory.h"
-#include "chrome/browser/android/tab_android.h"
-#include "components/offline_pages/client_namespace_constants.h"
-#include "components/offline_pages/offline_page_feature.h"
-#include "components/offline_pages/offline_page_item.h"
-#include "components/offline_pages/offline_page_model.h"
+#include "base/guid.h"
+#include "chrome/browser/android/offline_pages/request_coordinator_factory.h"
+#include "components/offline_pages/core/background/request_coordinator.h"
+#include "components/offline_pages/core/client_namespace_constants.h"
 #endif  // BUILDFLAG(ANDROID_JAVA_UI)
 
 using content::BrowserContext;
@@ -93,7 +91,7 @@ void NetErrorTabHelper::RenderFrameCreated(
   if (render_frame_host->GetParent())
     return;
 
-  mojom::NetworkDiagnosticsClientAssociatedPtr client;
+  chrome::mojom::NetworkDiagnosticsClientAssociatedPtr client;
   render_frame_host->GetRemoteAssociatedInterfaces()->GetInterface(&client);
   client->SetCanShowNetworkDiagnosticsDialog(CanShowNetworkDiagnosticsDialog());
 }
@@ -108,10 +106,6 @@ void NetErrorTabHelper::DidStartNavigation(
     error_page::RecordEvent(
         error_page::NETWORK_ERROR_PAGE_BROWSER_INITIATED_RELOAD);
   }
-
-#if BUILDFLAG(ANDROID_JAVA_UI)
-  UpdateHasOfflinePages(navigation_handle->GetFrameTreeNodeId());
-#endif  // BUILDFLAG(ANDROID_JAVA_UI)
 }
 
 void NetErrorTabHelper::DidFinishNavigation(
@@ -147,7 +141,7 @@ bool NetErrorTabHelper::OnMessageReceived(
 #if BUILDFLAG(ANDROID_JAVA_UI)
   bool handled = true;
   IPC_BEGIN_MESSAGE_MAP(NetErrorTabHelper, message)
-    IPC_MESSAGE_HANDLER(ChromeViewHostMsg_ShowOfflinePages, ShowOfflinePages)
+    IPC_MESSAGE_HANDLER(ChromeViewHostMsg_DownloadPageLater, DownloadPageLater)
     IPC_MESSAGE_UNHANDLED(handled = false)
   IPC_END_MESSAGE_MAP()
 
@@ -214,6 +208,23 @@ void NetErrorTabHelper::OnDnsProbeFinished(DnsProbeStatus result) {
     SendInfo();
 }
 
+#if BUILDFLAG(ANDROID_JAVA_UI)
+void NetErrorTabHelper::DownloadPageLater() {
+  // Makes sure that this is coming from an error page.
+  content::NavigationEntry* entry =
+      web_contents()->GetController().GetLastCommittedEntry();
+  if (!entry || entry->GetPageType() != content::PAGE_TYPE_ERROR)
+    return;
+
+  // Only download the page for HTTP/HTTPS URLs.
+  GURL url(entry->GetVirtualURL());
+  if (!url.SchemeIsHTTPOrHTTPS())
+    return;
+
+  DownloadPageLaterHelper(url);
+}
+#endif  // BUILDFLAG(ANDROID_JAVA_UI)
+
 void NetErrorTabHelper::InitializePref(WebContents* contents) {
   DCHECK(contents);
 
@@ -266,39 +277,18 @@ void NetErrorTabHelper::RunNetworkDiagnosticsHelper(
 }
 
 #if BUILDFLAG(ANDROID_JAVA_UI)
-void NetErrorTabHelper::UpdateHasOfflinePages(int frame_tree_node_id) {
-  // TODO(chili): remove entirely in M55 if AsyncLoading does not need this.
-  SetHasOfflinePages(frame_tree_node_id, false);
+void NetErrorTabHelper::DownloadPageLaterHelper(const GURL& page_url) {
+  offline_pages::RequestCoordinator* request_coordinator =
+      offline_pages::RequestCoordinatorFactory::GetForBrowserContext(
+          web_contents()->GetBrowserContext());
+  DCHECK(request_coordinator) << "No RequestCoordinator for SavePageLater";
+  offline_pages::ClientId client_id(
+      offline_pages::kAsyncNamespace, base::GenerateGUID());
+  request_coordinator->SavePageLater(
+      page_url, client_id, true /*user_requested*/,
+      offline_pages::RequestCoordinator::RequestAvailability::
+          ENABLED_FOR_OFFLINER);
 }
-
-void NetErrorTabHelper::SetHasOfflinePages(int frame_tree_node_id,
-                                           bool has_offline_pages) {
-  content::RenderFrameHost* render_frame_host =
-      web_contents()->FindFrameByFrameTreeNodeId(frame_tree_node_id);
-  if (render_frame_host == nullptr)
-    return;
-
-  render_frame_host->Send(new ChromeViewMsg_SetHasOfflinePages(
-      render_frame_host->GetRoutingID(), has_offline_pages));
-}
-
-void NetErrorTabHelper::ShowOfflinePages() {
-  // Makes sure that this is coming from an error page.
-  if (!IsFromErrorPage())
-    return;
-
-  DCHECK(web_contents());
-  TabAndroid* tab = TabAndroid::FromWebContents(web_contents());
-  if (tab)
-    tab->ShowOfflinePages();
-}
-
-bool NetErrorTabHelper::IsFromErrorPage() const {
-  content::NavigationEntry* entry =
-      web_contents()->GetController().GetLastCommittedEntry();
-  return entry && (entry->GetPageType() == content::PAGE_TYPE_ERROR);
-}
-
 #endif  // BUILDFLAG(ANDROID_JAVA_UI)
 
 }  // namespace chrome_browser_net
