@@ -14,7 +14,7 @@
 #include "components/ntp_snippets/category_factory.h"
 #include "components/ntp_snippets/mock_content_suggestions_provider_observer.h"
 #include "components/ntp_snippets/offline_pages/offline_pages_test_utils.h"
-#include "components/offline_pages/client_namespace_constants.h"
+#include "components/offline_pages/core/client_namespace_constants.h"
 #include "components/prefs/testing_pref_service.h"
 #include "content/public/test/mock_download_item.h"
 #include "content/public/test/mock_download_manager.h"
@@ -135,8 +135,9 @@ OfflinePageItem CreateDummyOfflinePage(int id) {
 std::vector<OfflinePageItem> CreateDummyOfflinePages(
     const std::vector<int>& ids) {
   std::vector<OfflinePageItem> result;
-  for (int id : ids)
+  for (int id : ids) {
     result.push_back(CreateDummyOfflinePage(id));
+  }
 
   return result;
 }
@@ -187,8 +188,9 @@ class ObservedMockDownloadManager : public MockDownloadManager {
  public:
   ObservedMockDownloadManager() {}
   ~ObservedMockDownloadManager() override {
-    for (auto& observer : observers_)
+    for (auto& observer : observers_) {
       observer.ManagerGoingDown(this);
+    }
   }
 
   // Observer accessors.
@@ -201,8 +203,9 @@ class ObservedMockDownloadManager : public MockDownloadManager {
   }
 
   void NotifyDownloadCreated(DownloadItem* item) {
-    for (auto& observer : observers_)
+    for (auto& observer : observers_) {
       observer.OnDownloadCreated(this, item);
+    }
   }
 
   std::vector<std::unique_ptr<FakeDownloadItem>>* mutable_items() {
@@ -215,8 +218,9 @@ class ObservedMockDownloadManager : public MockDownloadManager {
 
   void GetAllDownloads(std::vector<DownloadItem*>* all_downloads) override {
     all_downloads->clear();
-    for (const auto& item : items_)
+    for (const auto& item : items_) {
       all_downloads->push_back(item.get());
+    }
   }
 
  private:
@@ -272,9 +276,10 @@ class DownloadSuggestionsProviderTest : public testing::Test {
     provider_->OfflinePageModelLoaded(&offline_pages_model_);
   }
 
-  void FireOfflinePageModelChanged() {
+  void AddOfflinePage(const offline_pages::OfflinePageItem& added_page) {
     DCHECK(provider_);
-    provider_->OfflinePageModelChanged(&offline_pages_model_);
+    offline_pages_model_.mutable_items()->push_back(added_page);
+    provider_->OfflinePageAdded(&offline_pages_model_, added_page);
   }
 
   void FireOfflinePageDeleted(const OfflinePageItem& item) {
@@ -289,8 +294,9 @@ class DownloadSuggestionsProviderTest : public testing::Test {
 
   void FireDownloadsCreated(
       const std::vector<std::unique_ptr<FakeDownloadItem>>& items) {
-    for (const auto& item : items)
+    for (const auto& item : items) {
       FireDownloadCreated(item.get());
+    }
   }
 
   ContentSuggestion::ID GetDummySuggestionId(int id, bool is_offline_page) {
@@ -520,8 +526,9 @@ TEST_F(DownloadSuggestionsProviderTest,
       *observer(),
       OnNewSuggestions(_, downloads_category(),
                        UnorderedElementsAre(HasUrl("http://dummy.com/2"),
+                                            HasUrl("http://dummy.com/3"),
                                             HasUrl("http://download.com/2"))));
-  FireOfflinePageModelChanged();
+  AddOfflinePage(CreateDummyOfflinePage(3));
 }
 
 TEST_F(DownloadSuggestionsProviderTest, ShouldReturnDismissedSuggestions) {
@@ -612,9 +619,10 @@ TEST_F(DownloadSuggestionsProviderTest,
       *observer(),
       OnNewSuggestions(_, downloads_category(),
                        UnorderedElementsAre(HasUrl("http://dummy.com/2"),
+                                            HasUrl("http://dummy.com/3"),
                                             HasUrl("http://download.com/1"),
                                             HasUrl("http://download.com/2"))));
-  FireOfflinePageModelChanged();
+  AddOfflinePage(CreateDummyOfflinePage(3));
 }
 
 TEST_F(DownloadSuggestionsProviderTest, ShouldReplaceDismissedItemWithNewData) {
@@ -640,18 +648,20 @@ TEST_F(DownloadSuggestionsProviderTest, ShouldReplaceDismissedItemWithNewData) {
 
   provider()->DismissSuggestion(
       GetDummySuggestionId(1, /*is_offline_page=*/false));
+  provider()->DismissSuggestion(
+      GetDummySuggestionId(2, /*is_offline_page=*/false));
 
   // The provider is not notified about the 6th item, however, it must report
   // it now.
   EXPECT_CALL(
       *observer(),
       OnNewSuggestions(_, downloads_category(),
-                       UnorderedElementsAre(HasUrl("http://download.com/2"),
+                       UnorderedElementsAre(HasUrl("http://dummy.com/1"),
                                             HasUrl("http://download.com/3"),
                                             HasUrl("http://download.com/4"),
                                             HasUrl("http://download.com/5"),
                                             HasUrl("http://download.com/6"))));
-  FireOfflinePageModelChanged();
+  AddOfflinePage(CreateDummyOfflinePage(1));
 }
 
 TEST_F(DownloadSuggestionsProviderTest,
@@ -737,20 +747,21 @@ TEST_F(DownloadSuggestionsProviderTest, ShouldReplaceRemovedItemWithNewData) {
   EXPECT_CALL(
       *observer(),
       OnNewSuggestions(_, downloads_category(),
-                       UnorderedElementsAre(HasUrl("http://download.com/1"),
+                       UnorderedElementsAre(HasUrl("http://dummy.com/6"),
+                                            HasUrl("http://download.com/1"),
                                             HasUrl("http://download.com/2"),
                                             HasUrl("http://download.com/3"),
-                                            HasUrl("http://download.com/4"),
-                                            HasUrl("http://download.com/5"))));
-  FireOfflinePageModelChanged();
+                                            HasUrl("http://download.com/4"))));
+  AddOfflinePage(CreateDummyOfflinePage(6));
 }
 
 TEST_F(DownloadSuggestionsProviderTest, ShouldPruneOfflinePagesDismissedIDs) {
   IgnoreOnCategoryStatusChangedToAvailable();
   IgnoreOnSuggestionInvalidated();
 
-  *(offline_pages_model()->mutable_items()) =
-      CreateDummyOfflinePages({1, 2, 3});
+  auto offline_pages = CreateDummyOfflinePages({1, 2, 3});
+
+  *(offline_pages_model()->mutable_items()) = offline_pages;
   EXPECT_CALL(*observer(), OnNewSuggestions(_, downloads_category(),
                                             UnorderedElementsAre(
                                                 HasUrl("http://dummy.com/1"),
@@ -766,17 +777,9 @@ TEST_F(DownloadSuggestionsProviderTest, ShouldPruneOfflinePagesDismissedIDs) {
       GetDummySuggestionId(3, /*is_offline_page=*/true));
   EXPECT_THAT(GetDismissedSuggestions(), SizeIs(3));
 
-  // Prune on getting all offline pages. Note that the first suggestion is not
-  // removed from |offline_pages_model| storage, because otherwise
-  // |GetDismissedSuggestions| cannot return it.
-  EXPECT_CALL(*observer(),
-              OnNewSuggestions(_, downloads_category(), IsEmpty()));
-
-  // TODO(vitaliii): Add the first suggestion back, so that
-  // GetDismissedSuggestions can return it.
-  *(offline_pages_model()->mutable_items()) =
-      CreateDummyOfflinePages({2, 3});
-  FireOfflinePageModelChanged();
+  // Note that the first suggestion is not removed from |offline_pages_model|
+  // storage, because otherwise |GetDismissedSuggestions| cannot return it.
+  FireOfflinePageDeleted(offline_pages[0]);
   EXPECT_THAT(GetDismissedSuggestions(), SizeIs(2));
 
   // Prune when offline page is deleted.
