@@ -15,7 +15,6 @@
 #include "base/files/scoped_temp_dir.h"
 #include "base/memory/ptr_util.h"
 #include "base/run_loop.h"
-#include "base/stl_util.h"
 #include "base/strings/string_util.h"
 #include "base/strings/stringprintf.h"
 #include "base/strings/utf_string_conversions.h"
@@ -399,10 +398,6 @@ class PasswordStoreXTest : public testing::TestWithParam<BackendType> {
   base::ScopedTempDir temp_dir_;
 };
 
-ACTION(STLDeleteElements0) {
-  base::STLDeleteContainerPointers(arg0.begin(), arg0.end());
-}
-
 TEST_P(PasswordStoreXTest, Notifications) {
   std::unique_ptr<password_manager::LoginDatabase> login_db(
       new password_manager::LoginDatabase(test_login_db_file_path()));
