@@ -11,20 +11,17 @@
 #include <string>
 #include <vector>
 
-#include "base/containers/hash_tables.h"
 #include "base/files/file_path.h"
-#include "base/memory/ref_counted.h"
 #include "base/memory/singleton.h"
 #include "base/synchronization/lock.h"
-#include "build/build_config.h"
+#include "chrome/browser/plugins/plugin_prefs.h"
 #include "content/public/browser/notification_observer.h"
 #include "content/public/browser/notification_registrar.h"
 #include "content/public/browser/plugin_service_filter.h"
 #include "content/public/common/webplugininfo.h"
 #include "url/gurl.h"
+#include "url/origin.h"
 
-class HostContentSettingsMap;
-class PluginPrefs;
 class Profile;
 
 namespace content {
@@ -36,6 +33,11 @@ class WebContents;
 class ChromePluginServiceFilter : public content::PluginServiceFilter,
                                   public content::NotificationObserver {
  public:
+  // Public for testing purposes.
+  static const char kEngagementSettingAllowedHistogram[];
+  static const char kEngagementSettingBlockedHistogram[];
+  static const char kEngagementNoSettingHistogram[];
+
   static ChromePluginServiceFilter* GetInstance();
 
   // This method should be called on the UI thread.
@@ -63,13 +65,13 @@ class ChromePluginServiceFilter : public content::PluginServiceFilter,
                            const std::string& identifier);
 
   // PluginServiceFilter implementation.
-  // If |url| is not available, the same GURL passed as |policy_url| should be
-  // passed.
+  // If |plugin_content_url| is not available, pass the same URL used to
+  // generate |main_frame_origin|. These parameters may be empty.
   bool IsPluginAvailable(int render_process_id,
                          int render_frame_id,
                          const void* context,
-                         const GURL& url,
-                         const GURL& policy_url,
+                         const GURL& plugin_content_url,
+                         const url::Origin& main_frame_origin,
                          content::WebPluginInfo* plugin) override;
 
   // CanLoadPlugin always grants permission to the browser
@@ -78,8 +80,8 @@ class ChromePluginServiceFilter : public content::PluginServiceFilter,
                      const base::FilePath& path) override;
 
  private:
-  struct ContextInfo;
   friend struct base::DefaultSingletonTraits<ChromePluginServiceFilter>;
+  struct ContextInfo;
 
   struct OverriddenPlugin {
     OverriddenPlugin();
