@@ -17,7 +17,7 @@
 #import "base/mac/scoped_nsautorelease_pool.h"
 #include "base/macros.h"
 #include "base/strings/sys_string_conversions.h"
-#include "policy/policy_constants.h"
+#include "components/policy/policy_constants.h"
 
 namespace policy {
 
