@@ -14,7 +14,6 @@
 #include "base/metrics/histogram_macros.h"
 #include "base/metrics/sparse_histogram.h"
 #include "base/strings/string_number_conversions.h"
-#include "base/strings/stringprintf.h"
 #include "base/time/time.h"
 #include "base/trace_event/trace_event.h"
 #include "chrome/browser/history/history_service_factory.h"
@@ -218,11 +217,12 @@ bool ResourcePrefetchPredictor::IsHandledResourceType(
 content::ResourceType ResourcePrefetchPredictor::GetResourceType(
     content::ResourceType resource_type,
     const std::string& mime_type) {
-  // Restricts content::RESOURCE_TYPE_{PREFETCH,SUB_RESOURCE} to a small set of
-  // mime types, because these resource types don't communicate how the
+  // Restricts content::RESOURCE_TYPE_{PREFETCH,SUB_RESOURCE,XHR} to a small set
+  // of mime types, because these resource types don't communicate how the
   // resources will be used.
   if (resource_type == content::RESOURCE_TYPE_PREFETCH ||
-      resource_type == content::RESOURCE_TYPE_SUB_RESOURCE) {
+      resource_type == content::RESOURCE_TYPE_SUB_RESOURCE ||
+      resource_type == content::RESOURCE_TYPE_XHR) {
     return GetResourceTypeFromMimeType(mime_type,
                                        content::RESOURCE_TYPE_LAST_TYPE);
   }
@@ -325,20 +325,14 @@ ResourcePrefetchPredictor::URLRequestSummary::~URLRequestSummary() {
 bool ResourcePrefetchPredictor::URLRequestSummary::SummarizeResponse(
     const net::URLRequest& request,
     URLRequestSummary* summary) {
-  const content::ResourceRequestInfo* info =
+  const content::ResourceRequestInfo* request_info =
       content::ResourceRequestInfo::ForRequest(&request);
-  if (!info)
+  if (!request_info)
     return false;
 
-  int render_process_id, render_frame_id;
-  if (!info->GetAssociatedRenderFrame(&render_process_id, &render_frame_id))
-    return false;
-
-  summary->navigation_id = NavigationID(render_process_id, render_frame_id,
-                                        request.first_party_for_cookies());
-  summary->navigation_id.creation_time = request.creation_time();
   summary->resource_url = request.original_url();
-  content::ResourceType resource_type_from_request = info->GetResourceType();
+  content::ResourceType resource_type_from_request =
+      request_info->GetResourceType();
   summary->priority = request.priority();
   request.GetMimeType(&summary->mime_type);
   summary->was_cached = request.was_cached();
@@ -384,18 +378,16 @@ ResourcePrefetchPredictor::ResourcePrefetchPredictor(
 
   // Some form of learning has to be enabled.
   DCHECK(config_.IsLearningEnabled());
-  if (config_.IsURLPrefetchingEnabled(profile_))
-    DCHECK(config_.IsURLLearningEnabled());
-  if (config_.IsHostPrefetchingEnabled(profile_))
-    DCHECK(config_.IsHostLearningEnabled());
 }
 
 ResourcePrefetchPredictor::~ResourcePrefetchPredictor() {}
 
 void ResourcePrefetchPredictor::StartInitialization() {
   DCHECK_CURRENTLY_ON(BrowserThread::UI);
+  TRACE_EVENT0("browser", "ResourcePrefetchPredictor::StartInitialization");
 
-  DCHECK_EQ(NOT_INITIALIZED, initialization_state_);
+  if (initialization_state_ != NOT_INITIALIZED)
+    return;
   initialization_state_ = INITIALIZING;
 
   // Create local caches using the database as loaded.
@@ -474,17 +466,18 @@ void ResourcePrefetchPredictor::RecordMainFrameLoadComplete(
   }
 }
 
-void ResourcePrefetchPredictor::StartPrefetching(const GURL& url) {
+void ResourcePrefetchPredictor::StartPrefetching(const GURL& url,
+                                                 PrefetchOrigin origin) {
   TRACE_EVENT1("browser", "ResourcePrefetchPredictor::StartPrefetching", "url",
                url.spec());
   if (!prefetch_manager_.get())  // Prefetching not enabled.
     return;
+  if (!config_.IsPrefetchingEnabledForOrigin(profile_, origin))
+    return;
 
   std::vector<GURL> subresource_urls;
-  if (!GetPrefetchData(url, &subresource_urls)) {
-    // No prefetching data at host or URL level.
+  if (!GetPrefetchData(url, &subresource_urls))
     return;
-  }
 
   BrowserThread::PostTask(
       BrowserThread::IO, FROM_HERE,
@@ -522,7 +515,7 @@ void ResourcePrefetchPredictor::OnMainFrameRequest(
   DCHECK_EQ(INITIALIZED, initialization_state_);
 
   const GURL& main_frame_url = request.navigation_id.main_frame_url;
-  StartPrefetching(main_frame_url);
+  StartPrefetching(main_frame_url, PrefetchOrigin::NAVIGATION);
 
   // Cleanup older navigations.
   CleanupAbandonedNavigations(request.navigation_id);
@@ -616,37 +609,29 @@ bool ResourcePrefetchPredictor::GetPrefetchData(const GURL& main_frame_url,
                                                 std::vector<GURL>* urls) {
   DCHECK(urls);
   DCHECK(urls->empty());
-  bool use_url_data = config_.IsPrefetchingEnabled(profile_) ?
-      config_.IsURLPrefetchingEnabled(profile_) :
-      config_.IsURLLearningEnabled();
-  bool use_host_data = config_.IsPrefetchingEnabled(profile_) ?
-      config_.IsHostPrefetchingEnabled(profile_) :
-      config_.IsHostLearningEnabled();
 
   // Fetch URLs based on a redirect endpoint for URL/host first.
   std::string redirect_endpoint;
-  if (use_url_data &&
-      GetRedirectEndpoint(main_frame_url.spec(), *url_redirect_table_cache_,
+  if (GetRedirectEndpoint(main_frame_url.spec(), *url_redirect_table_cache_,
                           &redirect_endpoint) &&
       PopulatePrefetcherRequest(redirect_endpoint, *url_table_cache_, urls)) {
     return true;
   }
 
-  if (use_host_data &&
-      GetRedirectEndpoint(main_frame_url.host(), *host_redirect_table_cache_,
+  if (GetRedirectEndpoint(main_frame_url.host(), *host_redirect_table_cache_,
                           &redirect_endpoint) &&
       PopulatePrefetcherRequest(redirect_endpoint, *host_table_cache_, urls)) {
     return true;
   }
 
   // Fallback to fetching URLs based on the incoming URL/host.
-  if (use_url_data && PopulatePrefetcherRequest(main_frame_url.spec(),
-                                                *url_table_cache_, urls)) {
+  if (PopulatePrefetcherRequest(main_frame_url.spec(), *url_table_cache_,
+                                urls)) {
     return true;
   }
 
-  return use_host_data && PopulatePrefetcherRequest(main_frame_url.host(),
-                                                    *host_table_cache_, urls);
+  return PopulatePrefetcherRequest(main_frame_url.host(), *host_table_cache_,
+                                   urls);
 }
 
 bool ResourcePrefetchPredictor::PopulatePrefetcherRequest(
@@ -706,7 +691,7 @@ void ResourcePrefetchPredictor::OnHistoryAndCacheLoaded() {
   DCHECK_EQ(INITIALIZING, initialization_state_);
 
   // Initialize the prefetch manager only if prefetching is enabled.
-  if (config_.IsPrefetchingEnabled(profile_)) {
+  if (config_.IsPrefetchingEnabledForSomeOrigin(profile_)) {
     prefetch_manager_ = new ResourcePrefetcherManager(
         this, config_, profile_->GetRequestContext());
   }
@@ -857,7 +842,7 @@ void ResourcePrefetchPredictor::OnVisitCountLookup(
   bool should_track_url =
       already_tracking || (url_visit_count >= config_.min_url_visit_count);
 
-  if (should_track_url && config_.IsURLLearningEnabled()) {
+  if (should_track_url) {
     LearnNavigation(url_spec, PREFETCH_KEY_TYPE_URL,
                     summary.subresource_requests, config_.max_urls_to_track,
                     url_table_cache_.get(), summary.initial_url.spec(),
@@ -865,13 +850,10 @@ void ResourcePrefetchPredictor::OnVisitCountLookup(
   }
 
   // Host level data - no cutoff, always learn the navigation if enabled.
-  if (config_.IsHostLearningEnabled()) {
-    const std::string host = summary.main_frame_url.host();
-    LearnNavigation(host, PREFETCH_KEY_TYPE_HOST, summary.subresource_requests,
-                    config_.max_hosts_to_track, host_table_cache_.get(),
-                    summary.initial_url.host(),
-                    host_redirect_table_cache_.get());
-  }
+  const std::string host = summary.main_frame_url.host();
+  LearnNavigation(host, PREFETCH_KEY_TYPE_HOST, summary.subresource_requests,
+                  config_.max_hosts_to_track, host_table_cache_.get(),
+                  summary.initial_url.host(), host_redirect_table_cache_.get());
 
   if (observer_)
     observer_->OnNavigationLearned(url_visit_count, summary);
