@@ -38,6 +38,7 @@ class URLRequest;
 
 namespace predictors {
 
+class TestObserver;
 class ResourcePrefetcherManager;
 
 // Contains logic for learning what can be prefetched and for kicking off
@@ -95,15 +96,34 @@ class ResourcePrefetchPredictor
     bool always_revalidate;
 
     // Initializes a |URLRequestSummary| from a |URLRequest| response.
-    // Returns true for success.
+    // Returns true for success. Note: NavigationID is NOT initialized
+    // by this function.
     static bool SummarizeResponse(const net::URLRequest& request,
                                   URLRequestSummary* summary);
   };
 
+  // Stores the data learned from a single navigation.
+  struct PageRequestSummary {
+    explicit PageRequestSummary(const GURL& main_frame_url);
+    PageRequestSummary(const PageRequestSummary& other);
+    ~PageRequestSummary();
+
+    GURL main_frame_url;
+    GURL initial_url;
+
+    // Stores all subresource requests within a single navigation, from initial
+    // main frame request to navigation completion.
+    std::vector<URLRequestSummary> subresource_requests;
+  };
+
   ResourcePrefetchPredictor(const ResourcePrefetchPredictorConfig& config,
                             Profile* profile);
   ~ResourcePrefetchPredictor() override;
 
+  // Starts initialization by posting a task to the DB thread to read the
+  // predictor database.
+  void StartInitialization();
+
   // Thread safe.
   static bool ShouldRecordRequest(net::URLRequest* request,
                                   content::ResourceType resource_type);
@@ -132,9 +152,23 @@ class ResourcePrefetchPredictor
   // Called when the main frame of a page completes loading.
   void RecordMainFrameLoadComplete(const NavigationID& navigation_id);
 
+  // Starts prefetching if it is enabled for |origin| and prefetching data
+  // exists for the |main_frame_url| either at the URL or at the host level.
+  void StartPrefetching(const GURL& main_frame_url, PrefetchOrigin origin);
+
+  // Stops prefetching that may be in progress corresponding to
+  // |main_frame_url|.
+  void StopPrefetching(const GURL& main_frame_url);
+
+  // Sets the |observer| to be notified when the resource prefetch predictor
+  // data changes. Previously registered observer will be discarded. Call
+  // this with nullptr parameter to de-register observer.
+  void SetObserverForTesting(TestObserver* observer);
+
  private:
   friend class ::PredictorsHandler;
   friend class ResourcePrefetchPredictorTest;
+  friend class ResourcePrefetchPredictorBrowserTest;
 
   FRIEND_TEST_ALL_PREFIXES(ResourcePrefetchPredictorTest, DeleteUrls);
   FRIEND_TEST_ALL_PREFIXES(ResourcePrefetchPredictorTest,
@@ -155,6 +189,10 @@ class ResourcePrefetchPredictor
                            OnSubresourceResponse);
   FRIEND_TEST_ALL_PREFIXES(ResourcePrefetchPredictorTest, GetCorrectPLT);
   FRIEND_TEST_ALL_PREFIXES(ResourcePrefetchPredictorTest, HandledResourceTypes);
+  FRIEND_TEST_ALL_PREFIXES(ResourcePrefetchPredictorTest,
+                           PopulatePrefetcherRequest);
+  FRIEND_TEST_ALL_PREFIXES(ResourcePrefetchPredictorTest, GetRedirectEndpoint);
+  FRIEND_TEST_ALL_PREFIXES(ResourcePrefetchPredictorTest, GetPrefetchData);
 
   enum InitializationState {
     NOT_INITIALIZED = 0,
@@ -162,48 +200,6 @@ class ResourcePrefetchPredictor
     INITIALIZED = 2
   };
 
-  // Stores information about inflight navigations.
-  struct PageRequestSummary {
-    explicit PageRequestSummary(const GURL& initial_url);
-    ~PageRequestSummary();
-
-    GURL initial_url;
-
-    // Stores all subresources requests within a single navigation, from initial
-    // main frame request to navigation completion.
-    std::vector<URLRequestSummary> subresource_requests;
-  };
-
-  // Used to fetch the visit count for a URL from the History database.
-  class GetUrlVisitCountTask : public history::HistoryDBTask {
-   public:
-    typedef ResourcePrefetchPredictor::URLRequestSummary URLRequestSummary;
-    typedef ResourcePrefetchPredictor::PageRequestSummary PageRequestSummary;
-    typedef base::Callback<void(size_t,  // Visit count.
-                                const NavigationID&,
-                                const PageRequestSummary&)>
-        VisitInfoCallback;
-
-    GetUrlVisitCountTask(const NavigationID& navigation_id,
-                         std::unique_ptr<PageRequestSummary> summary,
-                         VisitInfoCallback callback);
-
-    bool RunOnDBThread(history::HistoryBackend* backend,
-                       history::HistoryDatabase* db) override;
-
-    void DoneRunOnMainThread() override;
-
-   private:
-    ~GetUrlVisitCountTask() override;
-
-    int visit_count_;
-    NavigationID navigation_id_;
-    std::unique_ptr<PageRequestSummary> summary_;
-    VisitInfoCallback callback_;
-
-    DISALLOW_COPY_AND_ASSIGN(GetUrlVisitCountTask);
-  };
-
   typedef ResourcePrefetchPredictorTables::PrefetchDataMap PrefetchDataMap;
   typedef ResourcePrefetchPredictorTables::RedirectDataMap RedirectDataMap;
 
@@ -224,6 +220,12 @@ class ResourcePrefetchPredictor
   // Returns true if the request (should have a response in it) is "no-store".
   static bool IsNoStore(const net::URLRequest* request);
 
+  // Returns true iff |redirect_data_map| contains confident redirect endpoint
+  // for |entry_point| and assigns it to the |redirect_endpoint|.
+  static bool GetRedirectEndpoint(const std::string& entry_point,
+                                  const RedirectDataMap& redirect_data_map,
+                                  std::string* redirect_endpoint);
+
   // KeyedService methods override.
   void Shutdown() override;
 
@@ -239,27 +241,18 @@ class ResourcePrefetchPredictor
   // this point are the only ones considered for prefetching.
   void OnNavigationComplete(const NavigationID& nav_id_without_timing_info);
 
-  // Returns true if there is PrefetchData that can be used for a URL and fills
-  // |urls| with resources that need to be prefetched.
+  // Returns true iff there is PrefetchData that can be used for a
+  // |main_frame_url| and fills |urls| with resources that need to be
+  // prefetched.
   bool GetPrefetchData(const GURL& main_frame_url, std::vector<GURL>* urls);
 
-  // Converts a PrefetchData into a list of URLs.
-  void PopulatePrefetcherRequest(const PrefetchData& data,
+  // Returns true iff the |data_map| contains PrefetchData that can be used
+  // for a |main_frame_key| and fills |urls| with resources that need to be
+  // prefetched.
+  bool PopulatePrefetcherRequest(const std::string& main_frame_key,
+                                 const PrefetchDataMap& data_map,
                                  std::vector<GURL>* urls);
 
- public:
-  // Starts prefetching if it is enabled and prefetching data exists for the
-  // NavigationID either at the URL or at the host level.
-  void StartPrefetching(const GURL& main_frame_url);
-
-  // Stops prefetching that may be in progress corresponding to |navigation_id|.
-  void StopPrefetching(const GURL& main_frame_url);
-
- private:
-  // Starts initialization by posting a task to the DB thread to read the
-  // predictor database.
-  void StartInitialization();
-
   // Callback for task to read predictor database. Takes ownership of
   // all arguments.
   void CreateCaches(std::unique_ptr<PrefetchDataMap> url_data_map,
@@ -284,8 +277,7 @@ class ResourcePrefetchPredictor
   void DeleteUrls(const history::URLRows& urls);
 
   // Callback for GetUrlVisitCountTask.
-  void OnVisitCountLookup(size_t visit_count,
-                          const NavigationID& navigation_id,
+  void OnVisitCountLookup(size_t url_visit_count,
                           const PageRequestSummary& summary);
 
   // Removes the oldest entry in the input |data_map|, also deleting it from the
@@ -343,6 +335,7 @@ class ResourcePrefetchPredictor
   }
 
   Profile* const profile_;
+  TestObserver* observer_;
   ResourcePrefetchPredictorConfig const config_;
   InitializationState initialization_state_;
   scoped_refptr<ResourcePrefetchPredictorTables> tables_;
@@ -363,6 +356,30 @@ class ResourcePrefetchPredictor
   DISALLOW_COPY_AND_ASSIGN(ResourcePrefetchPredictor);
 };
 
+// An interface used to notify that data in the ResourcePrefetchPredictor
+// has changed. All methods are invoked on the UI thread.
+class TestObserver {
+ public:
+  // De-registers itself from |predictor_| on destruction.
+  virtual ~TestObserver();
+
+  virtual void OnNavigationLearned(
+      size_t url_visit_count,
+      const ResourcePrefetchPredictor::PageRequestSummary& summary) {}
+
+  virtual void OnPredictorInitialized() {}
+
+ protected:
+  // |predictor| must be non-NULL and has to outlive the TestObserver.
+  // Also the predictor must not have a TestObserver set.
+  explicit TestObserver(ResourcePrefetchPredictor* predictor);
+
+ private:
+  ResourcePrefetchPredictor* predictor_;
+
+  DISALLOW_COPY_AND_ASSIGN(TestObserver);
+};
+
 }  // namespace predictors
 
 #endif  // CHROME_BROWSER_PREDICTORS_RESOURCE_PREFETCH_PREDICTOR_H_
