@@ -243,8 +243,7 @@ class ResourcePrefetchPredictorTest : public testing::Test {
     config.min_resource_confidence_to_trigger_prefetch = 0.5;
 
     // TODO(shishir): Enable the prefetching mode in the tests.
-    config.mode |= ResourcePrefetchPredictorConfig::URL_LEARNING;
-    config.mode |= ResourcePrefetchPredictorConfig::HOST_LEARNING;
+    config.mode |= ResourcePrefetchPredictorConfig::LEARNING;
     predictor_.reset(new ResourcePrefetchPredictor(config, profile_.get()));
     predictor_->set_mock_tables(mock_tables_);
   }
@@ -1164,6 +1163,12 @@ TEST_F(ResourcePrefetchPredictorTest, HandledResourceTypes) {
       content::RESOURCE_TYPE_PREFETCH, "application/font-woff"));
   EXPECT_TRUE(ResourcePrefetchPredictor::IsHandledResourceType(
       content::RESOURCE_TYPE_PREFETCH, "font/woff2"));
+  EXPECT_FALSE(ResourcePrefetchPredictor::IsHandledResourceType(
+      content::RESOURCE_TYPE_XHR, ""));
+  EXPECT_FALSE(ResourcePrefetchPredictor::IsHandledResourceType(
+      content::RESOURCE_TYPE_XHR, "bogus/mime-type"));
+  EXPECT_TRUE(ResourcePrefetchPredictor::IsHandledResourceType(
+      content::RESOURCE_TYPE_XHR, "application/javascript"));
 }
 
 TEST_F(ResourcePrefetchPredictorTest, ShouldRecordRequestMainFrame) {
@@ -1319,14 +1324,16 @@ TEST_F(ResourcePrefetchPredictorTest, SummarizeResponse) {
       url, net::MEDIUM, content::RESOURCE_TYPE_IMAGE, 1, 1, true);
   URLRequestSummary summary;
   EXPECT_TRUE(URLRequestSummary::SummarizeResponse(*request, &summary));
-  EXPECT_EQ(1, summary.navigation_id.render_process_id);
-  EXPECT_EQ(1, summary.navigation_id.render_frame_id);
-  EXPECT_EQ(url, summary.navigation_id.main_frame_url);
   EXPECT_EQ(url, summary.resource_url);
   EXPECT_EQ(content::RESOURCE_TYPE_IMAGE, summary.resource_type);
   EXPECT_TRUE(summary.was_cached);
   EXPECT_FALSE(summary.has_validators);
   EXPECT_FALSE(summary.always_revalidate);
+
+  // Navigation_id elements should be unset by default.
+  EXPECT_EQ(-1, summary.navigation_id.render_process_id);
+  EXPECT_EQ(-1, summary.navigation_id.render_frame_id);
+  EXPECT_EQ(GURL(), summary.navigation_id.main_frame_url);
 }
 
 TEST_F(ResourcePrefetchPredictorTest, SummarizeResponseContentType) {
