@@ -44,7 +44,6 @@ struct HistoryAddPageArgs;
 
 namespace prerender {
 
-class PrerenderHandle;
 class PrerenderManager;
 class PrerenderResourceThrottle;
 
@@ -74,21 +73,21 @@ class PrerenderContents : public content::NotificationObserver,
   class Observer {
    public:
     // Signals that the prerender has started running.
-    virtual void OnPrerenderStart(PrerenderContents* contents) = 0;
+    virtual void OnPrerenderStart(PrerenderContents* contents) {}
 
     // Signals that the prerender has had its load event.
-    virtual void OnPrerenderStopLoading(PrerenderContents* contents);
+    virtual void OnPrerenderStopLoading(PrerenderContents* contents) {}
 
     // Signals that the prerender has had its 'DOMContentLoaded' event.
-    virtual void OnPrerenderDomContentLoaded(PrerenderContents* contents);
+    virtual void OnPrerenderDomContentLoaded(PrerenderContents* contents) {}
 
     // Signals that the prerender has stopped running. A PrerenderContents with
     // an unset final status will always call OnPrerenderStop before being
     // destroyed.
-    virtual void OnPrerenderStop(PrerenderContents* contents) = 0;
+    virtual void OnPrerenderStop(PrerenderContents* contents) {}
 
    protected:
-    Observer();
+    Observer() {}
     virtual ~Observer() = 0;
   };
 
@@ -171,8 +170,7 @@ class PrerenderContents : public content::NotificationObserver,
   void DidStartProvisionalLoadForFrame(
       content::RenderFrameHost* render_frame_host,
       const GURL& validated_url,
-      bool is_error_page,
-      bool is_iframe_srcdoc) override;
+      bool is_error_page) override;
   void DidFinishLoad(content::RenderFrameHost* render_frame_host,
                      const GURL& validated_url) override;
   void DidNavigateMainFrame(
@@ -237,6 +235,10 @@ class PrerenderContents : public content::NotificationObserver,
   // Increments the number of bytes fetched over the network for this prerender.
   void AddNetworkBytes(int64_t bytes);
 
+  bool prerendering_has_been_cancelled() const {
+    return prerendering_has_been_cancelled_;
+  }
+
  protected:
   PrerenderContents(PrerenderManager* prerender_manager,
                     Profile* profile,
@@ -265,10 +267,6 @@ class PrerenderContents : public content::NotificationObserver,
     return notification_registrar_;
   }
 
-  bool prerendering_has_been_cancelled() const {
-    return prerendering_has_been_cancelled_;
-  }
-
   content::WebContents* CreateWebContents(
       content::SessionStorageNamespace* session_storage_namespace);
 
