@@ -29,9 +29,7 @@
 #include "content/public/browser/render_process_host_observer.h"
 #include "url/gurl.h"
 
-class InstantSearchPrerendererTest;
 class Profile;
-struct ChromeCookieDetails;
 
 namespace base {
 class DictionaryValue;
@@ -58,10 +56,6 @@ class Rect;
 class Size;
 }
 
-namespace offline_pages {
-class PrerenderAdapterTest;
-}
-
 namespace prerender {
 
 namespace test_utils {
@@ -70,7 +64,6 @@ class PrerenderInProcessBrowserTest;
 
 class PrerenderHandle;
 class PrerenderHistory;
-class PrerenderLocalPredictor;
 
 // PrerenderManager is responsible for initiating and keeping prerendered
 // views of web pages. All methods must be called on the UI thread unless
@@ -80,19 +73,13 @@ class PrerenderManager : public content::NotificationObserver,
                          public KeyedService,
                          public MediaCaptureDevicesDispatcher::Observer {
  public:
-  // NOTE: New values need to be appended, since they are used in histograms.
   enum PrerenderManagerMode {
-    PRERENDER_MODE_DISABLED = 0,
-    PRERENDER_MODE_ENABLED = 1,
-    PRERENDER_MODE_EXPERIMENT_CONTROL_GROUP = 2,
-    PRERENDER_MODE_EXPERIMENT_PRERENDER_GROUP = 3,
-    // Obsolete: PRERENDER_MODE_EXPERIMENT_5MIN_TTL_GROUP = 4,
-    PRERENDER_MODE_EXPERIMENT_NO_USE_GROUP = 5,
-    PRERENDER_MODE_EXPERIMENT_MULTI_PRERENDER_GROUP = 6,
-    PRERENDER_MODE_EXPERIMENT_15MIN_TTL_GROUP = 7,
-    // Obsolete: PRERENDER_MODE_EXPERIMENT_MATCH_COMPLETE_GROUP = 8,
-    PRERENDER_MODE_NOSTATE_PREFETCH = 9,
-    PRERENDER_MODE_MAX = 10
+    PRERENDER_MODE_DISABLED,
+    PRERENDER_MODE_ENABLED,
+    PRERENDER_MODE_NOSTATE_PREFETCH,
+    // Like PRERENDER_MODE_DISABLED, but keeps track of pages that would have
+    // been prerendered and records metrics for comparison with other modes.
+    PRERENDER_MODE_SIMPLE_LOAD_EXPERIMENT
   };
 
   // One or more of these flags must be passed to ClearData() to specify just
@@ -230,10 +217,8 @@ class PrerenderManager : public content::NotificationObserver,
   static PrerenderManagerMode GetMode();
   static void SetMode(PrerenderManagerMode mode);
   static bool IsPrerenderingPossible();
-  static bool ActuallyPrerendering();
-  static bool IsControlGroup();
-  static bool IsNoUseGroup();
   static bool IsNoStatePrefetch();
+  static bool IsSimpleLoadExperiment();
 
   // Query the list of current prerender pages to see if the given web contents
   // is prerendering a page. The optional parameter |origin| is an output
@@ -356,6 +341,8 @@ class PrerenderManager : public content::NotificationObserver,
     return IsPrerenderSilenceExperiment(origin);
   }
 
+  base::WeakPtr<PrerenderManager> AsWeakPtr();
+
  protected:
   class PrerenderData : public base::SupportsWeakPtr<PrerenderData> {
    public:
