@@ -5,6 +5,7 @@
 #include "chrome/browser/prerender/prerender_resource_throttle.h"
 
 #include "base/logging.h"
+#include "base/memory/ref_counted.h"
 #include "base/numerics/safe_conversions.h"
 #include "build/build_config.h"
 #include "chrome/browser/prerender/prerender_final_status.h"
@@ -12,13 +13,13 @@
 #include "chrome/browser/prerender/prerender_util.h"
 #include "content/public/browser/browser_thread.h"
 #include "content/public/browser/render_frame_host.h"
-#include "content/public/browser/resource_controller.h"
 #include "content/public/browser/resource_request_info.h"
 #include "content/public/browser/web_contents.h"
 #include "net/http/http_response_headers.h"
 #include "net/url_request/redirect_info.h"
 #include "net/url_request/url_request.h"
 
+using content::BrowserThread;
 using content::ResourceType;
 
 namespace prerender {
@@ -38,26 +39,64 @@ bool IsNoStoreResponse(const net::URLRequest& request) {
 
 }  // namespace
 
+// Used to pass information between different UI thread tasks of the same
+// throttle. This is reference counted as the throttler may be destroyed before
+// the UI thread task has a chance to run.
+//
+// This class is created on the IO thread, and destroyed on the UI thread. Its
+// members should only be accessed on the UI thread.
+class PrerenderThrottleInfo
+    : public base::RefCountedThreadSafe<PrerenderThrottleInfo,
+                                        BrowserThread::DeleteOnUIThread> {
+ public:
+  PrerenderThrottleInfo() : manager_(nullptr) {}
+
+  void Set(PrerenderMode mode, Origin origin, PrerenderManager* manager) {
+    DCHECK_CURRENTLY_ON(BrowserThread::UI);
+    mode_ = mode;
+    origin_ = origin;
+    manager_ = manager->AsWeakPtr();
+  }
+
+  PrerenderMode mode() const { return mode_; }
+  Origin origin() const { return origin_; }
+  base::WeakPtr<PrerenderManager> manager() const {
+    DCHECK_CURRENTLY_ON(BrowserThread::UI);
+    return manager_;
+  }
+
+ private:
+  friend class base::RefCountedThreadSafe<PrerenderThrottleInfo>;
+  friend struct BrowserThread::DeleteOnThread<BrowserThread::UI>;
+  friend class base::DeleteHelper<PrerenderThrottleInfo>;
+  ~PrerenderThrottleInfo() {}
+
+  PrerenderMode mode_;
+  Origin origin_;
+  base::WeakPtr<PrerenderManager> manager_;
+};
+
 void PrerenderResourceThrottle::OverridePrerenderContentsForTesting(
     PrerenderContents* contents) {
   g_prerender_contents_for_testing = contents;
 }
 
 PrerenderResourceThrottle::PrerenderResourceThrottle(net::URLRequest* request)
-    : request_(request) {
-}
+    : request_(request),
+      prerender_throttle_info_(new PrerenderThrottleInfo()) {}
+
+PrerenderResourceThrottle::~PrerenderResourceThrottle() {}
 
 void PrerenderResourceThrottle::WillStartRequest(bool* defer) {
   const content::ResourceRequestInfo* info =
       content::ResourceRequestInfo::ForRequest(request_);
   *defer = true;
-  content::BrowserThread::PostTask(
-      content::BrowserThread::UI,
-      FROM_HERE,
-      base::Bind(&PrerenderResourceThrottle::WillStartRequestOnUI,
-                 AsWeakPtr(), request_->method(), info->GetResourceType(),
-                 info->GetChildID(), info->GetRenderFrameID(),
-                 request_->url()));
+  BrowserThread::PostTask(
+      BrowserThread::UI, FROM_HERE,
+      base::Bind(&PrerenderResourceThrottle::WillStartRequestOnUI, AsWeakPtr(),
+                 request_->method(), info->GetResourceType(),
+                 info->GetChildID(), info->GetRenderFrameID(), request_->url(),
+                 prerender_throttle_info_));
 }
 
 void PrerenderResourceThrottle::WillRedirectRequest(
@@ -69,8 +108,8 @@ void PrerenderResourceThrottle::WillRedirectRequest(
   std::string header;
   request_->GetResponseHeaderByName(kFollowOnlyWhenPrerenderShown, &header);
 
-  content::BrowserThread::PostTask(
-      content::BrowserThread::UI, FROM_HERE,
+  BrowserThread::PostTask(
+      BrowserThread::UI, FROM_HERE,
       base::Bind(&PrerenderResourceThrottle::WillRedirectRequestOnUI,
                  AsWeakPtr(), header, info->GetResourceType(), info->IsAsync(),
                  IsNoStoreResponse(*request_), info->GetChildID(),
@@ -87,24 +126,21 @@ void PrerenderResourceThrottle::WillProcessResponse(bool* defer) {
   int redirect_count =
       base::saturated_cast<int>(request_->url_chain().size()) - 1;
 
-  content::BrowserThread::PostTask(
-      content::BrowserThread::UI, FROM_HERE,
+  BrowserThread::PostTask(
+      BrowserThread::UI, FROM_HERE,
       base::Bind(&PrerenderResourceThrottle::WillProcessResponseOnUI,
                  content::IsResourceTypeFrame(info->GetResourceType()),
                  IsNoStoreResponse(*request_), redirect_count,
-                 info->GetChildID(), info->GetRenderFrameID()));
+                 info->GetChildID(), info->GetRenderFrameID(),
+                 prerender_throttle_info_));
 }
 
 const char* PrerenderResourceThrottle::GetNameForLogging() const {
   return "PrerenderResourceThrottle";
 }
 
-void PrerenderResourceThrottle::Resume() {
-  controller()->Resume();
-}
-
-void PrerenderResourceThrottle::Cancel() {
-  controller()->Cancel();
+void PrerenderResourceThrottle::ResumeHandler() {
+  Resume();
 }
 
 // static
@@ -114,11 +150,17 @@ void PrerenderResourceThrottle::WillStartRequestOnUI(
     ResourceType resource_type,
     int render_process_id,
     int render_frame_id,
-    const GURL& url) {
+    const GURL& url,
+    scoped_refptr<PrerenderThrottleInfo> prerender_throttle_info) {
   bool cancel = false;
   PrerenderContents* prerender_contents =
       PrerenderContentsFromRenderFrame(render_process_id, render_frame_id);
   if (prerender_contents) {
+    DCHECK(prerender_throttle_info);
+    prerender_throttle_info->Set(prerender_contents->prerender_mode(),
+                                 prerender_contents->origin(),
+                                 prerender_contents->prerender_manager());
+
     // Abort any prerenders that spawn requests that use unsupported HTTP
     // methods or schemes.
     if (!prerender_contents->IsValidHttpMethod(method)) {
@@ -144,11 +186,11 @@ void PrerenderResourceThrottle::WillStartRequestOnUI(
     }
   }
 
-  content::BrowserThread::PostTask(
-      content::BrowserThread::IO,
-      FROM_HERE,
-      base::Bind(cancel ? &PrerenderResourceThrottle::Cancel :
-                 &PrerenderResourceThrottle::Resume, throttle));
+  BrowserThread::PostTask(
+      BrowserThread::IO, FROM_HERE,
+      base::Bind(cancel ? &PrerenderResourceThrottle::Cancel
+                        : &PrerenderResourceThrottle::ResumeHandler,
+                 throttle));
 }
 
 // static
@@ -191,32 +233,33 @@ void PrerenderResourceThrottle::WillRedirectRequestOnUI(
     }
   }
 
-  content::BrowserThread::PostTask(
-      content::BrowserThread::IO,
-      FROM_HERE,
-      base::Bind(cancel ? &PrerenderResourceThrottle::Cancel :
-                 &PrerenderResourceThrottle::Resume, throttle));
+  BrowserThread::PostTask(
+      BrowserThread::IO, FROM_HERE,
+      base::Bind(cancel ? &PrerenderResourceThrottle::Cancel
+                        : &PrerenderResourceThrottle::ResumeHandler,
+                 throttle));
 }
 
 // static
-void PrerenderResourceThrottle::WillProcessResponseOnUI(bool is_main_resource,
-                                                        bool is_no_store,
-                                                        int redirect_count,
-                                                        int render_process_id,
-                                                        int render_frame_id) {
-  PrerenderContents* prerender_contents =
-      PrerenderContentsFromRenderFrame(render_process_id, render_frame_id);
-  if (!prerender_contents)
+void PrerenderResourceThrottle::WillProcessResponseOnUI(
+    bool is_main_resource,
+    bool is_no_store,
+    int redirect_count,
+    int render_process_id,
+    int render_frame_id,
+    scoped_refptr<PrerenderThrottleInfo> prerender_throttle_info) {
+  DCHECK(prerender_throttle_info);
+  if (!prerender_throttle_info->manager())
     return;
 
-  if (prerender_contents->prerender_mode() != PREFETCH_ONLY)
+  if (prerender_throttle_info->mode() != PREFETCH_ONLY)
     return;
 
-  prerender_contents->prerender_manager()->RecordPrefetchResponseReceived(
-      prerender_contents->origin(), is_main_resource, false /* is_redirect */,
-      is_no_store);
-  prerender_contents->prerender_manager()->RecordPrefetchRedirectCount(
-      prerender_contents->origin(), is_main_resource, redirect_count);
+  prerender_throttle_info->manager()->RecordPrefetchResponseReceived(
+      prerender_throttle_info->origin(), is_main_resource,
+      false /* is_redirect */, is_no_store);
+  prerender_throttle_info->manager()->RecordPrefetchRedirectCount(
+      prerender_throttle_info->origin(), is_main_resource, redirect_count);
 }
 
 // static
