@@ -14,7 +14,9 @@
 #include "base/memory/ptr_util.h"
 #include "base/message_loop/message_loop.h"
 #include "base/metrics/field_trial.h"
+#include "base/metrics/field_trial_param_associator.h"
 #include "base/strings/stringprintf.h"
+#include "base/test/scoped_feature_list.h"
 #include "base/test/simple_test_clock.h"
 #include "base/test/simple_test_tick_clock.h"
 #include "base/time/time.h"
@@ -32,6 +34,7 @@
 #include "chrome/test/base/testing_profile.h"
 #include "components/content_settings/core/common/pref_names.h"
 #include "components/prefs/pref_service.h"
+#include "components/variations/variations_associated_data.h"
 #include "content/public/browser/render_view_host.h"
 #include "content/public/test/test_browser_thread.h"
 #include "net/base/network_change_notifier.h"
@@ -298,16 +301,10 @@ DummyPrerenderContents::~DummyPrerenderContents() {
 void DummyPrerenderContents::StartPrerendering(
     const gfx::Rect& bounds,
     content::SessionStorageNamespace* session_storage_namespace) {
-  // In the base PrerenderContents implementation, StartPrerendering will
-  // be called even when the PrerenderManager is part of the control group,
-  // but it will early exit before actually creating a new RenderView if
-  // |is_control_group| is true;
   load_start_time_ = test_prerender_manager_->GetCurrentTimeTicks();
-  if (!test_prerender_manager_->IsControlGroup()) {
-    prerendering_has_started_ = true;
-    test_prerender_manager_->DummyPrerenderContentsStarted(-1, route_id_, this);
-    NotifyPrerenderStart();
-  }
+  prerendering_has_started_ = true;
+  test_prerender_manager_->DummyPrerenderContentsStarted(-1, route_id_, this);
+  NotifyPrerenderStart();
 }
 
 class PrerenderTest : public testing::Test {
@@ -405,8 +402,9 @@ class PrerenderTest : public testing::Test {
  private:
   // Needed to pass PrerenderManager's DCHECKs.
   base::MessageLoop message_loop_;
-  TestingProfile profile_;
   content::TestBrowserThread ui_thread_;
+
+  TestingProfile profile_;
   std::unique_ptr<UnitTestPrerenderManager> prerender_manager_;
   std::unique_ptr<PrerenderLinkManager> prerender_link_manager_;
   int last_prerender_id_;
@@ -416,12 +414,53 @@ class PrerenderTest : public testing::Test {
 TEST_F(PrerenderTest, PrerenderRespectsDisableFlag) {
   RestorePrerenderMode restore_prerender_mode;
   ASSERT_TRUE(PrerenderManager::IsPrerenderingPossible());
-  base::CommandLine* command_line = base::CommandLine::ForCurrentProcess();
-  command_line->AppendSwitchASCII(
-    switches::kPrerenderMode,
-    switches::kPrerenderModeSwitchValueDisabled);
-  prerender::ConfigurePrerender(*command_line);
-  ASSERT_FALSE(PrerenderManager::IsPrerenderingPossible());
+  ASSERT_EQ(PrerenderManager::PRERENDER_MODE_ENABLED,
+            PrerenderManager::GetMode());
+
+  {
+    base::test::ScopedFeatureList scoped_feature_list;
+    scoped_feature_list.InitAndDisableFeature(kNoStatePrefetchFeature);
+    prerender::ConfigurePrerender();
+    EXPECT_EQ(PrerenderManager::PRERENDER_MODE_DISABLED,
+              PrerenderManager::GetMode());
+    EXPECT_FALSE(PrerenderManager::IsPrerenderingPossible());
+  }
+}
+
+TEST_F(PrerenderTest, PrerenderRespectsFieldTrialParameters) {
+  RestorePrerenderMode restore_prerender_mode;
+
+  // Set up the prerender mode through a field trial.
+  std::string kTrialName = "name";
+  std::string kTrialGroup = "group";
+  base::FieldTrial* trial =
+      base::FieldTrialList::CreateFieldTrial(kTrialName, kTrialGroup);
+  std::map<std::string, std::string> params = {
+      {kNoStatePrefetchFeatureModeParameterName,
+       kNoStatePrefetchFeatureModeParameterSimpleLoad}};
+  ASSERT_TRUE(
+      variations::AssociateVariationParams(kTrialName, kTrialGroup, params));
+
+  std::unique_ptr<base::FeatureList> feature_list =
+      base::MakeUnique<base::FeatureList>();
+  feature_list->RegisterFieldTrialOverride(
+      kNoStatePrefetchFeature.name, base::FeatureList::OVERRIDE_ENABLE_FEATURE,
+      trial);
+
+  base::test::ScopedFeatureList scoped_feature_list;
+  scoped_feature_list.InitWithFeatureList(std::move(feature_list));
+
+  EXPECT_EQ(base::FeatureList::GetFieldTrial(kNoStatePrefetchFeature), trial);
+
+  std::map<std::string, std::string> actual_params;
+  EXPECT_TRUE(variations::GetVariationParamsByFeature(kNoStatePrefetchFeature,
+                                                      &actual_params));
+  EXPECT_EQ(params, actual_params);
+
+  prerender::ConfigurePrerender();
+  EXPECT_TRUE(PrerenderManager::IsPrerenderingPossible());
+  EXPECT_EQ(PrerenderManager::PRERENDER_MODE_SIMPLE_LOAD_EXPERIMENT,
+            PrerenderManager::GetMode());
 }
 
 TEST_F(PrerenderTest, PrerenderRespectsThirdPartyCookiesPref) {
@@ -913,21 +952,6 @@ TEST_F(PrerenderTest, CancelPendingPrerenderTest) {
   EXPECT_FALSE(LauncherHasRunningPrerender(child_id, last_prerender_id()));
 }
 
-// Tests that a PrerenderManager created for a browser session in the control
-// group works as expected.
-TEST_F(PrerenderTest, ControlGroup) {
-  RestorePrerenderMode restore_prerender_mode;
-  PrerenderManager::SetMode(
-      PrerenderManager::PRERENDER_MODE_EXPERIMENT_CONTROL_GROUP);
-  GURL url("http://www.google.com/");
-  DummyPrerenderContents* prerender_contents =
-      prerender_manager()->CreateNextPrerenderContents(
-          url,
-          FINAL_STATUS_MANAGER_SHUTDOWN);
-  EXPECT_TRUE(AddSimplePrerender(url));
-  EXPECT_FALSE(prerender_contents->prerendering_has_started());
-}
-
 // Tests that prerendering is cancelled when the source render view does not
 // exist.  On failure, the DCHECK in CreatePrerenderContents() above should be
 // triggered.
