@@ -19,9 +19,11 @@
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/profiles/profile_impl_io_data.h"
 #include "chrome/browser/ui/zoom/chrome_zoom_level_prefs.h"
+#include "chrome/common/features.h"
 #include "components/prefs/pref_change_registrar.h"
 #include "content/public/browser/content_browser_client.h"
 #include "content/public/browser/host_zoom_map.h"
+#include "extensions/features/features.h"
 
 class PrefService;
 
@@ -44,10 +46,6 @@ namespace domain_reliability {
 class DomainReliabilityMonitor;
 }
 
-namespace extensions {
-class ExtensionSystem;
-}
-
 namespace policy {
 class CloudPolicyManager;
 class ProfilePolicyConnector;
@@ -58,7 +56,7 @@ namespace ssl_config {
 class SSLConfigServiceManager;
 }
 
-namespace syncable_prefs {
+namespace sync_preferences {
 class PrefServiceSyncable;
 }
 
@@ -172,7 +170,7 @@ class ProfileImpl : public Profile {
   // Does final prefs initialization and calls Init().
   void OnLocaleReady();
 
-#if defined(ENABLE_SESSION_SERVICE)
+#if BUILDFLAG(ENABLE_SESSION_SERVICE)
   void StopCreateSessionServiceTimer();
 
   void EnsureSessionServiceCreated();
@@ -222,10 +220,10 @@ class ProfileImpl : public Profile {
   // |io_data_| and others store pointers to |prefs_| and shall be destructed
   // first.
   scoped_refptr<user_prefs::PrefRegistrySyncable> pref_registry_;
-  std::unique_ptr<syncable_prefs::PrefServiceSyncable> prefs_;
-  std::unique_ptr<syncable_prefs::PrefServiceSyncable> otr_prefs_;
+  std::unique_ptr<sync_preferences::PrefServiceSyncable> prefs_;
+  std::unique_ptr<sync_preferences::PrefServiceSyncable> otr_prefs_;
   ProfileImplIOData::Handle io_data_;
-#if defined(ENABLE_EXTENSIONS)
+#if BUILDFLAG(ENABLE_EXTENSIONS)
   scoped_refptr<ExtensionSpecialStoragePolicy>
       extension_special_storage_policy_;
 #endif
@@ -236,7 +234,7 @@ class ProfileImpl : public Profile {
   // prefs.
   ExitType last_session_exit_type_;
 
-#if defined(ENABLE_SESSION_SERVICE)
+#if BUILDFLAG(ENABLE_SESSION_SERVICE)
   base::OneShotTimer create_session_service_timer_;
 #endif
 
