@@ -21,10 +21,6 @@ namespace chrome_browser_net {
 class Predictor;
 }  // namespace chrome_browser_net
 
-namespace data_reduction_proxy {
-class DataReductionProxyNetworkDelegate;
-}  // namespace data_reduction_proxy
-
 namespace domain_reliability {
 class DomainReliabilityMonitor;
 }  // namespace domain_reliability
@@ -183,7 +179,8 @@ class ProfileImplIOData : public ProfileIOData {
       const override;
   net::URLRequestContext* InitializeMediaRequestContext(
       net::URLRequestContext* original_context,
-      const StoragePartitionDescriptor& partition_descriptor) const override;
+      const StoragePartitionDescriptor& partition_descriptor,
+      const std::string& name) const override;
   net::URLRequestContext* AcquireMediaRequestContext() const override;
   net::URLRequestContext* AcquireIsolatedAppRequestContext(
       net::URLRequestContext* main_context,
