@@ -22,7 +22,6 @@
 #include "base/stl_util.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/string_util.h"
-#include "base/strings/stringprintf.h"
 #include "base/threading/sequenced_worker_pool.h"
 #include "base/threading/thread_task_runner_handle.h"
 #include "build/build_config.h"
@@ -555,7 +554,9 @@ void ProfileIOData::InitializeOnUIThread(Profile* profile) {
   BrowserContext::EnsureResourceContextInitialized(profile);
 }
 
-ProfileIOData::MediaRequestContext::MediaRequestContext() {
+ProfileIOData::MediaRequestContext::MediaRequestContext(
+    const std::string& name) {
+  set_name(name);
 }
 
 void ProfileIOData::MediaRequestContext::SetHttpTransactionFactory(
@@ -569,6 +570,7 @@ ProfileIOData::MediaRequestContext::~MediaRequestContext() {
 }
 
 ProfileIOData::AppRequestContext::AppRequestContext() {
+  set_name("app_request");
 }
 
 void ProfileIOData::AppRequestContext::SetCookieStore(
@@ -905,11 +907,6 @@ bool ProfileIOData::GetMetricsEnabledStateOnIOThread() const {
   return enable_metrics_.GetValue();
 }
 
-bool ProfileIOData::IsDataReductionProxyEnabled() const {
-  return data_reduction_proxy_io_data() &&
-      data_reduction_proxy_io_data()->IsEnabled();
-}
-
 chrome_browser_net::Predictor* ProfileIOData::GetPredictor() {
   return nullptr;
 }
@@ -1023,6 +1020,8 @@ void ProfileIOData::Init(
   main_request_context_storage_.reset(
       new net::URLRequestContextStorage(main_request_context_.get()));
   extensions_request_context_.reset(new net::URLRequestContext());
+  main_request_context_->set_name("main");
+  extensions_request_context_->set_name("extensions");
 
   main_request_context_->set_enable_brotli(io_thread_globals->enable_brotli);
 
