@@ -16,6 +16,7 @@
 #include "base/macros.h"
 #include "base/memory/weak_ptr.h"
 #include "chrome/browser/background/background_trigger.h"
+#include "chrome/browser/push_messaging/push_messaging_notification_manager.h"
 #include "chrome/common/features.h"
 #include "components/content_settings/core/browser/content_settings_observer.h"
 #include "components/content_settings/core/common/content_settings.h"
@@ -30,10 +31,6 @@
 #include "third_party/WebKit/public/platform/modules/permissions/permission_status.mojom.h"
 #include "third_party/WebKit/public/platform/modules/push_messaging/WebPushPermissionStatus.h"
 
-#if defined(ENABLE_NOTIFICATIONS)
-#include "chrome/browser/push_messaging/push_messaging_notification_manager.h"
-#endif
-
 class Profile;
 class PushMessagingAppIdentifier;
 class PushMessagingServiceObserver;
@@ -48,10 +45,6 @@ namespace instance_id {
 class InstanceIDDriver;
 }
 
-namespace user_prefs {
-class PrefRegistrySyncable;
-}
-
 class PushMessagingServiceImpl : public content::PushMessagingService,
                                  public gcm::GCMAppHandler,
                                  public content_settings::Observer,
@@ -66,6 +59,7 @@ class PushMessagingServiceImpl : public content::PushMessagingService,
 
   // gcm::GCMAppHandler implementation.
   void ShutdownHandler() override;
+  void OnStoreReset() override;
   void OnMessage(const std::string& app_id,
                  const gcm::IncomingMessage& message) override;
   void OnMessagesDeleted(const std::string& app_id) override;
@@ -255,9 +249,7 @@ class PushMessagingServiceImpl : public content::PushMessagingService,
   base::Closure message_callback_for_testing_;
   base::Closure content_setting_changed_callback_for_testing_;
 
-#if defined(ENABLE_NOTIFICATIONS)
   PushMessagingNotificationManager notification_manager_;
-#endif
 
   // A multiset containing one entry for each in-flight push message delivery,
   // keyed by the receiver's app id.
