@@ -8,6 +8,7 @@
 
 goog.provide('Panel');
 
+goog.require('BrailleCommandHandler');
 goog.require('ISearchUI');
 goog.require('Msgs');
 goog.require('PanelCommand');
@@ -24,6 +25,16 @@ goog.require('cvox.CommandStore');
 Panel = function() {
 };
 
+/**
+ * @enum {string}
+ */
+Panel.Mode = {
+  COLLAPSED: 'collapsed',
+  FOCUSED: 'focused',
+  FULLSCREEN_MENUS: 'menus',
+  FULLSCREEN_TUTORIAL: 'tutorial'
+};
+
 /**
  * Initialize the panel.
  */
@@ -44,10 +55,11 @@ Panel.init = function() {
   this.searchInput_ = $('search');
 
   /** @type {Element} @private */
-  this.brailleTextElement_ = $('braille-text');
+  this.brailleTableElement_ = $('braille-table');
+  this.brailleTableElement2_ = $('braille-table2');
 
-  /** @type {Element} @private */
-  this.brailleCellsElement_ = $('braille-cells');
+  /** @type {Panel.Mode} @private */
+  this.mode_ = Panel.Mode.COLLAPSED;
 
   /**
    * The array of top-level menus.
@@ -119,6 +131,12 @@ Panel.init = function() {
 
   document.addEventListener('keydown', Panel.onKeyDown, false);
   document.addEventListener('mouseup', Panel.onMouseUp, false);
+  window.addEventListener('blur', function(evt) {
+    if (evt.target != window || document.activeElement == document.body)
+      return;
+
+    Panel.closeMenusAndRestoreFocus();
+  }, false);
 
   Panel.searchInput_.addEventListener('blur', Panel.onSearchInputBlur, false);
 };
@@ -128,15 +146,15 @@ Panel.init = function() {
  */
 Panel.updateFromPrefs = function() {
   if (Panel.searching_) {
-    this.speechContainer_.style.display = 'none';
-    this.brailleContainer_.style.display = 'none';
-    this.searchContainer_.style.display = 'block';
+    this.speechContainer_.hidden = true;
+    this.brailleContainer_.hidden = true;
+    this.searchContainer_.hidden = false;
     return;
   }
 
-  this.speechContainer_.style.display = 'block';
-  this.brailleContainer_.style.display = 'block';
-  this.searchContainer_.style.display = 'none';
+  this.speechContainer_.hidden = false;
+  this.brailleContainer_.hidden = false;
+  this.searchContainer_.hidden = true;
 
   if (localStorage['brailleCaptions'] === String(true)) {
     this.speechContainer_.style.visibility = 'hidden';
@@ -187,8 +205,7 @@ Panel.exec = function(command) {
       this.speechElement_.innerHTML += escapeForHtml(command.data);
       break;
     case PanelCommandType.UPDATE_BRAILLE:
-      this.brailleTextElement_.textContent = command.data.text;
-      this.brailleCellsElement_.textContent = command.data.braille;
+      Panel.onUpdateBraille(command.data);
       break;
     case PanelCommandType.ENABLE_MENUS:
       Panel.onEnableMenus();
@@ -205,6 +222,9 @@ Panel.exec = function(command) {
     case PanelCommandType.TUTORIAL:
       Panel.onTutorial();
       break;
+    case PanelCommandType.UPDATE_NOTES:
+      Panel.onTutorial('updateNotes');
+      break;
   }
 };
 
@@ -214,7 +234,7 @@ Panel.exec = function(command) {
 Panel.onEnableMenus = function() {
   Panel.menusEnabled_ = true;
   $('menus_button').disabled = false;
-  $('triangle').style.display = '';
+  $('triangle').hidden = false;
 };
 
 /**
@@ -223,7 +243,38 @@ Panel.onEnableMenus = function() {
 Panel.onDisableMenus = function() {
   Panel.menusEnabled_ = false;
   $('menus_button').disabled = true;
-  $('triangle').style.display = 'none';
+  $('triangle').hidden = true;
+};
+
+/**
+ * Sets the mode, which determines the size of the panel and what objects
+ *     are shown or hidden.
+ * @param {Panel.Mode} mode The new mode.
+ */
+Panel.setMode = function(mode) {
+  if (this.mode_ == mode)
+    return;
+
+  this.mode_ = mode;
+
+  if (this.mode_ == Panel.Mode.FULLSCREEN_MENUS ||
+      this.mode_ == Panel.Mode.FULLSCREEN_TUTORIAL) {
+    // Change the url fragment to 'fullscreen', which signals the native
+    // host code to make the window fullscreen and give it focus.
+    window.location = '#fullscreen';
+  } else if (this.mode_ == Panel.Mode.FOCUSED) {
+    // Change the url fragment to 'focus', which signals the native
+    // host code to give the window focus.
+    window.location = '#focus';
+  } else {
+    // Remove the url fragment, which signals the native host code to
+    // collapse the panel to its normal size and cause it to lose focus.
+    window.location = '#';
+  }
+
+  $('main').hidden = (this.mode_ == Panel.Mode.FULLSCREEN_TUTORIAL);
+  $('menus_background').hidden = (this.mode_ != Panel.Mode.FULLSCREEN_MENUS);
+  $('tutorial').hidden = (this.mode_ != Panel.Mode.FULLSCREEN_TUTORIAL);
 };
 
 /**
@@ -244,9 +295,7 @@ Panel.onOpenMenus = function(opt_event, opt_activateMenuTitle) {
     opt_event.preventDefault();
   }
 
-  // Change the url fragment to 'fullscreen', which signals the native
-  // host code to make the window fullscreen, revealing the menus.
-  window.location = '#fullscreen';
+  Panel.setMode(Panel.Mode.FULLSCREEN_MENUS);
 
   // Clear any existing menus and clear the callback.
   Panel.clearMenus();
@@ -263,13 +312,13 @@ Panel.onOpenMenus = function(opt_event, opt_activateMenuTitle) {
   var categoryToMenu = {
     'navigation': jumpMenu,
     'jump_commands': jumpMenu,
+    'overview': jumpMenu,
+    'tables': jumpMenu,
     'controlling_speech': speechMenu,
+    'information': speechMenu,
     'modifier_keys': chromevoxMenu,
     'help_commands': chromevoxMenu,
 
-    'information': null,  // Get link URL, get page title, etc.
-    'overview': null,     // Headings list, etc.
-    'tables': null,       // Table navigation.
     'braille': null,
     'developer': null};
 
@@ -302,13 +351,19 @@ Panel.onOpenMenus = function(opt_event, opt_activateMenuTitle) {
   });
 
   // Insert items from the bindings into the menus.
+  var sawBindingSet = {};
   sortedBindings.forEach(goog.bind(function(binding) {
+    var command = binding.command;
+    if (sawBindingSet[command])
+      return;
+    sawBindingSet[command] = true;
     var category = cvox.CommandStore.categoryForCommand(binding.command);
     var menu = category ? categoryToMenu[category] : null;
     if (binding.title && menu) {
       menu.addMenuItem(
           binding.title,
           binding.keySeq,
+          BrailleCommandHandler.getDotShortcut(binding.command, true),
           function() {
             var CommandHandler =
                 chrome.extension.getBackgroundPage()['CommandHandler'];
@@ -326,7 +381,7 @@ Panel.onOpenMenus = function(opt_event, opt_activateMenuTitle) {
           var title = tabs[j].title;
           if (tabs[j].active && windows[i].id == lastFocusedWindow.id)
             title += ' ' + Msgs.getMsg('active_tab');
-          tabsMenu.addMenuItem(title, '', (function(win, tab) {
+          tabsMenu.addMenuItem(title, '', '', (function(win, tab) {
             bkgnd.chrome.windows.update(win.id, {focused: true}, function() {
               bkgnd.chrome.tabs.update(tab.id, {active: true});
             });
@@ -338,17 +393,27 @@ Panel.onOpenMenus = function(opt_event, opt_activateMenuTitle) {
 
   // Add a menu item that disables / closes ChromeVox.
   chromevoxMenu.addMenuItem(
-      Msgs.getMsg('disable_chromevox'), 'Ctrl+Alt+Z', function() {
+      Msgs.getMsg('disable_chromevox'), 'Ctrl+Alt+Z', '', function() {
         Panel.onClose();
       });
 
-  // Add menus for various role types.
+  var roleListMenuMapping = [
+    { menuTitle: 'role_heading', predicate: AutomationPredicate.heading },
+    { menuTitle: 'role_landmark', predicate: AutomationPredicate.landmark },
+    { menuTitle: 'role_link', predicate: AutomationPredicate.link },
+    { menuTitle: 'role_form', predicate: AutomationPredicate.formField },
+    { menuTitle: 'role_table', predicate: AutomationPredicate.table }];
+
   var node = bkgnd.ChromeVoxState.instance.getCurrentRange().start.node;
-  Panel.addNodeMenu('role_heading', node, AutomationPredicate.heading);
-  Panel.addNodeMenu('role_landmark', node, AutomationPredicate.landmark);
-  Panel.addNodeMenu('role_link', node, AutomationPredicate.link);
-  Panel.addNodeMenu('role_form', node, AutomationPredicate.formField);
-  Panel.addNodeMenu('role_table', node, AutomationPredicate.table);
+  for (var i = 0; i < roleListMenuMapping.length; ++i) {
+    var menuTitle = roleListMenuMapping[i].menuTitle;
+    var predicate = roleListMenuMapping[i].predicate;
+    // Create node menus asynchronously (because it may require searching a
+    // long document) unless that's the specific menu the
+    // user requested.
+    var async = (menuTitle != opt_activateMenuTitle);
+    Panel.addNodeMenu(menuTitle, node, predicate, async);
+  }
 
   // Activate either the specified menu or the first menu.
   var selectedMenu = Panel.menus_[0];
@@ -365,8 +430,7 @@ Panel.onSearch = function() {
   Panel.pendingCallback_ = null;
   Panel.searching_ = true;
   Panel.updateFromPrefs();
-
-  window.location = '#focus';
+  Panel.setMode(Panel.Mode.FOCUSED);
 
   ISearchUI.get(Panel.searchInput_);
 };
@@ -401,16 +465,129 @@ Panel.addMenu = function(menuMsg) {
   return menu;
 };
 
+/**
+ * Updates the content shown on the virtual braille display.
+ * @param {*=} data The data sent through the PanelCommand.
+ */
+Panel.onUpdateBraille = function(data) {
+  var groups = data.groups;
+  var cols = data.cols;
+  var rows = data.rows;
+  var sideBySide = localStorage['brailleSideBySide'] === 'true';
+
+  var addBorders = function(event) {
+    var cell = event.target;
+    if (cell.tagName == 'TD') {
+      cell.className = 'highlighted-cell';
+      var companionIDs = cell.getAttribute('data-companionIDs');
+      companionIDs.split(' ').map(function(companionID) {
+        var companion = $(companionID);
+        companion.className = 'highlighted-cell';
+      });
+    }
+  };
+
+  var removeBorders = function(event) {
+    var cell = event.target;
+    if (cell.tagName == 'TD') {
+      cell.className = 'unhighlighted-cell';
+      var companionIDs = cell.getAttribute('data-companionIDs');
+      companionIDs.split(' ').map(function(companionID) {
+        var companion = $(companionID);
+        companion.className = 'unhighlighted-cell';
+      });
+    }
+  };
+
+  this.brailleContainer_.addEventListener('mouseover', addBorders);
+  this.brailleContainer_.addEventListener('mouseout', removeBorders);
+
+  // Clear the tables.
+  var rowCount = this.brailleTableElement_.rows.length;
+  for (var i = 0; i < rowCount; i++) {
+    this.brailleTableElement_.deleteRow(0);
+  }
+  rowCount = this.brailleTableElement2_.rows.length;
+  for (var i = 0; i < rowCount; i++) {
+    this.brailleTableElement2_.deleteRow(0);
+  }
+
+  var row1, row2;
+  rowCount = 0;
+  var cellCount = cols;
+  for (var i = 0; i < groups.length; i++) {
+    if (cellCount == cols) {
+      cellCount = 0;
+      // Check if we reached the limit on the number of rows we can have.
+      if (rowCount == rows)
+        break;
+      rowCount++;
+      row1 = this.brailleTableElement_.insertRow(-1);
+      if (sideBySide) {
+        // Side by side.
+        row2 = this.brailleTableElement2_.insertRow(-1);
+      } else {
+        // Interleaved.
+        row2 = this.brailleTableElement_.insertRow(-1);
+      }
+    }
+
+    var topCell = row1.insertCell(-1);
+    topCell.innerHTML = groups[i][0];
+    topCell.id = i + '-textCell';
+    topCell.setAttribute('data-companionIDs', i + '-brailleCell');
+    topCell.className = 'unhighlighted-cell';
+
+    var bottomCell = row2.insertCell(-1);
+    bottomCell.id = i + '-brailleCell';
+    bottomCell.setAttribute('data-companionIDs', i + '-textCell');
+    bottomCell.className = 'unhighlighted-cell';
+    if (cellCount + groups[i][1].length > cols) {
+      bottomCell.innerHTML = groups[i][1].substring(0, cols - cellCount);
+      if (rowCount == rows)
+        break;
+      rowCount++;
+      row1 = this.brailleTableElement_.insertRow(-1);
+      if (sideBySide) {
+        // Side by side.
+        row2 = this.brailleTableElement2_.insertRow(-1);
+      } else {
+        // Interleaved.
+        row2 = this.brailleTableElement_.insertRow(-1);
+      }
+      var bottomCell2 = row2.insertCell(-1);
+      bottomCell2.id = i + '-brailleCell2';
+      bottomCell2.setAttribute('data-companionIDs',
+          i + '-textCell ' + i + '-brailleCell');
+      bottomCell.setAttribute('data-companionIDs',
+          bottomCell.getAttribute('data-companionIDs') +
+          ' ' + i + '-brailleCell2');
+      topCell.setAttribute('data-companionID2',
+          bottomCell.getAttribute('data-companionIDs') +
+          ' ' + i + '-brailleCell2');
+
+      bottomCell2.className = 'unhighlighted-cell';
+      bottomCell2.innerHTML = groups[i][1].substring(cols - cellCount);
+      cellCount = bottomCell2.innerHTML.length;
+    } else {
+      bottomCell.innerHTML = groups[i][1];
+      cellCount += groups[i][1].length;
+    }
+  }
+};
+
+
 
 /**
  * Create a new node menu with the given name and add it to the menu bar.
  * @param {string} menuMsg The msg id of the new menu to add.
- * @param {chrome.automation.AutomationNode} node
+ * @param {!chrome.automation.AutomationNode} node
  * @param {AutomationPredicate.Unary} pred
+ * @param {boolean} defer If true, defers populating the menu.
  * @return {PanelMenu} The menu just created.
  */
-Panel.addNodeMenu = function(menuMsg, node, pred) {
-  var menu = new PanelNodeMenu(menuMsg, node, pred);
+Panel.addNodeMenu = function(menuMsg, node, pred, defer) {
+  var menu = new PanelNodeMenu(menuMsg, node, pred, defer);
   $('menu-bar').appendChild(menu.menuBarItemElement);
   menu.menuBarItemElement.addEventListener('mouseover', function() {
     Panel.activateMenu(menu);
@@ -522,6 +699,11 @@ Panel.onMouseUp = function(event) {
  * @param {Event} event The key event.
  */
 Panel.onKeyDown = function(event) {
+  if (event.key == 'Escape' && Panel.mode_ == Panel.Mode.FULLSCREEN_TUTORIAL) {
+    Panel.setMode(Panel.Mode.COLLAPSED);
+    return;
+  }
+
   if (!Panel.activeMenu_)
     return;
 
@@ -577,8 +759,7 @@ Panel.onSearchInputBlur = function() {
   if (Panel.searching_) {
     if (document.activeElement != Panel.searchInput_ || !document.hasFocus()) {
       Panel.searching_ = false;
-      if (window.location == '#focus')
-        window.location = '#';
+      Panel.setMode(Panel.Mode.COLLAPSED);
       Panel.updateFromPrefs();
       Panel.searchInput_.value = '';
     }
@@ -592,13 +773,15 @@ Panel.onOptions = function() {
   var bkgnd =
       chrome.extension.getBackgroundPage()['ChromeVoxState']['instance'];
   bkgnd['showOptionsPage']();
-  window.location = '#';
+  Panel.setMode(Panel.Mode.COLLAPSED);
 };
 
 /**
  * Exit ChromeVox.
  */
 Panel.onClose = function() {
+  // Change the url fragment to 'close', which signals the native code
+  // to exit ChromeVox.
   window.location = '#close';
 };
 
@@ -617,33 +800,51 @@ Panel.getCallbackForCurrentItem = function() {
  * was queued, execute it once focus is restored.
  */
 Panel.closeMenusAndRestoreFocus = function() {
-  // Make sure we're not in full-screen mode.
-  window.location = '#';
+  // Watch for the next focus event.
+  var onFocus = function(desktop, evt) {
+    desktop.removeEventListener(chrome.automation.EventType.focus, onFocus);
+    if (Panel.pendingCallback_) {
+      // Clear it before calling it, in case the callback itself triggers
+      // another pending callback.
+      var pendingCallback = Panel.pendingCallback_;
+      Panel.pendingCallback_ = null;
+      pendingCallback();
+    }
+  }.bind(this);
 
-  this.activeMenu_ = null;
+  chrome.automation.getDesktop(function(desktop) {
+    onFocus = /** @type {function(chrome.automation.AutomationEvent)} */(
+        onFocus.bind(this, desktop));
+    desktop.addEventListener(chrome.automation.EventType.focus,
+                             onFocus,
+                             true);
 
-  var bkgnd =
-      chrome.extension.getBackgroundPage()['ChromeVoxState']['instance'];
-  bkgnd['endExcursion'](Panel.pendingCallback_);
+    // Make sure all menus are cleared to avoid bogous output when we re-open.
+    Panel.clearMenus();
+
+    // Make sure we're not in full-screen mode.
+    Panel.setMode(Panel.Mode.COLLAPSED);
+
+    this.activeMenu_ = null;
+  });
 };
 
 /**
  * Open the tutorial.
+ * @param {string=} opt_page Show a specific page.
  */
-Panel.onTutorial = function() {
-  var bkgnd =
-      chrome.extension.getBackgroundPage()['ChromeVoxState']['instance'];
-  bkgnd['startExcursion']();
-
+Panel.onTutorial = function(opt_page) {
   // Change the url fragment to 'fullscreen', which signals the native
   // host code to make the window fullscreen, revealing the menus.
-  window.location = '#fullscreen';
+  Panel.setMode(Panel.Mode.FULLSCREEN_TUTORIAL);
 
-  $('main').style.display = 'none';
-  $('menus_background').style.display = 'none';
-  $('tutorial').style.display = 'block';
-
-  Panel.tutorial_.firstPage();
+  switch (opt_page) {
+    case 'updateNotes':
+      Panel.tutorial_.updateNotes();
+      break;
+    default:
+      Panel.tutorial_.lastViewedPage();
+  }
 };
 
 /**
@@ -664,13 +865,16 @@ Panel.onTutorialPrevious = function() {
  * Close the tutorial.
  */
 Panel.onCloseTutorial = function() {
-  $('main').style.display = 'block';
-  $('tutorial').style.display = 'none';
-  Panel.closeMenusAndRestoreFocus();
+  Panel.setMode(Panel.Mode.COLLAPSED);
 };
 
 window.addEventListener('load', function() {
   Panel.init();
+
+  switch (location.search.slice(1)) {
+    case 'tutorial':
+      Panel.onTutorial();
+  }
 }, false);
 
 window.addEventListener('hashchange', function() {
