@@ -57,7 +57,7 @@ cvox.TtsBackground = function(opt_enableMath) {
   // specified.
   if (this.ttsProperties['lang'] == undefined) {
     this.ttsProperties['lang'] =
-        chrome.i18n.getMessage('@@ui_locale').replace('_', '-');
+        chrome.i18n.getUILanguage();
   }
 
   this.lastEventType = 'end';
@@ -303,6 +303,19 @@ cvox.TtsBackground.prototype.speakUsingQueue_ = function(utterance, queueMode) {
   // Next, add the new utterance to the queue.
   this.utteranceQueue_.push(utterance);
 
+  // Update the caption panel.
+  if (utterance.properties &&
+      utterance.properties['pitch'] &&
+      utterance.properties['pitch'] < this.ttsProperties['pitch']) {
+    (new PanelCommand(
+        PanelCommandType.ADD_ANNOTATION_SPEECH,
+        utterance.textString)).send();
+  } else {
+    (new PanelCommand(
+        PanelCommandType.ADD_NORMAL_SPEECH,
+        utterance.textString)).send();
+  }
+
   // Now start speaking the next item in the queue.
   this.startSpeakingNextItemInQueue_();
 };
@@ -329,10 +342,9 @@ cvox.TtsBackground.prototype.startSpeakingNextItemInQueue_ = function() {
   }
 
   this.currentUtterance_ = this.utteranceQueue_.shift();
-  var utterance = this.currentUtterance_;
-  var utteranceId = utterance.id;
+  var utteranceId = this.currentUtterance_.id;
 
-  utterance.properties['onEvent'] = goog.bind(function(event) {
+  this.currentUtterance_.properties['onEvent'] = goog.bind(function(event) {
             this.onTtsEvent_(event, utteranceId);
           },
   this);
@@ -340,25 +352,13 @@ cvox.TtsBackground.prototype.startSpeakingNextItemInQueue_ = function() {
   var validatedProperties = {};
   for (var i = 0; i < cvox.TtsBackground.ALLOWED_PROPERTIES_.length; i++) {
     var p = cvox.TtsBackground.ALLOWED_PROPERTIES_[i];
-    if (utterance.properties[p]) {
-      validatedProperties[p] = utterance.properties[p];
+    if (this.currentUtterance_.properties[p]) {
+      validatedProperties[p] = this.currentUtterance_.properties[p];
     }
   }
 
-  // Update the caption panel.
-  if (utterance.properties &&
-      utterance.properties['pitch'] &&
-      utterance.properties['pitch'] < this.ttsProperties['pitch']) {
-    (new PanelCommand(
-        PanelCommandType.ADD_ANNOTATION_SPEECH,
-        utterance.textString)).send();
-  } else {
-    (new PanelCommand(
-        PanelCommandType.ADD_NORMAL_SPEECH,
-        utterance.textString)).send();
-  }
-
-  chrome.tts.speak(utterance.textString, validatedProperties);
+  chrome.tts.speak(this.currentUtterance_.textString,
+                   validatedProperties);
 };
 
 /**
@@ -680,24 +680,30 @@ cvox.TtsBackground.prototype.clearTimeout_ = function() {
  * Update the current voice used to speak based upon values in storage. If that
  * does not succeed, fallback to use system locale when picking a voice.
  * @param {string} voiceName Voice name to set.
+ * @param {function(string) : void=} opt_callback Called when the voice is
+ * determined.
  * @private
  */
-cvox.TtsBackground.prototype.updateVoice_ = function(voiceName) {
+cvox.TtsBackground.prototype.updateVoice_ = function(voiceName, opt_callback) {
   chrome.tts.getVoices(goog.bind(function(voices) {
-    var currentLocale = chrome.i18n.getMessage('@@ui_locale').replace('_', '-');
+    chrome.i18n.getAcceptLanguages(goog.bind(function(acceptLanguages) {
+      var currentLocale = acceptLanguages[0] ||
+          chrome.i18n.getUILanguage() || '';
+      var match = voices.find.bind(voices);
+      var newVoice =
+          match(function(v) { return v.voiceName == voiceName; }) ||
+          match(function(v) { return v.lang === currentLocale; }) ||
+          match(function(v) { return currentLocale.startsWith(v.lang); }) ||
+          match(function(v) { return v.lang &&
+              v.lang.startsWith(currentLocale); }) ||
+          voices[0];
 
-    // TODO(dtseng): Prefer voices having the default property once we switch to
-    // web speech. See crbug.com/544139.
-
-    var newVoice = voices.find(
-            function(v) { return v.voiceName == voiceName; }) ||
-        voices.find(function(v) { return v.lang === currentLocale; }) ||
-        voices.find(function(v) { return currentLocale.startsWith(v.lang); }) ||
-        voices[0];
-
-    if (newVoice) {
-      this.currentVoice = newVoice.voiceName;
-      this.startSpeakingNextItemInQueue_();
-    }
+      if (newVoice) {
+        this.currentVoice = newVoice.voiceName;
+        this.startSpeakingNextItemInQueue_();
+      }
+      if (opt_callback)
+        opt_callback(this.currentVoice);
+    }, this));
   }, this));
 };
