@@ -58,6 +58,14 @@ Polymer({
       value: false,
     },
 
+    /**
+     * Flag that shows Timezone Selection screen.
+     */
+    timezoneScreenShown: {
+      type: Boolean,
+      value: false,
+    },
+
     /**
      * Flag that shows Network Selection screen.
      */
@@ -81,6 +89,23 @@ Polymer({
     a11yStatus: {
       type: Object,
     },
+
+    /**
+     * A list of timezones for Timezone Selection screen.
+     * @type {!Array<OobeTypes.TimezoneDsc>}
+     */
+    timezones: {
+      type: Object,
+      value: [],
+    },
+
+    /**
+     * If UI uses forced keyboard navigation.
+     */
+    highlightStrength: {
+      type: String,
+      value: '',
+    },
   },
 
   /**
@@ -91,6 +116,7 @@ Polymer({
     this.networkSelectionScreenShown = false;
     this.languageSelectionScreenShown = false;
     this.accessibilityOptionsScreenShown = false;
+    this.timezoneScreenShown = false;
   },
 
   /**
@@ -123,21 +149,21 @@ Polymer({
     return [
       {
         customItemName: 'proxySettingsMenuName',
-        polymerIcon: 'oobe-welcome:add',
+        polymerIcon: 'oobe-welcome-20:add-proxy',
         customData: {
           onTap: function() { self.OpenProxySettingsDialog_(); },
         },
       },
       {
         customItemName: 'addWiFiNetworkMenuName',
-        polymerIcon: 'oobe-welcome:add',
+        polymerIcon: 'oobe-welcome-20:add-wifi',
         customData: {
           onTap: function() { self.OpenAddWiFiNetworkDialog_(); },
         },
       },
       {
         customItemName: 'addMobileNetworkMenuName',
-        polymerIcon: 'oobe-welcome:add',
+        polymerIcon: 'oobe-welcome-20:add-cellular',
         customData: {
           onTap: function() { self.OpenAddWiFiNetworkDialog_(); },
         },
@@ -145,6 +171,14 @@ Polymer({
     ];
   },
 
+  /**
+   * Returns true if timezone button should be visible.
+   * @private
+   */
+  isTimezoneButtonVisible_: function(highlightStrength) {
+    return highlightStrength === 'strong';
+  },
+
   /**
    * Handle "Next" button for "Welcome" screen.
    *
@@ -175,6 +209,16 @@ Polymer({
     this.accessibilityOptionsScreenShown = true;
   },
 
+  /**
+   * Handle "Timezone" button for "Welcome" screen.
+   *
+   * @private
+   */
+  onWelcomeTimezoneButtonClicked_: function() {
+    this.hideAllScreens_();
+    this.timezoneScreenShown = true;
+  },
+
   /**
    * Handle Networwork Setup screen "Proxy settings" button.
    *
@@ -222,6 +266,9 @@ Polymer({
     if (state.GUID != this.networkLastSelectedGuid_)
       return;
 
+    // Duplicate asynchronous event may be delivered to some other screen,
+    // so disable it.
+    this.networkLastSelectedGuid_ = '';
     this.onSelectedNetworkConnected_();
   },
 
@@ -273,6 +320,17 @@ Polymer({
     itemState.customData.onTap();
   },
 
+  /**
+   * Handle "<- Back" button on network selection screen.
+   *
+   * @private
+   */
+  onNetworkSelectionBackButtonPressed_: function() {
+    this.networkLastSelectedGuid_ = '';
+    this.hideAllScreens_();
+    this.welcomeScreenShown = true;
+  },
+
   /**
    * Handle language selection.
    *
@@ -331,4 +389,30 @@ Polymer({
     chrome.send(
         event.currentTarget.chromeMessage, [event.currentTarget.checked]);
   },
+
+  /** ******************** Timezone section ******************* */
+
+  /**
+   * Handle "OK" button for "Timezone Selection" screen.
+   *
+   * @private
+   */
+  closeTimezoneSection_: function() {
+    this.hideAllScreens_();
+    this.welcomeScreenShown = true;
+  },
+
+  /**
+   * Handle timezone selection.
+   *
+   * @param {!{detail: {!OobeTypes.Timezone}}} event
+   * @private
+   */
+  onTimezoneSelected_: function(event) {
+    var item = event.detail;
+    if (!item)
+      return;
+
+    this.screen.onTimezoneSelected_(item.value);
+  },
 });
