@@ -8,7 +8,7 @@ chrome.runtime.onMessageExternal.addListener(
         var error = null;
         if (errorString) {
           error = {};
-          error['name'] = 'ComponentExtensonError';
+          error['name'] = 'ComponentExtensionError';
           error['message'] = errorString;
         }
 
@@ -79,36 +79,39 @@ chrome.runtime.onMessageExternal.addListener(
               requestInfo, origin, logId, doSendResponse);
           return true;
         } else if (method == 'logging.stopAndUpload') {
-          stopAllRtpDump(requestInfo, origin,
-                         function(rtpDumpValue, rtpDumpErrorString) {
-            if (chrome.extension.lastError !== undefined) {
-              // Stopping RTP dump failed, try to stop logging but don't try
-              // to upload since that will fail.
+          // Stop everything and upload. This is allowed to be called even if
+          // logs have already been stopped or not started. Therefore, ignore
+          // any errors along the way, but store them, so that if upload fails
+          // they are all reported back.
+          // Stop incoming and outgoing RTP dumps separately, otherwise
+          // stopRtpDump will fail and not stop anything if either type has not
+          // been started.
+          var errors = [];
+          chrome.webrtcLoggingPrivate.stopRtpDump(
+              requestInfo, origin, true /* incoming */, false /* outgoing */,
+              function() {
+            appendLastErrorMessage(errors);
+            chrome.webrtcLoggingPrivate.stopRtpDump(
+                requestInfo, origin, false /* incoming */, true /* outgoing */,
+                function() {
+              appendLastErrorMessage(errors);
               chrome.webrtcLoggingPrivate.stop(
-                  requestInfo, origin, function(stopValue, stopErrorString) {
-                if (chrome.extension.lastError !== undefined) {
-                  // Stopping logging also failed, report the error for logging.
-                  doSendResponse(stopValue, stopErrorString);
-                } else {
-                  // Stopping logging succeeded, report the error for RTP dump.
-                  doSendResponse(rtpDumpValue, rtpDumpErrorString);
-                }
+                  requestInfo, origin, function() {
+                appendLastErrorMessage(errors);
+                chrome.webrtcLoggingPrivate.upload(
+                    requestInfo, origin,
+                    function(uploadValue) {
+                  var errorMessage = null;
+                  // If upload fails, report all previous errors. Otherwise,
+                  // throw them away.
+                  if (chrome.extension.lastError !== undefined) {
+                    appendLastErrorMessage(errors);
+                    errorMessage = errors.join('; ');
+                  }
+                  doSendResponse(uploadValue, errorMessage);
+                });
               });
-            } else {
-              // Stopping RTP dump succeeded.
-              chrome.webrtcLoggingPrivate.stop(
-                  requestInfo, origin, function(stopValue, stopErrorString) {
-                if (chrome.extension.lastError !== undefined) {
-                  // Stopping logging failed, report error and don't try to
-                  // upload since that will fail.
-                  doSendResponse(stopValue, stopErrorString);
-                } else {
-                  // Stopping logging succeeded.
-                  chrome.webrtcLoggingPrivate.upload(
-                      requestInfo, origin, doSendResponse);
-                }
-              });
-            }
+            });
           });
           return true;
         } else if (method == 'logging.store') {
@@ -289,15 +292,9 @@ function onProcessCpu(port) {
   });
 }
 
-function stopAllRtpDump(requestInfo, origin, callback) {
-  // Stops incoming and outgoing separately, otherwise stopRtpDump will fail if
-  // either type of dump has not been started.
-  chrome.webrtcLoggingPrivate.stopRtpDump(
-      requestInfo, origin, true, false,
-      function() {
-        chrome.webrtcLoggingPrivate.stopRtpDump(
-            requestInfo, origin, false, true, callback);
-      });
+function appendLastErrorMessage(errors) {
+  if (chrome.extension.lastError !== undefined)
+    errors.push(chrome.extension.lastError.message);
 }
 
 chrome.runtime.onConnectExternal.addListener(function(port) {
