@@ -44,6 +44,20 @@ function removeChildren(element_id) {
   element.textContent = '';
 }
 
+function removeAdditionalChildren(element_id) {
+  var element = $(element_id);
+  var elements = element.querySelectorAll('.row.additional');
+  for (var i = 0; i != elements.length; i++)
+    element.removeChild(elements[i]);
+}
+
+function removeChildrenExceptAdditional(element_id) {
+  var element = $(element_id);
+  var elements = element.querySelectorAll('.row:not(.additional)');
+  for (var i = 0; i != elements.length; i++)
+      element.removeChild(elements[i]);
+}
+
 function onload() {
   var tabContents = document.querySelectorAll('#content > div');
   for (var i = 0; i != tabContents.length; i++) {
@@ -104,15 +118,21 @@ function populateTargets(source, data) {
     console.error('Unknown source type: ' + source);
 }
 
+function populateAdditionalTargets(data) {
+  removeAdditionalChildren('others-list');
+  for (var i = 0; i < data.length; i++)
+    addAdditionalTargetsToOthersList(data[i]);
+}
+
 function populateLocalTargets(data) {
   removeChildren('pages-list');
   removeChildren('extensions-list');
   removeChildren('apps-list');
-  removeChildren('others-list');
   removeChildren('workers-list');
   removeChildren('service-workers-list');
+  removeChildrenExceptAdditional('others-list');
 
-    for (var i = 0; i < data.length; i++) {
+  for (var i = 0; i < data.length; i++) {
     if (data[i].type === 'page')
       addToPagesList(data[i]);
     else if (data[i].type === 'background_page')
@@ -428,6 +448,10 @@ function addToOthersList(data) {
   addTargetToList(data, $('others-list'), ['url']);
 }
 
+function addAdditionalTargetsToOthersList(data) {
+  addTargetToList(data, $('others-list'), ['name', 'url']);
+}
+
 function formatValue(data, property) {
   var value = data[property];
 
@@ -567,7 +591,11 @@ function addTargetToList(data, list, properties) {
   actionBox.className = 'actions';
   subrowBox.appendChild(actionBox);
 
-  if (!data.hasCustomInspectAction) {
+  if (data.isAdditional) {
+    addActionLink(row, 'inspect',
+        sendCommand.bind(null, 'inspect-additional', data.url), false);
+    row.classList.add('additional');
+  } else if (!data.hasCustomInspectAction) {
     addActionLink(row, 'inspect', sendTargetCommand.bind(null, 'inspect', data),
         data.hasNoUniqueId || data.adbAttachedForeign);
   }
@@ -774,6 +802,8 @@ function updateDiscoverUsbDevicesEnabled(enabled) {
 
 function updatePortForwardingEnabled(enabled) {
   updateCheckbox('port-forwarding-enable', enabled);
+  $('infobar').classList.toggle('show', enabled);
+  $('infobar').scrollIntoView();
 }
 
 function updatePortForwardingConfig(config) {
@@ -995,5 +1025,4 @@ function populatePortStatus(devicesStatusMap) {
 }
 
 document.addEventListener('DOMContentLoaded', onload);
-
 window.addEventListener('hashchange', onHashChange);
