@@ -24,7 +24,6 @@ Polymer({
 
   behaviors: [
     Polymer.IronScrollTargetBehavior,
-    WebUIListenerBehavior,
   ],
 
   properties: {
@@ -51,7 +50,6 @@ Polymer({
           queryingDisabled: false,
           _range: HistoryRange.ALL_TIME,
           searchTerm: '',
-          // TODO(calamity): Make history toolbar buttons change the offset
           groupedOffset: 0,
 
           set range(val) { this._range = Number(val); },
@@ -86,32 +84,50 @@ Polymer({
       type: Boolean,
       reflectToAttribute: true,
       notify: true,
-    }
+    },
+
+    showMenuPromo_: {
+      type: Boolean,
+      value: function() {
+        return loadTimeData.getBoolean('showMenuPromo');
+      },
+    },
   },
 
-  // TODO(calamity): Replace these event listeners with data bound properties.
   listeners: {
-    'cr-menu-tap': 'onMenuTap_',
-    'history-checkbox-select': 'checkboxSelected',
-    'unselect-all': 'unselectAll',
+    'cr-toolbar-menu-promo-close': 'onCrToolbarMenuPromoClose_',
+    'cr-toolbar-menu-promo-shown': 'onCrToolbarMenuPromoShown_',
+    'cr-toolbar-menu-tap': 'onCrToolbarMenuTap_',
     'delete-selected': 'deleteSelected',
+    'history-checkbox-select': 'checkboxSelected',
     'history-close-drawer': 'closeDrawer_',
     'history-view-changed': 'historyViewChanged_',
+    'opened-changed': 'onOpenedChanged_',
+    'unselect-all': 'unselectAll',
   },
 
-  /** @override */
-  ready: function() {
-    this.grouped_ = loadTimeData.getBoolean('groupByDomain');
+  /** @private {?function(!Event)} */
+  boundOnCanExecute_: null,
 
-    cr.ui.decorate('command', cr.ui.Command);
-    document.addEventListener('canExecute', this.onCanExecute_.bind(this));
-    document.addEventListener('command', this.onCommand_.bind(this));
-  },
+  /** @private {?function(!Event)} */
+  boundOnCommand_: null,
 
   /** @override */
   attached: function() {
-    this.addWebUIListener('sign-in-state-updated',
-                          this.updateSignInState.bind(this));
+    this.grouped_ = loadTimeData.getBoolean('groupByDomain');
+
+    cr.ui.decorate('command', cr.ui.Command);
+    this.boundOnCanExecute_ = this.onCanExecute_.bind(this);
+    this.boundOnCommand_ = this.onCommand_.bind(this);
+
+    document.addEventListener('canExecute', this.boundOnCanExecute_);
+    document.addEventListener('command', this.boundOnCommand_);
+  },
+
+  /** @override */
+  detached: function() {
+    document.removeEventListener('canExecute', this.boundOnCanExecute_);
+    document.removeEventListener('command', this.boundOnCommand_);
   },
 
   onFirstRender: function() {
@@ -130,7 +146,11 @@ Polymer({
     }
 
     // Lazily load the remainder of the UI.
-    md_history.ensureLazyLoaded();
+    md_history.ensureLazyLoaded().then(function() {
+      window.requestIdleCallback(function() {
+        document.fonts.load('bold 12px Roboto');
+      });
+    });
   },
 
   /** Overridden from IronScrollTargetBehavior */
@@ -140,12 +160,31 @@ Polymer({
   },
 
   /** @private */
-  onMenuTap_: function() {
+  onCrToolbarMenuPromoClose_: function() {
+    this.showMenuPromo_ = false;
+  },
+
+  /** @private */
+  onCrToolbarMenuPromoShown_: function() {
+    md_history.BrowserService.getInstance().menuPromoShown();
+  },
+
+  /** @private */
+  onCrToolbarMenuTap_: function() {
     var drawer = this.$$('#drawer');
     if (drawer)
       drawer.toggle();
   },
 
+  /**
+   * @param {!CustomEvent} e
+   * @private
+   */
+  onOpenedChanged_: function(e) {
+    if (e.detail.value)
+      this.showMenuPromo_ = false;
+  },
+
   /**
    * Listens for history-item being selected or deselected (through checkbox)
    * and changes the view of the top toolbar.
@@ -199,6 +238,7 @@ Polymer({
     e = /** @type {cr.ui.CanExecuteEvent} */(e);
     switch (e.command.id) {
       case 'find-command':
+      case 'toggle-grouped':
         e.canExecute = true;
         break;
       case 'slash-command':
@@ -219,23 +259,15 @@ Polymer({
       this.focusToolbarSearchField();
     if (e.command.id == 'delete-command')
       this.deleteSelected();
+    if (e.command.id == 'toggle-grouped')
+      this.grouped_ = !this.grouped_;
   },
 
   /**
    * @param {!Array<!ForeignSession>} sessionList Array of objects describing
    *     the sessions from other devices.
-   * @param {boolean} isTabSyncEnabled Is tab sync enabled for this profile?
    */
-  setForeignSessions: function(sessionList, isTabSyncEnabled) {
-    if (!isTabSyncEnabled) {
-      var syncedDeviceManagerElem =
-      /** @type {HistorySyncedDeviceManagerElement} */this
-          .$$('history-synced-device-manager');
-      if (syncedDeviceManagerElem)
-        syncedDeviceManagerElem.tabSyncDisabled();
-      return;
-    }
-
+  setForeignSessions: function(sessionList) {
     this.set('queryResult_.sessionList', sessionList);
   },
 
@@ -298,13 +330,15 @@ Polymer({
     // This allows the synced-device-manager to render so that it can be set as
     // the scroll target.
     requestAnimationFrame(function() {
-      // <iron-pages> can occasionally end up with no item selected during
-      // tests.
-      if (!this.$.content.selectedItem)
-        return;
-      this.scrollTarget =
-          this.$.content.selectedItem.getContentScrollTarget();
-      this._scrollHandler();
+      md_history.ensureLazyLoaded().then(function() {
+        // <iron-pages> can occasionally end up with no item selected during
+        // tests.
+        if (!this.$.content.selectedItem)
+          return;
+        this.scrollTarget =
+            this.$.content.selectedItem.getContentScrollTarget();
+        this._scrollHandler();
+      }.bind(this));
     }.bind(this));
     this.recordHistoryPageView_();
   },
