@@ -58,30 +58,24 @@ function historyResult(info, results) {
  */
 function showNotification(
     hasSyncedResults, includeOtherFormsOfBrowsingHistory) {
-  // TODO(msramek): |hasSyncedResults| was used in the old WebUI to show
-  // the message about other signed-in devices. This message does not exist
-  // in the MD history anymore, so the parameter is not needed. Remove it
-  // when WebUI is removed and this becomes the only client of
-  // BrowsingHistoryHandler.
   waitForAppUpgrade().then(function() {
-    /** @type {HistoryAppElement} */ ($('history-app')).showSidebarFooter =
-        includeOtherFormsOfBrowsingHistory;
+    var app = /** @type {HistoryAppElement} */ ($('history-app'));
+    app.showSidebarFooter = includeOtherFormsOfBrowsingHistory;
+    app.hasSyncedResults = hasSyncedResults;
   });
 }
 
 /**
  * Receives the synced history data. An empty list means that either there are
  * no foreign sessions, or tab sync is disabled for this profile.
- * |isTabSyncEnabled| makes it possible to distinguish between the cases.
  *
  * @param {!Array<!ForeignSession>} sessionList Array of objects describing the
  *     sessions from other devices.
- * @param {boolean} isTabSyncEnabled Is tab sync enabled for this profile?
  */
-function setForeignSessions(sessionList, isTabSyncEnabled) {
+function setForeignSessions(sessionList) {
   waitForAppUpgrade().then(function() {
     /** @type {HistoryAppElement} */($('history-app'))
-        .setForeignSessions(sessionList, isTabSyncEnabled);
+        .setForeignSessions(sessionList);
   });
 }
 
