@@ -45,6 +45,15 @@ var HistoryListBehavior = {
     'history-checkbox-select': 'itemSelected_',
   },
 
+  /**
+   * @param {!Array<!HistoryEntry>} results
+   * @param {boolean} incremental True if the results are from an incremental
+   *     query.
+   * @param {boolean} finished True if this is the end of available results.
+   * @abstract
+   */
+  addNewResults: function(results, incremental, finished) {},
+
   /**
    * @param {number} historyDataLength
    * @return {boolean}
@@ -213,10 +222,12 @@ var HistoryListBehavior = {
     if (paths.length == 0)
       paths.push(item.path);
 
-    paths.forEach(function(path) {
-      this.set(path + '.selected', item.selected);
+    var selected = !this.selectedPaths.has(item.path);
 
-      if (item.selected) {
+    paths.forEach(function(path) {
+      this.set(path + '.selected', selected);
+
+      if (selected) {
         this.selectedPaths.add(path);
         return;
       }
