@@ -8,19 +8,11 @@ Polymer({
     // Number of history items currently selected.
     // TODO(calamity): bind this to
     // listContainer.selectedItem.selectedPaths.length.
-    count: {
-      type: Number,
-      value: 0,
-      observer: 'changeToolbarView_'
-    },
+    count: {type: Number, value: 0, observer: 'changeToolbarView_'},
 
     // True if 1 or more history items are selected. When this value changes
     // the background colour changes.
-    itemsSelected_: {
-      type: Boolean,
-      value: false,
-      reflectToAttribute: true
-    },
+    itemsSelected_: {type: Boolean, value: false, reflectToAttribute: true},
 
     // The most recent term entered in the search field. Updated incrementally
     // as the user types.
@@ -32,14 +24,10 @@ Polymer({
 
     // True if the backend is processing and a spinner should be shown in the
     // toolbar.
-    spinnerActive: {
-      type: Boolean,
-      value: false
-    },
+    spinnerActive: {type: Boolean, value: false},
 
     hasDrawer: {
       type: Boolean,
-      observer: 'hasDrawerChanged_',
       reflectToAttribute: true,
     },
 
@@ -54,11 +42,19 @@ Polymer({
     // The period to search over. Matches BrowsingHistoryHandler::Range.
     groupedRange: {
       type: Number,
-      value: 0,
       reflectToAttribute: true,
-      notify: true
+      notify: true,
     },
 
+    groupedOffset: {
+      type: Number,
+      notify: true,
+    },
+
+    querying: Boolean,
+
+    hasMoreResults: Boolean,
+
     // The start time of the query range.
     queryStartTime: String,
 
@@ -67,12 +63,7 @@ Polymer({
 
     // Whether to show the menu promo (a tooltip that points at the menu button
     // in narrow mode).
-    showMenuPromo_: {
-      type: Boolean,
-      value: function() {
-        return loadTimeData.getBoolean('showMenuPromo');
-      },
-    },
+    showMenuPromo: Boolean,
   },
 
   /** @return {CrToolbarSearchFieldElement} */
@@ -81,22 +72,19 @@ Polymer({
         .getSearchField();
   },
 
-  showSearchField: function() {
-    this.searchField.showAndFocus();
-  },
+  showSearchField: function() { this.searchField.showAndFocus(); },
 
   /**
    * Changes the toolbar background color depending on whether any history items
    * are currently selected.
    * @private
    */
-  changeToolbarView_: function() {
-    this.itemsSelected_ = this.count > 0;
-  },
+  changeToolbarView_: function() { this.itemsSelected_ = this.count > 0; },
 
   /**
    * When changing the search term externally, update the search field to
    * reflect the new search term.
+   * @private
    */
   searchTermChanged_: function() {
     if (this.searchField.getValue() != this.searchTerm) {
@@ -105,11 +93,6 @@ Polymer({
     }
   },
 
-  /** @private */
-  onMenuPromoShown_: function() {
-    md_history.BrowserService.getInstance().menuPromoShown();
-  },
-
   /**
    * @param {!CustomEvent} event
    * @private
@@ -128,13 +111,11 @@ Polymer({
       dropdown.open();
   },
 
-  onClearSelectionTap_: function() {
-    this.fire('unselect-all');
-  },
+  /** @private */
+  onClearSelectionTap_: function() { this.fire('unselect-all'); },
 
-  onDeleteTap_: function() {
-    this.fire('delete-selected');
-  },
+  /** @private */
+  onDeleteTap_: function() { this.fire('delete-selected'); },
 
   /**
    * If the user is a supervised user the delete button is not shown.
@@ -144,10 +125,12 @@ Polymer({
     return loadTimeData.getBoolean('allowDeletingHistory');
   },
 
+  /** @private */
   numberOfItemsSelected_: function(count) {
     return count > 0 ? loadTimeData.getStringF('itemsSelected', count) : '';
   },
 
+  /** @private */
   getHistoryInterval_: function(queryStartTime, queryEndTime) {
     // TODO(calamity): Fix the format of these dates.
     return loadTimeData.getStringF(
@@ -155,7 +138,26 @@ Polymer({
   },
 
   /** @private */
-  hasDrawerChanged_: function() {
-    this.updateStyles();
+  onTodayTap_: function() {
+    if (!this.querying)
+      this.groupedOffset = 0;
   },
+
+  /** @private */
+  onPrevTap_: function() {
+    if (!this.querying)
+      this.groupedOffset = this.groupedOffset + 1;
+  },
+
+  /** @private */
+  onNextTap_: function() {
+    if (!this.querying)
+      this.groupedOffset = this.groupedOffset - 1;
+  },
+
+  /**
+   * @private
+   * @return {boolean}
+   */
+  isToday_: function() { return this.groupedOffset == 0; },
 });
