@@ -266,14 +266,6 @@ Polymer({
     this.syncedDevices_ = devices;
   },
 
-  /**
-   * End fetching synced tabs when sync is disabled.
-   */
-  tabSyncDisabled: function() {
-    this.fetchingSyncedTabs_ = false;
-    this.clearDisplayedSyncedDevices_();
-  },
-
   /**
    * Get called when user's sign in state changes, this will affect UI of synced
    * tabs page. Sign in promo gets displayed when user is signed out, and
