@@ -98,21 +98,22 @@ cr.define('media_router.ui', function() {
    *          },
    *          routes: !Array<!media_router.Route>,
    *          castModes: !Array<!media_router.CastMode>,
-   *          isOffTheRecord: boolean}} data
+   *          useTabMirroring: boolean}} data
    * Parameters in data:
    *   deviceMissingUrl - url to be opened on "Device missing?" clicked.
    *   sinksAndIdentity - list of sinks to be displayed and user identity.
    *   routes - list of routes that are associated with the sinks.
    *   castModes - list of available cast modes.
-   *   isOffTheRecord - whether or not the browser is currently incognito.
+   *   useTabMirroring - whether the cast mode should be set to TAB_MIRROR.
    */
   function setInitialData(data) {
     container.deviceMissingUrl = data['deviceMissingUrl'];
     container.castModeList = data['castModes'];
     this.setSinkListAndIdentity(data['sinksAndIdentity']);
-    container.isOffTheRecord = data['isOffTheRecord'];
     container.routeList = data['routes'];
     container.maybeShowRouteDetailsOnOpen();
+    if (data['useTabMirroring'])
+      container.selectCastMode(media_router.CastModeType.TAB_MIRROR);
     media_router.browserApi.onInitialDataReceived();
   }
 
@@ -205,6 +206,19 @@ cr.define('media_router.browserApi', function() {
                                 helpPageId: helpPageId}]);
   }
 
+  /**
+   * Modifies |route| by changing its source to the one identified by
+   * |selectedCastMode|.
+   *
+   * @param {!media_router.Route} route The route being modified.
+   * @param {number} selectedCastMode The value of the cast mode the user
+   *   selected.
+   */
+  function changeRouteSource(route, selectedCastMode) {
+    chrome.send('requestRoute',
+                [{sinkId: route.sinkId, selectedCastMode: selectedCastMode}]);
+  }
+
   /**
    * Closes the dialog.
    *
@@ -390,6 +404,7 @@ cr.define('media_router.browserApi', function() {
   return {
     acknowledgeFirstRunFlow: acknowledgeFirstRunFlow,
     actOnIssue: actOnIssue,
+    changeRouteSource: changeRouteSource,
     closeDialog: closeDialog,
     closeRoute: closeRoute,
     joinRoute: joinRoute,
