@@ -77,7 +77,7 @@ function loadShowDetailsFromPrefs(showDetails) {
  *             type: 'BROWSER PLUGIN',
  *             mime_types: [
  *               {
- *                 description: 'New Guy Media',
+ *                 description: 'New Media Type',
  *                 file_extensions: ['mfp'],
  *                 mime_type: 'application/x-my-first'
  *               },
@@ -103,34 +103,6 @@ function returnPluginsData(pluginsData) {
   renderTemplate(pluginsData);
 
   // Add handlers to dynamically created HTML elements.
-  var links = document.getElementsByClassName('disable-plugin-link');
-  for (var i = 0; i < links.length; i++) {
-    links[i].onclick = function() {
-      handleEnablePlugin(this, false, false);
-      return false;
-    };
-  }
-  links = document.getElementsByClassName('enable-plugin-link');
-  for (var i = 0; i < links.length; i++) {
-    links[i].onclick = function() {
-      handleEnablePlugin(this, true, false);
-      return false;
-    };
-  }
-  links = document.getElementsByClassName('disable-group-link');
-  for (var i = 0; i < links.length; i++) {
-    links[i].onclick = function() {
-      handleEnablePlugin(this, false, true);
-      return false;
-    };
-  }
-  links = document.getElementsByClassName('enable-group-link');
-  for (var i = 0; i < links.length; i++) {
-    links[i].onclick = function() {
-      handleEnablePlugin(this, true, true);
-      return false;
-    };
-  }
   var checkboxes = document.getElementsByClassName('always-allow');
   for (var i = 0; i < checkboxes.length; i++) {
     checkboxes[i].onclick = function() {
@@ -172,20 +144,6 @@ function returnPluginsData(pluginsData) {
      'show-tmi-mode-initial' : 'hide-tmi-mode-initial';
 }
 
-/**
- * Handles a 'enable' or 'disable' button getting clicked.
- * @param {HTMLElement} node The HTML element for the plugin being changed.
- * @param {boolean} enable Whether to enable or disable the plugin.
- * @param {boolean} isGroup True if we're enabling/disabling a plugin group,
- *     rather than a single plugin.
- */
-function handleEnablePlugin(node, enable, isGroup) {
-  if (isGroup)
-    browserProxy.setPluginGroupEnabled(node.path, enable);
-  else
-    browserProxy.setPluginEnabled(node.path, enable);
-}
-
 /*
  * Toggles visibility of details.
  */
@@ -261,19 +219,6 @@ function isPluginPolicyClickToPlay(plugin) {
     return plugin.policy_click_to_play == true;
 }
 
-/**
- * Helper to convert callback-based define() API to a promise-based API.
- * @param {!Array<string>} moduleNames
- * @return {!Promise}
- */
-function importModules(moduleNames) {
-  return new Promise(function(resolve, reject) {
-    define(moduleNames, function(var_args) {
-      resolve(Array.prototype.slice.call(arguments, 0));
-    });
-  });
-}
-
 // NOTE: Need to keep a global reference to the |pageImpl| such that it is not
 // garbage collected, which causes the pipe to close and future calls from C++
 // to JS to get dropped. This also allows tests to make direct calls on it.
