@@ -13,11 +13,17 @@ Polymer({
 
   properties: {
     /** @private {?UpdateStatusChangedEvent} */
-    currentUpdateStatusEvent_: Object,
+    currentUpdateStatusEvent_: {
+      type: Object,
+      value: {message: '', progress: 0, status: UpdateStatus.DISABLED},
+    },
 
 <if expr="chromeos">
     /** @private */
-    hasCheckedForUpdates_: Boolean,
+    hasCheckedForUpdates_: {
+      type: Boolean,
+      value: false,
+    },
 
     /** @private {!BrowserChannel} */
     currentChannel_: String,
@@ -39,8 +45,52 @@ Polymer({
         };
       },
     },
+
+    /** @private */
+    showUpdateStatus_: Boolean,
+
+    /** @private */
+    showButtonContainer_: Boolean,
+
+    /** @private */
+    showRelaunch_: Boolean,
+
+<if expr="chromeos">
+    /** @private */
+    showRelaunchAndPowerwash_: {
+      type: Boolean,
+      computed: 'computeShowRelaunchAndPowerwash_(' +
+          'currentUpdateStatusEvent_, targetChannel_)',
+    },
+
+    /** @private */
+    showCheckUpdates_: {
+      type: Boolean,
+      computed: 'computeShowCheckUpdates_(currentUpdateStatusEvent_)',
+    },
+</if>
   },
 
+  observers: [
+<if expr="not chromeos">
+    'updateShowUpdateStatus_(' +
+        'obsoleteSystemInfo_, currentUpdateStatusEvent_)',
+    'updateShowRelaunch_(currentUpdateStatusEvent_)',
+    'updateShowButtonContainer_(showRelaunch_)',
+</if>
+
+<if expr="chromeos">
+    'updateShowUpdateStatus_(' +
+        'obsoleteSystemInfo_, currentUpdateStatusEvent_,' +
+        'hasCheckedForUpdates_)',
+    'updateShowRelaunch_(currentUpdateStatusEvent_, targetChannel_,' +
+        'currentChannel_)',
+    'updateShowButtonContainer_(' +
+        'showRelaunch_, showRelaunchAndPowerwash_, showCheckUpdates_)',
+</if>
+  ],
+
+
   /** @private {?settings.AboutPageBrowserProxy} */
   aboutBrowserProxy_: null,
 
@@ -60,13 +110,9 @@ Polymer({
       this.targetChannel_ = e.detail;
     }.bind(this));
 
-    Promise.all([
-      this.aboutBrowserProxy_.getCurrentChannel(),
-      this.aboutBrowserProxy_.getTargetChannel(),
-    ]).then(function(channels) {
-      this.currentChannel_ = channels[0];
-      this.targetChannel_ = channels[1];
-
+    this.aboutBrowserProxy_.getChannelInfo().then(function(info) {
+      this.currentChannel_ = info.currentChannel;
+      this.targetChannel_ = info.targetChannel;
       this.startListening_();
     }.bind(this));
 
@@ -109,38 +155,45 @@ Polymer({
     this.lifetimeBrowserProxy_.relaunch();
   },
 
-  /**
-   * @return {boolean}
-   * @private
-   */
-  shouldShowUpdateStatusMessage_: function() {
-    return this.currentUpdateStatusEvent_.status != UpdateStatus.DISABLED &&
+  /** @private */
+  updateShowUpdateStatus_: function() {
+<if expr="chromeos">
+    // Assume the "updated" status is stale if we haven't checked yet.
+    if (this.currentUpdateStatusEvent_.status == UpdateStatus.UPDATED &&
+        !this.hasCheckedForUpdates_) {
+      this.showUpdateStatus_ = false;
+      return;
+    }
+</if>
+    this.showUpdateStatus_ =
+        this.currentUpdateStatusEvent_.status != UpdateStatus.DISABLED &&
         !this.obsoleteSystemInfo_.endOfLine;
   },
 
   /**
-   * @return {boolean}
+   * Hide the button container if all buttons are hidden, otherwise the
+   * container displayes an unwanted border (see secondary-action class).
    * @private
    */
-  shouldShowUpdateStatusIcon_: function() {
-    return this.currentUpdateStatusEvent_.status != UpdateStatus.DISABLED ||
-        this.obsoleteSystemInfo_.endOfLine;
-  },
-
-  /**
-   * @return {boolean}
-   * @private
-   */
-  shouldShowRelaunch_: function() {
-    var shouldShow = false;
+  updateShowButtonContainer_: function() {
 <if expr="not chromeos">
-    shouldShow = this.checkStatus_(UpdateStatus.NEARLY_UPDATED);
+    this.showButtonContainer_ = this.showRelaunch_;
 </if>
 <if expr="chromeos">
-    shouldShow = this.checkStatus_(UpdateStatus.NEARLY_UPDATED) &&
+    this.showButtonContainer_ = this.showRelaunch_ ||
+        this.showRelaunchAndPowerwash_ || this.showCheckUpdates_;
+</if>
+  },
+
+  /** @private */
+  updateShowRelaunch_: function() {
+<if expr="not chromeos">
+    this.showRelaunch_ = this.checkStatus_(UpdateStatus.NEARLY_UPDATED);
+</if>
+<if expr="chromeos">
+    this.showRelaunch_ = this.checkStatus_(UpdateStatus.NEARLY_UPDATED) &&
         !this.isTargetChannelMoreStable_();
 </if>
-    return shouldShow;
   },
 
   /**
@@ -170,7 +223,15 @@ Polymer({
               progressPercent);
         }
 </if>
-        return this.i18n('aboutUpgradeUpdating', progressPercent);
+        if (this.currentUpdateStatusEvent_.progress > 0) {
+          // NOTE(dbeam): some platforms (i.e. Mac) always send 0% while
+          // updating (they don't support incremental upgrade progress). Though
+          // it's certainly quite possible to validly end up here with 0% on
+          // platforms that support incremental progress, nobody really likes
+          // seeing that they're 0% done with something.
+          return this.i18n('aboutUpgradeUpdatingPercent', progressPercent);
+        }
+        return this.i18n('aboutUpgradeUpdating');
       default:
         var message = this.currentUpdateStatusEvent_.message;
         return message ?
@@ -254,7 +315,7 @@ Polymer({
    * @return {boolean}
    * @private
    */
-  shouldShowRelaunchAndPowerwash_: function() {
+  computeShowRelaunchAndPowerwash_: function() {
     return this.checkStatus_(UpdateStatus.NEARLY_UPDATED) &&
         this.isTargetChannelMoreStable_();
   },
@@ -269,7 +330,7 @@ Polymer({
    * @return {boolean}
    * @private
    */
-  shouldShowCheckUpdates_: function() {
+  computeShowCheckUpdates_: function() {
     return !this.hasCheckedForUpdates_ ||
         this.checkStatus_(UpdateStatus.FAILED);
   },
