@@ -5,36 +5,20 @@
 /**
  * @fileoverview
  * 'settings-basic-page' is the settings page containing the basic settings.
- *
- * Example:
- *
- *    <iron-animated-pages>
- *      <settings-basic-page prefs="{{prefs}}"></settings-basic-page>
- *      ... other pages ...
- *    </iron-animated-pages>
  */
 Polymer({
   is: 'settings-basic-page',
 
-  behaviors: [I18nBehavior, SettingsPageVisibility, RoutableBehavior],
+  behaviors: [SettingsPageVisibility, MainPageBehavior],
 
   properties: {
-    /**
-     * Preferences state.
-     */
+    /** Preferences state. */
     prefs: {
       type: Object,
       notify: true,
     },
 
-    /**
-     * The current active route.
-     * @type {SettingsRoute}
-     */
-    currentRoute: {
-      type: Object,
-      notify: true,
-    },
+    showAndroidApps: Boolean,
 
     /**
      * True if the basic page should currently display the reset profile banner.
@@ -46,23 +30,20 @@ Polymer({
         return loadTimeData.getBoolean('showResetProfileBanner');
       },
     },
-
-  },
-
-  /**
-   * @type {string} Selector to get the sections.
-   * TODO(michaelpg): replace duplicate docs with @override once b/24294625
-   * is fixed.
-   */
-  sectionSelector: 'settings-section',
-
-  /** @override */
-  attached: function() {
-    /** @override */
-    this.scroller = this.parentElement;
   },
 
+  /** @private */
   onResetDone_: function() {
     this.showResetProfileBanner_ = false;
   },
+
+  /**
+   * @return {boolean}
+   * @private
+   */
+  shouldShowAndroidApps_: function() {
+    var visibility = /** @type {boolean|undefined} */ (
+        this.get('pageVisibility.androidApps'));
+    return this.showAndroidApps && this.showPage(visibility);
+  },
 });
