@@ -158,16 +158,52 @@ Polymer({
     }
     this.maxModeIndex_ = this.selectedDisplay.modes.length - 1;
     this.selectedModeIndex_ = this.getSelectedModeIndex_(this.selectedDisplay);
+    this.immediateSelectedModeIndex_ = this.selectedModeIndex_;
   },
 
   /**
-   * @param {!chrome.system.display.DisplayUnitInfo} selectedDisplay
-   * @param {string} primaryDisplayId
+   * @param {!Array<!chrome.system.display.DisplayUnitInfo>} displays
    * @return {boolean}
    * @private
    */
-  showMakePrimary_: function(selectedDisplay, primaryDisplayId) {
-    return !!selectedDisplay && selectedDisplay.id != primaryDisplayId;
+  showDisplayTabMenu_: function(displays) {
+    return displays.length > 1;
+  },
+
+  /**
+   * Returns false if the display select menu has to be hidden.
+   * @param {!Array<!chrome.system.display.DisplayUnitInfo>} displays
+   * @param {!chrome.system.display.DisplayUnitInfo} selectedDisplay
+   * @return {boolean}
+   * @private
+   */
+  showDisplaySelectMenu_: function(displays, selectedDisplay) {
+    return displays.length > 1 && !selectedDisplay.isPrimary;
+  },
+
+  /**
+   * Returns the select menu index indicating whether the display currently is
+   * primary or extended.
+   * @param {!chrome.system.display.DisplayUnitInfo} selectedDisplay
+   * @param {string} primaryDisplayId
+   * @return {number} Retruns 0 if the display is primary else returns 1.
+   * @private
+   */
+  getDisplaySelectMenuIndex_: function(selectedDisplay, primaryDisplayId) {
+    if (selectedDisplay && selectedDisplay.id == primaryDisplayId)
+      return 0;
+    return 1;
+  },
+
+  /**
+   * Returns the i18n string for the text to be used for mirroring settings.
+   * @param {!Array<!chrome.system.display.DisplayUnitInfo>} displays
+   * @return {string} i18n string for mirroring settings text.
+   * @private
+   */
+  getDisplayMirrorText_: function(displays) {
+    return this.i18n(
+        this.isMirrored_(displays) ? 'displayMirrorOn' : 'displayMirrorOff');
   },
 
   /**
@@ -208,21 +244,25 @@ Polymer({
   },
 
   /**
-   * @param {!chrome.system.display.DisplayUnitInfo} selectedDisplay
-   * @param {number} immediateSelectedModeIndex
    * @return {string}
    * @private
    */
-  getResolutionText_: function(selectedDisplay, immediateSelectedModeIndex) {
+  getResolutionText_: function() {
     if (this.selectedDisplay.modes.length == 0) {
-      var widthStr = selectedDisplay.bounds.width.toString();
-      var heightStr = selectedDisplay.bounds.height.toString();
+      var widthStr = this.selectedDisplay.bounds.width.toString();
+      var heightStr = this.selectedDisplay.bounds.height.toString();
       return this.i18n('displayResolutionText', widthStr, heightStr);
     }
-    if (isNaN(immediateSelectedModeIndex))
-      immediateSelectedModeIndex = this.getSelectedModeIndex_(selectedDisplay);
-    var mode = selectedDisplay.modes[immediateSelectedModeIndex];
-    var best = selectedDisplay.isInternal ? mode.uiScale == 1.0 : mode.isNative;
+    // immediateSelectedModeIndex_ is bound to paper-slider.immediate-value
+    // which may not be valid, or may not have updated yet when this is called.
+    if (isNaN(this.immediateSelectedModeIndex_) ||
+        this.immediateSelectedModeIndex_ >= this.selectedDisplay.modes.length) {
+      this.immediateSelectedModeIndex_ =
+          this.getSelectedModeIndex_(this.selectedDisplay);
+    }
+    var mode = this.selectedDisplay.modes[this.immediateSelectedModeIndex_];
+    var best =
+        this.selectedDisplay.isInternal ? mode.uiScale == 1.0 : mode.isNative;
     var widthStr = mode.width.toString();
     var heightStr = mode.height.toString();
     if (best)
@@ -245,12 +285,29 @@ Polymer({
     }
   },
 
-  /** @private */
-  onMakePrimaryTap_: function() {
+  /**
+   * Handles event when a display tab is selected.
+   * @param {!{detail: !{item: !{displayId: string}}}} e
+   * @private
+   */
+  onSelectDisplayTab_: function(e) {
+    this.onSelectDisplay_({detail: e.detail.item.displayId});
+  },
+
+  /**
+   * Handles the event when an option from display select menu is selected.
+   * @param {!{target: !HTMLSelectElement}} e
+   * @private
+   */
+  updatePrimaryDisplay_: function(e) {
+    /** @const {number} */ var PRIMARY_DISP_IDX = 0;
     if (!this.selectedDisplay)
       return;
     if (this.selectedDisplay.id == this.primaryDisplayId)
       return;
+    if (e.target.value != PRIMARY_DISP_IDX)
+      return;
+
     /** @type {!chrome.system.display.DisplayProperties} */ var properties = {
       isPrimary: true
     };
@@ -279,12 +336,13 @@ Polymer({
   },
 
   /**
-   * @param {!{detail: !{selected: string}}} e
+   * @param {!Event} event
    * @private
    */
-  onSetOrientation_: function(e) {
+  onOrientationChange_: function(event) {
+    let target = /** @type {!HTMLSelectElement} */ (event.target);
     /** @type {!chrome.system.display.DisplayProperties} */ var properties = {
-      rotation: parseInt(e.detail.selected, 10)
+      rotation: parseInt(target.value, 10)
     };
     settings.display.systemDisplayApi.setDisplayProperties(
         this.selectedDisplay.id, properties,
@@ -312,8 +370,12 @@ Polymer({
         id, properties, this.setPropertiesCallback_.bind(this));
   },
 
-  /** @private */
-  onOverscanTap_: function() {
+  /**
+   * @param {!Event} e
+   * @private
+   */
+  onOverscanTap_: function(e) {
+    e.preventDefault();
     this.overscanDisplayId = this.selectedDisplay.id;
     this.showOverscanDialog_(true);
   },
