@@ -35,9 +35,10 @@ Polymer({
     languageHelper: Object,
 
     /** @private */
-    spellCheckSecondary_: {
+    spellCheckSecondaryText_: {
       type: String,
-      value: 'Placeholder, e.g. English (United States)',
+      value: '',
+      computed: 'getSpellCheckSecondaryText_(languages.enabled.*)',
     },
 
     /**
@@ -51,22 +52,6 @@ Polymer({
     showAddLanguagesDialog_: Boolean,
   },
 
-  /**
-   * Handler for clicking a language on the main page, which selects the
-   * language as the prospective UI language on Chrome OS and Windows.
-   * @param {!Event} e The tap event.
-   */
-  onLanguageTap_: function(e) {
-    // Only change the UI language on platforms that allow it.
-    if ((!cr.isChromeOS && !cr.isWindows) || loadTimeData.getBoolean('isGuest'))
-      return;
-
-    // Set the prospective UI language. This won't take effect until a restart.
-    var tapEvent = /** @type {!{model: !{item: !LanguageState}}} */(e);
-    if (tapEvent.model.item.language.supportsUI)
-      this.languageHelper.setUILanguage(tapEvent.model.item.language.code);
-  },
-
   /**
    * Handler for enabling or disabling spell check.
    * @param {!{target: Element, model: !{item: !LanguageState}}} e
@@ -84,9 +69,11 @@ Polymer({
   /**
    * Stamps and opens the Add Languages dialog, registering a listener to
    * disable the dialog's dom-if again on close.
+   * @param {!Event} e
    * @private
    */
-  onAddLanguagesTap_: function() {
+  onAddLanguagesTap_: function(e) {
+    e.preventDefault();
     this.showAddLanguagesDialog_ = true;
     this.async(function() {
       var dialog = this.$$('settings-add-languages-dialog');
@@ -185,7 +172,7 @@ Polymer({
       // Reset the chosen UI language to the actual UI language.
       this.languageHelper.resetUILanguage();
     }
-    /** @type {!CrSharedMenuElement} */(this.$.menu.get()).closeMenu();
+    /** @type {!CrActionMenuElement} */(this.$.menu.get()).close();
   },
 
    /**
@@ -215,7 +202,7 @@ Polymer({
       this.languageHelper.disableTranslateLanguage(
           this.detailLanguage_.language.code);
     }
-    /** @type {!CrSharedMenuElement} */(this.$.menu.get()).closeMenu();
+    /** @type {!CrActionMenuElement} */(this.$.menu.get()).close();
   },
 
   /**
@@ -235,7 +222,7 @@ Polymer({
    * @private
    */
   onMoveToTopTap_: function() {
-    /** @type {!CrSharedMenuElement} */(this.$.menu.get()).closeMenu();
+    /** @type {!CrActionMenuElement} */(this.$.menu.get()).close();
     this.languageHelper.moveLanguageToFront(this.detailLanguage_.language.code);
   },
 
@@ -244,7 +231,7 @@ Polymer({
    * @private
    */
   onMoveUpTap_: function() {
-    /** @type {!CrSharedMenuElement} */(this.$.menu.get()).closeMenu();
+    /** @type {!CrActionMenuElement} */(this.$.menu.get()).close();
     this.languageHelper.moveLanguage(this.detailLanguage_.language.code, -1);
   },
 
@@ -253,7 +240,7 @@ Polymer({
    * @private
    */
   onMoveDownTap_: function() {
-    /** @type {!CrSharedMenuElement} */(this.$.menu.get()).closeMenu();
+    /** @type {!CrActionMenuElement} */(this.$.menu.get()).close();
     this.languageHelper.moveLanguage(this.detailLanguage_.language.code, 1);
   },
 
@@ -262,7 +249,7 @@ Polymer({
    * @private
    */
   onRemoveLanguageTap_: function() {
-    /** @type {!CrSharedMenuElement} */(this.$.menu.get()).closeMenu();
+    /** @type {!CrActionMenuElement} */(this.$.menu.get()).close();
     this.languageHelper.disableLanguage(this.detailLanguage_.language.code);
   },
 
@@ -276,10 +263,12 @@ Polymer({
   },
 
   /**
-   * Handler for clicking an input method on the main page, which sets it as
-   * the current input method.
+   * Handler for tap and <Enter> events on an input method on the main page,
+   * which sets it as the current input method.
    * @param {!{model: !{item: !chrome.languageSettingsPrivate.InputMethod},
-   *           target: !{tagName: string}}} e
+   *           target: !{tagName: string},
+   *           type: string,
+   *           key: (string|undefined)}} e
    */
   onInputMethodTap_: function(e) {
     assert(cr.isChromeOS);
@@ -288,6 +277,10 @@ Polymer({
     if (e.target.tagName == 'PAPER-ICON-BUTTON')
       return;
 
+    // Ignore key presses other than <Enter>.
+    if (e.type == 'keypress' && e.key != 'Enter')
+      return;
+
     // Set the input method.
     this.languageHelper.setCurrentInputMethod(e.model.item.id);
   },
@@ -366,6 +359,7 @@ Polymer({
     return languageCode == this.languageHelper.getProspectiveUILanguage();
   },
 
+<if expr="chromeos or is_win">
    /**
     * @return {string}
     * @private
@@ -374,6 +368,23 @@ Polymer({
     return this.languageHelper.getLanguage(
         this.languageHelper.getProspectiveUILanguage()).displayName;
   },
+</if>
+
+  /**
+   * @return {string}
+   * @private
+   */
+  getLanguageListTwoLine_: function() {
+    return cr.isChromeOS || cr.isWindows ? 'two-line' : '';
+  },
+
+  /**
+   * @return {string}
+   * @private
+   */
+  getSpellCheckListTwoLine_: function() {
+    return this.spellCheckSecondaryText_.length ? 'two-line' : '';
+  },
 
   /**
    * Returns either the "selected" class, if the language matches the
@@ -449,29 +460,27 @@ Polymer({
   },
 
   /**
-   * Opens or closes the shared menu at the location of the tapped item.
    * @param {!Event} e
    * @private
    */
-  toggleMenu_: function(e) {
-    e.stopPropagation();  // Prevent the tap event from closing the menu.
-
+  onDotsTap_: function(e) {
     this.detailLanguage_ =
         /** @type {!{model: !{item: !LanguageState}}} */(e).model.item;
 
     // Ensure the template has been stamped.
-    var menu = /** @type {?CrSharedMenuElement} */(this.$.menu.getIfExists());
+    var menu = /** @type {?CrActionMenuElement} */(
+        this.$.menu.getIfExists());
     if (!menu) {
-      menu = /** @type {!CrSharedMenuElement} */(this.$.menu.get());
+      menu = /** @type {!CrActionMenuElement} */(this.$.menu.get());
       this.initializeMenu_(menu);
     }
 
-    menu.toggleMenu(/** @type {!Element} */(e.target));
+    menu.showAt(/** @type {!Element} */ (e.target));
   },
 
   /**
    * Applies Chrome OS session tweaks to the menu.
-   * @param {!CrSharedMenuElement} menu
+   * @param {!CrActionMenuElement} menu
    * @private
    */
   initializeMenu_: function(menu) {
@@ -501,5 +510,22 @@ Polymer({
     settings.LifetimeBrowserProxyImpl.getInstance().restart();
 </if>
   },
+
+  /**
+   * Toggles the expand button within the element being listened to.
+   * @param {!Event} e
+   * @private
+   */
+  toggleExpandButton_: function(e) {
+    // The expand button handles toggling itself.
+    var expandButtonTag = 'CR-EXPAND-BUTTON';
+    if (e.target.tagName == expandButtonTag)
+      return;
+
+    /** @type {!CrExpandButtonElement} */
+    var expandButton = e.currentTarget.querySelector(expandButtonTag);
+    assert(expandButton);
+    expandButton.expanded = !expandButton.expanded;
+  },
 });
 })();
