@@ -35,6 +35,7 @@ Polymer({
   is: 'settings-change-picture',
 
   behaviors: [
+    settings.RouteObserverBehavior,
     I18nBehavior,
     WebUIListenerBehavior,
   ],
@@ -111,7 +112,7 @@ Polymer({
       readOnly: true,
     },
 
-    /** @private {!settings.ChangePictureBrowserProxyImpl} */
+    /** @private {!settings.ChangePictureBrowserProxy} */
     browserProxy_: {
       type: Object,
       value: function() {
@@ -132,8 +133,18 @@ Polymer({
                           this.receiveProfileImage_.bind(this));
     this.addWebUIListener('camera-presence-changed',
                           this.receiveCameraPresence_.bind(this));
+  },
 
-    this.browserProxy_.initialize();
+
+  /** @protected */
+  currentRouteChanged: function(newRoute) {
+    // Reset the selection state when we navigate to this page.
+    if (newRoute == settings.Route.CHANGE_PICTURE) {
+      this.browserProxy_.initialize();
+    } else {
+      // Ensure we deactivate the camera when we navigate away.
+      this.selectedItem_ = null;
+    }
   },
 
   /**
@@ -240,7 +251,7 @@ Polymer({
 
   /**
    * Handler for when accessibility-specific keys are pressed.
-   * @param {!{detail: !{key: string}}} e
+   * @param {!{detail: !{key: string, keyboardEvent: Object}}} e
    */
   onKeysPress_: function(e) {
     if (!this.selectedItem_)
@@ -268,6 +279,7 @@ Polymer({
         } while (this.selectedItem_.hidden);
 
         this.lastSelectedImageType_ = this.selectedItem_.dataset.type;
+        e.detail.keyboardEvent.preventDefault();
         break;
 
       case 'down':
@@ -279,6 +291,7 @@ Polymer({
         } while (this.selectedItem_.hidden);
 
         this.lastSelectedImageType_ = this.selectedItem_.dataset.type;
+        e.detail.keyboardEvent.preventDefault();
         break;
 
       case 'enter':
@@ -372,7 +385,7 @@ Polymer({
    * @private
    */
   isCameraActive_: function(cameraPresent, selectedItem) {
-    return cameraPresent && selectedItem &&
+    return cameraPresent && !!selectedItem &&
         selectedItem.dataset.type == ChangePictureSelectionTypes.CAMERA;
   },
 
@@ -392,7 +405,7 @@ Polymer({
    * @private
    */
   isAuthorCreditShown_: function(selectedItem) {
-    return selectedItem &&
+    return !!selectedItem &&
         selectedItem.dataset.type == ChangePictureSelectionTypes.DEFAULT;
   },
 
