@@ -5,7 +5,7 @@
 (function() {
 
 /**
- * Names of the radio buttons which allow the user to choose his encryption
+ * Names of the radio buttons which allow the user to choose their encryption
  * mechanism.
  * @enum {string}
  */
@@ -91,7 +91,7 @@ Polymer({
     /**
      * Whether the "create passphrase" inputs should be shown. These inputs
      * give the user the opportunity to use a custom passphrase instead of
-     * authenticating with his Google credentials.
+     * authenticating with their Google credentials.
      * @private
      */
     creatingNewPassphrase_: {
@@ -99,6 +99,33 @@ Polymer({
       value: false,
     },
 
+    /**
+     * The passphrase input field value.
+     * @private
+     */
+    passphrase_: {
+      type: String,
+      value: '',
+    },
+
+    /**
+     * The passphrase confirmation input field value.
+     * @private
+     */
+    confirmation_: {
+      type: String,
+      value: '',
+    },
+
+    /**
+     * The existing passphrase input field value.
+     * @private
+     */
+    existingPassphrase_: {
+      type: String,
+      value: '',
+    },
+
     /** @private {!settings.SyncBrowserProxy} */
     browserProxy_: {
       type: Object,
@@ -138,9 +165,6 @@ Polymer({
 
   /** @protected */
   currentRouteChanged: function() {
-    if (!this.isAttached)
-      return;
-
     if (settings.getCurrentRoute() == settings.Route.SYNC)
       this.onNavigateToPage_();
     else
@@ -158,8 +182,6 @@ Polymer({
 
   /** @private */
   onNavigateToPage_: function() {
-    // The element is not ready for C++ interaction until it is attached.
-    assert(this.isAttached);
     assert(settings.getCurrentRoute() == settings.Route.SYNC);
 
     if (this.unloadCallback_)
@@ -259,6 +281,16 @@ Polymer({
     this.onSingleSyncDataTypeChanged_();
   },
 
+  /**
+   * @param {string} passphrase The passphrase input field value
+   * @param {string} confirmation The passphrase confirmation input field value.
+   * @return {boolean} Whether the passphrase save button should be enabled.
+   * @private
+   */
+  isSaveNewPassphraseEnabled_: function(passphrase, confirmation) {
+    return passphrase !== '' && confirmation !== '';
+  },
+
   /**
    * Sends the newly created custom sync passphrase to the browser.
    * @private
@@ -273,7 +305,7 @@ Polymer({
 
     this.syncPrefs.encryptAllData = true;
     this.syncPrefs.setNewPassphrase = true;
-    this.syncPrefs.passphrase = this.$$('#passphraseInput').value;
+    this.syncPrefs.passphrase = this.passphrase_;
 
     this.browserProxy_.setSyncEncryption(this.syncPrefs).then(
         this.handlePageStatusChanged_.bind(this));
@@ -288,9 +320,8 @@ Polymer({
 
     this.syncPrefs.setNewPassphrase = false;
 
-    var existingPassphraseInput = this.$$('#existingPassphraseInput');
-    this.syncPrefs.passphrase = existingPassphraseInput.value;
-    existingPassphraseInput.value = '';
+    this.syncPrefs.passphrase = this.existingPassphrase_;
+    this.existingPassphrase_ = '';
 
     this.browserProxy_.setSyncEncryption(this.syncPrefs).then(
         this.handlePageStatusChanged_.bind(this));
@@ -343,14 +374,14 @@ Polymer({
   },
 
   /**
-   * Computed binding returning the encryption text body.
+   * Computed binding returning text of the prompt for entering the passphrase.
    * @private
    */
-  encryptWithPassphraseBody_: function() {
-    if (this.syncPrefs && this.syncPrefs.fullEncryptionBody)
-      return this.syncPrefs.fullEncryptionBody;
+  enterPassphrasePrompt_: function() {
+    if (this.syncPrefs && this.syncPrefs.passphraseTypeIsCustom)
+      return this.syncPrefs.enterPassphraseBody;
 
-    return this.i18n('encryptWithSyncPassphraseLabel');
+    return this.syncPrefs.enterGooglePassphraseBody;
   },
 
   /**
@@ -374,28 +405,31 @@ Polymer({
 
   /**
    * Checks the supplied passphrases to ensure that they are not empty and that
-   * they match each other. Additionally, displays error UI if they are
-   * invalid.
+   * they match each other. Additionally, displays error UI if they are invalid.
    * @return {boolean} Whether the check was successful (i.e., that the
    *     passphrases were valid).
    * @private
    */
   validateCreatedPassphrases_: function() {
-    var passphraseInput = this.$$('#passphraseInput');
-    var passphraseConfirmationInput = this.$$('#passphraseConfirmationInput');
+    var emptyPassphrase = !this.passphrase_;
+    var mismatchedPassphrase = this.passphrase_ != this.confirmation_;
 
-    var passphrase = passphraseInput.value;
-    var confirmation = passphraseConfirmationInput.value;
-
-    var emptyPassphrase = !passphrase;
-    var mismatchedPassphrase = passphrase != confirmation;
-
-    passphraseInput.invalid = emptyPassphrase;
-    passphraseConfirmationInput.invalid =
+    this.$$('#passphraseInput').invalid = emptyPassphrase;
+    this.$$('#passphraseConfirmationInput').invalid =
         !emptyPassphrase && mismatchedPassphrase;
 
     return !emptyPassphrase && !mismatchedPassphrase;
   },
+
+  /**
+   * @param {!Event} event
+   * @private
+   */
+  onLearnMoreTap_: function(event) {
+    // Stop the propagation of events, so that clicking on links inside
+    // checkbox labels won't change the checkbox value.
+    event.stopPropagation();
+  }
 });
 
 })();
