@@ -55,19 +55,13 @@ Polymer({
     }.bind(this));
   },
 
-  /** @private */
-  openAddUserDialog_: function() {
-    this.$.addUserDialog.open();
-  },
-
   /**
-   * @param {boolean} isOwner
-   * @param {boolean} isWhitelistManaged
+   * @param {!Event} e
    * @private
-   * @return {boolean}
    */
-  isOwnerLabelHidden_: function(isOwner, isWhitelistManaged) {
-    return isOwner || isWhitelistManaged;
+  openAddUserDialog_: function(e) {
+    e.preventDefault();
+    this.$.addUserDialog.open();
   },
 
   /**
