@@ -8,7 +8,7 @@
  * Subdialogs include:
  * - 'add-printer-discovery-dialog' is a dialog showing discovered printers on
  *   the network that are available for setup.
- * - 'add-printer-maually-dialog' is a dialog in which user can manually enter
+ * - 'add-printer-manually-dialog' is a dialog in which user can manually enter
  *   the information to set up a new printer.
  * - 'add-printer-configuring-dialog' is the configuring-in-progress dialog.
  * - 'add-printer-manufacturer-model-dialog' is a dialog in which the user can
@@ -21,7 +21,7 @@
  */
 var AddPrinterDialogs = {
   DISCOVERY: 'add-printer-discovery-dialog',
-  MANUALLY: 'add-printer-maually-dialog',
+  MANUALLY: 'add-printer-manually-dialog',
   CONFIGURING: 'add-printer-configuring-dialog',
   MANUFACTURER: 'add-printer-manufacturer-model-dialog',
 };
@@ -118,7 +118,7 @@ Polymer({
 });
 
 Polymer({
-  is: 'add-printer-maually-dialog',
+  is: 'add-printer-manually-dialog',
 
   properties: {
     /** @type {!CupsPrinterInfo} */
@@ -154,9 +154,9 @@ Polymer({
   },
 
   /** @private */
-  switchToConfiguringDialog_: function() {
+  switchToManufacturerDialog_: function() {
     this.$$('add-printer-dialog').close();
-    this.fire('open-configuring-printer-dialog');
+    this.fire('open-manufacturer-model-dialog');
   },
 
   /** @private */
@@ -165,6 +165,14 @@ Polymer({
     // corresponding message after the API is ready.
     // The format of address is: ip-address-or-hostname:port-number.
   },
+
+  /**
+   * @param {!Event} event
+   * @private
+   */
+  onProtocolChange_: function(event) {
+    this.newPrinter.printerProtocol = event.target.value;
+  },
 });
 
 Polymer({
@@ -177,12 +185,12 @@ Polymer({
       notify: true,
     },
 
-    /** @type {!Array<string>} */
+    /** @type {?Array<string>} */
     manufacturerList: {
       type: Array,
     },
 
-    /** @type {!Array<string>} */
+    /** @type {?Array<string>} */
     modelList: {
       type: Array,
     },
@@ -199,13 +207,22 @@ Polymer({
 
   /** @override */
   ready: function() {
-    // TODO(xdai): Get available manufacturerList after the API is ready.
+    settings.CupsPrintersBrowserProxyImpl.getInstance().
+        getCupsPrinterManufacturersList().then(
+            this.manufacturerListChanged_.bind(this));
   },
 
-  /** @private */
-  selectedManufacturerChanged_: function() {
-    // TODO(xdai): Get available modelList for a selected manufacturer after
-    // the API is ready.
+  /**
+   * @param {string} manufacturer The manufacturer for which we are retrieving
+   *     models.
+   * @private
+   */
+  selectedManufacturerChanged_: function(manufacturer) {
+    if (manufacturer) {
+      settings.CupsPrintersBrowserProxyImpl.getInstance()
+          .getCupsPrinterModelsList(manufacturer)
+          .then(this.modelListChanged_.bind(this));
+    }
   },
 
   /** @private */
@@ -223,6 +240,24 @@ Polymer({
     this.$$('paper-input').value = this.getBaseName_(path);
   },
 
+  /**
+   * @param {!ManufacturersInfo} manufacturersInfo
+   * @private
+   */
+  manufacturerListChanged_: function(manufacturersInfo) {
+    if (manufacturersInfo.success)
+      this.manufacturerList = manufacturersInfo.manufacturers;
+  },
+
+  /**
+   * @param {!ModelsInfo} modelsInfo
+   * @private
+   */
+  modelListChanged_: function(modelsInfo) {
+    if (modelsInfo.success)
+      this.modelList = modelsInfo.models;
+  },
+
   /** @private */
   switchToManualAddDialog_: function() {
     this.$$('add-printer-dialog').close();
@@ -255,6 +290,7 @@ Polymer({
 
   properties: {
     printerName: String,
+    dialogTitle: String,
   },
 
   /** @override */
@@ -296,6 +332,8 @@ Polymer({
       value: false,
     },
 
+    configuringDialogTitle: String,
+
     /** @private {string} */
     previousDialog_: String,
 
@@ -331,7 +369,8 @@ Polymer({
   /** Opens the Add printer discovery dialog. */
   open: function() {
     this.resetData_();
-    this.switchDialog_('', AddPrinterDialogs.DISCOVERY, 'showDiscoveryDialog_');
+    this.switchDialog_(
+        '', AddPrinterDialogs.MANUALLY, 'showManuallyAddDialog_');
   },
 
   /**
@@ -379,15 +418,19 @@ Polymer({
 
   /** @private */
   openConfiguringPrinterDialog_: function() {
-    this.switchDialog_(this.currentDialog_, AddPrinterDialogs.CONFIGURING,
-                       'showConfiguringDialog_');
+    this.switchDialog_(
+        this.currentDialog_, AddPrinterDialogs.CONFIGURING,
+        'showConfiguringDialog_');
     if (this.previousDialog_ == AddPrinterDialogs.DISCOVERY) {
-      settings.CupsPrintersBrowserProxyImpl.getInstance().
-          addCupsPrinter(this.selectedPrinter);
-    } else if (this.previousDialog_ == AddPrinterDialogs.MANUALLY ||
-               this.previousDialog_ == AddPrinterDialogs.MANUFACTURER) {
-      settings.CupsPrintersBrowserProxyImpl.getInstance().
-          addCupsPrinter(this.newPrinter);
+      this.configuringDialogTitle =
+          loadTimeData.getString('addPrintersNearbyTitle');
+      settings.CupsPrintersBrowserProxyImpl.getInstance().addCupsPrinter(
+          this.selectedPrinter);
+    } else if (this.previousDialog_ == AddPrinterDialogs.MANUFACTURER) {
+      this.configuringDialogTitle =
+          loadTimeData.getString('addPrintersManuallyTitle');
+      settings.CupsPrintersBrowserProxyImpl.getInstance().addCupsPrinter(
+          this.newPrinter);
     }
   },
 
@@ -399,10 +442,7 @@ Polymer({
 
   /** @private */
   configuringDialogClosed_: function() {
-    if (this.previousDialog_ == AddPrinterDialogs.DISCOVERY) {
-      this.switchDialog_(
-          this.currentDialog_, this.previousDialog_, 'showDiscoveryDialog_');
-    } else if (this.previousDialog_ == AddPrinterDialogs.MANUALLY) {
+    if (this.previousDialog_ == AddPrinterDialogs.MANUALLY) {
       this.switchDialog_(
           this.currentDialog_, this.previousDialog_, 'showManuallyAddDialog_');
     } else if (this.previousDialog_ == AddPrinterDialogs.MANUFACTURER) {
@@ -458,9 +498,6 @@ Polymer({
 
     if (this.previousDialog_ == AddPrinterDialogs.MANUFACTURER) {
       this.setupFailed = true;
-    } else if (this.previousDialog_ == AddPrinterDialogs.MANUALLY) {
-      this.switchDialog_(this.currentDialog_, AddPrinterDialogs.MANUFACTURER,
-                         'showManufacturerDialog_');
     }
   },
 });
