@@ -31,18 +31,29 @@ Polymer({
       type: Boolean,
       value: cr.isChromeOS ? loadTimeData.getBoolean('allowPowerwash') : false
     },
+
+    /** @private */
+    showResetProfileDialog_: {
+      type: Boolean,
+      value: false,
+    },
   },
 
-  /** @protected */
-  currentRouteChanged: function() {
-    if (settings.getCurrentRoute() == settings.Route.RESET_DIALOG) {
-      this.$.resetProfileDialog.get().open();
-    }
+  /**
+   * settings.RouteObserverBehavior
+   * @param {!settings.Route} route
+   * @protected
+   */
+  currentRouteChanged: function(route) {
+    this.showResetProfileDialog_ =
+        route == settings.Route.TRIGGERED_RESET_DIALOG ||
+        route == settings.Route.RESET_DIALOG;
   },
 
   /** @private */
   onShowResetProfileDialog_: function() {
-    settings.navigateTo(settings.Route.RESET_DIALOG);
+    settings.navigateTo(settings.Route.RESET_DIALOG,
+                        new URLSearchParams('origin=userclick'));
   },
 
   /** @private */
@@ -51,8 +62,12 @@ Polymer({
   },
 
 <if expr="chromeos">
-  /** @private */
-  onShowPowerwashDialog_: function() {
+  /**
+   * @param {!Event} e
+   * @private
+   */
+  onShowPowerwashDialog_: function(e) {
+    e.preventDefault();
     this.showPowerwashDialog_ = true;
   },
 
