@@ -13,7 +13,10 @@
  *            canBeRemoved: boolean,
  *            default: boolean,
  *            displayName: string,
- *            extension: (Object|undefined),
+ *            extension: ({id: string,
+ *                         name: string,
+ *                         canBeDisabled: boolean,
+ *                         icon: string}|undefined),
  *            iconURL: (string|undefined),
  *            isOmniboxExtension: boolean,
  *            keyword: string,
@@ -34,6 +37,18 @@ var SearchEngine;
  */
 var SearchEnginesInfo;
 
+/**
+ * @typedef {{
+ *   allowed: boolean,
+ *   enabled: boolean,
+ *   alwaysOn: boolean,
+ *   errorMessage: string,
+ *   userName: string,
+ *   historyEnabled: boolean
+ * }}
+ */
+var SearchPageHotwordInfo;
+
 cr.define('settings', function() {
   /** @interface */
   function SearchEnginesBrowserProxy() {}
@@ -57,9 +72,7 @@ cr.define('settings', function() {
      */
     searchEngineEditCompleted: function(searchEngine, keyword, queryUrl) {},
 
-    /**
-     * @return {!Promise<!SearchEnginesInfo>}
-     */
+    /** @return {!Promise<!SearchEnginesInfo>} */
     getSearchEnginesList: function() {},
 
     /**
@@ -69,11 +82,11 @@ cr.define('settings', function() {
      */
     validateSearchEngineInput: function(fieldName, fieldValue) {},
 
-    /** @param {string} extensionId */
-    disableExtension: function(extensionId) {},
+    /** @return {!Promise<!SearchPageHotwordInfo>} */
+    getHotwordInfo: function() {},
 
-    /** @param {string} extensionId */
-    manageExtension: function(extensionId) {},
+    /** @param {boolean} enabled */
+    setHotwordSearchEnabled: function(enabled) {},
   };
 
   /**
@@ -125,13 +138,13 @@ cr.define('settings', function() {
     },
 
     /** @override */
-    disableExtension: function(extensionId) {
-      chrome.send('disableExtension', [extensionId]);
+    getHotwordInfo: function() {
+      return cr.sendWithPromise('getHotwordInfo');
     },
 
     /** @override */
-    manageExtension: function(extensionId) {
-      window.open('chrome://extensions?id=' + extensionId);
+    setHotwordSearchEnabled: function(enabled) {
+      chrome.send('setHotwordSearchEnabled', [enabled]);
     },
   };
 
