@@ -9,6 +9,19 @@
  * @polymerBehavior MainPageBehavior
  */
 var MainPageBehaviorImpl = {
+  properties: {
+    /**
+     * Whether a search operation is in progress or previous search results are
+     * being displayed.
+     * @private {boolean}
+     */
+    inSearchMode: {
+      type: Boolean,
+      value: false,
+      observer: 'inSearchModeChanged_',
+    },
+  },
+
   /** @type {?HTMLElement} The scrolling container. */
   scroller: null,
 
@@ -25,14 +38,36 @@ var MainPageBehaviorImpl = {
    * @param {settings.Route} oldRoute
    */
   currentRouteChanged: function(newRoute, oldRoute) {
-    // If this is the first route, or the page was hidden, allow the page to
-    // render before expanding the section.
-    if (!oldRoute && newRoute.contains(settings.getCurrentRoute()) ||
-        this.scrollHeight == 0) {
-      setTimeout(this.tryTransitionToSection_.bind(this));
-    } else {
-      this.tryTransitionToSection_();
+    // Scroll to the section except for back/forward. Also scroll for any
+    // back/forward navigations that are in-page.
+    var oldRouteWasSection =
+        !!oldRoute && !!oldRoute.parent && !!oldRoute.section &&
+        oldRoute.parent.section != oldRoute.section;
+
+    if (oldRouteWasSection && newRoute == settings.Route.BASIC) {
+      this.scroller.scrollTop = 0;
+      return;
     }
+
+    var scrollToSection =
+        !settings.lastRouteChangeWasPopstate() || oldRouteWasSection;
+
+    // For previously uncreated pages (including on first load), allow the page
+    // to render before scrolling to or expanding the section.
+    if (!oldRoute || this.scrollHeight == 0)
+      setTimeout(this.tryTransitionToSection_.bind(this, scrollToSection));
+    else
+      this.tryTransitionToSection_(scrollToSection);
+  },
+
+  /**
+   * When exiting search mode, we need to make another attempt to scroll to
+   * the correct section, since it has just been re-rendered.
+   * @private
+   */
+  inSearchModeChanged_: function(inSearchMode) {
+    if (!inSearchMode)
+      this.tryTransitionToSection_(!settings.lastRouteChangeWasPopstate());
   },
 
   /**
@@ -41,9 +76,10 @@ var MainPageBehaviorImpl = {
    * that one, then schedules this function again. This ensures the current
    * section is quickly shown, without getting the page into a broken state --
    * if currentRoute changes in between calls, just transition to the new route.
+   * @param {boolean} scrollToSection
    * @private
    */
-  tryTransitionToSection_: function() {
+  tryTransitionToSection_: function(scrollToSection) {
     var currentRoute = settings.getCurrentRoute();
     var currentSection = this.getSection(currentRoute.section);
 
@@ -63,7 +99,7 @@ var MainPageBehaviorImpl = {
       if (!currentRoute.isSubpage() || expandedSection != currentSection) {
         promise = this.collapseSection_(expandedSection);
         // Scroll to the collapsed section.
-        if (currentSection && !settings.lastRouteChangeWasPopstate())
+        if (currentSection && scrollToSection)
           currentSection.scrollIntoView();
       } else {
         // Scroll to top while sliding to another subpage.
@@ -73,14 +109,14 @@ var MainPageBehaviorImpl = {
       // Expand the section into a subpage or scroll to it on the main page.
       if (currentRoute.isSubpage())
         promise = this.expandSection_(currentSection);
-      else if (!settings.lastRouteChangeWasPopstate())
+      else if (scrollToSection)
         currentSection.scrollIntoView();
     }
 
     // When this animation ends, another may be necessary. Call this function
     // again after the promise resolves.
     if (promise)
-      promise.then(this.tryTransitionToSection_.bind(this));
+      promise.then(this.tryTransitionToSection_.bind(this, scrollToSection));
   },
 
   /**
