@@ -21,7 +21,7 @@ Polymer({
     categoryEnabled: Boolean,
 
     /**
-     * The site that was selected by the user in the dropdown list.
+     * The site that is passed down to the site list.
      * @type {SiteException}
      */
     selectedSite: {
@@ -31,6 +31,7 @@ Polymer({
 
     /**
      * The description to be shown next to the slider.
+     * @private
      */
     sliderDescription_: String,
 
@@ -78,7 +79,7 @@ Polymer({
    * A handler for changing the default permission value for a content type.
    * @private
    */
-  onChangePermissionControl_: function(event) {
+  onChangePermissionControl_: function() {
     switch (this.category) {
       case settings.ContentSettingsTypes.BACKGROUND_SYNC:
       case settings.ContentSettingsTypes.IMAGES:
@@ -139,9 +140,9 @@ Polymer({
   onCategoryChanged_: function() {
     settings.SiteSettingsPrefsBrowserProxyImpl.getInstance()
         .getDefaultValueForContentType(
-            this.category).then(function(setting) {
-              this.categoryEnabled =
-                  this.computeIsSettingEnabled(this.category, setting);
+            this.category).then(function(defaultValue) {
+              var setting = defaultValue.setting;
+              this.categoryEnabled = this.computeIsSettingEnabled(setting);
 
               // Flash only shows ALLOW or BLOCK descriptions on the slider.
               var sliderSetting = setting;
@@ -182,26 +183,4 @@ Polymer({
   isCookiesCategory_: function(category) {
     return category == settings.ContentSettingsTypes.COOKIES;
   },
-
-  /**
-   * Returns whether this is the Plugins category.
-   * @param {string} category The current category.
-   * @return {boolean} Whether this is the Plugins category.
-   * @private
-   */
-  isPluginCategory_: function(category) {
-    return category == settings.ContentSettingsTypes.PLUGINS;
-  },
-
-  /** @private */
-  onLearnMoreClicked_: function() {
-    window.open(
-        'https://support.google.com/chrome/?p=settings_manage_exceptions');
-  },
-
-  /** @private */
-  onAdobeFlashStorageClicked_: function() {
-    window.open('https://www.macromedia.com/support/' +
-        'documentation/en/flashplayer/help/settings_manager07.html');
-  },
 });
