@@ -7,12 +7,23 @@
  * interact with the content settings prefs.
  */
 
+/**
+ * The handler will send a police source that is similar, but not exactly the
+ * same as a ControlledBy value. If the ContentSettingProvider is omitted it
+ * should be treated as 'default'.
+ * @enum {string}
+ */
+var ContentSettingProvider = {
+  EXTENSION: 'extension',
+  PREFERENCE: 'preference',
+};
+
 /**
  * @typedef {{embeddingOrigin: string,
- *            embeddingOriginForDisplay: string,
+ *            embeddingDisplayName: string,
  *            incognito: boolean,
  *            origin: string,
- *            originForDisplay: string,
+ *            displayName: string,
  *            setting: string,
  *            source: string}}
  */
@@ -24,6 +35,12 @@ var SiteException;
  */
 var CategoryDefaultsPref;
 
+/**
+ * @typedef {{setting: string,
+ *            source: ContentSettingProvider}}
+ */
+var DefaultContentSetting;
+
 /**
  * @typedef {{location: Array<SiteException>,
  *            notifications: Array<SiteException>}}
@@ -86,24 +103,31 @@ cr.define('settings', function() {
      */
     setDefaultValueForContentType: function(contentType, defaultValue) {},
 
+    /**
+     * Gets the cookie details for a particular site.
+     * @param {string} site The name of the site.
+     * @return {!Promise<!CookieDataSummaryItem>}
+     */
+    getCookieDetails: function(site) {},
+
     /**
      * Gets the default value for a site settings category.
      * @param {string} contentType The name of the category to query.
-     * @return {Promise<string>} The string value of the default setting.
+     * @return {!Promise<!DefaultContentSetting>}
      */
     getDefaultValueForContentType: function(contentType) {},
 
     /**
      * Gets the exceptions (site list) for a particular category.
      * @param {string} contentType The name of the category to query.
-     * @return {Promise<Array<SiteException>>}
+     * @return {!Promise<!Array<!SiteException>>}
      */
     getExceptionList: function(contentType) {},
 
     /**
      * Gets the exception details for a particular site.
      * @param {string} site The name of the site.
-     * @return {Promise<SiteException>}
+     * @return {!Promise<!SiteException>}
      */
     getSiteDetails: function(site) {},
 
@@ -157,7 +181,7 @@ cr.define('settings', function() {
 
     /**
      * Reloads all cookies.
-     * @return {!Promise<Array<CookieDataSummaryItem>>} Returns the full cookie
+     * @return {!Promise<!CookieList>} Returns the full cookie
      *     list.
      */
     reloadCookies: function() {},
@@ -165,7 +189,7 @@ cr.define('settings', function() {
     /**
      * Fetches all children of a given cookie.
      * @param {string} path The path to the parent cookie.
-     * @return {!Promise<Array<CookieDataSummaryItem>>} Returns a cookie list
+     * @return {!Promise<!Array<!CookieDataSummaryItem>>} Returns a cookie list
      *     for the given path.
      */
     loadCookieChildren: function(path) {},
@@ -178,7 +202,7 @@ cr.define('settings', function() {
 
     /**
      * Removes all cookies.
-     * @return {!Promise<Array<CookieDataSummaryItem>>} Returns the up to date
+     * @return {!Promise<!CookieList>} Returns the up to date
      *     cookie list once deletion is complete (empty list).
      */
     removeAllCookies: function() {},
@@ -212,7 +236,7 @@ cr.define('settings', function() {
 
     /**
      * Fetches a list of all USB devices and the sites permitted to use them.
-     * @return {!Promise<Array<UsbDeviceEntry>>} The list of USB devices.
+     * @return {!Promise<!Array<!UsbDeviceEntry>>} The list of USB devices.
      */
     fetchUsbDevices: function() {},
 
@@ -221,7 +245,7 @@ cr.define('settings', function() {
      * origin.
      * @param {string} origin The origin to look up the permission for.
      * @param {string} embeddingOrigin the embedding origin to look up.
-     * @param {UsbDeviceDetails} usbDevice The USB device to revoke permission
+     * @param {!UsbDeviceDetails} usbDevice The USB device to revoke permission
      *     for.
      */
     removeUsbDevice: function(origin, embeddingOrigin, usbDevice) {},
@@ -261,6 +285,11 @@ cr.define('settings', function() {
       chrome.send('setDefaultValueForContentType', [contentType, defaultValue]);
     },
 
+    /** @override */
+    getCookieDetails: function(site) {
+      return cr.sendWithPromise('getCookieDetails', site);
+    },
+
     /** @override */
     getDefaultValueForContentType: function(contentType) {
       return cr.sendWithPromise('getDefaultValueForContentType', contentType);
