@@ -6,6 +6,7 @@
 #define CHROME_BROWSER_SAFE_BROWSING_INCIDENT_REPORTING_ENVIRONMENT_DATA_COLLECTION_WIN_H_
 
 #include <windows.h>
+#include <stddef.h>
 
 namespace google {
 namespace protobuf {
@@ -16,6 +17,7 @@ class RepeatedPtrField;
 
 namespace safe_browsing {
 
+class ClientIncidentReport_EnvironmentData_OS;
 class ClientIncidentReport_EnvironmentData_OS_RegistryKey;
 class ClientIncidentReport_EnvironmentData_Process;
 
@@ -55,6 +57,11 @@ void CollectRegistryData(
     google::protobuf::RepeatedPtrField<
         ClientIncidentReport_EnvironmentData_OS_RegistryKey>* key_data);
 
+// Populates |os_data| with information about the machine's domain enrollment
+// status.
+void CollectDomainEnrollmentData(
+    ClientIncidentReport_EnvironmentData_OS* os_data);
+
 }  // namespace safe_browsing
 
 #endif  // CHROME_BROWSER_SAFE_BROWSING_INCIDENT_REPORTING_ENVIRONMENT_DATA_COLLECTION_WIN_H_
