@@ -9,6 +9,8 @@
 #include "base/base64.h"
 #include "base/logging.h"
 #include "base/memory/ptr_util.h"
+#include "base/metrics/histogram_macros.h"
+#include "base/metrics/sparse_histogram.h"
 #include "base/strings/string_util.h"
 #include "base/strings/stringprintf.h"
 #include "base/values.h"
@@ -67,6 +69,12 @@ std::unique_ptr<base::Value> NetLogPingEndCallback(
   return std::move(event_params);
 }
 
+// Records an UMA histogram of the net errors when certificate reports
+// fail to send.
+void RecordUMAOnFailure(const GURL& report_uri, int net_error) {
+  UMA_HISTOGRAM_SPARSE_SLOWLY("SSL.CertificateErrorReportFailure", -net_error);
+}
+
 }  // namespace
 
 namespace safe_browsing {
@@ -186,7 +194,8 @@ void SafeBrowsingPingManager::ReportThreatDetails(const std::string& report) {
 void SafeBrowsingPingManager::ReportInvalidCertificateChain(
     const std::string& serialized_report) {
   DCHECK(certificate_error_reporter_);
-  certificate_error_reporter_->SendExtendedReportingReport(serialized_report);
+  certificate_error_reporter_->SendExtendedReportingReport(
+      serialized_report, base::Closure(), base::Bind(RecordUMAOnFailure));
 }
 
 void SafeBrowsingPingManager::SetCertificateErrorReporterForTesting(
@@ -210,7 +219,7 @@ GURL SafeBrowsingPingManager::SafeBrowsingHitUrl(
          hit_report.threat_type == SB_THREAT_TYPE_CLIENT_SIDE_MALWARE_URL);
   std::string url = SafeBrowsingProtocolManagerHelper::ComposeUrl(
       url_prefix_, "report", client_name_, version_, std::string(),
-      hit_report.is_extended_reporting);
+      hit_report.extended_reporting_level);
 
   std::string threat_list = "none";
   switch (hit_report.threat_type) {
