@@ -34,6 +34,7 @@
 #include "chrome/grit/generated_resources.h"
 #include "components/google/core/browser/google_util.h"
 #include "components/prefs/pref_service.h"
+#include "components/safe_browsing_db/safe_browsing_prefs.h"
 #include "components/security_interstitials/core/common_string_util.h"
 #include "components/security_interstitials/core/controller_client.h"
 #include "content/public/browser/browser_thread.h"
@@ -306,6 +307,10 @@ void SafeBrowsingBlockingPage::CommandReceived(const std::string& page_cmd) {
       web_contents()->OpenURL(params);
       break;
     }
+    case security_interstitials::CMD_OPEN_WHITEPAPER: {
+      controller()->OpenExtendedReportingWhitepaper();
+      break;
+    }
   }
 }
 
@@ -323,7 +328,8 @@ void SafeBrowsingBlockingPage::OnProceed() {
   FinishThreatDetails(threat_details_proceed_delay_ms_, true, /* did_proceed */
                       controller()->metrics_helper()->NumVisits());
 
-  ui_manager_->OnBlockingPageDone(unsafe_resources_, true);
+  ui_manager_->OnBlockingPageDone(unsafe_resources_, true, web_contents(),
+                                  main_frame_url_);
 
   // Check to see if some new notifications of unsafe resources have been
   // received while we were showing the interstitial.
@@ -372,14 +378,16 @@ void SafeBrowsingBlockingPage::OnDontProceed() {
   FinishThreatDetails(0, false /* did_proceed */,
                       controller()->metrics_helper()->NumVisits());  // No delay
 
-  ui_manager_->OnBlockingPageDone(unsafe_resources_, false);
+  ui_manager_->OnBlockingPageDone(unsafe_resources_, false, web_contents(),
+                                  main_frame_url_);
 
   // The user does not want to proceed, clear the queued unsafe resources
   // notifications we received while the interstitial was showing.
   UnsafeResourceMap* unsafe_resource_map = GetUnsafeResourcesMap();
   UnsafeResourceMap::iterator iter = unsafe_resource_map->find(web_contents());
   if (iter != unsafe_resource_map->end() && !iter->second.empty()) {
-    ui_manager_->OnBlockingPageDone(iter->second, false);
+    ui_manager_->OnBlockingPageDone(iter->second, false, web_contents(),
+                                    main_frame_url_);
     unsafe_resource_map->erase(iter);
   }
 
@@ -406,7 +414,7 @@ void SafeBrowsingBlockingPage::FinishThreatDetails(int64_t delay_ms,
     return;  // Not all interstitials have threat details (eg., incognito mode).
 
   const bool enabled =
-      IsPrefEnabled(prefs::kSafeBrowsingExtendedReportingEnabled) &&
+      IsExtendedReportingEnabled(*profile()->GetPrefs()) &&
       IsPrefEnabled(prefs::kSafeBrowsingExtendedReportingOptInAllowed);
   if (!enabled)
     return;
@@ -450,19 +458,11 @@ void SafeBrowsingBlockingPage::ShowBlockingPage(
   DVLOG(1) << __func__ << " " << unsafe_resource.url.spec();
   WebContents* web_contents = unsafe_resource.web_contents_getter.Run();
 
-  InterstitialPage* interstitial =
-      InterstitialPage::GetInterstitialPage(web_contents);
-  if (interstitial && !unsafe_resource.is_subresource) {
-    // There is already an interstitial showing and we are about to display a
-    // new one for the main frame. Just hide the current one, it is now
-    // irrelevent
-    interstitial->DontProceed();
-    interstitial = NULL;
-  }
-
-  if (!interstitial) {
-    // There are no interstitial currently showing in that tab, go ahead and
-    // show this interstitial.
+  if (!InterstitialPage::GetInterstitialPage(web_contents) ||
+      !unsafe_resource.is_subresource) {
+    // There is no interstitial currently showing in that tab, or we are about
+    // to display a new one for the main frame. If there is already an
+    // interstitial, showing the new one will automatically hide the old one.
     content::NavigationEntry* entry =
         unsafe_resource.GetNavigationEntryForResource();
     SafeBrowsingBlockingPage* blocking_page =
@@ -686,11 +686,14 @@ void SafeBrowsingBlockingPage::PopulateExtendedReportingOption(
       l10n_util::GetStringUTF8(IDS_SAFE_BROWSING_PRIVACY_POLICY_PAGE).c_str());
   load_time_data->SetString(
       security_interstitials::kOptInLink,
-      l10n_util::GetStringFUTF16(IDS_SAFE_BROWSING_MALWARE_REPORTING_AGREE,
-                                 base::UTF8ToUTF16(privacy_link)));
+      l10n_util::GetStringFUTF16(
+          ChooseOptInTextResource(*profile()->GetPrefs(),
+                                  IDS_SAFE_BROWSING_MALWARE_REPORTING_AGREE,
+                                  IDS_SAFE_BROWSING_SCOUT_REPORTING_AGREE),
+          base::UTF8ToUTF16(privacy_link)));
   load_time_data->SetBoolean(
       security_interstitials::kBoxChecked,
-      IsPrefEnabled(prefs::kSafeBrowsingExtendedReportingEnabled));
+      IsExtendedReportingEnabled(*profile()->GetPrefs()));
 }
 
 void SafeBrowsingBlockingPage::PopulateMalwareLoadTimeData(
