@@ -49,6 +49,7 @@
 #include "content/public/browser/notification_types.h"
 #include "content/public/browser/render_frame_host.h"
 #include "content/public/browser/render_process_host.h"
+#include "content/public/browser/security_style_explanations.h"
 #include "content/public/browser/web_contents.h"
 #include "content/public/test/browser_test_utils.h"
 #include "content/public/test/test_browser_thread.h"
@@ -211,7 +212,7 @@ class TestThreatDetailsFactory : public ThreatDetailsFactory {
   ThreatDetails* CreateThreatDetails(
       SafeBrowsingUIManager* delegate,
       WebContents* web_contents,
-      const SafeBrowsingUIManager::UnsafeResource& unsafe_resource) override {
+      const security_interstitials::UnsafeResource& unsafe_resource) override {
     details_ = new ThreatDetails(delegate, web_contents, unsafe_resource);
     return details_;
   }
@@ -917,6 +918,46 @@ IN_PROC_BROWSER_TEST_P(SafeBrowsingBlockingPageBrowserTest,
       net::URLRequestMockHTTPJob::GetMockUrl(kEmptyPage));
 }
 
+// Verifies that the reporting checkbox is still shown if the page is reloaded
+// while the interstitial is showing.
+IN_PROC_BROWSER_TEST_P(SafeBrowsingBlockingPageBrowserTest,
+                       ReloadWhileInterstitialShowing) {
+  // Start navigation to bad page (kEmptyPage), which will be blocked before it
+  // is committed.
+  const GURL url = SetupWarningAndNavigate();
+
+  // Checkbox should be showing.
+  EXPECT_EQ(VISIBLE, GetVisibility("extended-reporting-opt-in"));
+
+  WebContents* tab = browser()->tab_strip_model()->GetActiveWebContents();
+  ASSERT_TRUE(tab);
+  // Security indicator should be showing.
+  ExpectSecurityIndicatorDowngrade(tab, 0u);
+
+  // Check navigation entry state.
+  const NavigationController& controller = tab->GetController();
+  ASSERT_TRUE(controller.GetVisibleEntry());
+  EXPECT_EQ(url, controller.GetVisibleEntry()->GetURL());
+  ASSERT_TRUE(controller.GetPendingEntry());
+  EXPECT_EQ(url, controller.GetPendingEntry()->GetURL());
+
+  // "Reload" the tab.
+  SetupWarningAndNavigate();
+
+  // Checkbox should be showing.
+  EXPECT_EQ(VISIBLE, GetVisibility("extended-reporting-opt-in"));
+
+  // TODO(crbug.com/666172): Security indicator should be showing.
+  // Call |ExpectSecurityIndicatorDowngrade(tab, 0u);| here once the bug is
+  // fixed.
+
+  // Check navigation entry state.
+  ASSERT_TRUE(controller.GetVisibleEntry());
+  EXPECT_EQ(url, controller.GetVisibleEntry()->GetURL());
+  ASSERT_TRUE(controller.GetPendingEntry());
+  EXPECT_EQ(url, controller.GetPendingEntry()->GetURL());
+}
+
 IN_PROC_BROWSER_TEST_P(SafeBrowsingBlockingPageBrowserTest, LearnMore) {
   SetupWarningAndNavigate();
   EXPECT_TRUE(ClickAndWaitForDetach("learn-more-link"));
@@ -1083,10 +1124,10 @@ class SecurityStyleTestObserver : public content::WebContentsObserver {
   }
 
   // WebContentsObserver:
-  void SecurityStyleChanged(blink::WebSecurityStyle security_style,
-                            const content::SecurityStyleExplanations&
-                                security_style_explanations) override {
-    latest_security_style_ = security_style;
+  void DidChangeVisibleSecurityState() override {
+    content::SecurityStyleExplanations security_style_explanations;
+    latest_security_style_ = web_contents()->GetDelegate()->GetSecurityStyle(
+        web_contents(), &security_style_explanations);
   }
 
  private:
@@ -1290,7 +1331,7 @@ class SafeBrowsingBlockingPageIDNTest
     resource.is_subresource = is_subresource;
     resource.threat_type = testing::get<1>(GetParam());
     resource.web_contents_getter =
-        SafeBrowsingUIManager::UnsafeResource::GetWebContentsGetter(
+        security_interstitials::UnsafeResource::GetWebContentsGetter(
             contents->GetRenderProcessHost()->GetID(),
             contents->GetMainFrame()->GetRoutingID());
     resource.threat_source = safe_browsing::ThreatSource::LOCAL_PVER3;
