@@ -29,14 +29,14 @@
 #include "chrome/browser/profiles/profile_manager.h"
 #include "chrome/browser/safe_browsing/ping_manager.h"
 #include "chrome/browser/safe_browsing/ui_manager.h"
-#include "chrome/common/chrome_constants.h"
 #include "chrome/common/chrome_paths.h"
 #include "chrome/common/chrome_switches.h"
 #include "chrome/common/pref_names.h"
 #include "chrome/common/safe_browsing/file_type_policies.h"
-#include "chrome/common/url_constants.h"
 #include "components/prefs/pref_change_registrar.h"
 #include "components/prefs/pref_service.h"
+#include "components/safe_browsing/common/safebrowsing_constants.h"
+#include "components/safe_browsing/common/safebrowsing_switches.h"
 #include "components/safe_browsing_db/database_manager.h"
 #include "components/safe_browsing_db/safe_browsing_prefs.h"
 #include "components/safe_browsing_db/v4_feature_list.h"
@@ -219,6 +219,7 @@ SafeBrowsingURLRequestContextGetter::GetURLRequestContext() {
       safe_browsing_request_context_->set_http_transaction_factory(
           http_transaction_factory_.get());
     }
+    safe_browsing_request_context_->set_name("safe_browsing");
   }
 
   return safe_browsing_request_context_.get();
@@ -271,7 +272,7 @@ base::FilePath SafeBrowsingService::GetBaseFilename() {
   base::FilePath path;
   bool result = PathService::Get(chrome::DIR_USER_DATA, &path);
   DCHECK(result);
-  return path.Append(chrome::kSafeBrowsingBaseFilename);
+  return path.Append(safe_browsing::kSafeBrowsingBaseFilename);
 }
 
 
@@ -476,8 +477,8 @@ SafeBrowsingProtocolConfig SafeBrowsingService::GetProtocolConfig() const {
 
   base::CommandLine* cmdline = base::CommandLine::ForCurrentProcess();
   config.disable_auto_update =
-      cmdline->HasSwitch(switches::kSbDisableAutoUpdate) ||
-      cmdline->HasSwitch(switches::kDisableBackgroundNetworking);
+      cmdline->HasSwitch(safe_browsing::switches::kSbDisableAutoUpdate) ||
+      cmdline->HasSwitch(::switches::kDisableBackgroundNetworking);
   config.url_prefix = kSbDefaultURLPrefix;
   config.backup_connect_error_url_prefix = kSbBackupConnectErrorURLPrefix;
   config.backup_http_error_url_prefix = kSbBackupHttpErrorURLPrefix;
@@ -491,7 +492,7 @@ SafeBrowsingService::GetV4ProtocolConfig() const {
   base::CommandLine* cmdline = base::CommandLine::ForCurrentProcess();
   return V4ProtocolConfig(
       GetProtocolConfigClientName(),
-      cmdline->HasSwitch(switches::kDisableBackgroundNetworking),
+      cmdline->HasSwitch(::switches::kDisableBackgroundNetworking),
       google_apis::GetAPIKey(), SafeBrowsingProtocolManagerHelper::Version());
 }
 
