@@ -123,8 +123,6 @@ class SuggestionsSource : public content::URLDataSource {
       const content::ResourceRequestInfo::WebContentsGetter& wc_getter,
       const content::URLDataSource::GotDataCallback& callback) override;
   std::string GetMimeType(const std::string& path) const override;
-  base::MessageLoop* MessageLoopForRequestPath(
-      const std::string& path) const override;
 
  private:
   ~SuggestionsSource() override;
@@ -232,12 +230,6 @@ std::string SuggestionsSource::GetMimeType(const std::string& path) const {
   return "text/html";
 }
 
-base::MessageLoop* SuggestionsSource::MessageLoopForRequestPath(
-    const std::string& path) const {
-  // This can be accessed from the IO thread.
-  return content::URLDataSource::MessageLoopForRequestPath(path);
-}
-
 void SuggestionsSource::OnThumbnailsFetched(RequestContext* context) {
   std::unique_ptr<RequestContext> context_deleter(context);
 
