@@ -101,8 +101,8 @@ void TemplateURLParserTest::ParseFile(
 
   std::string contents;
   ASSERT_TRUE(base::ReadFileToString(full_path, &contents));
-  template_url_ = TemplateURLParser::Parse(
-      SearchTermsData(), false, contents.data(), contents.length(), filter);
+  template_url_ = TemplateURLParser::Parse(SearchTermsData(), contents.data(),
+                                           contents.length(), filter);
 }
 
 
