@@ -7,6 +7,7 @@
 #include <stddef.h>
 #include <utility>
 
+#include "base/bind.h"
 #include "base/command_line.h"
 #include "base/strings/utf_string_conversions.h"
 #include "build/build_config.h"
@@ -21,8 +22,12 @@
 #include "chrome/browser/signin/local_auth.h"
 #include "chrome/browser/signin/profile_oauth2_token_service_factory.h"
 #include "chrome/browser/signin/signin_manager_factory.h"
+#include "chrome/browser/ui/browser_list.h"
+#include "chrome/browser/ui/user_manager.h"
 #include "chrome/browser/web_data_service_factory.h"
 #include "chrome/common/channel_info.h"
+#include "chrome/common/features.h"
+#include "chrome/common/pref_names.h"
 #include "components/content_settings/core/browser/cookie_settings.h"
 #include "components/metrics/metrics_service.h"
 #include "components/prefs/pref_service.h"
@@ -32,12 +37,13 @@
 #include "components/signin/core/common/profile_management_switches.h"
 #include "components/signin/core/common/signin_pref_names.h"
 #include "components/signin/core/common/signin_switches.h"
+#include "content/public/browser/browser_thread.h"
 #include "google_apis/gaia/gaia_constants.h"
 #include "google_apis/gaia/gaia_urls.h"
 #include "net/url_request/url_request_context_getter.h"
 #include "url/gurl.h"
 
-#if defined(ENABLE_SUPERVISED_USERS)
+#if BUILDFLAG(ENABLE_SUPERVISED_USERS)
 #include "chrome/browser/supervised_user/supervised_user_constants.h"
 #endif
 
@@ -52,11 +58,24 @@
 #include "chrome/browser/first_run/first_run.h"
 #endif
 
+namespace {
+
+bool IsForceSigninEnabled() {
+  PrefService* prefs = g_browser_process->local_state();
+  return prefs && prefs->GetBoolean(prefs::kForceBrowserSignin);
+}
+
+}  // namespace
+
 ChromeSigninClient::ChromeSigninClient(
-    Profile* profile, SigninErrorController* signin_error_controller)
+    Profile* profile,
+    SigninErrorController* signin_error_controller)
     : OAuth2TokenService::Consumer("chrome_signin_client"),
       profile_(profile),
-      signin_error_controller_(signin_error_controller) {
+      signin_error_controller_(signin_error_controller),
+      is_force_signin_enabled_(IsForceSigninEnabled()),
+      request_context_pointer_(nullptr),
+      number_of_request_context_pointer_changes_(0) {
   signin_error_controller_->AddObserver(this);
 #if !defined(OS_CHROMEOS)
   net::NetworkChangeNotifier::AddNetworkChangeObserver(this);
@@ -183,7 +202,34 @@ void ChromeSigninClient::OnSignedOut() {
 }
 
 net::URLRequestContextGetter* ChromeSigninClient::GetURLRequestContext() {
-  return profile_->GetRequestContext();
+  net::URLRequestContextGetter* getter = profile_->GetRequestContext();
+  scoped_refptr<net::URLRequestContextGetter> scoped_getter(getter);
+  content::BrowserThread::PostTaskAndReplyWithResult(
+      content::BrowserThread::IO,
+      FROM_HERE,
+      base::Bind(&net::URLRequestContextGetter::GetURLRequestContext,
+                 scoped_getter),
+      base::Bind(&ChromeSigninClient::RequestContextPointerReply,
+                 base::Unretained(this)));
+  return getter;
+}
+
+void ChromeSigninClient::RequestContextPointerReply(
+    net::URLRequestContext* pointer) {
+  // Because this function runs in the UI thread, it is not possible to
+  // dereference the pointer.  The pointer is used only for its value.
+  if (request_context_pointer_ != nullptr &&
+      pointer != request_context_pointer_) {
+    ++number_of_request_context_pointer_changes_;
+
+    // In theory, |request_context_pointer_changed_| should never be > 0.
+    // Adding a DCHECK here to catch it in debug builds.  In release builds
+    // requests to gaia will be tagged with a special source= parameter.
+    DCHECK_EQ(0, number_of_request_context_pointer_changes_)
+        << "If you hit this DCHECK, open a bug for rogerta@chromium.org";
+  }
+
+  request_context_pointer_ = pointer;
 }
 
 bool ChromeSigninClient::ShouldMergeSigninCredentialsIntoCookieJar() {
@@ -259,6 +305,23 @@ void ChromeSigninClient::PostSignedIn(const std::string& account_id,
 #endif
 }
 
+void ChromeSigninClient::PreSignOut(const base::Callback<void()>& sign_out) {
+#if !defined(OS_ANDROID) && !defined(OS_CHROMEOS)
+  if (is_force_signin_enabled_ && !profile_->IsSystemProfile() &&
+      !profile_->IsGuestSession() && !profile_->IsSupervised()) {
+    BrowserList::CloseAllBrowsersWithProfile(
+        profile_, base::Bind(&ChromeSigninClient::OnCloseBrowsersSuccess,
+                             base::Unretained(this), sign_out),
+        base::Bind(&ChromeSigninClient::OnCloseBrowsersAborted,
+                   base::Unretained(this)));
+  } else {
+#else
+  {
+#endif
+    SigninClient::PreSignOut(sign_out);
+  }
+}
+
 void ChromeSigninClient::OnErrorChanged() {
   // Some tests don't have a ProfileManager.
   if (g_browser_process->profile_manager() == nullptr)
@@ -384,3 +447,54 @@ void ChromeSigninClient::MaybeFetchSigninTokenHandle() {
   }
 #endif
 }
+
+void ChromeSigninClient::AfterCredentialsCopied() {
+  if (is_force_signin_enabled_) {
+    // The signout after credential copy won't open UserManager after all
+    // browser window are closed. Because the browser window will be opened for
+    // the new profile soon.
+    should_display_user_manager_ = false;
+  }
+}
+
+int ChromeSigninClient::number_of_request_context_pointer_changes() const {
+  return number_of_request_context_pointer_changes_;
+}
+
+void ChromeSigninClient::OnCloseBrowsersSuccess(
+    const base::Callback<void()>& sign_out,
+    const base::FilePath& profile_path) {
+  SigninClient::PreSignOut(sign_out);
+
+  LockForceSigninProfile(profile_path);
+  // After sign out, lock the profile and show UserManager if necessary.
+  if (should_display_user_manager_) {
+    ShowUserManager(profile_path);
+  } else {
+    should_display_user_manager_ = true;
+  }
+}
+
+void ChromeSigninClient::OnCloseBrowsersAborted(
+    const base::FilePath& profile_path) {
+  should_display_user_manager_ = true;
+}
+
+void ChromeSigninClient::LockForceSigninProfile(
+    const base::FilePath& profile_path) {
+  ProfileAttributesEntry* entry;
+  bool has_entry =
+      g_browser_process->profile_manager()
+          ->GetProfileAttributesStorage()
+          .GetProfileAttributesWithPath(profile_->GetPath(), &entry);
+  if (!has_entry)
+    return;
+  entry->LockForceSigninProfile(true);
+}
+
+void ChromeSigninClient::ShowUserManager(const base::FilePath& profile_path) {
+#if !defined(OS_ANDROID) && !defined(OS_CHROMEOS)
+  UserManager::Show(profile_path, profiles::USER_MANAGER_NO_TUTORIAL,
+                    profiles::USER_MANAGER_SELECT_PROFILE_NO_ACTION);
+#endif
+}
