@@ -26,16 +26,16 @@
 #include "chrome/common/extensions/api/easy_unlock_private.h"
 #include "chrome/common/extensions/extension_constants.h"
 #include "chrome/common/pref_names.h"
+#include "components/cryptauth/cryptauth_access_token_fetcher.h"
+#include "components/cryptauth/cryptauth_client_impl.h"
+#include "components/cryptauth/cryptauth_enrollment_manager.h"
+#include "components/cryptauth/cryptauth_enrollment_utils.h"
+#include "components/cryptauth/cryptauth_gcm_manager_impl.h"
+#include "components/cryptauth/secure_message_delegate.h"
 #include "components/gcm_driver/gcm_profile_service.h"
 #include "components/pref_registry/pref_registry_syncable.h"
 #include "components/prefs/pref_service.h"
 #include "components/prefs/scoped_user_pref_update.h"
-#include "components/proximity_auth/cryptauth/cryptauth_access_token_fetcher.h"
-#include "components/proximity_auth/cryptauth/cryptauth_client_impl.h"
-#include "components/proximity_auth/cryptauth/cryptauth_enrollment_manager.h"
-#include "components/proximity_auth/cryptauth/cryptauth_enrollment_utils.h"
-#include "components/proximity_auth/cryptauth/cryptauth_gcm_manager_impl.h"
-#include "components/proximity_auth/cryptauth/secure_message_delegate.h"
 #include "components/proximity_auth/cryptauth_enroller_factory_impl.h"
 #include "components/proximity_auth/logging/logging.h"
 #include "components/proximity_auth/proximity_auth_pref_manager.h"
@@ -87,12 +87,12 @@ EasyUnlockServiceRegular::EasyUnlockServiceRegular(Profile* profile)
 EasyUnlockServiceRegular::~EasyUnlockServiceRegular() {
 }
 
-proximity_auth::CryptAuthEnrollmentManager*
+cryptauth::CryptAuthEnrollmentManager*
 EasyUnlockServiceRegular::GetCryptAuthEnrollmentManager() {
   return enrollment_manager_.get();
 }
 
-proximity_auth::CryptAuthDeviceManager*
+cryptauth::CryptAuthDeviceManager*
 EasyUnlockServiceRegular::GetCryptAuthDeviceManager() {
   return device_manager_.get();
 }
@@ -104,7 +104,7 @@ EasyUnlockServiceRegular::GetProximityAuthPrefManager() {
 
 void EasyUnlockServiceRegular::LoadRemoteDevices() {
   if (device_manager_->unlock_keys().empty()) {
-    SetProximityAuthDevices(GetAccountId(), proximity_auth::RemoteDeviceList());
+    SetProximityAuthDevices(GetAccountId(), cryptauth::RemoteDeviceList());
     return;
   }
 
@@ -119,7 +119,7 @@ void EasyUnlockServiceRegular::LoadRemoteDevices() {
 }
 
 void EasyUnlockServiceRegular::OnRemoteDevicesLoaded(
-    const proximity_auth::RemoteDeviceList& remote_devices) {
+    const cryptauth::RemoteDeviceList& remote_devices) {
   SetProximityAuthDevices(GetAccountId(), remote_devices);
 
 #if defined(OS_CHROMEOS)
@@ -344,7 +344,7 @@ void EasyUnlockServiceRegular::RunTurnOffFlow() {
 
   SetTurnOffFlowStatus(PENDING);
 
-  std::unique_ptr<proximity_auth::CryptAuthClientFactory> factory =
+  std::unique_ptr<cryptauth::CryptAuthClientFactory> factory =
       proximity_auth_client()->CreateCryptAuthClientFactory();
   cryptauth_client_ = factory->CreateInstance();
 
@@ -498,11 +498,11 @@ void EasyUnlockServiceRegular::OnRefreshTokenAvailable(
 }
 
 void EasyUnlockServiceRegular::OnSyncFinished(
-    proximity_auth::CryptAuthDeviceManager::SyncResult sync_result,
-    proximity_auth::CryptAuthDeviceManager::DeviceChangeResult
+    cryptauth::CryptAuthDeviceManager::SyncResult sync_result,
+    cryptauth::CryptAuthDeviceManager::DeviceChangeResult
         device_change_result) {
   if (device_change_result !=
-      proximity_auth::CryptAuthDeviceManager::DeviceChangeResult::CHANGED)
+      cryptauth::CryptAuthDeviceManager::DeviceChangeResult::CHANGED)
     return;
 
   if (proximity_auth::ScreenlockBridge::Get()->IsLocked()) {
@@ -608,7 +608,7 @@ cryptauth::GcmDeviceInfo EasyUnlockServiceRegular::GetGcmDeviceInfo() {
   device_info.set_device_type(cryptauth::CHROME);
   device_info.set_device_software_version(version_info::GetVersionNumber());
   google::protobuf::int64 software_version_code =
-      proximity_auth::HashStringToInt64(version_info::GetLastChange());
+      cryptauth::HashStringToInt64(version_info::GetLastChange());
   device_info.set_device_software_version_code(software_version_code);
   device_info.set_locale(
       translate::TranslateDownloadManager::GetInstance()->application_locale());
@@ -652,14 +652,14 @@ cryptauth::GcmDeviceInfo EasyUnlockServiceRegular::GetGcmDeviceInfo() {
 void EasyUnlockServiceRegular::InitializeCryptAuth() {
   PA_LOG(INFO) << "Initializing CryptAuth managers.";
   // Initialize GCM manager.
-  gcm_manager_.reset(new proximity_auth::CryptAuthGCMManagerImpl(
+  gcm_manager_.reset(new cryptauth::CryptAuthGCMManagerImpl(
       gcm::GCMProfileServiceFactory::GetForProfile(profile())->driver(),
       proximity_auth_client()->GetPrefService()));
   gcm_manager_->StartListening();
 
   // Initialize enrollment manager.
   cryptauth::GcmDeviceInfo device_info;
-  enrollment_manager_.reset(new proximity_auth::CryptAuthEnrollmentManager(
+  enrollment_manager_.reset(new cryptauth::CryptAuthEnrollmentManager(
       base::MakeUnique<base::DefaultClock>(),
       base::MakeUnique<proximity_auth::CryptAuthEnrollerFactoryImpl>(
           proximity_auth_client()),
@@ -668,7 +668,7 @@ void EasyUnlockServiceRegular::InitializeCryptAuth() {
       proximity_auth_client()->GetPrefService()));
 
   // Initialize device manager.
-  device_manager_.reset(new proximity_auth::CryptAuthDeviceManager(
+  device_manager_.reset(new cryptauth::CryptAuthDeviceManager(
       base::MakeUnique<base::DefaultClock>(),
       proximity_auth_client()->CreateCryptAuthClientFactory(),
       gcm_manager_.get(), proximity_auth_client()->GetPrefService()));
