@@ -44,6 +44,7 @@ class CertReportHelper {
                    certificate_reporting::ErrorReport::InterstitialReason
                        interstitial_reason,
                    bool overridable,
+                   const base::Time& interstitial_time,
                    security_interstitials::MetricsHelper* metrics_helper);
 
   virtual ~CertReportHelper();
@@ -88,6 +89,8 @@ class CertReportHelper {
   // True if the user was given the option to proceed through the
   // certificate chain error being reported.
   bool overridable_;
+  // The time at which the interstitial was constructed.
+  const base::Time interstitial_time_;
   // Helpful for recording metrics about cert reports.
   security_interstitials::MetricsHelper* metrics_helper_;
 
