@@ -8,8 +8,8 @@
 #include <utility>
 
 #include "base/callback_helpers.h"
+#include "base/feature_list.h"
 #include "base/macros.h"
-#include "base/metrics/field_trial.h"
 #include "base/metrics/histogram_macros.h"
 #include "base/strings/stringprintf.h"
 #include "base/time/clock.h"
@@ -42,6 +42,14 @@ class NetworkTimeTracker;
 
 namespace {
 
+#if BUILDFLAG(ENABLE_CAPTIVE_PORTAL_DETECTION)
+const base::Feature kCaptivePortalInterstitial{
+    "CaptivePortalInterstitial", base::FEATURE_ENABLED_BY_DEFAULT};
+#endif
+
+const base::Feature kSSLCommonNameMismatchHandling{
+    "SSLCommonNameMismatchHandling", base::FEATURE_ENABLED_BY_DEFAULT};
+
 // The delay in milliseconds before displaying the SSL interstitial.
 // This can be changed in tests.
 // - If there is a name mismatch and a suggested URL available result arrives
@@ -113,7 +121,7 @@ class CommonNameMismatchRedirectObserver
             "Redirecting navigation %s -> %s because the server presented a "
             "certificate valid for %s but not for %s. To disable such "
             "redirects launch Chrome with the following flag: "
-            "--force-fieldtrials=SSLCommonNameMismatchHandling/Disabled/",
+            "--disable-features=SSLCommonNameMismatchHandling",
             request_url_hostname_.c_str(), suggested_url_hostname_.c_str(),
             suggested_url_hostname_.c_str(), request_url_hostname_.c_str()));
     web_contents_->RemoveUserData(UserDataKey());
@@ -137,14 +145,12 @@ void RecordUMA(SSLErrorHandlerEvent event) {
 
 #if BUILDFLAG(ENABLE_CAPTIVE_PORTAL_DETECTION)
 bool IsCaptivePortalInterstitialEnabled() {
-  return base::FieldTrialList::FindFullName("CaptivePortalInterstitial") ==
-         "Enabled";
+  return base::FeatureList::IsEnabled(kCaptivePortalInterstitial);
 }
 #endif
 
 bool IsSSLCommonNameMismatchHandlingEnabled() {
-  return base::FieldTrialList::FindFullName("SSLCommonNameMismatchHandling") ==
-         "Enabled";
+  return base::FeatureList::IsEnabled(kSSLCommonNameMismatchHandling);
 }
 
 }  // namespace
