@@ -9,6 +9,7 @@
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/utf_string_conversions.h"
 #include "chrome/grit/generated_resources.h"
+#include "components/arc/arc_bridge_service.h"
 #include "components/arc/arc_service_manager.h"
 #include "components/arc/common/process.mojom.h"
 #include "content/public/browser/browser_thread.h"
@@ -106,12 +107,18 @@ void ArcProcessTask::StartIconLoading() {
 
   if (result == arc::ActivityIconLoader::GetResult::FAILED_ARC_NOT_READY) {
     // Need to retry loading the icon.
-    arc::ArcBridgeService::Get()->intent_helper()->AddObserver(this);
+    arc::ArcServiceManager::Get()
+        ->arc_bridge_service()
+        ->intent_helper()
+        ->AddObserver(this);
   }
 }
 
 ArcProcessTask::~ArcProcessTask() {
-  arc::ArcBridgeService::Get()->intent_helper()->RemoveObserver(this);
+  arc::ArcServiceManager::Get()
+      ->arc_bridge_service()
+      ->intent_helper()
+      ->RemoveObserver(this);
 }
 
 Task::Type ArcProcessTask::GetType() const {
@@ -130,8 +137,10 @@ bool ArcProcessTask::IsKillable() {
 
 void ArcProcessTask::Kill() {
   auto* process_instance =
-      arc::ArcBridgeService::Get()->process()->GetInstanceForMethod(
-          "KillProcess", kKillProcessMinInstanceVersion);
+      arc::ArcServiceManager::Get()
+          ->arc_bridge_service()
+          ->process()
+          ->GetInstanceForMethod("KillProcess", kKillProcessMinInstanceVersion);
   if (!process_instance)
     return;
   process_instance->KillProcess(nspid_, "Killed manually from Task Manager");
@@ -142,7 +151,10 @@ void ArcProcessTask::OnInstanceReady() {
 
   VLOG(2) << "intent_helper instance is ready. Fetching the icon for "
           << package_name_;
-  arc::ArcBridgeService::Get()->intent_helper()->RemoveObserver(this);
+  arc::ArcServiceManager::Get()
+      ->arc_bridge_service()
+      ->intent_helper()
+      ->RemoveObserver(this);
 
   // Instead of calling into StartIconLoading() directly, return to the main
   // loop first to make sure other ArcBridgeService observers are notified.
