@@ -118,9 +118,13 @@ class TaskManagerBrowserTest : public ExtensionBrowserTest {
     command_line->AppendSwitch(switches::kDisableDeviceDiscoveryNotifications);
   }
 
-  void TearDownOnMainThread() override { model_.reset(); }
+  void TearDownOnMainThread() override {
+    model_.reset();
+    ExtensionBrowserTest::TearDownOnMainThread();
+  }
 
   void SetUpOnMainThread() override {
+    ExtensionBrowserTest::SetUpOnMainThread();
     host_resolver()->AddRule("*", "127.0.0.1");
 
     // Add content/test/data so we can use cross_site_iframe_factory.html
@@ -128,8 +132,9 @@ class TaskManagerBrowserTest : public ExtensionBrowserTest {
     ASSERT_TRUE(base::PathService::Get(base::DIR_SOURCE_ROOT, &test_data_dir));
     embedded_test_server()->ServeFilesFromDirectory(
         test_data_dir.AppendASCII("content/test/data/"));
-    ASSERT_TRUE(embedded_test_server()->Start());
+    ASSERT_TRUE(embedded_test_server()->InitializeAndListen());
     content::SetupCrossSiteRedirector(embedded_test_server());
+    embedded_test_server()->StartAcceptingConnections();
   }
 
  private:
