@@ -31,8 +31,7 @@ class NavigationTracingObserver
   void DidStartProvisionalLoadForFrame(
       content::RenderFrameHost* render_frame_host,
       const GURL& validated_url,
-      bool is_error_page,
-      bool is_iframe_srcdoc) override;
+      bool is_error_page) override;
 
   static content::BackgroundTracingManager::TriggerHandle navigation_handle;
 
