@@ -12,8 +12,8 @@
 #include "base/metrics/histogram_macros.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/task_runner_util.h"
-#include "chrome/browser/policy/profile_policy_connector.h"
-#include "chrome/browser/policy/profile_policy_connector_factory.h"
+#include "chrome/browser/chromeos/app_mode/arc/arc_kiosk_app_service.h"
+#include "chrome/browser/chromeos/arc/policy/arc_policy_util.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/app_list/app_list_service.h"
 #include "chrome/browser/ui/app_list/arc/arc_app_list_prefs_factory.h"
@@ -21,10 +21,11 @@
 #include "chrome/browser/ui/app_list/arc/arc_package_syncable_service.h"
 #include "chrome/common/pref_names.h"
 #include "chrome/grit/generated_resources.h"
-#include "components/arc/arc_bridge_service.h"
+#include "components/arc/arc_service_manager.h"
 #include "components/crx_file/id_util.h"
 #include "components/pref_registry/pref_registry_syncable.h"
 #include "components/prefs/scoped_user_pref_update.h"
+#include "components/user_manager/user_manager.h"
 #include "content/public/browser/browser_thread.h"
 #include "ui/base/l10n/l10n_util.h"
 
@@ -142,15 +143,11 @@ void DeleteAppFolderFromFileThread(const base::FilePath& path) {
 }
 
 bool IsArcEnabled() {
-  arc::ArcAuthService* auth_service = arc::ArcAuthService::Get();
-  return auth_service &&
-         auth_service->state() != arc::ArcAuthService::State::NOT_INITIALIZED &&
-         auth_service->IsArcEnabled();
-}
-
-bool IsAccountManaged(Profile* profile) {
-  return policy::ProfilePolicyConnectorFactory::GetForBrowserContext(profile)
-      ->IsManaged();
+  arc::ArcSessionManager* arc_session_manager = arc::ArcSessionManager::Get();
+  return arc_session_manager &&
+         arc_session_manager->state() !=
+             arc::ArcSessionManager::State::NOT_INITIALIZED &&
+         arc_session_manager->IsArcEnabled();
 }
 
 bool GetInt64FromPref(const base::DictionaryValue* dict,
@@ -236,7 +233,6 @@ ArcAppListPrefs::ArcAppListPrefs(
     : profile_(profile),
       prefs_(profile->GetPrefs()),
       app_instance_holder_(app_instance_holder),
-      sync_service_(nullptr),
       binding_(this),
       default_apps_(this, profile),
       weak_ptr_factory_(this) {
@@ -246,35 +242,35 @@ ArcAppListPrefs::ArcAppListPrefs(
   const base::FilePath& base_path = profile->GetPath();
   base_path_ = base_path.AppendASCII(prefs::kArcApps);
 
-  arc::ArcAuthService* auth_service = arc::ArcAuthService::Get();
-  if (!auth_service)
+  arc::ArcSessionManager* arc_session_manager = arc::ArcSessionManager::Get();
+  if (!arc_session_manager)
     return;
 
-  DCHECK(arc::ArcAuthService::IsAllowedForProfile(profile));
+  DCHECK(arc::ArcSessionManager::IsAllowedForProfile(profile));
+
+  const std::vector<std::string> existing_app_ids = GetAppIds();
+  tracked_apps_.insert(existing_app_ids.begin(), existing_app_ids.end());
 
   // Once default apps are ready OnDefaultAppsReady is called.
 }
 
 ArcAppListPrefs::~ArcAppListPrefs() {
-  // A reference to ArcBridgeService is kept here so that it would crash the
-  // tests where ArcBridgeService and ArcAppListPrefs are not destroyed in right
-  // order.
-  arc::ArcBridgeService* bridge_service = arc::ArcBridgeService::Get();
-  if (bridge_service)
-    app_instance_holder_->RemoveObserver(this);
-
-  arc::ArcAuthService* auth_service = arc::ArcAuthService::Get();
-  if (auth_service)
-    auth_service->RemoveObserver(this);
+  arc::ArcSessionManager* arc_session_manager = arc::ArcSessionManager::Get();
+  if (!arc_session_manager)
+    return;
+  DCHECK(arc::ArcServiceManager::Get());
+  arc_session_manager->RemoveObserver(this);
+  app_instance_holder_->RemoveObserver(this);
 }
 
 void ArcAppListPrefs::StartPrefs() {
-  arc::ArcAuthService* auth_service = arc::ArcAuthService::Get();
-  CHECK(auth_service);
+  arc::ArcSessionManager* arc_session_manager = arc::ArcSessionManager::Get();
+  CHECK(arc_session_manager);
 
-  if (auth_service->state() != arc::ArcAuthService::State::NOT_INITIALIZED)
-    OnOptInEnabled(auth_service->IsArcEnabled());
-  auth_service->AddObserver(this);
+  if (arc_session_manager->state() !=
+      arc::ArcSessionManager::State::NOT_INITIALIZED)
+    OnOptInEnabled(arc_session_manager->IsArcEnabled());
+  arc_session_manager->AddObserver(this);
 
   app_instance_holder_->AddObserver(this);
   if (!app_instance_holder_->has_instance())
@@ -366,9 +362,8 @@ void ArcAppListPrefs::SetNotificationsEnabled(const std::string& app_id,
   // In case app is not ready, defer this request.
   if (!ready_apps_.count(app_id)) {
     SetNotificationsEnabledDeferred(prefs_).Put(app_id, enabled);
-    FOR_EACH_OBSERVER(
-        Observer, observer_list_,
-        OnNotificationsEnabledChanged(app_info->package_name, enabled));
+    for (auto& observer : observer_list_)
+      observer.OnNotificationsEnabledChanged(app_info->package_name, enabled);
     return;
   }
 
@@ -554,8 +549,8 @@ void ArcAppListPrefs::DisableAllApps() {
   std::unordered_set<std::string> old_ready_apps;
   old_ready_apps.swap(ready_apps_);
   for (auto& app_id : old_ready_apps) {
-    FOR_EACH_OBSERVER(Observer, observer_list_,
-                      OnAppReadyChanged(app_id, false));
+    for (auto& observer : observer_list_)
+      observer.OnAppReadyChanged(app_id, false);
   }
 }
 
@@ -571,11 +566,12 @@ void ArcAppListPrefs::NotifyRegisteredApps() {
       NOTREACHED();
       continue;
     }
+
     // Default apps are reported earlier.
-    if (default_apps_.HasApp(app_id))
-      continue;
-    FOR_EACH_OBSERVER(Observer, observer_list_,
-                      OnAppRegistered(app_id, *app_info));
+    if (tracked_apps_.insert(app_id).second) {
+      for (auto& observer : observer_list_)
+        observer.OnAppRegistered(app_id, *app_info);
+    }
   }
 
   apps_restored_ = true;
@@ -589,8 +585,8 @@ void ArcAppListPrefs::RemoveAllApps() {
     } else {
       if (ready_apps_.count(app_id)) {
         ready_apps_.erase(app_id);
-        FOR_EACH_OBSERVER(Observer, observer_list_,
-                          OnAppReadyChanged(app_id, false));
+        for (auto& observer : observer_list_)
+          observer.OnAppReadyChanged(app_id, false);
       }
     }
   }
@@ -612,7 +608,7 @@ void ArcAppListPrefs::UpdateDefaultAppsHiddenState() {
   // one, we have no option but to ban all pre-installed apps on Android side.
   // Match this requirement and don't show pre-installed apps for managed users
   // in app list.
-  const bool now_hidden = IsAccountManaged(profile_);
+  const bool now_hidden = arc::policy_util::IsAccountManaged(profile_);
   default_apps_.set_hidden(now_hidden);
   if (was_hidden && !default_apps_.is_hidden())
     RegisterDefaultApps();
@@ -669,8 +665,14 @@ void ArcAppListPrefs::OnInstanceReady() {
   arc::mojom::AppInstance* app_instance =
       app_instance_holder_->GetInstanceForMethod("RefreshAppList");
 
+  // Note, sync_service_ may be nullptr in testing.
   sync_service_ = arc::ArcPackageSyncableService::Get(profile_);
-  DCHECK(sync_service_);
+
+  // Kiosk apps should be run only for kiosk sessions.
+  if (user_manager::UserManager::Get()->IsLoggedInAsArcKioskApp()) {
+    kiosk_app_service_ = chromeos::ArcKioskAppService::Get(profile_);
+    DCHECK(kiosk_app_service_);
+  }
 
   // In some tests app_instance may not be set.
   if (!app_instance)
@@ -691,27 +693,24 @@ void ArcAppListPrefs::OnInstanceClosed() {
     sync_service_ = nullptr;
   }
 
+  kiosk_app_service_ = nullptr;
   is_initialized_ = false;
   package_list_initial_refreshed_ = false;
 }
 
-void ArcAppListPrefs::MaybeAddNonLaunchableApp(const std::string& name,
-                                               const std::string& package_name,
-                                               const std::string& activity) {
+void ArcAppListPrefs::MaybeAddNonLaunchableApp(
+    const base::Optional<std::string>& name,
+    const std::string& package_name,
+    const std::string& activity) {
   DCHECK(IsArcEnabled());
   if (IsRegistered(GetAppId(package_name, activity)))
     return;
 
-  AddAppAndShortcut(true /* app_ready */,
-                    name, package_name,
-                    activity,
-                    std::string() /* intent_uri */,
-                    std::string() /* icon_resource_id */,
-                    false /* sticky */,
-                    false /* notifications_enabled */,
-                    false /* shortcut */,
-                    false /* launchable */,
-                    arc::mojom::OrientationLock::NONE);
+  AddAppAndShortcut(true /* app_ready */, name.has_value() ? *name : "",
+                    package_name, activity, std::string() /* intent_uri */,
+                    std::string() /* icon_resource_id */, false /* sticky */,
+                    false /* notifications_enabled */, false /* shortcut */,
+                    false /* launchable */, arc::mojom::OrientationLock::NONE);
 }
 
 void ArcAppListPrefs::AddAppAndShortcut(
@@ -733,14 +732,14 @@ void ArcAppListPrefs::AddAppAndShortcut(
   if (app_id == arc::kPlayStoreAppId)
     updated_name = l10n_util::GetStringUTF8(IDS_ARC_PLAYSTORE_ICON_TITLE_BETA);
 
-  const bool was_registered = IsRegistered(app_id);
-  if (was_registered) {
+  const bool was_tracked = tracked_apps_.count(app_id);
+  if (was_tracked) {
     std::unique_ptr<ArcAppListPrefs::AppInfo> app_old_info = GetApp(app_id);
     DCHECK(app_old_info);
     DCHECK(launchable);
     if (updated_name != app_old_info->name) {
-      FOR_EACH_OBSERVER(Observer, observer_list_,
-                        OnAppNameUpdated(app_id, updated_name));
+      for (auto& observer : observer_list_)
+        observer.OnAppNameUpdated(app_id, updated_name);
     }
   }
 
@@ -770,10 +769,10 @@ void ArcAppListPrefs::AddAppAndShortcut(
   if (was_disabled && app_ready)
     ready_apps_.insert(app_id);
 
-  if (was_registered) {
+  if (was_tracked) {
     if (was_disabled && app_ready) {
-      FOR_EACH_OBSERVER(Observer, observer_list_,
-                        OnAppReadyChanged(app_id, true));
+      for (auto& observer : observer_list_)
+        observer.OnAppReadyChanged(app_id, true);
     }
   } else {
     AppInfo app_info(updated_name, package_name, activity, intent_uri,
@@ -781,9 +780,9 @@ void ArcAppListPrefs::AddAppAndShortcut(
                      sticky, notifications_enabled, true,
                      launchable && arc::ShouldShowInLauncher(app_id), shortcut,
                      launchable, orientation_lock);
-    FOR_EACH_OBSERVER(Observer,
-                      observer_list_,
-                      OnAppRegistered(app_id, app_info));
+    for (auto& observer : observer_list_)
+      observer.OnAppRegistered(app_id, app_info);
+    tracked_apps_.insert(app_id);
   }
 
   if (app_ready) {
@@ -826,7 +825,10 @@ void ArcAppListPrefs::RemoveApp(const std::string& app_id) {
   const bool removed = apps->Remove(app_id, nullptr);
   DCHECK(removed);
 
-  FOR_EACH_OBSERVER(Observer, observer_list_, OnAppRemoved(app_id));
+  DCHECK(tracked_apps_.count(app_id));
+  for (auto& observer : observer_list_)
+    observer.OnAppRemoved(app_id);
+  tracked_apps_.erase(app_id);
 
   // Remove local data on file system.
   content::BrowserThread::GetBlockingPool()->PostTask(
@@ -853,6 +855,7 @@ void ArcAppListPrefs::AddOrUpdatePackagePrefs(
   package_dict->SetString(kLastBackupAndroidId, id_str);
   package_dict->SetString(kLastBackupTime, time_str);
   package_dict->SetBoolean(kSystem, package.system);
+  package_dict->SetBoolean(kUninstalled, false);
 }
 
 void ArcAppListPrefs::RemovePackageFromPrefs(PrefService* prefs,
@@ -873,7 +876,7 @@ void ArcAppListPrefs::RemovePackageFromPrefs(PrefService* prefs,
 }
 
 void ArcAppListPrefs::OnAppListRefreshed(
-    mojo::Array<arc::mojom::AppInfoPtr> apps) {
+    std::vector<arc::mojom::AppInfoPtr> apps) {
   DCHECK(IsArcEnabled());
   std::vector<std::string> old_apps = GetAppIds();
 
@@ -918,13 +921,13 @@ void ArcAppListPrefs::OnAppListRefreshed(
 void ArcAppListPrefs::OnTaskOrientationLockRequested(
     int32_t task_id,
     const arc::mojom::OrientationLock orientation_lock) {
-  FOR_EACH_OBSERVER(Observer, observer_list_,
-                    OnTaskOrientationLockRequested(task_id, orientation_lock));
+  for (auto& observer : observer_list_)
+    observer.OnTaskOrientationLockRequested(task_id, orientation_lock);
 }
 
 void ArcAppListPrefs::AddApp(const arc::mojom::AppInfo& app_info) {
-  if ((app_info.name.get().empty() || app_info.package_name.get().empty() ||
-       app_info.activity.get().empty())) {
+  if ((app_info.name.empty() || app_info.package_name.empty() ||
+       app_info.activity.empty())) {
     VLOG(2) << "App Name, package name, and activity cannot be empty.";
     return;
   }
@@ -947,15 +950,16 @@ void ArcAppListPrefs::OnAppAddedDeprecated(arc::mojom::AppInfoPtr app) {
 }
 
 void ArcAppListPrefs::OnPackageAppListRefreshed(
-    const mojo::String& package_name,
-    mojo::Array<arc::mojom::AppInfoPtr> apps) {
-  if (package_name.get().empty()) {
+    const std::string& package_name,
+    std::vector<arc::mojom::AppInfoPtr> apps) {
+  if (package_name.empty()) {
     VLOG(2) << "Package name cannot be empty.";
     return;
   }
 
   std::unordered_set<std::string> apps_to_remove =
       GetAppsForPackage(package_name);
+  default_apps_.MaybeMarkPackageUninstalled(package_name, false);
   for (const auto& app : apps) {
     apps_to_remove.erase(GetAppId(app->package_name, app->activity));
     AddApp(*app);
@@ -966,7 +970,7 @@ void ArcAppListPrefs::OnPackageAppListRefreshed(
 }
 
 void ArcAppListPrefs::OnInstallShortcut(arc::mojom::ShortcutInfoPtr shortcut) {
-  if ((shortcut->name.get().empty() || shortcut->intent_uri.get().empty())) {
+  if ((shortcut->name.empty() || shortcut->intent_uri.empty())) {
     VLOG(2) << "Shortcut Name, and intent_uri cannot be empty.";
     return;
   }
@@ -1012,20 +1016,21 @@ std::unordered_set<std::string> ArcAppListPrefs::GetAppsForPackage(
   return app_set;
 }
 
-void ArcAppListPrefs::OnPackageRemoved(const mojo::String& package_name) {
+void ArcAppListPrefs::OnPackageRemoved(const std::string& package_name) {
   const std::unordered_set<std::string> apps_to_remove =
       GetAppsForPackage(package_name);
   for (const auto& app_id : apps_to_remove)
     RemoveApp(app_id);
 
   RemovePackageFromPrefs(prefs_, package_name);
-  FOR_EACH_OBSERVER(Observer, observer_list_, OnPackageRemoved(package_name));
+  for (auto& observer : observer_list_)
+    observer.OnPackageRemoved(package_name);
 }
 
-void ArcAppListPrefs::OnAppIcon(const mojo::String& package_name,
-                                const mojo::String& activity,
+void ArcAppListPrefs::OnAppIcon(const std::string& package_name,
+                                const std::string& activity,
                                 arc::mojom::ScaleFactor scale_factor,
-                                mojo::Array<uint8_t> icon_png_data) {
+                                const std::vector<uint8_t>& icon_png_data) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
   DCHECK_NE(0u, icon_png_data.size());
 
@@ -1036,12 +1041,12 @@ void ArcAppListPrefs::OnAppIcon(const mojo::String& package_name,
   }
 
   InstallIcon(app_id, static_cast<ui::ScaleFactor>(scale_factor),
-              icon_png_data.To<std::vector<uint8_t>>());
+              icon_png_data);
 }
 
-void ArcAppListPrefs::OnIcon(const mojo::String& app_id,
+void ArcAppListPrefs::OnIcon(const std::string& app_id,
                              arc::mojom::ScaleFactor scale_factor,
-                             mojo::Array<uint8_t> icon_png_data) {
+                             const std::vector<uint8_t>& icon_png_data) {
   DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
   DCHECK_NE(0u, icon_png_data.size());
 
@@ -1051,28 +1056,35 @@ void ArcAppListPrefs::OnIcon(const mojo::String& app_id,
   }
 
   InstallIcon(app_id, static_cast<ui::ScaleFactor>(scale_factor),
-              icon_png_data.To<std::vector<uint8_t>>());
+              icon_png_data);
 }
 
 void ArcAppListPrefs::OnTaskCreated(int32_t task_id,
-                                    const mojo::String& package_name,
-                                    const mojo::String& activity,
-                                    const mojo::String& name) {
+                                    const std::string& package_name,
+                                    const std::string& activity,
+                                    const base::Optional<std::string>& name,
+                                    const base::Optional<std::string>& intent) {
   MaybeAddNonLaunchableApp(name, package_name, activity);
-  FOR_EACH_OBSERVER(Observer, observer_list_,
-                    OnTaskCreated(task_id, package_name, activity));
+  for (auto& observer : observer_list_) {
+    observer.OnTaskCreated(task_id,
+                           package_name,
+                           activity,
+                           intent.value_or(std::string()));
+  }
 }
 
 void ArcAppListPrefs::OnTaskDestroyed(int32_t task_id) {
-  FOR_EACH_OBSERVER(Observer, observer_list_, OnTaskDestroyed(task_id));
+  for (auto& observer : observer_list_)
+    observer.OnTaskDestroyed(task_id);
 }
 
 void ArcAppListPrefs::OnTaskSetActive(int32_t task_id) {
-  FOR_EACH_OBSERVER(Observer, observer_list_, OnTaskSetActive(task_id));
+  for (auto& observer : observer_list_)
+    observer.OnTaskSetActive(task_id);
 }
 
 void ArcAppListPrefs::OnNotificationsEnabledChanged(
-    const mojo::String& package_name,
+    const std::string& package_name,
     bool enabled) {
   const base::DictionaryValue* apps = prefs_->GetDictionary(prefs::kArcApps);
   for (base::DictionaryValue::Iterator app(*apps); !app.IsAtEnd();
@@ -1091,8 +1103,8 @@ void ArcAppListPrefs::OnNotificationsEnabledChanged(
     base::DictionaryValue* updateing_app_dict = update.Get();
     updateing_app_dict->SetBoolean(kNotificationsEnabled, enabled);
   }
-  FOR_EACH_OBSERVER(Observer, observer_list_,
-                    OnNotificationsEnabledChanged(package_name, enabled));
+  for (auto& observer : observer_list_)
+    observer.OnNotificationsEnabledChanged(package_name, enabled);
 }
 
 void ArcAppListPrefs::MaybeShowPackageInAppLauncher(
@@ -1129,8 +1141,8 @@ void ArcAppListPrefs::OnPackageAdded(
       !sync_service_->IsPackageSyncing(package_info->package_name);
 
   AddOrUpdatePackagePrefs(prefs_, *package_info);
-  FOR_EACH_OBSERVER(Observer, observer_list_,
-                    OnPackageInstalled(*package_info));
+  for (auto& observer : observer_list_)
+    observer.OnPackageInstalled(*package_info);
   if (new_package_in_system)
     MaybeShowPackageInAppLauncher(*package_info);
 }
@@ -1139,11 +1151,12 @@ void ArcAppListPrefs::OnPackageModified(
     arc::mojom::ArcPackageInfoPtr package_info) {
   DCHECK(IsArcEnabled());
   AddOrUpdatePackagePrefs(prefs_, *package_info);
-  FOR_EACH_OBSERVER(Observer, observer_list_, OnPackageModified(*package_info));
+  for (auto& observer : observer_list_)
+    observer.OnPackageModified(*package_info);
 }
 
 void ArcAppListPrefs::OnPackageListRefreshed(
-    mojo::Array<arc::mojom::ArcPackageInfoPtr> packages) {
+    std::vector<arc::mojom::ArcPackageInfoPtr> packages) {
   DCHECK(IsArcEnabled());
 
   const std::vector<std::string> old_packages(GetPackagesFromPrefs());
@@ -1165,7 +1178,8 @@ void ArcAppListPrefs::OnPackageListRefreshed(
     return;
 
   package_list_initial_refreshed_ = true;
-  FOR_EACH_OBSERVER(Observer, observer_list_, OnPackageListInitialRefreshed());
+  for (auto& observer : observer_list_)
+    observer.OnPackageListInitialRefreshed();
 }
 
 std::vector<std::string> ArcAppListPrefs::GetPackagesFromPrefs() const {
@@ -1182,8 +1196,14 @@ std::vector<std::string> ArcAppListPrefs::GetPackagesFromPrefs(
       prefs_->GetDictionary(prefs::kArcPackages);
   for (base::DictionaryValue::Iterator package(*package_prefs);
        !package.IsAtEnd(); package.Advance()) {
+    const base::DictionaryValue* package_info;
+    if (!package.value().GetAsDictionary(&package_info)) {
+      NOTREACHED();
+      continue;
+    }
+
     bool uninstalled = false;
-    package_prefs->GetBoolean(kSystem, &uninstalled);
+    package_info->GetBoolean(kUninstalled, &uninstalled);
     if (installed != !uninstalled)
       continue;
 
@@ -1228,8 +1248,8 @@ void ArcAppListPrefs::OnIconInstalled(const std::string& app_id,
   if (!install_succeed)
     return;
 
-  FOR_EACH_OBSERVER(Observer, observer_list_,
-                    OnAppIconUpdated(app_id, scale_factor));
+  for (auto& observer : observer_list_)
+    observer.OnAppIconUpdated(app_id, scale_factor);
 }
 
 ArcAppListPrefs::AppInfo::AppInfo(const std::string& name,
