@@ -12,12 +12,16 @@
 #include "base/json/json_writer.h"
 #include "base/synchronization/waitable_event.h"
 #include "base/values.h"
+#include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/app_list/arc/arc_app_list_prefs.h"
 #include "chrome/browser/ui/ash/launcher/arc_app_deferred_launcher_controller.h"
+#include "chrome/browser/ui/ash/launcher/arc_app_shelf_id.h"
 #include "chrome/browser/ui/ash/launcher/chrome_launcher_controller.h"
 #include "chromeos/dbus/dbus_thread_manager.h"
 #include "chromeos/dbus/session_manager_client.h"
 #include "components/arc/arc_bridge_service.h"
+#include "components/arc/arc_service_manager.h"
+#include "components/arc/common/intent_helper.mojom.h"
 #include "ui/aura/window.h"
 #include "ui/display/display.h"
 #include "ui/display/screen.h"
@@ -66,15 +70,15 @@ constexpr char kShowTalkbackSettingsIntent[] =
 // happens.
 arc::mojom::AppInstance* GetAppInstance(uint32_t required_version,
                                         const std::string& service_name) {
-  arc::ArcBridgeService* bridge_service = arc::ArcBridgeService::Get();
-  if (!bridge_service) {
+  auto* arc_service_manager = arc::ArcServiceManager::Get();
+  if (!arc_service_manager) {
     VLOG(2) << "Request to " << service_name
             << " when bridge service is not ready.";
     return nullptr;
   }
 
-  return bridge_service->app()->GetInstanceForMethod(service_name.c_str(),
-                                                     required_version);
+  return arc_service_manager->arc_bridge_service()->app()->GetInstanceForMethod(
+      service_name, required_version);
 }
 
 // Helper function which returns the IntentHelperInstance. Create related logs
@@ -82,15 +86,16 @@ arc::mojom::AppInstance* GetAppInstance(uint32_t required_version,
 arc::mojom::IntentHelperInstance* GetIntentHelperInstance(
     uint32_t required_version,
     const std::string& service_name) {
-  arc::ArcBridgeService* bridge_service = arc::ArcBridgeService::Get();
-  if (!bridge_service) {
+  auto* arc_service_manager = arc::ArcServiceManager::Get();
+  if (!arc_service_manager) {
     VLOG(2) << "Request to " << service_name
             << " when bridge service is not ready.";
     return nullptr;
   }
 
-  return bridge_service->intent_helper()->GetInstanceForMethod(
-      service_name.c_str(), required_version);
+  return arc_service_manager->arc_bridge_service()
+      ->intent_helper()
+      ->GetInstanceForMethod(service_name, required_version);
 }
 
 void PrioritizeArcInstanceCallback(bool success) {
@@ -281,18 +286,18 @@ bool LaunchApp(content::BrowserContext* context,
   ArcAppListPrefs* prefs = ArcAppListPrefs::Get(context);
   std::unique_ptr<ArcAppListPrefs::AppInfo> app_info = prefs->GetApp(app_id);
   if (app_info && !app_info->ready) {
-    ArcAuthService* auth_service = ArcAuthService::Get();
-    DCHECK(auth_service);
+    ArcSessionManager* arc_session_manager = ArcSessionManager::Get();
+    DCHECK(arc_session_manager);
 
     bool arc_activated = false;
-    if (!auth_service->IsArcEnabled()) {
+    if (!arc_session_manager->IsArcEnabled()) {
       if (!prefs->IsDefault(app_id)) {
         NOTREACHED();
         return false;
       }
 
-      auth_service->EnableArc();
-      if (!auth_service->IsArcEnabled()) {
+      arc_session_manager->EnableArc();
+      if (!arc_session_manager->IsArcEnabled()) {
         NOTREACHED();
         return false;
       }
@@ -391,6 +396,22 @@ void UninstallPackage(const std::string& package_name) {
   app_instance->UninstallPackage(package_name);
 }
 
+void UninstallArcApp(const std::string& app_id, Profile* profile) {
+  ArcAppListPrefs* arc_prefs = ArcAppListPrefs::Get(profile);
+  DCHECK(arc_prefs);
+  std::unique_ptr<ArcAppListPrefs::AppInfo> app_info =
+      arc_prefs->GetApp(app_id);
+  if (!app_info) {
+    VLOG(2) << "Package being uninstalled does not exist: " << app_id << ".";
+    return;
+  }
+  // For shortcut we just remove the shortcut instead of the package.
+  if (app_info->shortcut)
+    arc_prefs->RemoveApp(app_id);
+  else
+    UninstallPackage(app_info->package_name);
+}
+
 void RemoveCachedIcon(const std::string& icon_resource_id) {
   VLOG(2) << "Removing icon " << icon_resource_id;
 
@@ -431,4 +452,18 @@ bool ShowPackageInfoOnPage(const std::string& package_name,
   return true;
 }
 
+bool IsArcItem(content::BrowserContext* context, const std::string& id) {
+  DCHECK(context);
+
+  // Some unit tests use empty id.
+  if (id.empty())
+    return false;
+
+  const ArcAppListPrefs* const arc_prefs = ArcAppListPrefs::Get(context);
+  if (!arc_prefs)
+    return false;
+
+  return arc_prefs->IsRegistered(ArcAppShelfId::FromString(id).app_id());
+}
+
 }  // namespace arc
