@@ -13,7 +13,6 @@
 #include "base/strings/string_number_conversions.h"
 #include "base/values.h"
 #include "chrome/browser/app_mode/app_mode_utils.h"
-#include "chrome/browser/chromeos/arc/arc_auth_service.h"
 #include "chrome/browser/chromeos/arc/arc_support_host.h"
 #include "chrome/browser/prefs/pref_service_syncable_util.h"
 #include "chrome/browser/ui/app_list/app_list_syncable_service.h"
@@ -29,6 +28,7 @@
 #include "components/sync_preferences/pref_service_syncable.h"
 #include "ui/display/display.h"
 #include "ui/display/screen.h"
+#include "ui/display/types/display_constants.h"
 
 namespace ash {
 namespace launcher {
@@ -237,19 +237,15 @@ class AppTracker {
   }
 
   void MaybeAddApp(const AppLauncherId& app_launcher_id,
-                   const LauncherControllerHelper* helper,
-                   bool check_for_valid_app) {
+                   const LauncherControllerHelper* helper) {
     DCHECK_NE(kPinnedAppsPlaceholder, app_launcher_id.ToString());
-    if (check_for_valid_app &&
-        !helper->IsValidIDForCurrentUser(app_launcher_id.ToString())) {
+    if (!helper->IsValidIDForCurrentUser(app_launcher_id.ToString()))
       return;
-    }
     AddApp(app_launcher_id);
   }
 
   void MaybeAddAppFromPref(const base::DictionaryValue* app_pref,
-                           const LauncherControllerHelper* helper,
-                           bool check_for_valid_app) {
+                           const LauncherControllerHelper* helper) {
     std::string app_id;
     if (!app_pref->GetString(kPinnedAppsPrefAppIDPath, &app_id)) {
       LOG(ERROR) << "Cannot get app id from app pref entry.";
@@ -266,7 +262,7 @@ class AppTracker {
       return;
     }
 
-    MaybeAddApp(AppLauncherId(app_id), helper, check_for_valid_app);
+    MaybeAddApp(AppLauncherId(app_id), helper);
   }
 
   const std::vector<AppLauncherId>& app_list() const { return app_list_; }
@@ -346,7 +342,7 @@ std::unique_ptr<base::DictionaryValue> CreateAppDict(
 
 ShelfAutoHideBehavior GetShelfAutoHideBehaviorPref(PrefService* prefs,
                                                    int64_t display_id) {
-  DCHECK_NE(display_id, display::Display::kInvalidDisplayID);
+  DCHECK_NE(display_id, display::kInvalidDisplayId);
 
   // Don't show the shelf in app mode.
   if (chrome::IsRunningInAppMode())
@@ -361,7 +357,7 @@ ShelfAutoHideBehavior GetShelfAutoHideBehaviorPref(PrefService* prefs,
 void SetShelfAutoHideBehaviorPref(PrefService* prefs,
                                   int64_t display_id,
                                   ShelfAutoHideBehavior behavior) {
-  DCHECK_NE(display_id, display::Display::kInvalidDisplayID);
+  DCHECK_NE(display_id, display::kInvalidDisplayId);
 
   const char* value = AutoHideBehaviorToPref(behavior);
   if (!value)
@@ -376,7 +372,7 @@ void SetShelfAutoHideBehaviorPref(PrefService* prefs,
 }
 
 ShelfAlignment GetShelfAlignmentPref(PrefService* prefs, int64_t display_id) {
-  DCHECK_NE(display_id, display::Display::kInvalidDisplayID);
+  DCHECK_NE(display_id, display::kInvalidDisplayId);
 
   // See comment in |kShelfAlignment| as to why we consider two prefs.
   return AlignmentFromPref(GetPerDisplayPref(
@@ -386,7 +382,7 @@ ShelfAlignment GetShelfAlignmentPref(PrefService* prefs, int64_t display_id) {
 void SetShelfAlignmentPref(PrefService* prefs,
                            int64_t display_id,
                            ShelfAlignment alignment) {
-  DCHECK_NE(display_id, display::Display::kInvalidDisplayID);
+  DCHECK_NE(display_id, display::kInvalidDisplayId);
 
   const char* value = AlignmentToPref(alignment);
   if (!value)
@@ -403,7 +399,6 @@ void SetShelfAlignmentPref(PrefService* prefs,
 // Helper that extracts app list from policy preferences.
 void GetAppsPinnedByPolicy(const PrefService* prefs,
                            const LauncherControllerHelper* helper,
-                           bool check_for_valid_app,
                            AppTracker* apps) {
   DCHECK(apps);
   DCHECK(apps->app_list().empty());
@@ -438,19 +433,17 @@ void GetAppsPinnedByPolicy(const PrefService* prefs,
       for (const auto& activity : activities) {
         const std::string arc_app_id =
             ArcAppListPrefs::GetAppId(arc_package, activity);
-        apps->MaybeAddApp(AppLauncherId(arc_app_id), helper,
-                          check_for_valid_app);
+        apps->MaybeAddApp(AppLauncherId(arc_app_id), helper);
       }
     } else {
-      apps->MaybeAddApp(AppLauncherId(app_id), helper, check_for_valid_app);
+      apps->MaybeAddApp(AppLauncherId(app_id), helper);
     }
   }
 }
 
 std::vector<AppLauncherId> GetPinnedAppsFromPrefsLegacy(
     const PrefService* prefs,
-    const LauncherControllerHelper* helper,
-    bool check_for_valid_app) {
+    const LauncherControllerHelper* helper) {
   // Adding the app list item to the list of items requires that the ID is not
   // a valid and known ID for the extension system. The ID was constructed that
   // way - but just to make sure...
@@ -468,7 +461,7 @@ std::vector<AppLauncherId> GetPinnedAppsFromPrefsLegacy(
       CreateAppDict(AppLauncherId(extension_misc::kChromeAppId)));
 
   AppTracker apps;
-  GetAppsPinnedByPolicy(prefs, helper, check_for_valid_app, &apps);
+  GetAppsPinnedByPolicy(prefs, helper, &apps);
 
   std::string app_id;
   for (size_t i = 0; i < pinned_apps->GetSize(); ++i) {
@@ -481,7 +474,7 @@ std::vector<AppLauncherId> GetPinnedAppsFromPrefsLegacy(
       LOG(ERROR) << "There is no dictionary for app entry.";
       continue;
     }
-    apps.MaybeAddAppFromPref(app_pref, helper, check_for_valid_app);
+    apps.MaybeAddAppFromPref(app_pref, helper);
   }
 
   // If not added yet, the chrome item will be the last item in the list.
@@ -566,24 +559,22 @@ syncer::StringOrdinal GetLastPinPosition(Profile* profile) {
 
 std::vector<AppLauncherId> ImportLegacyPinnedApps(
     const PrefService* prefs,
-    LauncherControllerHelper* helper) {
-  std::vector<AppLauncherId> legacy_pins_all =
-      GetPinnedAppsFromPrefsLegacy(prefs, helper, false);
-  DCHECK(!legacy_pins_all.empty());
+    LauncherControllerHelper* helper,
+    const AppTracker& policy_apps) {
+  std::vector<AppLauncherId> legacy_pins =
+      GetPinnedAppsFromPrefsLegacy(prefs, helper);
+  DCHECK(!legacy_pins.empty());
 
   app_list::AppListSyncableService* app_service =
       app_list::AppListSyncableServiceFactory::GetForProfile(helper->profile());
 
-  std::vector<AppLauncherId> legacy_pins_valid;
   syncer::StringOrdinal last_position =
       syncer::StringOrdinal::CreateInitialOrdinal();
   // Convert to sync item record.
-  for (const auto& app_launcher_id : legacy_pins_all) {
+  for (const auto& app_launcher_id : legacy_pins) {
     DCHECK_NE(kPinnedAppsPlaceholder, app_launcher_id.ToString());
     app_service->SetPinPosition(app_launcher_id.ToString(), last_position);
     last_position = last_position.CreateAfter();
-    if (helper->IsValidIDForCurrentUser(app_launcher_id.ToString()))
-      legacy_pins_valid.push_back(app_launcher_id);
   }
 
   // Now process default apps.
@@ -599,7 +590,7 @@ std::vector<AppLauncherId> ImportLegacyPinnedApps(
     last_position = last_position.CreateAfter();
   }
 
-  return legacy_pins_valid;
+  return legacy_pins;
 }
 
 std::vector<AppLauncherId> GetPinnedAppsFromPrefs(
@@ -613,6 +604,9 @@ std::vector<AppLauncherId> GetPinnedAppsFromPrefs(
 
   std::vector<PinInfo> pin_infos;
 
+  AppTracker policy_apps;
+  GetAppsPinnedByPolicy(prefs, helper, &policy_apps);
+
   // Empty pins indicates that sync based pin model is used for the first
   // time. In normal workflow we have at least Chrome browser pin info.
   bool first_run = true;
@@ -633,23 +627,14 @@ std::vector<AppLauncherId> GetPinnedAppsFromPrefs(
   }
 
   if (first_run) {
-    // Return default apps in case profile is not synced yet.
-    sync_preferences::PrefServiceSyncable* const pref_service_syncable =
-        PrefServiceSyncableFromProfile(helper->profile());
-    if (!pref_service_syncable->IsSyncing())
-      return GetPinnedAppsFromPrefsLegacy(prefs, helper, true);
-
     // We need to import legacy pins model and convert it to sync based
     // model.
-    return ImportLegacyPinnedApps(prefs, helper);
+    return ImportLegacyPinnedApps(prefs, helper, policy_apps);
   }
 
   // Sort pins according their ordinals.
   std::sort(pin_infos.begin(), pin_infos.end(), ComparePinInfo());
 
-  AppTracker policy_apps;
-  GetAppsPinnedByPolicy(prefs, helper, true, &policy_apps);
-
   // Pinned by policy apps appear first, if they were not shown before.
   syncer::StringOrdinal front_position = GetFirstPinPosition(helper->profile());
   std::vector<AppLauncherId>::const_reverse_iterator it;
