@@ -11,7 +11,7 @@
 
 #include "ash/public/cpp/shelf_types.h"
 #include "base/macros.h"
-#include "components/syncable_prefs/pref_service_syncable_observer.h"
+#include "components/sync_preferences/pref_service_syncable_observer.h"
 
 class LauncherControllerHelper;
 class PrefService;
@@ -21,7 +21,7 @@ namespace base {
 class DictionaryValue;
 }
 
-namespace syncable_prefs {
+namespace sync_preferences {
 class PrefServiceSyncable;
 }
 
@@ -51,10 +51,45 @@ extern const char kShelfAlignmentBottom[];
 extern const char kShelfAlignmentLeft[];
 extern const char kShelfAlignmentRight[];
 
+// A unique chrome launcher id used to identify a shelf item. This class is a
+// wrapper for the chrome launcher identifier. |app_launcher_id_| includes the
+// |app_id| and the |launch_id|. The |app_id| is the application id associated
+// with a set of windows. The |launch_id| is an id that can be passed to an app
+// when launched in order to support multiple shelf items per app. This id is
+// used together with the |app_id| to uniquely identify each shelf item that
+// has the same |app_id|. The |app_id| must not be empty.
+class AppLauncherId {
+ public:
+  AppLauncherId(const std::string& app_id, const std::string& launch_id);
+  // Creates an AppLauncherId with an empty |launch_id|.
+  explicit AppLauncherId(const std::string& app_id);
+  // Empty constructor for pre-allocating.
+  AppLauncherId();
+  ~AppLauncherId();
+
+  AppLauncherId(const AppLauncherId& app_launcher_id) = default;
+  AppLauncherId(AppLauncherId&& app_launcher_id) = default;
+  AppLauncherId& operator=(const AppLauncherId& other) = default;
+
+  std::string ToString() const;
+  const std::string& app_id() const { return app_id_; }
+  const std::string& launch_id() const { return launch_id_; }
+
+  bool operator<(const AppLauncherId& other) const;
+
+ private:
+  // The application id associated with a set of windows.
+  std::string app_id_;
+  // An id that can be passed to an app when launched in order to support
+  // multiple shelf items per app.
+  std::string launch_id_;
+};
+
 void RegisterChromeLauncherUserPrefs(
     user_prefs::PrefRegistrySyncable* registry);
 
-base::DictionaryValue* CreateAppDict(const std::string& app_id);
+std::unique_ptr<base::DictionaryValue> CreateAppDict(
+    const AppLauncherId& app_launcher_id);
 
 // Get or set the shelf auto hide behavior preference for a particular display.
 ShelfAutoHideBehavior GetShelfAutoHideBehaviorPref(PrefService* prefs,
@@ -70,25 +105,25 @@ void SetShelfAlignmentPref(PrefService* prefs,
                            ShelfAlignment alignment);
 
 // Get the list of pinned apps from preferences.
-std::vector<std::string> GetPinnedAppsFromPrefs(
+std::vector<AppLauncherId> GetPinnedAppsFromPrefs(
     const PrefService* prefs,
     LauncherControllerHelper* helper);
 
 // Removes information about pin position from sync model for the app.
-void RemovePinPosition(Profile* profile, const std::string& app_id);
+void RemovePinPosition(Profile* profile, const AppLauncherId& app_launcher_id);
 
-// Updates information about pin position in sync model for the app |app_id|.
-// |app_id_before| optionally specifies an app that exists right before the
-// target app. |app_ids_after| optionally specifies sorted by position apps that
-// exist right after the target app.
+// Updates information about pin position in sync model for the app
+// |app_launcher_id|. |app_launcher_id_before| optionally specifies an app that
+// exists right before the target app. |app_launcher_ids_after| optionally
+// specifies sorted by position apps that exist right after the target app.
 void SetPinPosition(Profile* profile,
-                    const std::string& app_id,
-                    const std::string& app_id_before,
-                    const std::vector<std::string>& app_ids_after);
+                    const AppLauncherId& app_launcher_id,
+                    const AppLauncherId& app_launcher_id_before,
+                    const std::vector<AppLauncherId>& app_launcher_ids_after);
 
 // Used to propagate remote preferences to local during the first run.
 class ChromeLauncherPrefsObserver
-    : public syncable_prefs::PrefServiceSyncableObserver {
+    : public sync_preferences::PrefServiceSyncableObserver {
  public:
   // Creates and returns an instance of ChromeLauncherPrefsObserver if the
   // profile prefs do not contain all the necessary local settings for the
@@ -100,13 +135,13 @@ class ChromeLauncherPrefsObserver
 
  private:
   explicit ChromeLauncherPrefsObserver(
-      syncable_prefs::PrefServiceSyncable* prefs);
+      sync_preferences::PrefServiceSyncable* prefs);
 
-  // syncable_prefs::PrefServiceSyncableObserver:
+  // sync_preferences::PrefServiceSyncableObserver:
   void OnIsSyncingChanged() override;
 
   // Profile prefs. Not owned.
-  syncable_prefs::PrefServiceSyncable* prefs_;
+  sync_preferences::PrefServiceSyncable* prefs_;
 
   DISALLOW_COPY_AND_ASSIGN(ChromeLauncherPrefsObserver);
 };
