@@ -9,17 +9,13 @@
 
 #include "ash/public/interfaces/new_window.mojom.h"
 #include "base/macros.h"
-
-class Browser;
+#include "mojo/public/cpp/bindings/associated_binding.h"
 
 class ChromeNewWindowClient : public ash::mojom::NewWindowClient {
  public:
   ChromeNewWindowClient();
   ~ChromeNewWindowClient() override;
 
-  // Returns the active browser that has active browser window, if any.
-  static Browser* GetActiveBrowser();
-
   // Overridden from ash::mojom::NewWindowClient:
   void NewTab() override;
   void NewWindow(bool incognito) override;
@@ -36,6 +32,11 @@ class ChromeNewWindowClient : public ash::mojom::NewWindowClient {
 
   std::unique_ptr<TabRestoreHelper> tab_restore_helper_;
 
+  ash::mojom::NewWindowControllerPtr new_window_controller_;
+
+  // Binds this object to the client interface.
+  mojo::AssociatedBinding<ash::mojom::NewWindowClient> binding_;
+
   DISALLOW_COPY_AND_ASSIGN(ChromeNewWindowClient);
 };
 
