@@ -16,6 +16,10 @@
 class Browser;
 class URLPattern;
 
+namespace content {
+class WebContents;
+}
+
 namespace extensions {
 class Extension;
 }
@@ -48,7 +52,6 @@ class AppShortcutLauncherItemController : public LauncherItemController {
   ash::ShelfMenuModel* CreateApplicationMenu(int event_flags) override;
   bool IsDraggable() override;
   bool CanPin() const override;
-  bool ShouldShowTooltip() override;
   void Close() override;
 
   // Get the refocus url pattern, which can be used to identify this application
@@ -59,10 +62,6 @@ class AppShortcutLauncherItemController : public LauncherItemController {
 
   ChromeLauncherController* controller() { return chrome_launcher_controller_; }
 
-  const std::string& app_id() const { return app_id_; }
-
-  const std::string& launch_id() const { return launch_id_; }
-
  protected:
   AppShortcutLauncherItemController(const std::string& app_id,
                                     const std::string& launch_id,
@@ -105,14 +104,6 @@ class AppShortcutLauncherItemController : public LauncherItemController {
 
   ChromeLauncherController* chrome_launcher_controller_;
 
-  // The application id associated with this app shortcut.
-  const std::string app_id_;
-
-  // An id that can be passed to an app when launched in order to support
-  // multiple shelf items per app. This id is used together with the app_id to
-  // uniquely identify each shelf item that has the same app_id.
-  const std::string launch_id_;
-
   DISALLOW_COPY_AND_ASSIGN(AppShortcutLauncherItemController);
 };
 
