@@ -16,13 +16,10 @@
 #include "ui/wm/core/window_animations.h"
 
 AppWindowLauncherItemController::AppWindowLauncherItemController(
-    Type type,
     const std::string& app_id,
     const std::string& launch_id,
     ChromeLauncherController* controller)
-    : LauncherItemController(type, app_id, launch_id, controller),
-      app_id_(app_id),
-      launch_id_(launch_id),
+    : LauncherItemController(app_id, launch_id, controller),
       observed_windows_(this) {}
 
 AppWindowLauncherItemController::~AppWindowLauncherItemController() {}
@@ -72,10 +69,6 @@ void AppWindowLauncherItemController::SetActiveWindow(aura::Window* window) {
     last_active_window_ = app_window;
 }
 
-bool AppWindowLauncherItemController::IsOpen() const {
-  return !windows_.empty();
-}
-
 bool AppWindowLauncherItemController::IsVisible() const {
   // Return true if any windows are visible.
   for (const auto* window : windows_) {
@@ -126,7 +119,6 @@ AppWindowLauncherItemController::ItemSelected(const ui::Event& event) {
   if (windows_.empty())
     return kNoAction;
 
-  DCHECK_EQ(TYPE_APP, type());
   ui::BaseWindow* window_to_show =
       last_active_window_ ? last_active_window_ : windows_.front();
   // If the event was triggered by a keystroke, we try to advance to the next
@@ -140,25 +132,19 @@ AppWindowLauncherItemController::ItemSelected(const ui::Event& event) {
 }
 
 base::string16 AppWindowLauncherItemController::GetTitle() {
-  return LauncherControllerHelper::GetAppTitle(
-      launcher_controller()->GetProfile(), app_id());
+  return LauncherControllerHelper::GetAppTitle(launcher_controller()->profile(),
+                                               app_id());
 }
 
 bool AppWindowLauncherItemController::IsDraggable() {
-  DCHECK_EQ(TYPE_APP, type());
   return true;
 }
 
 bool AppWindowLauncherItemController::CanPin() const {
-  return GetPinnableForAppID(app_id(), launcher_controller()->GetProfile()) ==
+  return GetPinnableForAppID(app_id(), launcher_controller()->profile()) ==
          AppListControllerDelegate::PIN_EDITABLE;
 }
 
-bool AppWindowLauncherItemController::ShouldShowTooltip() {
-  DCHECK_EQ(TYPE_APP, type());
-  return true;
-}
-
 void AppWindowLauncherItemController::OnWindowPropertyChanged(
     aura::Window* window,
     const void* key,
