@@ -18,7 +18,7 @@ ArcAppDeferredLauncherItemController::ArcAppDeferredLauncherItemController(
     ChromeLauncherController* controller,
     int event_flags,
     const base::WeakPtr<ArcAppDeferredLauncherController>& host)
-    : LauncherItemController(TYPE_APP, arc_app_id, "", controller),
+    : LauncherItemController(arc_app_id, "", controller),
       event_flags_(event_flags),
       host_(host),
       start_time_(base::Time::Now()) {}
@@ -39,7 +39,7 @@ ArcAppDeferredLauncherItemController::ItemSelected(const ui::Event& event) {
 
 base::string16 ArcAppDeferredLauncherItemController::GetTitle() {
   ArcAppListPrefs* arc_prefs =
-      ArcAppListPrefs::Get(launcher_controller()->GetProfile());
+      ArcAppListPrefs::Get(launcher_controller()->profile());
   DCHECK(arc_prefs);
   std::unique_ptr<ArcAppListPrefs::AppInfo> app_info = arc_prefs->GetApp(
       ArcAppWindowLauncherController::GetArcAppIdFromShelfAppId(app_id()));
@@ -64,19 +64,11 @@ bool ArcAppDeferredLauncherItemController::IsDraggable() {
   return false;
 }
 
-bool ArcAppDeferredLauncherItemController::ShouldShowTooltip() {
-  return true;
-}
-
 void ArcAppDeferredLauncherItemController::Close() {
   if (host_)
     host_->Close(app_id());
 }
 
-bool ArcAppDeferredLauncherItemController::IsOpen() const {
-  return true;
-}
-
 bool ArcAppDeferredLauncherItemController::IsVisible() const {
   return true;
 }
