@@ -158,10 +158,12 @@ class ArcAppLauncherBrowserTest : public ExtensionBrowserTest {
 
   void SetUpInProcessBrowserTestFixture() override {
     ExtensionBrowserTest::SetUpInProcessBrowserTestFixture();
-    arc::ArcAuthService::DisableUIForTesting();
+    arc::ArcSessionManager::DisableUIForTesting();
   }
 
-  void SetUpOnMainThread() override { arc::ArcAuthService::Get()->EnableArc(); }
+  void SetUpOnMainThread() override {
+    arc::ArcSessionManager::Get()->EnableArc();
+  }
 
   void InstallTestApps(bool multi_app) {
     app_host()->OnAppListRefreshed(GetTestAppsList(multi_app));
@@ -220,13 +222,13 @@ class ArcAppLauncherBrowserTest : public ExtensionBrowserTest {
   void SendPackageRemoved() { app_host()->OnPackageRemoved(kTestAppPackage); }
 
   void StartInstance() {
-    if (auth_service()->profile() != profile())
-      auth_service()->OnPrimaryUserProfilePrepared(profile());
+    if (arc_session_manager()->profile() != profile())
+      arc_session_manager()->OnPrimaryUserProfilePrepared(profile());
     app_instance_observer()->OnInstanceReady();
   }
 
   void StopInstance() {
-    auth_service()->Shutdown();
+    arc_session_manager()->Shutdown();
     app_instance_observer()->OnInstanceClosed();
   }
 
@@ -234,12 +236,7 @@ class ArcAppLauncherBrowserTest : public ExtensionBrowserTest {
     const ash::ShelfID shelf_id = shelf_delegate()->GetShelfIDForAppID(id);
     if (!shelf_id)
       return nullptr;
-    LauncherItemController* controller =
-        chrome_controller()->GetLauncherItemController(shelf_id);
-    if (!controller)
-      return nullptr;
-    DCHECK_EQ(LauncherItemController::TYPE_APP, controller->type());
-    return controller;
+    return chrome_controller()->GetLauncherItemController(shelf_id);
   }
 
   ArcAppListPrefs* app_prefs() { return ArcAppListPrefs::Get(profile()); }
@@ -255,7 +252,9 @@ class ArcAppLauncherBrowserTest : public ExtensionBrowserTest {
     return app_prefs();
   }
 
-  arc::ArcAuthService* auth_service() { return arc::ArcAuthService::Get(); }
+  arc::ArcSessionManager* arc_session_manager() {
+    return arc::ArcSessionManager::Get();
+  }
 
  private:
   DISALLOW_COPY_AND_ASSIGN(ArcAppLauncherBrowserTest);
@@ -501,6 +500,6 @@ IN_PROC_BROWSER_TEST_F(ArcAppLauncherBrowserTest, ShelfGroup) {
   EXPECT_FALSE(GetAppItemController(shelf_id2));
 
   // Disable Arc, this removes app and as result kills shelf group 3.
-  arc::ArcAuthService::Get()->DisableArc();
+  arc::ArcSessionManager::Get()->DisableArc();
   EXPECT_FALSE(GetAppItemController(shelf_id3));
 }
