@@ -18,7 +18,7 @@
 ArcAppWindowLauncherItemController::ArcAppWindowLauncherItemController(
     const std::string& arc_app_id,
     ChromeLauncherController* controller)
-    : AppWindowLauncherItemController(TYPE_APP, arc_app_id, "", controller) {}
+    : AppWindowLauncherItemController(arc_app_id, "", controller) {}
 
 ArcAppWindowLauncherItemController::~ArcAppWindowLauncherItemController() {}
 
@@ -77,7 +77,8 @@ ArcAppWindowLauncherItemController::GetApplicationList(int event_flags) {
     gfx::Image image;
     aura::Window* window = (*it)->GetNativeWindow();
     items.push_back(new ChromeLauncherAppMenuItemV2App(
-        ((window && !window->title().empty()) ? window->title() : GetTitle()),
+        ((window && !window->GetTitle().empty()) ? window->GetTitle()
+                                                 : GetTitle()),
         &image, app_id(), launcher_controller(), i,
         i == 0 /* has_leading_separator */));
   }
