@@ -63,8 +63,7 @@ bool IsSettingsBrowser(Browser* browser) {
 BrowserShortcutLauncherItemController::BrowserShortcutLauncherItemController(
     ChromeLauncherController* launcher_controller,
     ash::ShelfModel* shelf_model)
-    : LauncherItemController(TYPE_SHORTCUT,
-                             extension_misc::kChromeAppId,
+    : LauncherItemController(extension_misc::kChromeAppId,
                              "",
                              launcher_controller),
       shelf_model_(shelf_model) {}
@@ -130,19 +129,9 @@ void BrowserShortcutLauncherItemController::SetShelfIDForBrowserWindowContents(
           launcher_controller()->GetShelfIDForWebContents(web_contents));
 }
 
-bool BrowserShortcutLauncherItemController::IsOpen() const {
-  const BrowserList* browser_list = BrowserList::GetInstance();
-  for (BrowserList::const_iterator it = browser_list->begin();
-       it != browser_list->end(); ++it) {
-    if (IsBrowserFromActiveUser(*it))
-      return true;
-  }
-  return false;
-}
-
 bool BrowserShortcutLauncherItemController::IsVisible() const {
   Browser* last_browser =
-      chrome::FindTabbedBrowser(launcher_controller()->GetProfile(), true);
+      chrome::FindTabbedBrowser(launcher_controller()->profile(), true);
 
   if (!last_browser) {
     return false;
@@ -159,10 +148,10 @@ void BrowserShortcutLauncherItemController::Launch(ash::LaunchSource source,
 ash::ShelfItemDelegate::PerformedAction
 BrowserShortcutLauncherItemController::Activate(ash::LaunchSource source) {
   Browser* last_browser =
-      chrome::FindTabbedBrowser(launcher_controller()->GetProfile(), true);
+      chrome::FindTabbedBrowser(launcher_controller()->profile(), true);
 
   if (!last_browser) {
-    chrome::NewEmptyWindow(launcher_controller()->GetProfile());
+    chrome::NewEmptyWindow(launcher_controller()->profile());
     return kNewWindowCreated;
   }
 
@@ -219,7 +208,7 @@ BrowserShortcutLauncherItemController::GetApplicationList(int event_flags) {
 ash::ShelfItemDelegate::PerformedAction
 BrowserShortcutLauncherItemController::ItemSelected(const ui::Event& event) {
   if (event.flags() & ui::EF_CONTROL_DOWN) {
-    chrome::NewEmptyWindow(launcher_controller()->GetProfile());
+    chrome::NewEmptyWindow(launcher_controller()->profile());
     return kNewWindowCreated;
   }
 
@@ -249,10 +238,6 @@ bool BrowserShortcutLauncherItemController::CanPin() const {
   return true;
 }
 
-bool BrowserShortcutLauncherItemController::ShouldShowTooltip() {
-  return true;
-}
-
 bool BrowserShortcutLauncherItemController::IsListOfActiveBrowserEmpty() {
   return GetListOfActiveBrowsers().empty();
 }
@@ -294,7 +279,7 @@ BrowserShortcutLauncherItemController::ActivateOrAdvanceToNextBrowser() {
   }
   // If there are no suitable browsers we create a new one.
   if (items.empty()) {
-    chrome::NewEmptyWindow(launcher_controller()->GetProfile());
+    chrome::NewEmptyWindow(launcher_controller()->profile());
     return kNewWindowCreated;
   }
   Browser* browser = chrome::FindBrowserWithWindow(ash::wm::GetActiveWindow());
@@ -317,9 +302,8 @@ BrowserShortcutLauncherItemController::ActivateOrAdvanceToNextBrowser() {
       browser = (++i == items.end()) ? items[0] : *i;
     } else {
       browser =
-          chrome::FindTabbedBrowser(launcher_controller()->GetProfile(), true);
-      if (!browser ||
-          !IsBrowserRepresentedInBrowserList(browser))
+          chrome::FindTabbedBrowser(launcher_controller()->profile(), true);
+      if (!browser || !IsBrowserRepresentedInBrowserList(browser))
         browser = items[0];
     }
   }
