@@ -22,14 +22,12 @@
 #include "chrome/browser/ui/ash/launcher/chrome_launcher_controller.h"
 #include "chrome/browser/ui/ash/launcher/launcher_app_updater.h"
 #include "components/prefs/pref_change_registrar.h"
-#include "components/sync_preferences/pref_service_syncable_observer.h"
 #include "ui/aura/window_observer.h"
 
 class AppSyncUIState;
 class BrowserStatusMonitor;
 class Profile;
 class AppWindowLauncherController;
-class TabContents;
 
 namespace ash {
 class ShelfModel;
@@ -38,18 +36,10 @@ class ChromeLauncherPrefsObserver;
 }
 }
 
-namespace aura {
-class Window;
-}
-
 namespace content {
 class BrowserContext;
 }
 
-namespace extensions {
-class Extension;
-}
-
 class ChromeLauncherControllerUserSwitchObserver;
 
 // Implementation of ChromeLauncherController, used for classic Ash.
@@ -63,8 +53,7 @@ class ChromeLauncherControllerImpl
       private ash::ShelfModelObserver,
       private ash::WindowTreeHostManager::Observer,
       private AppSyncUIStateObserver,
-      private app_list::AppListSyncableService::Observer,
-      private sync_preferences::PrefServiceSyncableObserver {
+      private app_list::AppListSyncableService::Observer {
  public:
   ChromeLauncherControllerImpl(Profile* profile, ash::ShelfModel* model);
   ~ChromeLauncherControllerImpl() override;
@@ -74,6 +63,8 @@ class ChromeLauncherControllerImpl
   ash::ShelfID CreateAppLauncherItem(LauncherItemController* controller,
                                      const std::string& app_id,
                                      ash::ShelfItemStatus status) override;
+  const ash::ShelfItem* GetItem(ash::ShelfID id) const override;
+  void SetItemType(ash::ShelfID id, ash::ShelfItemType type) override;
   void SetItemStatus(ash::ShelfID id, ash::ShelfItemStatus status) override;
   void SetItemController(ash::ShelfID id,
                          LauncherItemController* controller) override;
@@ -92,12 +83,8 @@ class ChromeLauncherControllerImpl
   void ActivateApp(const std::string& app_id,
                    ash::LaunchSource source,
                    int event_flags) override;
-  extensions::LaunchType GetLaunchType(ash::ShelfID id) override;
   void SetLauncherItemImage(ash::ShelfID shelf_id,
                             const gfx::ImageSkia& image) override;
-  bool IsWindowedAppInLauncher(const std::string& app_id) override;
-  void SetLaunchType(ash::ShelfID id,
-                     extensions::LaunchType launch_type) override;
   void UpdateAppState(content::WebContents* contents,
                       AppState app_state) override;
   ash::ShelfID GetShelfIDForWebContents(
@@ -112,7 +99,7 @@ class ChromeLauncherControllerImpl
                                                 int event_flags) override;
   std::vector<content::WebContents*> GetV1ApplicationsFromAppId(
       const std::string& app_id) override;
-  void ActivateShellApp(const std::string& app_id, int index) override;
+  void ActivateShellApp(const std::string& app_id, int window_index) override;
   bool IsWebContentHandledByApplication(content::WebContents* web_contents,
                                         const std::string& app_id) override;
   bool ContentCanBeHandledByGmailApp(
@@ -233,10 +220,6 @@ class ChromeLauncherControllerImpl
                                      int index,
                                      ash::ShelfItemType shelf_item_type);
 
-  // Enumerate all Web contents which match a given shortcut |controller|.
-  std::vector<content::WebContents*> GetV1ApplicationsFromController(
-      LauncherItemController* controller);
-
   // Create ShelfItem for Browser Shortcut.
   void CreateBrowserShortcutLauncherItem();
 
@@ -280,9 +263,6 @@ class ChromeLauncherControllerImpl
   // app_list::AppListSyncableService::Observer:
   void OnSyncModelUpdated() override;
 
-  // sync_preferences::PrefServiceSyncableObserver:
-  void OnIsSyncingChanged() override;
-
   // Unpins shelf item and optionally updates pin prefs when |update_prefs| is
   // set to true.
   void UnpinAndUpdatePrefs(ash::ShelfID id, bool update_prefs);
