@@ -9,14 +9,17 @@
 #include "base/bind.h"
 #include "chrome/browser/extensions/context_menu_matcher.h"
 #include "chrome/browser/extensions/extension_util.h"
+#include "chrome/browser/extensions/launch_util.h"
 #include "chrome/browser/prefs/incognito_mode_prefs.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/ash/launcher/browser_shortcut_launcher_item_controller.h"
 #include "chrome/browser/ui/ash/launcher/chrome_launcher_controller_impl.h"
+#include "chrome/browser/ui/ash/launcher/chrome_launcher_controller_util.h"
 #include "chrome/browser/ui/browser_commands.h"
 #include "chrome/common/extensions/extension_constants.h"
 #include "chrome/grit/generated_resources.h"
 #include "content/public/common/context_menu_params.h"
+#include "extensions/browser/extension_prefs.h"
 #include "ui/base/l10n/l10n_util.h"
 
 namespace {
@@ -39,21 +42,25 @@ ExtensionLauncherContextMenu::~ExtensionLauncherContextMenu() {}
 
 void ExtensionLauncherContextMenu::Init() {
   extension_items_.reset(new extensions::ContextMenuMatcher(
-      controller()->GetProfile(), this, this,
+      controller()->profile(), this, this,
       base::Bind(MenuItemHasLauncherContext)));
-  if (item().type == ash::TYPE_APP_SHORTCUT ||
-      item().type == ash::TYPE_WINDOWED_APP) {
+  if (item().type == ash::TYPE_APP_SHORTCUT || item().type == ash::TYPE_APP) {
     // V1 apps can be started from the menu - but V2 apps should not.
     if (!controller()->IsPlatformApp(item().id)) {
       AddItem(MENU_OPEN_NEW, base::string16());
       AddSeparator(ui::NORMAL_SEPARATOR);
     }
+
     AddPinMenu();
-    if (controller()->IsOpen(item().id))
+
+    if (controller()->IsOpen(item().id) &&
+        !extension_misc::IsImeMenuExtensionId(
+            controller()->GetAppIDForShelfID(item().id))) {
       AddItemWithStringId(MENU_CLOSE, IDS_LAUNCHER_CONTEXT_MENU_CLOSE);
+    }
 
     if (!controller()->IsPlatformApp(item().id) &&
-        item().type != ash::TYPE_WINDOWED_APP) {
+        item().type == ash::TYPE_APP_SHORTCUT) {
       AddSeparator(ui::NORMAL_SEPARATOR);
       if (extensions::util::IsNewBookmarkAppsEnabled()) {
         // With bookmark apps enabled, hosted apps launch in a window by
@@ -76,7 +83,7 @@ void ExtensionLauncherContextMenu::Init() {
     }
   } else if (item().type == ash::TYPE_BROWSER_SHORTCUT) {
     AddItemWithStringId(MENU_NEW_WINDOW, IDS_APP_LIST_NEW_WINDOW);
-    if (!controller()->GetProfile()->IsGuestSession()) {
+    if (!controller()->profile()->IsGuestSession()) {
       AddItemWithStringId(MENU_NEW_INCOGNITO_WINDOW,
                           IDS_APP_LIST_NEW_INCOGNITO_WINDOW);
     }
@@ -89,21 +96,14 @@ void ExtensionLauncherContextMenu::Init() {
   } else if (item().type == ash::TYPE_DIALOG) {
     AddItemWithStringId(MENU_CLOSE, IDS_LAUNCHER_CONTEXT_MENU_CLOSE);
   } else {
-    if (item().type == ash::TYPE_PLATFORM_APP)
-      AddPinMenu();
-    bool show_close_button = controller()->IsOpen(item().id);
-    if (extension_misc::IsImeMenuExtensionId(
+    if (controller()->IsOpen(item().id) &&
+        !extension_misc::IsImeMenuExtensionId(
             controller()->GetAppIDForShelfID(item().id))) {
-      show_close_button = false;
-    }
-
-    if (show_close_button)
       AddItemWithStringId(MENU_CLOSE, IDS_LAUNCHER_CONTEXT_MENU_CLOSE);
+    }
   }
   AddSeparator(ui::NORMAL_SEPARATOR);
-  if (item().type == ash::TYPE_APP_SHORTCUT ||
-      item().type == ash::TYPE_WINDOWED_APP ||
-      item().type == ash::TYPE_PLATFORM_APP) {
+  if (item().type == ash::TYPE_APP_SHORTCUT || item().type == ash::TYPE_APP) {
     const extensions::MenuItem::ExtensionKey app_key(
         controller()->GetAppIDForShelfID(item().id));
     if (!app_key.empty()) {
@@ -124,9 +124,9 @@ bool ExtensionLauncherContextMenu::IsItemForCommandIdDynamic(
 base::string16 ExtensionLauncherContextMenu::GetLabelForCommandId(
     int command_id) const {
   if (command_id == MENU_OPEN_NEW) {
-    if (item().type == ash::TYPE_PLATFORM_APP)
+    if (controller()->IsPlatformApp(item().id))
       return l10n_util::GetStringUTF16(IDS_APP_LIST_CONTEXT_MENU_NEW_WINDOW);
-    switch (controller()->GetLaunchType(item().id)) {
+    switch (GetLaunchType()) {
       case extensions::LAUNCH_TYPE_PINNED:
       case extensions::LAUNCH_TYPE_REGULAR:
         return l10n_util::GetStringUTF16(IDS_APP_LIST_CONTEXT_MENU_NEW_TAB);
@@ -145,17 +145,13 @@ base::string16 ExtensionLauncherContextMenu::GetLabelForCommandId(
 bool ExtensionLauncherContextMenu::IsCommandIdChecked(int command_id) const {
   switch (command_id) {
     case LAUNCH_TYPE_PINNED_TAB:
-      return controller()->GetLaunchType(item().id) ==
-             extensions::LAUNCH_TYPE_PINNED;
+      return GetLaunchType() == extensions::LAUNCH_TYPE_PINNED;
     case LAUNCH_TYPE_REGULAR_TAB:
-      return controller()->GetLaunchType(item().id) ==
-             extensions::LAUNCH_TYPE_REGULAR;
+      return GetLaunchType() == extensions::LAUNCH_TYPE_REGULAR;
     case LAUNCH_TYPE_WINDOW:
-      return controller()->GetLaunchType(item().id) ==
-             extensions::LAUNCH_TYPE_WINDOW;
+      return GetLaunchType() == extensions::LAUNCH_TYPE_WINDOW;
     case LAUNCH_TYPE_FULLSCREEN:
-      return controller()->GetLaunchType(item().id) ==
-             extensions::LAUNCH_TYPE_FULLSCREEN;
+      return GetLaunchType() == extensions::LAUNCH_TYPE_FULLSCREEN;
     default:
       if (command_id < MENU_ITEM_COUNT)
         return LauncherContextMenu::IsCommandIdChecked(command_id);
@@ -169,12 +165,12 @@ bool ExtensionLauncherContextMenu::IsCommandIdEnabled(int command_id) const {
     case MENU_NEW_WINDOW:
       // "Normal" windows are not allowed when incognito is enforced.
       return IncognitoModePrefs::GetAvailability(
-                 controller()->GetProfile()->GetPrefs()) !=
+                 controller()->profile()->GetPrefs()) !=
              IncognitoModePrefs::FORCED;
     case MENU_NEW_INCOGNITO_WINDOW:
       // Incognito windows are not allowed when incognito is disabled.
       return IncognitoModePrefs::GetAvailability(
-                 controller()->GetProfile()->GetPrefs()) !=
+                 controller()->profile()->GetPrefs()) !=
              IncognitoModePrefs::DISABLED;
     default:
       if (command_id < MENU_ITEM_COUNT)
@@ -190,34 +186,31 @@ void ExtensionLauncherContextMenu::ExecuteCommand(int command_id,
     return;
   switch (static_cast<MenuItem>(command_id)) {
     case LAUNCH_TYPE_PINNED_TAB:
-      controller()->SetLaunchType(item().id, extensions::LAUNCH_TYPE_PINNED);
+      SetLaunchType(extensions::LAUNCH_TYPE_PINNED);
       break;
     case LAUNCH_TYPE_REGULAR_TAB:
-      controller()->SetLaunchType(item().id, extensions::LAUNCH_TYPE_REGULAR);
+      SetLaunchType(extensions::LAUNCH_TYPE_REGULAR);
       break;
     case LAUNCH_TYPE_WINDOW: {
       extensions::LaunchType launch_type = extensions::LAUNCH_TYPE_WINDOW;
       // With bookmark apps enabled, hosted apps can only toggle between
       // LAUNCH_WINDOW and LAUNCH_REGULAR.
       if (extensions::util::IsNewBookmarkAppsEnabled()) {
-        launch_type = controller()->GetLaunchType(item().id) ==
-                              extensions::LAUNCH_TYPE_WINDOW
+        launch_type = GetLaunchType() == extensions::LAUNCH_TYPE_WINDOW
                           ? extensions::LAUNCH_TYPE_REGULAR
                           : extensions::LAUNCH_TYPE_WINDOW;
       }
-      controller()->SetLaunchType(item().id, launch_type);
+      SetLaunchType(launch_type);
       break;
     }
     case LAUNCH_TYPE_FULLSCREEN:
-      controller()->SetLaunchType(item().id,
-                                  extensions::LAUNCH_TYPE_FULLSCREEN);
+      SetLaunchType(extensions::LAUNCH_TYPE_FULLSCREEN);
       break;
     case MENU_NEW_WINDOW:
-      chrome::NewEmptyWindow(controller()->GetProfile());
+      chrome::NewEmptyWindow(controller()->profile());
       break;
     case MENU_NEW_INCOGNITO_WINDOW:
-      chrome::NewEmptyWindow(
-          controller()->GetProfile()->GetOffTheRecordProfile());
+      chrome::NewEmptyWindow(controller()->profile()->GetOffTheRecordProfile());
       break;
     default:
       if (extension_items_) {
@@ -226,3 +219,19 @@ void ExtensionLauncherContextMenu::ExecuteCommand(int command_id,
       }
   }
 }
+
+extensions::LaunchType ExtensionLauncherContextMenu::GetLaunchType() const {
+  const extensions::Extension* extension =
+      GetExtensionForAppID(item().app_id, controller()->profile());
+
+  // An extension can be unloaded/updated/unavailable at any time.
+  if (!extension)
+    return extensions::LAUNCH_TYPE_DEFAULT;
+
+  return extensions::GetLaunchType(
+      extensions::ExtensionPrefs::Get(controller()->profile()), extension);
+}
+
+void ExtensionLauncherContextMenu::SetLaunchType(extensions::LaunchType type) {
+  extensions::SetLaunchType(controller()->profile(), item().app_id, type);
+}
