@@ -5,15 +5,18 @@
 #include "chrome/browser/ui/ash/launcher/launcher_context_menu.h"
 
 #include "ash/common/shelf/shelf_item_types.h"
+#include "ash/common/wm_lookup.h"
 #include "ash/common/wm_root_window_controller.h"
 #include "ash/common/wm_shell.h"
 #include "ash/common/wm_window.h"
+#include "ash/shell.h"
 #include "ash/test/ash_test_base.h"
 #include "base/macros.h"
 #include "chrome/app/chrome_command_ids.h"
 #include "chrome/browser/prefs/incognito_mode_prefs.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/app_list/arc/arc_app_test.h"
+#include "chrome/browser/ui/ash/launcher/arc_app_shelf_id.h"
 #include "chrome/browser/ui/ash/launcher/arc_launcher_context_menu.h"
 #include "chrome/browser/ui/ash/launcher/browser_shortcut_launcher_item_controller.h"
 #include "chrome/browser/ui/ash/launcher/chrome_launcher_controller_impl.h"
@@ -24,6 +27,8 @@
 #include "components/exo/shell_surface.h"
 #include "components/prefs/pref_service.h"
 #include "ui/aura/window_event_dispatcher.h"
+#include "ui/display/display.h"
+#include "ui/display/screen.h"
 #include "ui/views/widget/widget.h"
 
 class LauncherContextMenuTest : public ash::test::AshTestBase {
@@ -47,24 +52,26 @@ class LauncherContextMenuTest : public ash::test::AshTestBase {
     ash::test::AshTestBase::TearDown();
   }
 
-  ash::WmShelf* GetWmShelf() {
-    return ash::WmShell::Get()
-        ->GetPrimaryRootWindow()
-        ->GetRootWindowController()
-        ->GetShelf();
+  ash::WmShelf* GetWmShelf(int64_t display_id) {
+    ash::WmRootWindowController* root_window_controller =
+        ash::WmLookup::Get()->GetRootWindowControllerWithDisplayId(display_id);
+    EXPECT_NE(nullptr, root_window_controller);
+    return root_window_controller->GetShelf();
   }
 
   LauncherContextMenu* CreateLauncherContextMenu(
-      ash::ShelfItemType shelf_item_type) {
+      ash::ShelfItemType shelf_item_type,
+      ash::WmShelf* wm_shelf) {
     ash::ShelfItem item;
     item.id = 123;  // dummy id
     item.type = shelf_item_type;
-    return LauncherContextMenu::Create(controller_.get(), &item, GetWmShelf());
+    return LauncherContextMenu::Create(controller_.get(), &item, wm_shelf);
   }
 
-  LauncherContextMenu* CreateLauncherContextMenuForDesktopShell() {
+  LauncherContextMenu* CreateLauncherContextMenuForDesktopShell(
+      ash::WmShelf* wm_shelf) {
     ash::ShelfItem* item = nullptr;
-    return LauncherContextMenu::Create(controller_.get(), item, GetWmShelf());
+    return LauncherContextMenu::Create(controller_.get(), item, wm_shelf);
   }
 
   // Creates app window and set optional Arc application id.
@@ -75,7 +82,7 @@ class LauncherContextMenuTest : public ash::test::AshTestBase {
     widget->Show();
     widget->Activate();
     exo::ShellSurface::SetApplicationId(widget->GetNativeWindow(),
-                                        &window_app_id);
+                                        window_app_id);
     return widget;
   }
 
@@ -97,9 +104,10 @@ class LauncherContextMenuTest : public ash::test::AshTestBase {
 // menu is disabled when Incognito mode is switched off (by a policy).
 TEST_F(LauncherContextMenuTest,
        NewIncognitoWindowMenuIsDisabledWhenIncognitoModeOff) {
+  int64_t primary_id = display::Screen::GetScreen()->GetPrimaryDisplay().id();
   // Initially, "New Incognito window" should be enabled.
-  std::unique_ptr<LauncherContextMenu> menu(
-      CreateLauncherContextMenu(ash::TYPE_BROWSER_SHORTCUT));
+  std::unique_ptr<LauncherContextMenu> menu(CreateLauncherContextMenu(
+      ash::TYPE_BROWSER_SHORTCUT, GetWmShelf(primary_id)));
   ASSERT_TRUE(IsItemPresentInMenu(
       menu.get(), LauncherContextMenu::MENU_NEW_INCOGNITO_WINDOW));
   EXPECT_TRUE(menu->IsCommandIdEnabled(
@@ -108,7 +116,8 @@ TEST_F(LauncherContextMenuTest,
   // Disable Incognito mode.
   IncognitoModePrefs::SetAvailability(profile()->GetPrefs(),
                                       IncognitoModePrefs::DISABLED);
-  menu.reset(CreateLauncherContextMenu(ash::TYPE_BROWSER_SHORTCUT));
+  menu.reset(CreateLauncherContextMenu(ash::TYPE_BROWSER_SHORTCUT,
+                                       GetWmShelf(primary_id)));
   // The item should be disabled.
   ASSERT_TRUE(IsItemPresentInMenu(
       menu.get(), LauncherContextMenu::MENU_NEW_INCOGNITO_WINDOW));
@@ -120,9 +129,10 @@ TEST_F(LauncherContextMenuTest,
 // menu is disabled when Incognito mode is forced (by a policy).
 TEST_F(LauncherContextMenuTest,
        NewWindowMenuIsDisabledWhenIncognitoModeForced) {
+  int64_t primary_id = display::Screen::GetScreen()->GetPrimaryDisplay().id();
   // Initially, "New window" should be enabled.
-  std::unique_ptr<LauncherContextMenu> menu(
-      CreateLauncherContextMenu(ash::TYPE_BROWSER_SHORTCUT));
+  std::unique_ptr<LauncherContextMenu> menu(CreateLauncherContextMenu(
+      ash::TYPE_BROWSER_SHORTCUT, GetWmShelf(primary_id)));
   ASSERT_TRUE(IsItemPresentInMenu(
       menu.get(), LauncherContextMenu::MENU_NEW_WINDOW));
   EXPECT_TRUE(menu->IsCommandIdEnabled(LauncherContextMenu::MENU_NEW_WINDOW));
@@ -130,7 +140,8 @@ TEST_F(LauncherContextMenuTest,
   // Disable Incognito mode.
   IncognitoModePrefs::SetAvailability(profile()->GetPrefs(),
                                       IncognitoModePrefs::FORCED);
-  menu.reset(CreateLauncherContextMenu(ash::TYPE_BROWSER_SHORTCUT));
+  menu.reset(CreateLauncherContextMenu(ash::TYPE_BROWSER_SHORTCUT,
+                                       GetWmShelf(primary_id)));
   ASSERT_TRUE(IsItemPresentInMenu(
       menu.get(), LauncherContextMenu::MENU_NEW_WINDOW));
   EXPECT_FALSE(menu->IsCommandIdEnabled(LauncherContextMenu::MENU_NEW_WINDOW));
@@ -138,8 +149,9 @@ TEST_F(LauncherContextMenuTest,
 
 // Verifies status of contextmenu items for desktop shell.
 TEST_F(LauncherContextMenuTest, DesktopShellLauncherContextMenuItemCheck) {
+  int64_t primary_id = display::Screen::GetScreen()->GetPrimaryDisplay().id();
   std::unique_ptr<LauncherContextMenu> menu(
-      CreateLauncherContextMenuForDesktopShell());
+      CreateLauncherContextMenuForDesktopShell(GetWmShelf(primary_id)));
   EXPECT_FALSE(
       IsItemPresentInMenu(menu.get(), LauncherContextMenu::MENU_OPEN_NEW));
   EXPECT_FALSE(IsItemPresentInMenu(menu.get(), LauncherContextMenu::MENU_PIN));
@@ -162,8 +174,9 @@ TEST_F(LauncherContextMenuTest, DesktopShellLauncherContextMenuItemCheck) {
 // opened.
 TEST_F(LauncherContextMenuTest,
        DesktopShellLauncherContextMenuVerifyCloseItem) {
-  std::unique_ptr<LauncherContextMenu> menu(
-      CreateLauncherContextMenu(ash::TYPE_BROWSER_SHORTCUT));
+  int64_t primary_id = display::Screen::GetScreen()->GetPrimaryDisplay().id();
+  std::unique_ptr<LauncherContextMenu> menu(CreateLauncherContextMenu(
+      ash::TYPE_BROWSER_SHORTCUT, GetWmShelf(primary_id)));
   ASSERT_FALSE(
       IsItemPresentInMenu(menu.get(), LauncherContextMenu::MENU_CLOSE));
 }
@@ -180,7 +193,8 @@ TEST_F(LauncherContextMenuTest, ArcLauncherContextMenuItemCheck) {
 
   ash::ShelfItem item;
   item.id = controller()->GetShelfIDForAppID(app_id);
-  ash::WmShelf* wm_shelf = GetWmShelf();
+  int64_t primary_id = display::Screen::GetScreen()->GetPrimaryDisplay().id();
+  ash::WmShelf* wm_shelf = GetWmShelf(primary_id);
 
   std::unique_ptr<LauncherContextMenu> menu(
       new ArcLauncherContextMenu(controller(), &item, wm_shelf));
@@ -211,7 +225,8 @@ TEST_F(LauncherContextMenuTest, ArcLauncherContextMenuItemCheck) {
   // Arc app is running.
   std::string window_app_id1("org.chromium.arc.1");
   CreateArcWindow(window_app_id1);
-  arc_test().app_instance()->SendTaskCreated(1, arc_test().fake_apps()[0]);
+  arc_test().app_instance()->SendTaskCreated(1, arc_test().fake_apps()[0],
+                                             std::string());
   menu.reset(new ArcLauncherContextMenu(controller(), &item, wm_shelf));
 
   EXPECT_FALSE(
@@ -225,7 +240,8 @@ TEST_F(LauncherContextMenuTest, ArcLauncherContextMenuItemCheck) {
   const std::string app_id2 = ArcAppTest::GetAppId(arc_test().fake_apps()[1]);
   std::string window_app_id2("org.chromium.arc.2");
   CreateArcWindow(window_app_id2);
-  arc_test().app_instance()->SendTaskCreated(2, arc_test().fake_apps()[1]);
+  arc_test().app_instance()->SendTaskCreated(2, arc_test().fake_apps()[1],
+                                             std::string());
   item.id = controller()->GetShelfIDForAppID(app_id2);
   ASSERT_TRUE(item.id);
   menu.reset(new ArcLauncherContextMenu(controller(), &item, wm_shelf));
@@ -235,4 +251,55 @@ TEST_F(LauncherContextMenuTest, ArcLauncherContextMenuItemCheck) {
   EXPECT_FALSE(IsItemPresentInMenu(menu.get(), LauncherContextMenu::MENU_PIN));
   EXPECT_TRUE(IsItemPresentInMenu(menu.get(), LauncherContextMenu::MENU_CLOSE));
   EXPECT_TRUE(menu->IsCommandIdEnabled(LauncherContextMenu::MENU_CLOSE));
+
+  // Shelf group context menu.
+  std::vector<arc::mojom::ShortcutInfo> shortcuts = arc_test().fake_shortcuts();
+  shortcuts[0].intent_uri +=
+      ";S.org.chromium.arc.shelf_group_id=arc_test_shelf_group;end";
+  arc_test().app_instance()->SendInstallShortcuts(shortcuts);
+  const std::string app_id3 =
+      arc::ArcAppShelfId("arc_test_shelf_group",
+                         ArcAppTest::GetAppId(arc_test().fake_apps()[2]))
+          .ToString();
+  std::string window_app_id3("org.chromium.arc.3");
+  CreateArcWindow(window_app_id3);
+  arc_test().app_instance()->SendTaskCreated(3, arc_test().fake_apps()[2],
+                                             shortcuts[0].intent_uri);
+  item.id = controller()->GetShelfIDForAppID(app_id3);
+  ASSERT_TRUE(item.id);
+  menu.reset(new ArcLauncherContextMenu(controller(), &item, wm_shelf));
+
+  EXPECT_FALSE(
+      IsItemPresentInMenu(menu.get(), LauncherContextMenu::MENU_OPEN_NEW));
+  EXPECT_FALSE(IsItemPresentInMenu(menu.get(), LauncherContextMenu::MENU_PIN));
+  EXPECT_TRUE(IsItemPresentInMenu(menu.get(), LauncherContextMenu::MENU_CLOSE));
+  EXPECT_TRUE(menu->IsCommandIdEnabled(LauncherContextMenu::MENU_CLOSE));
+}
+
+// Tests that fullscreen which makes "Autohide shelf" option disappeared on
+// shelf is a per-display setting (crbug.com/496681).
+TEST_F(LauncherContextMenuTest, AutohideShelfOptionOnExternalDisplay) {
+  if (!SupportsMultipleDisplays())
+    return;
+
+  UpdateDisplay("940x550,940x550");
+  int64_t primary_id = display::Screen::GetScreen()->GetPrimaryDisplay().id();
+  int64_t secondary_id = display_manager()->GetSecondaryDisplay().id();
+
+  // Create a normal window on primary display.
+  views::Widget* widget = new views::Widget;
+  views::Widget::InitParams params(views::Widget::InitParams::TYPE_WINDOW);
+  params.context = ash::Shell::GetPrimaryRootWindow();
+  widget->Init(params);
+  widget->Show();
+
+  widget->SetFullscreen(true);
+  std::unique_ptr<LauncherContextMenu> primary_menu(CreateLauncherContextMenu(
+      ash::TYPE_BROWSER_SHORTCUT, GetWmShelf(primary_id)));
+  std::unique_ptr<LauncherContextMenu> secondary_menu(CreateLauncherContextMenu(
+      ash::TYPE_BROWSER_SHORTCUT, GetWmShelf(secondary_id)));
+  EXPECT_FALSE(IsItemPresentInMenu(primary_menu.get(),
+                                   LauncherContextMenu::MENU_AUTO_HIDE));
+  EXPECT_TRUE(IsItemPresentInMenu(secondary_menu.get(),
+                                  LauncherContextMenu::MENU_AUTO_HIDE));
 }
