@@ -10,13 +10,13 @@
 #include "base/compiler_specific.h"
 #include "base/logging.h"
 #include "base/macros.h"
+#include "chrome/browser/chromeos/login/users/fake_chrome_user_manager.h"
 #include "chrome/browser/chromeos/login/users/scoped_user_manager_enabler.h"
 #include "chrome/browser/ui/ash/multi_user/multi_user_context_menu.h"
 #include "chrome/browser/ui/ash/multi_user/multi_user_window_manager.h"
 #include "chrome/browser/ui/ash/multi_user/multi_user_window_manager_chromeos.h"
 #include "chrome/common/chrome_switches.h"
 #include "components/signin/core/account_id/account_id.h"
-#include "components/user_manager/fake_user_manager.h"
 #include "ui/aura/window.h"
 #include "ui/base/models/menu_model.h"
 #include "ui/base/ui_base_types.h"
@@ -29,8 +29,7 @@ class MultiUserContextMenuChromeOSTest : public AshTestBase {
  public:
   MultiUserContextMenuChromeOSTest()
       : multi_user_window_manager_(NULL),
-        fake_user_manager_(new user_manager::FakeUserManager),
-        user_manager_enabler_(fake_user_manager_) {}
+        user_manager_enabler_(new chromeos::FakeChromeUserManager) {}
 
   void SetUp() override;
   void TearDown() override;
@@ -50,7 +49,6 @@ class MultiUserContextMenuChromeOSTest : public AshTestBase {
 
   // The instance of the MultiUserWindowManager.
   chrome::MultiUserWindowManagerChromeOS* multi_user_window_manager_;
-  user_manager::FakeUserManager* fake_user_manager_;  // Not owned.
   chromeos::ScopedUserManagerEnabler user_manager_enabler_;
 
   DISALLOW_COPY_AND_ASSIGN(MultiUserContextMenuChromeOSTest);
