@@ -11,7 +11,7 @@
 #include "ash/shell.h"
 #include "ash/utility/screenshot_controller.h"
 #include "chrome/browser/chrome_notification_types.h"
-#include "chrome/browser/chromeos/note_taking_app_utils.h"
+#include "chrome/browser/chromeos/note_taking_helper.h"
 #include "chrome/browser/chromeos/profiles/profile_helper.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/profiles/profile_manager.h"
@@ -57,14 +57,15 @@ void PaletteDelegateChromeOS::CreateNote() {
   if (!profile_)
     return;
 
-  chromeos::LaunchNoteTakingAppForNewNote(profile_, base::FilePath());
+  chromeos::NoteTakingHelper::Get()->LaunchAppForNewNote(profile_,
+                                                         base::FilePath());
 }
 
 bool PaletteDelegateChromeOS::HasNoteApp() {
   if (!profile_)
     return false;
 
-  return chromeos::IsNoteTakingAppAvailable(profile_);
+  return chromeos::NoteTakingHelper::Get()->IsAppAvailable(profile_);
 }
 
 void PaletteDelegateChromeOS::ActiveUserChanged(const AccountId& account_id) {
