@@ -59,6 +59,7 @@ class SystemTrayClient : public ash::mojom::SystemTrayClient,
   void ShowPublicAccountInfo() override;
   void ShowNetworkConfigure(const std::string& network_id) override;
   void ShowNetworkCreate(const std::string& type) override;
+  void ShowThirdPartyVpnCreate(const std::string& extension_id) override;
   void ShowNetworkSettings(const std::string& network_id) override;
   void ShowProxySettings() override;
   void SignOut() override;
@@ -68,15 +69,12 @@ class SystemTrayClient : public ash::mojom::SystemTrayClient,
   // chromeos::system::SystemClockObserver:
   void OnSystemClockChanged(chromeos::system::SystemClock* clock) override;
 
-  // Connects or reconnects the |system_tray_| interface.
-  void ConnectToSystemTray();
-
-  // Handles errors on the |system_tray_| interface connection.
-  void OnClientConnectionError();
-
   // System tray mojo service in ash.
   ash::mojom::SystemTrayPtr system_tray_;
 
+  // Binds this object to the client interface.
+  mojo::Binding<ash::mojom::SystemTrayClient> binding_;
+
   DISALLOW_COPY_AND_ASSIGN(SystemTrayClient);
 };
 
