@@ -7,6 +7,7 @@
 
 #include <stdint.h>
 
+#include <memory>
 #include <string>
 #include <vector>
 
@@ -42,7 +43,6 @@
 
 namespace ash {
 class SystemTrayNotifier;
-class VPNDelegate;
 }
 
 namespace user_manager {
@@ -70,6 +70,10 @@ class SystemTrayDelegateChromeOS
 
   ~SystemTrayDelegateChromeOS() override;
 
+  // Access a global pointer to the single instance of the
+  // SystemTrayDelegateChromeOS class.
+  static SystemTrayDelegateChromeOS* instance();
+
   void InitializeOnAdapterReady(
       scoped_refptr<device::BluetoothAdapter> adapter);
 
@@ -104,7 +108,6 @@ class SystemTrayDelegateChromeOS
   bool GetBluetoothAvailable() override;
   bool GetBluetoothEnabled() override;
   bool GetBluetoothDiscovering() override;
-  ash::CastConfigDelegate* GetCastConfigDelegate() override;
   ash::NetworkingConfigDelegate* GetNetworkingConfigDelegate() const override;
   bool GetSessionStartTime(base::TimeTicks* session_start_time) override;
   bool GetSessionLengthLimit(base::TimeDelta* session_length_limit) override;
@@ -115,7 +118,6 @@ class SystemTrayDelegateChromeOS
       ash::CustodianInfoTrayObserver* observer) override;
   void RemoveCustodianInfoTrayObserver(
       ash::CustodianInfoTrayObserver* observer) override;
-  ash::VPNDelegate* GetVPNDelegate() const override;
   std::unique_ptr<ash::SystemTrayItem> CreateRotationLockTrayItem(
       ash::SystemTray* tray) override;
 
@@ -125,6 +127,11 @@ class SystemTrayDelegateChromeOS
 
   void UserChangedChildStatus(user_manager::User* user) override;
 
+  // This notifies the system that a flash update is now available, and so the
+  // user should reboot.
+  void SetFlashUpdateAvailable();
+  bool GetFlashUpdateAvailable();
+
  private:
   ash::SystemTrayNotifier* GetSystemTrayNotifier();
 
@@ -237,14 +244,13 @@ class SystemTrayDelegateChromeOS
   std::string enterprise_realm_;
   bool should_run_bluetooth_discovery_ = false;
   bool session_started_ = false;
+  bool flash_update_available_ = false;
 
   scoped_refptr<device::BluetoothAdapter> bluetooth_adapter_;
   std::unique_ptr<device::BluetoothDiscoverySession>
       bluetooth_discovery_session_;
-  std::unique_ptr<ash::CastConfigDelegate> cast_config_delegate_;
   std::unique_ptr<ash::NetworkingConfigDelegate> networking_config_delegate_;
   std::unique_ptr<AccessibilityStatusSubscription> accessibility_subscription_;
-  std::unique_ptr<ash::VPNDelegate> vpn_delegate_;
 
   base::ObserverList<ash::CustodianInfoTrayObserver>
       custodian_info_changed_observers_;
@@ -257,4 +263,5 @@ class SystemTrayDelegateChromeOS
 ash::SystemTrayDelegate* CreateSystemTrayDelegate();
 
 }  // namespace chromeos
+
 #endif  // CHROME_BROWSER_UI_ASH_SYSTEM_TRAY_DELEGATE_CHROMEOS_H_
