@@ -70,7 +70,7 @@ AutofillPopupControllerImpl::AutofillPopupControllerImpl(
                                                    container_view,
                                                    web_contents)),
       view_(NULL),
-      layout_model_(this),
+      layout_model_(this, delegate->IsCreditCardPopup()),
       delegate_(delegate),
       weak_ptr_factory_(this) {
   ClearState();
@@ -288,7 +288,10 @@ void AutofillPopupControllerImpl::AcceptSuggestion(size_t index) {
 }
 
 bool AutofillPopupControllerImpl::IsWarning(size_t index) const {
-  return suggestions_[index].frontend_id == POPUP_ITEM_ID_WARNING_MESSAGE;
+  return suggestions_[index].frontend_id ==
+             POPUP_ITEM_ID_INSECURE_CONTEXT_PAYMENT_DISABLED_MESSAGE ||
+         suggestions_[index].frontend_id ==
+             POPUP_ITEM_ID_HTTP_NOT_SECURE_WARNING_MESSAGE;
 }
 
 gfx::Rect AutofillPopupControllerImpl::popup_bounds() const {
@@ -324,7 +327,7 @@ int AutofillPopupControllerImpl::GetElidedValueWidthForRow(size_t row) {
 
 int AutofillPopupControllerImpl::GetElidedLabelWidthForRow(size_t row) {
   return gfx::GetStringWidth(GetElidedLabelAt(row),
-                             layout_model_.GetLabelFontList());
+                             layout_model_.GetLabelFontListForRow(row));
 }
 #endif
 
@@ -460,7 +463,8 @@ bool AutofillPopupControllerImpl::RemoveSelectedLine() {
 }
 
 bool AutofillPopupControllerImpl::CanAccept(int id) {
-  return id != POPUP_ITEM_ID_SEPARATOR && id != POPUP_ITEM_ID_WARNING_MESSAGE &&
+  return id != POPUP_ITEM_ID_SEPARATOR &&
+         id != POPUP_ITEM_ID_INSECURE_CONTEXT_PAYMENT_DISABLED_MESSAGE &&
          id != POPUP_ITEM_ID_TITLE;
 }
 
@@ -506,8 +510,8 @@ void AutofillPopupControllerImpl::ElideValueAndLabelForRow(
     int available_width) {
   int value_width = gfx::GetStringWidth(
       suggestions_[row].value, layout_model_.GetValueFontListForRow(row));
-  int label_width = gfx::GetStringWidth(suggestions_[row].label,
-                                        layout_model_.GetLabelFontList());
+  int label_width = gfx::GetStringWidth(
+      suggestions_[row].label, layout_model_.GetLabelFontListForRow(row));
   int total_text_length = value_width + label_width;
 
   // The line can have no strings if it represents a UI element, such as
@@ -522,9 +526,9 @@ void AutofillPopupControllerImpl::ElideValueAndLabelForRow(
       value_size, gfx::ELIDE_TAIL);
 
   int label_size = available_width * label_width / total_text_length;
-  elided_labels_[row] =
-      gfx::ElideText(suggestions_[row].label, layout_model_.GetLabelFontList(),
-                     label_size, gfx::ELIDE_TAIL);
+  elided_labels_[row] = gfx::ElideText(
+      suggestions_[row].label, layout_model_.GetLabelFontListForRow(row),
+      label_size, gfx::ELIDE_TAIL);
 }
 #endif
 
