@@ -16,6 +16,7 @@
 #include "content/public/browser/navigation_controller.h"
 #include "content/public/browser/navigation_details.h"
 #include "content/public/browser/navigation_entry.h"
+#include "content/public/browser/render_view_host.h"
 #include "content/public/browser/web_contents.h"
 #include "third_party/WebKit/public/web/WebWindowFeatures.h"
 
@@ -90,25 +91,27 @@ bool PopupBlockerTabHelper::MaybeBlockPopup(
           creator, creator, CONTENT_SETTINGS_TYPE_POPUPS, std::string()) ==
           CONTENT_SETTING_ALLOW) {
     return false;
-  } else {
-    if (blocked_popups_.size() < kMaximumNumberOfPopups) {
-      blocked_popups_.Add(new BlockedRequest(params, window_features));
-      TabSpecificContentSettings::FromWebContents(web_contents())->
-          OnContentBlocked(CONTENT_SETTINGS_TYPE_POPUPS);
-    }
-    return true;
   }
+
+  AddBlockedPopup(params, window_features);
+  return true;
 }
 
 void PopupBlockerTabHelper::AddBlockedPopup(const BlockedWindowParams& params) {
-  chrome::NavigateParams nav_params =
-      params.CreateNavigateParams(web_contents());
+  AddBlockedPopup(params.CreateNavigateParams(web_contents()),
+                  params.features());
+}
 
-  if (blocked_popups_.size() < kMaximumNumberOfPopups) {
-    blocked_popups_.Add(new BlockedRequest(nav_params, params.features()));
-    TabSpecificContentSettings::FromWebContents(web_contents())->
-        OnContentBlocked(CONTENT_SETTINGS_TYPE_POPUPS);
-  }
+void PopupBlockerTabHelper::AddBlockedPopup(
+    const chrome::NavigateParams& params,
+    const WebWindowFeatures& window_features) {
+  if (blocked_popups_.size() >= kMaximumNumberOfPopups)
+    return;
+
+  blocked_popups_.Add(
+      base::MakeUnique<BlockedRequest>(params, window_features));
+  TabSpecificContentSettings::FromWebContents(web_contents())->
+      OnContentBlocked(CONTENT_SETTINGS_TYPE_POPUPS);
 }
 
 void PopupBlockerTabHelper::ShowBlockedPopup(int32_t id) {
@@ -124,7 +127,8 @@ void PopupBlockerTabHelper::ShowBlockedPopup(int32_t id) {
 #endif
   if (popup->params.target_contents) {
     popup->params.target_contents->Send(new ChromeViewMsg_SetWindowFeatures(
-        popup->params.target_contents->GetRoutingID(), popup->window_features));
+        popup->params.target_contents->GetRenderViewHost()->GetRoutingID(),
+        popup->window_features));
   }
   blocked_popups_.Remove(id);
   if (blocked_popups_.IsEmpty())
@@ -138,7 +142,7 @@ size_t PopupBlockerTabHelper::GetBlockedPopupsCount() const {
 PopupBlockerTabHelper::PopupIdMap
     PopupBlockerTabHelper::GetBlockedPopupRequests() {
   PopupIdMap result;
-  for (IDMap<BlockedRequest, IDMapOwnPointer>::const_iterator iter(
+  for (IDMap<std::unique_ptr<BlockedRequest>>::const_iterator iter(
            &blocked_popups_);
        !iter.IsAtEnd();
        iter.Advance()) {
