@@ -264,7 +264,7 @@ void ReloadInternal(Browser* browser,
     return;
 
   if (bypass_cache)
-    new_tab->GetController().ReloadBypassingCache(true);
+    new_tab->GetController().Reload(true, content::ReloadType::BYPASSING_CACHE);
   else
     new_tab->GetController().Reload(true);
 }
@@ -1082,7 +1082,7 @@ void ToggleDevToolsWindow(Browser* browser, DevToolsToggleAction action) {
 }
 
 bool CanOpenTaskManager() {
-#if defined(ENABLE_TASK_MANAGER)
+#if !defined(OS_ANDROID)
   return true;
 #else
   return false;
@@ -1090,7 +1090,7 @@ bool CanOpenTaskManager() {
 }
 
 void OpenTaskManager(Browser* browser) {
-#if defined(ENABLE_TASK_MANAGER)
+#if !defined(OS_ANDROID)
   content::RecordAction(UserMetricsAction("TaskManager"));
   chrome::ShowTaskManager(browser);
 #else
