@@ -25,10 +25,6 @@ class GURL;
 class LoginHandler;
 class Profile;
 
-namespace base {
-struct Feature;
-}
-
 namespace bookmarks {
 class BookmarkBubbleObserver;
 }
@@ -44,7 +40,6 @@ class Extension;
 }
 
 namespace gfx {
-class Image;
 class Point;
 }
 
@@ -53,6 +48,10 @@ class AuthChallengeInfo;
 class URLRequest;
 }
 
+namespace payments {
+class PaymentRequestImpl;
+}
+
 namespace security_state {
 struct SecurityInfo;
 }  // namespace security_state
@@ -67,14 +66,6 @@ class WebDialogDelegate;
 
 namespace chrome {
 
-#if defined(OS_MACOSX)
-// Makes ToolkitViewsDialogsEnabled() available to chrome://flags.
-extern const base::Feature kMacViewsNativeDialogs;
-
-// Makes ToolkitViewsWebUIDialogsEnabled() available to chrome://flags.
-extern const base::Feature kMacViewsWebUIDialogs;
-#endif  // OS_MACOSX
-
 // Shows or hides the Task Manager. |browser| can be NULL when called from Ash.
 // Returns a pointer to the underlying TableModel, which can be ignored, or used
 // for testing.
@@ -123,14 +114,6 @@ content::ColorChooser* ShowColorChooser(content::WebContents* web_contents,
 
 #if defined(OS_MACOSX)
 
-// For Mac, returns true if Chrome should show an equivalent toolkit-views based
-// dialog instead of a native-looking Cocoa dialog.
-bool ToolkitViewsDialogsEnabled();
-
-// For Mac, returns true if Chrome should show an equivalent toolkit-views based
-// dialog instead of a WebUI-styled Cocoa dialog.
-bool ToolkitViewsWebUIDialogsEnabled();
-
 // Shows a Views website settings bubble at the given anchor point.
 void ShowWebsiteSettingsBubbleViewsAtPoint(
     const gfx::Point& anchor_point,
@@ -167,6 +150,8 @@ void ShowBookmarkEditorViews(gfx::NativeWindow parent_window,
                              const BookmarkEditor::EditDetails& details,
                              BookmarkEditor::Configuration configuration);
 
+void ShowPaymentRequestDialog(payments::PaymentRequestImpl* impl);
+
 #if defined(OS_MACOSX)
 
 // This is a class so that it can be friended from ContentSettingBubbleContents,
