@@ -315,16 +315,19 @@ void ChooserContentViewController::OnOptionRemoved(size_t index) {
   // selected, if so, deselect it. Also if the removed item is before the
   // currently selected item, the currently selected item's index needs to
   // be adjusted by one.
-  NSInteger idx = static_cast<NSInteger>(index);
-  NSInteger selected_row = [table_view_ selectedRow];
-  if (selected_row == idx) {
-    [table_view_ deselectRow:idx];
-  } else if (selected_row > idx) {
-    [table_view_
-            selectRowIndexes:[NSIndexSet indexSetWithIndex:selected_row - 1]
-        byExtendingSelection:NO];
+  NSIndexSet* selected_rows = [table_view_ selectedRowIndexes];
+  NSMutableIndexSet* updated_selected_rows = [NSMutableIndexSet indexSet];
+  NSUInteger row = [selected_rows firstIndex];
+  while (row != NSNotFound) {
+    if (row < index)
+      [updated_selected_rows addIndex:row];
+    else if (row > index)
+      [updated_selected_rows addIndex:row - 1];
+    row = [selected_rows indexGreaterThanIndex:row];
   }
 
+  [table_view_ selectRowIndexes:updated_selected_rows byExtendingSelection:NO];
+
   UpdateTableView();
 }
 
@@ -379,14 +382,11 @@ void ChooserContentViewController::OnRefreshStateChanged(bool refreshing) {
 void ChooserContentViewController::UpdateTableView() {
   [table_view_ setEnabled:chooser_controller_->NumOptions() > 0];
   // For NSView-based table views, calling reloadData will deselect the
-  // currently selected row, so |selected_row| stores the currently selected
-  // row in order to select it again.
-  NSInteger selected_row = [table_view_ selectedRow];
+  // currently selected row, so |selected_rows| stores the currently selected
+  // rows in order to select them again.
+  NSIndexSet* selected_rows = [table_view_ selectedRowIndexes];
   [table_view_ reloadData];
-  if (selected_row != -1) {
-    [table_view_ selectRowIndexes:[NSIndexSet indexSetWithIndex:selected_row]
-             byExtendingSelection:NO];
-  }
+  [table_view_ selectRowIndexes:selected_rows byExtendingSelection:NO];
 }
 
 @implementation ChooserContentViewCocoa
@@ -452,13 +452,17 @@ void ChooserContentViewController::UpdateTableView() {
     separator_ = [self createSeparator];
 
     // Help button.
-    helpButton_ =
-        [self createHyperlinkButtonWithText:
-                  l10n_util::GetNSStringF(
-                      IDS_DEVICE_CHOOSER_GET_HELP_LINK_WITH_SCANNING_STATUS,
-                      base::string16())];
-    CGFloat helpButtonWidth = NSWidth([helpButton_ frame]);
-    CGFloat helpButtonHeight = NSHeight([helpButton_ frame]);
+    CGFloat helpButtonWidth = 0.0f;
+    CGFloat helpButtonHeight = 0.0f;
+    if (chooserController_->ShouldShowFootnoteView()) {
+      helpButton_ =
+          [self createHyperlinkButtonWithText:
+                    l10n_util::GetNSStringF(
+                        IDS_DEVICE_CHOOSER_GET_HELP_LINK_WITH_SCANNING_STATUS,
+                        base::string16())];
+      helpButtonWidth = NSWidth([helpButton_ frame]);
+      helpButtonHeight = NSHeight([helpButton_ frame]);
+    }
 
     // Scanning message.
     scanningMessage_ = CreateLabel(
@@ -477,12 +481,17 @@ void ChooserContentViewController::UpdateTableView() {
 
     // ScollView embedding with TableView.
     CGFloat scrollViewWidth = kChooserWidth - 2 * kMarginX;
-    CGFloat scrollViewHeight = kChooserHeight - 2 * kMarginY -
-                               4 * kVerticalPadding - titleHeight -
-                               connectButtonHeight - helpButtonHeight;
+    CGFloat scrollViewHeight =
+        kChooserHeight - 2 * kMarginY -
+        (chooserController_->ShouldShowFootnoteView() ? 4 * kVerticalPadding
+                                                      : 2 * kVerticalPadding) -
+        titleHeight - connectButtonHeight - helpButtonHeight;
     CGFloat scrollViewOriginX = kMarginX;
-    CGFloat scrollViewOriginY = kMarginY + helpButtonHeight +
-                                3 * kVerticalPadding + connectButtonHeight;
+    CGFloat scrollViewOriginY =
+        kMarginY + helpButtonHeight +
+        (chooserController_->ShouldShowFootnoteView() ? 3 * kVerticalPadding
+                                                      : kVerticalPadding) +
+        connectButtonHeight;
     NSRect scrollFrame = NSMakeRect(scrollViewOriginX, scrollViewOriginY,
                                     scrollViewWidth, scrollViewHeight);
     scrollView_.reset([[NSScrollView alloc] initWithFrame:scrollFrame]);
@@ -500,6 +509,10 @@ void ChooserContentViewController::UpdateTableView() {
     // Make the column title invisible.
     [tableView_ setHeaderView:nil];
     [tableView_ setFocusRingType:NSFocusRingTypeNone];
+    [tableView_
+        setAllowsMultipleSelection:chooserController_->AllowMultipleSelection()
+                                       ? YES
+                                       : NO];
 
     // Spinner.
     // Set the spinner in the center of the scroll view.
@@ -552,7 +565,9 @@ void ChooserContentViewController::UpdateTableView() {
                                    kHorizontalPadding - connectButtonWidth -
                                    cancelButtonWidth;
     CGFloat connectButtonOriginY =
-        kMarginY + helpButtonHeight + 2 * kVerticalPadding;
+        kMarginY + helpButtonHeight +
+        (chooserController_->ShouldShowFootnoteView() ? 2 * kVerticalPadding
+                                                      : 0.0f);
     [connectButton_
         setFrameOrigin:NSMakePoint(connectButtonOriginX, connectButtonOriginY)];
     [connectButton_ setEnabled:NO];
@@ -565,50 +580,52 @@ void ChooserContentViewController::UpdateTableView() {
         setFrameOrigin:NSMakePoint(cancelButtonOriginX, cancelButtonOriginY)];
     [self addSubview:cancelButton_];
 
-    // Separator.
-    CGFloat separatorOriginX = 0.0f;
-    separatorOriginY_ = kMarginY + helpButtonHeight + kVerticalPadding;
-    [separator_
-        setFrameOrigin:NSMakePoint(separatorOriginX, separatorOriginY_)];
-    [self addSubview:separator_];
+    if (chooserController_->ShouldShowFootnoteView()) {
+      // Separator.
+      CGFloat separatorOriginX = 0.0f;
+      separatorOriginY_ = kMarginY + helpButtonHeight + kVerticalPadding;
+      [separator_
+          setFrameOrigin:NSMakePoint(separatorOriginX, separatorOriginY_)];
+      [self addSubview:separator_];
 
-    // Help button.
-    CGFloat helpButtonOriginX = kMarginX;
-    CGFloat helpButtonOriginY = (kVerticalPadding + kMarginY) / 2;
-    [helpButton_
-        setFrameOrigin:NSMakePoint(helpButtonOriginX, helpButtonOriginY)];
-    [helpButton_ setTarget:self];
-    [helpButton_ setAction:@selector(onHelpPressed:)];
-    [self addSubview:helpButton_];
+      // Help button.
+      CGFloat helpButtonOriginX = kMarginX;
+      CGFloat helpButtonOriginY = (kVerticalPadding + kMarginY) / 2;
+      [helpButton_
+          setFrameOrigin:NSMakePoint(helpButtonOriginX, helpButtonOriginY)];
+      [helpButton_ setTarget:self];
+      [helpButton_ setAction:@selector(onHelpPressed:)];
+      [self addSubview:helpButton_];
 
-    // Scanning message.
-    CGFloat scanningMessageOriginX =
-        kMarginX + helpButtonWidth - kHorizontalPadding / 2;
-    CGFloat scanningMessageOriginY = helpButtonOriginY;
-    [scanningMessage_ setFrameOrigin:NSMakePoint(scanningMessageOriginX,
-                                                 scanningMessageOriginY)];
-    [self addSubview:scanningMessage_];
-    [scanningMessage_ setHidden:YES];
+      // Scanning message.
+      CGFloat scanningMessageOriginX =
+          kMarginX + helpButtonWidth - kHorizontalPadding / 2;
+      CGFloat scanningMessageOriginY = helpButtonOriginY;
+      [scanningMessage_ setFrameOrigin:NSMakePoint(scanningMessageOriginX,
+                                                   scanningMessageOriginY)];
+      [self addSubview:scanningMessage_];
+      [scanningMessage_ setHidden:YES];
 
-    // Word connector.
-    CGFloat wordConnectorOriginX =
-        kMarginX + helpButtonWidth - kHorizontalPadding / 2;
-    CGFloat wordConnectorOriginY = helpButtonOriginY;
-    [wordConnector_
-        setFrameOrigin:NSMakePoint(wordConnectorOriginX, wordConnectorOriginY)];
-    [self addSubview:wordConnector_];
-    [wordConnector_ setHidden:YES];
+      // Word connector.
+      CGFloat wordConnectorOriginX =
+          kMarginX + helpButtonWidth - kHorizontalPadding / 2;
+      CGFloat wordConnectorOriginY = helpButtonOriginY;
+      [wordConnector_ setFrameOrigin:NSMakePoint(wordConnectorOriginX,
+                                                 wordConnectorOriginY)];
+      [self addSubview:wordConnector_];
+      [wordConnector_ setHidden:YES];
 
-    // Re-scan button.
-    CGFloat reScanButtonOriginX =
-        kMarginX + helpButtonWidth + wordConnectorWidth - kHorizontalPadding;
-    CGFloat reScanButtonOriginY = helpButtonOriginY;
-    [rescanButton_
-        setFrameOrigin:NSMakePoint(reScanButtonOriginX, reScanButtonOriginY)];
-    [rescanButton_ setTarget:self];
-    [rescanButton_ setAction:@selector(onRescan:)];
-    [self addSubview:rescanButton_];
-    [rescanButton_ setHidden:YES];
+      // Re-scan button.
+      CGFloat reScanButtonOriginX =
+          kMarginX + helpButtonWidth + wordConnectorWidth - kHorizontalPadding;
+      CGFloat reScanButtonOriginY = helpButtonOriginY;
+      [rescanButton_
+          setFrameOrigin:NSMakePoint(reScanButtonOriginX, reScanButtonOriginY)];
+      [rescanButton_ setTarget:self];
+      [rescanButton_ setAction:@selector(onRescan:)];
+      [self addSubview:rescanButton_];
+      [rescanButton_ setHidden:YES];
+    }
 
     chooserContentViewController_.reset(new ChooserContentViewController(
         chooserController_.get(), adapterOffHelpButton_.get(),
@@ -794,7 +811,14 @@ void ChooserContentViewController::UpdateTableView() {
 }
 
 - (void)accept {
-  chooserController_->Select([tableView_ selectedRow]);
+  NSIndexSet* selectedRows = [tableView_ selectedRowIndexes];
+  NSUInteger index = [selectedRows firstIndex];
+  std::vector<size_t> indices;
+  while (index != NSNotFound) {
+    indices.push_back(index);
+    index = [selectedRows indexGreaterThanIndex:index];
+  }
+  chooserController_->Select(indices);
 }
 
 - (void)cancel {
@@ -818,15 +842,16 @@ void ChooserContentViewController::UpdateTableView() {
 }
 
 - (void)updateContentRowColor {
-  NSInteger selectedRow = [tableView_ selectedRow];
+  NSIndexSet* selectedRows = [tableView_ selectedRowIndexes];
   NSInteger numOptions =
       base::checked_cast<NSInteger>(chooserController_->NumOptions());
   ui::ResourceBundle& rb = ui::ResourceBundle::GetSharedInstance();
   for (NSInteger rowIndex = 0; rowIndex < numOptions; ++rowIndex) {
+    BOOL isSelected = [selectedRows containsIndex:rowIndex];
     // Update the color of the text.
     [[self tableRowViewText:rowIndex]
-        setTextColor:(rowIndex == selectedRow ? [NSColor whiteColor]
-                                              : [NSColor blackColor])];
+        setTextColor:(isSelected ? [NSColor whiteColor]
+                                 : [NSColor blackColor])];
 
     // Update the color of the image.
     if (chooserController_->ShouldShowIconBeforeText()) {
@@ -834,14 +859,13 @@ void ChooserContentViewController::UpdateTableView() {
         [[self tableRowViewImage:rowIndex]
             setImage:gfx::NSImageFromImageSkia(gfx::CreateVectorIcon(
                          gfx::VectorIconId::BLUETOOTH_CONNECTED,
-                         rowIndex == selectedRow ? SK_ColorWHITE
-                                                 : gfx::kChromeIconGrey))];
+                         isSelected ? SK_ColorWHITE : gfx::kChromeIconGrey))];
       } else {
         int signalStrengthLevel =
             chooserController_->GetSignalStrengthLevel(rowIndex);
         if (signalStrengthLevel != -1) {
           int imageId =
-              rowIndex == selectedRow
+              isSelected
                   ? kSignalStrengthLevelImageSelectedIds[signalStrengthLevel]
                   : kSignalStrengthLevelImageIds[signalStrengthLevel];
           [[self tableRowViewImage:rowIndex]
@@ -853,10 +877,9 @@ void ChooserContentViewController::UpdateTableView() {
     // Update the color of paired status.
     NSTextField* pairedStatusText = [self tableRowViewPairedStatus:rowIndex];
     if (pairedStatusText) {
-      [pairedStatusText
-          setTextColor:(skia::SkColorToCalibratedNSColor(
-                           rowIndex == selectedRow ? gfx::kGoogleGreen300
-                                                   : gfx::kGoogleGreen700))];
+      [pairedStatusText setTextColor:(skia::SkColorToCalibratedNSColor(
+                                         isSelected ? gfx::kGoogleGreen300
+                                                    : gfx::kGoogleGreen700))];
     }
   }
 }
