@@ -8,8 +8,8 @@
 
 #include "base/mac/sdk_forward_declarations.h"
 #include "base/macros.h"
-#import "chrome/browser/ui/cocoa/cocoa_test_helper.h"
 #import "chrome/browser/ui/cocoa/constrained_window/constrained_window_custom_sheet.h"
+#import "chrome/browser/ui/cocoa/test/cocoa_test_helper.h"
 #import "testing/gtest_mac.h"
 
 namespace {
