@@ -9,7 +9,7 @@
 #include "base/command_line.h"
 #include "base/logging.h"
 #include "base/macros.h"
-#include "base/stl_util.h"
+#include "base/memory/ptr_util.h"
 #include "base/strings/sys_string_conversions.h"
 #include "base/strings/utf_string_conversions.h"
 #include "chrome/browser/plugins/plugin_finder.h"
@@ -18,6 +18,7 @@
 #import "chrome/browser/ui/cocoa/l10n_util.h"
 #include "chrome/browser/ui/content_settings/content_setting_bubble_model.h"
 #include "chrome/browser/ui/content_settings/content_setting_media_menu_model.h"
+#import "chrome/browser/ui/cocoa/location_bar/content_setting_decoration.h"
 #include "chrome/grit/generated_resources.h"
 #include "components/content_settings/core/browser/host_content_settings_map.h"
 #include "content/public/browser/plugin_service.h"
@@ -204,6 +205,7 @@ class ContentSettingBubbleWebContentsObserverBridge
 - (id)initWithModel:(ContentSettingBubbleModel*)settingsBubbleModel
         webContents:(content::WebContents*)webContents
        parentWindow:(NSWindow*)parentWindow
+         decoration:(ContentSettingDecoration*)decoration
          anchoredAt:(NSPoint)anchoredAt;
 - (NSString*)getNibPathForModel:(ContentSettingBubbleModel*)model;
 - (NSButton*)hyperlinkButtonWithFrame:(NSRect)frame
@@ -229,16 +231,18 @@ class ContentSettingBubbleWebContentsObserverBridge
 @implementation ContentSettingBubbleController
 
 + (ContentSettingBubbleController*)
-    showForModel:(ContentSettingBubbleModel*)contentSettingBubbleModel
-     webContents:(content::WebContents*)webContents
-    parentWindow:(NSWindow*)parentWindow
-      anchoredAt:(NSPoint)anchor {
+showForModel:(ContentSettingBubbleModel*)contentSettingBubbleModel
+ webContents:(content::WebContents*)webContents
+parentWindow:(NSWindow*)parentWindow
+  decoration:(ContentSettingDecoration*)decoration
+  anchoredAt:(NSPoint)anchor {
   // Autoreleases itself on bubble close.
   return [[ContentSettingBubbleController alloc]
-             initWithModel:contentSettingBubbleModel
-               webContents:webContents
-              parentWindow:parentWindow
-                anchoredAt:anchor];
+      initWithModel:contentSettingBubbleModel
+        webContents:webContents
+       parentWindow:parentWindow
+         decoration:decoration
+         anchoredAt:anchor];
 }
 
 struct ContentTypeToNibPath {
@@ -263,6 +267,7 @@ const ContentTypeToNibPath kNibPaths[] = {
 - (id)initWithModel:(ContentSettingBubbleModel*)contentSettingBubbleModel
         webContents:(content::WebContents*)webContents
        parentWindow:(NSWindow*)parentWindow
+         decoration:(ContentSettingDecoration*)decoration
          anchoredAt:(NSPoint)anchoredAt {
   // This method takes ownership of |contentSettingBubbleModel| in all cases.
   std::unique_ptr<ContentSettingBubbleModel> model(contentSettingBubbleModel);
@@ -278,6 +283,7 @@ const ContentTypeToNibPath kNibPaths[] = {
                               parentWindow:parentWindow
                                 anchoredAt:anchoredAt])) {
     contentSettingBubbleModel_.reset(model.release());
+    decoration_ = decoration;
     [self showWindow:nil];
   }
   return self;
@@ -306,11 +312,6 @@ const ContentTypeToNibPath kNibPaths[] = {
   return nibPath;
 }
 
-- (void)dealloc {
-  base::STLDeleteValues(&mediaMenus_);
-  [super dealloc];
-}
-
 - (void)initializeTitle {
   if (!titleLabel_)
     return;
@@ -608,7 +609,7 @@ const ContentTypeToNibPath kNibPaths[] = {
     menuParts->model.reset(new ContentSettingMediaMenuModel(
         map_entry.first, contentSettingBubbleModel_.get(),
         ContentSettingMediaMenuModel::MenuLabelChangedCallback()));
-    mediaMenus_[button] = menuParts;
+    mediaMenus_[button] = base::WrapUnique(menuParts);
     CGFloat width = BuildPopUpMenuFromModel(
         button, menuParts->model.get(), map_entry.second.selected_device.name,
         map_entry.second.disabled);
@@ -643,8 +644,7 @@ const ContentTypeToNibPath kNibPaths[] = {
   // Resize and reposition the media menus layout.
   CGFloat topMenuY = NSMinY(radioFrame) - kMediaMenuVerticalPadding;
   maxMenuWidth = std::max(maxMenuWidth, kMinMediaMenuButtonWidth);
-  for (const std::pair<NSPopUpButton*, content_setting_bubble::MediaMenuParts*>&
-           map_entry : mediaMenus_) {
+  for (const auto& map_entry : mediaMenus_) {
     NSRect labelFrame = [map_entry.second->label frame];
     // Align the label text with the button text.
     labelFrame.origin.y =
@@ -869,8 +869,7 @@ const ContentTypeToNibPath kNibPaths[] = {
 
 - (IBAction)mediaMenuChanged:(id)sender {
   NSPopUpButton* button = static_cast<NSPopUpButton*>(sender);
-  content_setting_bubble::MediaMenuPartsMap::const_iterator it(
-      mediaMenus_.find(sender));
+  auto it = mediaMenus_.find(sender);
   DCHECK(it != mediaMenus_.end());
   NSInteger index = [[button selectedItem] tag];
 
@@ -884,4 +883,8 @@ const ContentTypeToNibPath kNibPaths[] = {
   return &mediaMenus_;
 }
 
+- (LocationBarDecoration*)decorationForBubble {
+  return decoration_;
+}
+
 @end  // ContentSettingBubbleController
