@@ -196,6 +196,12 @@ const CGFloat kAnimationDuration = 0.2;
   [editor mouseDown:theEvent];
 }
 
+- (void)mouseUp:(NSEvent*)theEvent {
+  const NSRect bounds([self bounds]);
+  AutocompleteTextFieldCell* cell = [self cell];
+  [cell mouseUp:theEvent inRect:bounds ofView:self];
+}
+
 - (void)rightMouseDown:(NSEvent*)event {
   if (observer_)
     observer_->OnMouseDown([event buttonNumber]);
@@ -277,25 +283,24 @@ const CGFloat kAnimationDuration = 0.2;
   [self addToolTipRect:aRect owner:tooltip userData:nil];
 }
 
-- (void)setGrayTextAutocompletion:(NSString*)suggestText
-                        textColor:(NSColor*)suggestColor {
-  [self setNeedsDisplay:YES];
-  suggestText_.reset([suggestText retain]);
-  suggestColor_.reset([suggestColor retain]);
-}
-
-- (NSString*)suggestText {
-  return suggestText_;
-}
-
-- (NSColor*)suggestColor {
-  return suggestColor_;
-}
-
 - (NSPoint)bubblePointForDecoration:(LocationBarDecoration*)decoration {
-  const NSRect frame =
-      [[self cell] frameForDecoration:decoration inFrame:[self bounds]];
-  const NSPoint point = decoration->GetBubblePointInFrame(frame);
+  NSPoint point;
+  if (ui::MaterialDesignController::IsSecondaryUiMaterial()) {
+    // Under MD, dialogs have no arrow and anchor to corner of the decoration
+    // frame, not a specific point within it. See http://crbug.com/566115.
+    BOOL isLeftDecoration;
+    const NSRect frame =
+        [[self cell] backgroundFrameForDecoration:decoration
+                                          inFrame:[self bounds]
+                                 isLeftDecoration:&isLeftDecoration];
+    point.y = NSMaxY(frame);
+    point.x = isLeftDecoration ? NSMinX(frame) : NSMaxX(frame);
+  } else {
+    const NSRect frame =
+        [[self cell] frameForDecoration:decoration inFrame:[self bounds]];
+    point = decoration->GetBubblePointInFrame(frame);
+  }
+
   return [self convertPoint:point toView:nil];
 }
 
@@ -316,7 +321,7 @@ const CGFloat kAnimationDuration = 0.2;
 
   // Reload the decoration tooltips.
   [currentToolTips_ removeAllObjects];
-  [[self cell] updateToolTipsInRect:[self bounds] ofView:self];
+  [[self cell] updateMouseTrackingAndToolTipsInRect:[self bounds] ofView:self];
 }
 
 // NOTE(shess): http://crbug.com/19116 describes a weird bug which
@@ -463,8 +468,8 @@ const CGFloat kAnimationDuration = 0.2;
   BOOL doAccept = [super becomeFirstResponder];
   if (doAccept) {
     [[BrowserWindowController browserWindowControllerForView:self]
-        lockBarVisibilityForOwner:self
-                    withAnimation:YES];
+        lockToolbarVisibilityForOwner:self
+                        withAnimation:YES];
 
     // Tells the observer that we get the focus.
     // But we can't call observer_->OnKillFocus() in resignFirstResponder:,
@@ -481,22 +486,12 @@ const CGFloat kAnimationDuration = 0.2;
   BOOL doResign = [super resignFirstResponder];
   if (doResign) {
     [[BrowserWindowController browserWindowControllerForView:self]
-        releaseBarVisibilityForOwner:self
-                       withAnimation:YES];
+        releaseToolbarVisibilityForOwner:self
+                           withAnimation:YES];
   }
   return doResign;
 }
 
-- (void)drawRect:(NSRect)rect {
-  [super drawRect:rect];
-  autocomplete_text_field::DrawGrayTextAutocompletion(
-      [self attributedStringValue],
-      suggestText_,
-      suggestColor_,
-      self,
-      [[self cell] drawingRectForBounds:[self bounds]]);
-}
-
 // (URLDropTarget protocol)
 - (id<URLDropTargetController>)urlDropController {
   BrowserWindowController* windowController =
@@ -557,42 +552,3 @@ const CGFloat kAnimationDuration = 0.2;
 }
 
 @end
-
-namespace autocomplete_text_field {
-
-void DrawGrayTextAutocompletion(NSAttributedString* mainText,
-                                NSString* suggestText,
-                                NSColor* suggestColor,
-                                NSView* controlView,
-                                NSRect frame) {
-  if (![suggestText length])
-    return;
-
-  base::scoped_nsobject<NSTextFieldCell> cell(
-      [[NSTextFieldCell alloc] initTextCell:@""]);
-  [cell setBordered:NO];
-  [cell setDrawsBackground:NO];
-  [cell setEditable:NO];
-
-  base::scoped_nsobject<NSMutableAttributedString> combinedText(
-      [[NSMutableAttributedString alloc] initWithAttributedString:mainText]);
-  NSRange range = NSMakeRange([combinedText length], 0);
-  [combinedText replaceCharactersInRange:range withString:suggestText];
-  [combinedText addAttribute:NSForegroundColorAttributeName
-                       value:suggestColor
-                       range:NSMakeRange(range.location, [suggestText length])];
-  [cell setAttributedStringValue:combinedText];
-
-  CGFloat mainTextWidth = [mainText size].width;
-  CGFloat suggestWidth = NSWidth(frame) - mainTextWidth;
-  NSRect suggestRect = NSMakeRect(NSMinX(frame) + mainTextWidth,
-                                  NSMinY(frame),
-                                  suggestWidth,
-                                  NSHeight(frame));
-
-  gfx::ScopedNSGraphicsContextSaveGState saveGState;
-  NSRectClip(suggestRect);
-  [cell drawInteriorWithFrame:frame inView:controlView];
-}
-
-}  // namespace autocomplete_text_field
