@@ -6,7 +6,6 @@
 
 #include "base/mac/scoped_nsobject.h"
 #include "base/strings/utf_string_conversions.h"
-#import "chrome/browser/ui/cocoa/cocoa_test_helper.h"
 #import "chrome/browser/ui/cocoa/location_bar/autocomplete_text_field.h"
 #import "chrome/browser/ui/cocoa/location_bar/autocomplete_text_field_cell.h"
 #import "chrome/browser/ui/cocoa/location_bar/keyword_hint_decoration.h"
@@ -15,6 +14,7 @@
 #import "chrome/browser/ui/cocoa/location_bar/security_state_bubble_decoration.h"
 #import "chrome/browser/ui/cocoa/location_bar/selected_keyword_decoration.h"
 #import "chrome/browser/ui/cocoa/location_bar/star_decoration.h"
+#import "chrome/browser/ui/cocoa/test/cocoa_test_helper.h"
 #include "testing/gmock/include/gmock/gmock.h"
 #include "testing/gtest/include/gtest/gtest.h"
 #import "testing/gtest_mac.h"
@@ -264,7 +264,8 @@ TEST_F(AutocompleteTextFieldCellTest, RightDecorationFrame) {
   EXPECT_LT(NSMinX(textFrame), NSMinX(decoration1Rect));
 }
 
-// Verify -[AutocompleteTextFieldCell updateToolTipsInRect:ofView:].
+// Verify -[AutocompleteTextFieldCell
+// updateMouseTrackingAndToolTipsInRect:ofView:].
 TEST_F(AutocompleteTextFieldCellTest, UpdateToolTips) {
   NSString* tooltip = @"tooltip";
 
@@ -292,7 +293,7 @@ TEST_F(AutocompleteTextFieldCellTest, UpdateToolTips) {
   id controlView = [OCMockObject mockForClass:[AutocompleteTextField class]];
   [[controlView expect] addToolTip:tooltip forRect:leftDecorationRect];
 
-  [cell updateToolTipsInRect:bounds ofView:controlView];
+  [cell updateMouseTrackingAndToolTipsInRect:bounds ofView:controlView];
 
   EXPECT_OCMOCK_VERIFY(controlView);
 }
