@@ -8,12 +8,15 @@
 
 #import "base/mac/mac_util.h"
 #include "base/strings/sys_string_conversions.h"
+#include "chrome/browser/ui/cocoa/l10n_util.h"
 #import "chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h"
 #import "chrome/browser/ui/cocoa/location_bar/location_icon_decoration.h"
 #import "chrome/browser/ui/cocoa/themed_window.h"
+#include "chrome/grit/generated_resources.h"
 #include "chrome/grit/theme_resources.h"
 #include "skia/ext/skia_utils_mac.h"
 #import "ui/base/cocoa/nsview_additions.h"
+#include "ui/base/l10n/l10n_util_mac.h"
 #include "ui/base/material_design/material_design_controller.h"
 #include "ui/gfx/animation/tween.h"
 #include "ui/gfx/color_palette.h"
@@ -27,8 +30,8 @@
 
 namespace {
 
-// This is used to increase the right margin of this decoration.
-const CGFloat kRightSideMargin = 1.0;
+// This is used to increase the left padding of this decoration.
+const CGFloat kLeftSidePadding = 5.0;
 
 // Padding between the icon and label.
 CGFloat kIconLabelPadding = 4.0;
@@ -41,6 +44,7 @@ const CGFloat kRetinaBaselineOffset = 0.5;
 
 // The info-bubble point should look like it points to the bottom of the lock
 // icon. Determined with Pixie.app.
+const CGFloat kPageInfoBubblePointXOffset = 5.0;
 const CGFloat kPageInfoBubblePointYOffset = 6.0;
 
 // Minimum acceptable width for the ev bubble.
@@ -56,7 +60,7 @@ const NSTimeInterval kOutAnimationDuration = 250;
 
 // Transformation values at the beginning of the animation.
 const CGFloat kStartScale = 0.25;
-const CGFloat kStartx_offset = -15.0;
+const CGFloat kStartx_offset = 15.0;
 
 }  // namespace
 
@@ -147,7 +151,9 @@ CGFloat SecurityStateBubbleDecoration::GetWidthForSpace(CGFloat width) {
 void SecurityStateBubbleDecoration::DrawInFrame(NSRect frame,
                                                 NSView* control_view) {
   const NSRect decoration_frame = NSInsetRect(frame, 0.0, kBackgroundYInset);
-  CGFloat text_offset = NSMinX(decoration_frame);
+  CGFloat text_left_offset = NSMinX(decoration_frame);
+  CGFloat text_right_offset = NSMaxX(decoration_frame);
+  const BOOL is_rtl = cocoa_l10n_util::ShouldDoExperimentalRTLLayout();
   if (image_) {
     // The image should fade in if we're animating in.
     CGFloat image_alpha =
@@ -158,6 +164,12 @@ void SecurityStateBubbleDecoration::DrawInFrame(NSRect frame,
     NSRect image_rect = decoration_frame;
     image_rect.origin.y +=
         std::floor((NSHeight(decoration_frame) - image_size.height) / 2.0);
+    if (is_rtl) {
+      image_rect.origin.x =
+          NSMaxX(decoration_frame) - image_size.width - kLeftSidePadding;
+    } else {
+      image_rect.origin.x += kLeftSidePadding;
+    }
     image_rect.size = image_size;
     [image_ drawInRect:image_rect
               fromRect:NSZeroRect  // Entire image
@@ -165,7 +177,10 @@ void SecurityStateBubbleDecoration::DrawInFrame(NSRect frame,
               fraction:image_alpha
         respectFlipped:YES
                  hints:nil];
-    text_offset = NSMaxX(image_rect) + kIconLabelPadding;
+    if (is_rtl)
+      text_right_offset = NSMinX(image_rect) - kIconLabelPadding;
+    else
+      text_left_offset = NSMaxX(image_rect) + kIconLabelPadding;
   }
 
   // Set the text color and draw the text.
@@ -194,9 +209,9 @@ void SecurityStateBubbleDecoration::DrawInFrame(NSRect frame,
     NSRect text_rect = frame;
     CGFloat textHeight = [text size].height;
 
-    text_rect.origin.x = text_offset;
+    text_rect.origin.x = text_left_offset;
     text_rect.origin.y = std::round(NSMidY(text_rect) - textHeight / 2.0) - 1;
-    text_rect.size.width = NSMaxX(decoration_frame) - NSMinX(text_rect);
+    text_rect.size.width = text_right_offset - text_left_offset;
     text_rect.size.height = textHeight;
 
     NSAffineTransform* transform = [NSAffineTransform transform];
@@ -211,8 +226,9 @@ void SecurityStateBubbleDecoration::DrawInFrame(NSRect frame,
 
     double x_origin_offset = NSMinX(text_rect) * (1 - scale);
     double y_origin_offset = NSMinY(text_rect) * (1 - scale);
+    double start_x_offset = is_rtl ? -kStartx_offset : kStartx_offset;
     double x_offset =
-        gfx::Tween::DoubleValueBetween(progress, kStartx_offset, 0);
+        gfx::Tween::DoubleValueBetween(progress, start_x_offset, 0);
     double y_offset = NSHeight(text_rect) * (1 - scale) / 2.0;
 
     [transform translateXBy:x_offset + x_origin_offset
@@ -224,40 +240,27 @@ void SecurityStateBubbleDecoration::DrawInFrame(NSRect frame,
     [text drawInRect:text_rect];
 
     // Draw the divider.
-    NSBezierPath* line = [NSBezierPath bezierPath];
-    [line setLineWidth:line_width];
-    [line moveToPoint:NSMakePoint(NSMaxX(decoration_frame) - DividerPadding(),
-                                  NSMinY(decoration_frame))];
-    [line lineToPoint:NSMakePoint(NSMaxX(decoration_frame) - DividerPadding(),
-                                  NSMaxY(decoration_frame))];
+    if (state() == DecorationMouseState::NONE && !active()) {
+      const CGFloat divider_x_position =
+          is_rtl ? NSMinX(decoration_frame) + DividerPadding()
+                 : NSMaxX(decoration_frame) - DividerPadding();
+      NSBezierPath* line = [NSBezierPath bezierPath];
+      [line setLineWidth:line_width];
+      [line moveToPoint:NSMakePoint(divider_x_position,
+                                    NSMinY(decoration_frame))];
+      [line lineToPoint:NSMakePoint(divider_x_position,
+                                    NSMaxY(decoration_frame))];
 
-    NSColor* divider_color = GetDividerColor(in_dark_mode);
-    CGFloat divider_alpha =
-        [divider_color alphaComponent] * GetAnimationProgress();
-    divider_color = [divider_color colorWithAlphaComponent:divider_alpha];
-    [divider_color set];
-    [line stroke];
+      NSColor* divider_color = GetDividerColor(in_dark_mode);
+      CGFloat divider_alpha =
+          [divider_color alphaComponent] * GetAnimationProgress();
+      divider_color = [divider_color colorWithAlphaComponent:divider_alpha];
+      [divider_color set];
+      [line stroke];
+    }
   }
 }
 
-void SecurityStateBubbleDecoration::DrawWithBackgroundInFrame(
-    NSRect background_frame,
-    NSRect frame,
-    NSView* control_view) {
-  NSRect rect = NSInsetRect(background_frame, 0, 3);
-  rect.size.width -= kRightSideMargin;
-
-  CGFloat line_width = [control_view cr_lineWidth];
-  bool in_dark_mode = [[control_view window] inIncognitoModeWithSystemTheme];
-  // Only adjust the path rect by 1/2 the line width if it's going to be
-  // stroked (so that the stroke lines fall along pixel lines).
-  if (!in_dark_mode) {
-    rect = NSInsetRect(rect, line_width / 2., line_width / 2.);
-  }
-
-  DrawInFrame(frame, control_view);
-}
-
 // Pass mouse operations through to location icon.
 bool SecurityStateBubbleDecoration::IsDraggable() {
   return location_icon_->IsDraggable();
@@ -286,10 +289,15 @@ bool SecurityStateBubbleDecoration::AcceptsMousePress() {
 
 NSPoint SecurityStateBubbleDecoration::GetBubblePointInFrame(NSRect frame) {
   NSRect image_rect = GetImageRectInFrame(frame);
-  return NSMakePoint(NSMidX(image_rect),
+  return NSMakePoint(NSMidX(image_rect) + kPageInfoBubblePointXOffset,
                      NSMaxY(image_rect) - kPageInfoBubblePointYOffset);
 }
 
+NSString* SecurityStateBubbleDecoration::GetToolTip() {
+  return [NSString stringWithFormat:@"%@. %@", full_label_.get(),
+                   l10n_util::GetNSStringWithFixup(IDS_TOOLTIP_LOCATION_ICON)];
+}
+
 //////////////////////////////////////////////////////////////////
 // SecurityStateBubbleDecoration::BubbleDecoration:
 
