@@ -81,19 +81,6 @@ const int kOmniboxLargeFontSizeDelta = 9;
 const int kOmniboxNormalFontSizeDelta = 1;
 const int kOmniboxSmallMaterialFontSizeDelta = -1;
 
-// TODO(shess): This is ugly, find a better way.  Using it right now
-// so that I can crib from gtk and still be able to see that I'm using
-// the same values easily.
-NSColor* ColorWithRGBBytes(int rr, int gg, int bb) {
-  DCHECK_LE(rr, 255);
-  DCHECK_LE(bb, 255);
-  DCHECK_LE(gg, 255);
-  return [NSColor colorWithCalibratedRed:static_cast<float>(rr)/255.0
-                                   green:static_cast<float>(gg)/255.0
-                                    blue:static_cast<float>(bb)/255.0
-                                   alpha:1.0];
-}
-
 NSColor* HostTextColor(bool in_dark_mode) {
   return in_dark_mode ? [NSColor whiteColor] : [NSColor blackColor];
 }
@@ -716,19 +703,6 @@ gfx::NativeView OmniboxViewMac::GetRelativeWindowForPopup() const {
   return NULL;
 }
 
-void OmniboxViewMac::SetGrayTextAutocompletion(
-    const base::string16& suggest_text) {
-  if (suggest_text == suggest_text_)
-    return;
-  suggest_text_ = suggest_text;
-  [field_ setGrayTextAutocompletion:base::SysUTF16ToNSString(suggest_text)
-                          textColor:SuggestTextColor()];
-}
-
-base::string16 OmniboxViewMac::GetGrayTextAutocompletion() const {
-  return suggest_text_;
-}
-
 int OmniboxViewMac::GetTextWidth() const {
   // Not used on mac.
   NOTREACHED();
@@ -817,15 +791,6 @@ bool OmniboxViewMac::OnDoCommandBySelector(SEL cmd) {
     }
   }
 
-  if (cmd == @selector(moveRight:)) {
-    // Only commit suggested text if the cursor is all the way to the right and
-    // there is no selection.
-    if (suggest_text_.length() > 0 && IsCaretAtEnd()) {
-      model()->CommitSuggestedText();
-      return true;
-    }
-  }
-
   if (cmd == @selector(scrollPageDown:)) {
     model()->OnUpOrDownKeyPressed(model()->result().size());
     return true;
