@@ -21,6 +21,7 @@
 #include "chrome/browser/command_observer.h"
 #include "chrome/browser/command_updater.h"
 #include "chrome/browser/profiles/profile.h"
+#include "chrome/browser/recovery/recovery_install_global_error_factory.h"
 #include "chrome/browser/search/search.h"
 #include "chrome/browser/sync/sync_global_error_factory.h"
 #include "chrome/browser/themes/theme_service.h"
@@ -273,6 +274,7 @@ class NotificationBridge : public AppMenuIconController::Delegate {
 
     // Start global error services now so we badge the menu correctly.
     SyncGlobalErrorFactory::GetForProfile(profile);
+    RecoveryInstallGlobalErrorFactory::GetForProfile(profile);
   }
   return self;
 }
@@ -1023,24 +1025,25 @@ class NotificationBridge : public AppMenuIconController::Delegate {
     return;
   }
 
-  // TODO(viettrungluu): dropping multiple URLs?
-  if ([urls count] > 1)
-    NOTIMPLEMENTED();
+  for (id urlString in urls) {
+    // Refactor this code.
+    // https://crbug.com/665261.
+    GURL url = url_formatter::FixupURL(base::SysNSStringToUTF8(urlString),
+                                       std::string());
 
-  // Get the first URL and fix it up.
-  GURL url(url_formatter::FixupURL(
-      base::SysNSStringToUTF8([urls objectAtIndex:0]), std::string()));
+    // If the URL isn't valid, don't bother.
+    if (!url.is_valid())
+      continue;
 
-  // Security: Sanitize text to prevent self-XSS.
-  if (url.SchemeIs(url::kJavaScriptScheme)) {
-    browser_->window()->GetLocationBar()->GetOmniboxView()->SetUserText(
-          OmniboxView::StripJavascriptSchemas(base::UTF8ToUTF16(url.spec())));
-    return;
+    // Security: Sanitize text to prevent self-XSS.
+    if (url.SchemeIs(url::kJavaScriptScheme))
+      continue;
+
+    OpenURLParams params(url, Referrer(),
+                         WindowOpenDisposition::NEW_FOREGROUND_TAB,
+                         ui::PAGE_TRANSITION_TYPED, false);
+    browser_->tab_strip_model()->GetActiveWebContents()->OpenURL(params);
   }
-
-  OpenURLParams params(url, Referrer(), WindowOpenDisposition::CURRENT_TAB,
-                       ui::PAGE_TRANSITION_TYPED, false);
-  browser_->tab_strip_model()->GetActiveWebContents()->OpenURL(params);
 }
 
 // (URLDropTargetController protocol)
