@@ -470,12 +470,12 @@ void ManagePasswordsBubbleModel::SetClockForTesting(
 
 void ManagePasswordsBubbleModel::UpdatePendingStateTitle() {
   title_brand_link_range_ = gfx::Range();
-  PasswordTittleType type =
+  PasswordTitleType type =
       state_ == password_manager::ui::PENDING_PASSWORD_UPDATE_STATE
-          ? PasswordTittleType::UPDATE_PASSWORD
+          ? PasswordTitleType::UPDATE_PASSWORD
           : (pending_password_.federation_origin.unique()
-                 ? PasswordTittleType::SAVE_PASSWORD
-                 : PasswordTittleType::SAVE_ACCOUNT);
+                 ? PasswordTitleType::SAVE_PASSWORD
+                 : PasswordTitleType::SAVE_ACCOUNT);
   GetSavePasswordDialogTitleTextAndLinkRange(
       GetWebContents()->GetVisibleURL(), origin_,
       GetSmartLockBrandingState(GetProfile()) !=
