@@ -10,6 +10,7 @@
 
 #include "base/memory/ptr_util.h"
 #include "base/strings/utf_string_conversions.h"
+#include "components/password_manager/core/browser/fake_form_fetcher.h"
 #include "components/password_manager/core/browser/password_form_manager.h"
 #include "components/password_manager/core/browser/password_manager.h"
 #include "components/password_manager/core/browser/stub_form_saver.h"
@@ -42,13 +43,22 @@ std::vector<const autofill::PasswordForm*> GetRawPointers(
 
 class ManagePasswordsStateTest : public testing::Test {
  public:
-  ManagePasswordsStateTest() : password_manager_(&stub_client_) {}
+  ManagePasswordsStateTest() : password_manager_(&stub_client_) {
+    fetcher_.Fetch();
+  }
 
   void SetUp() override {
     test_local_form_.origin = GURL("http://example.com");
     test_local_form_.username_value = base::ASCIIToUTF16("username");
+    test_local_form_.username_element = base::ASCIIToUTF16("username_element");
     test_local_form_.password_value = base::ASCIIToUTF16("12345");
 
+    test_psl_form_.origin = GURL("http://1.example.com");
+    test_psl_form_.username_value = base::ASCIIToUTF16("username_psl");
+    test_psl_form_.username_element = base::ASCIIToUTF16("username_element");
+    test_psl_form_.password_value = base::ASCIIToUTF16("12345");
+    test_psl_form_.is_public_suffix_match = true;
+
     test_submitted_form_ = test_local_form_;
     test_submitted_form_.username_value = base::ASCIIToUTF16("new one");
     test_submitted_form_.password_value = base::ASCIIToUTF16("asdfjkl;");
@@ -60,19 +70,16 @@ class ManagePasswordsStateTest : public testing::Test {
     test_local_federated_form_.signon_realm =
         "federation://example.com/accounts.com";
 
-    test_federated_form_.origin = GURL("https://idp.com");
-    test_federated_form_.username_value = base::ASCIIToUTF16("username");
-
     passwords_data_.set_client(&stub_client_);
   }
 
   autofill::PasswordForm& test_local_form() { return test_local_form_; }
+  autofill::PasswordForm& test_psl_form() { return test_psl_form_; }
   autofill::PasswordForm& test_submitted_form() { return test_submitted_form_; }
   autofill::PasswordForm& test_local_federated_form() {
     return test_local_federated_form_;
   }
-  autofill::PasswordForm& test_federated_form() { return test_federated_form_; }
-  std::vector<std::unique_ptr<autofill::PasswordForm>>& test_stored_forms() {
+  std::vector<const autofill::PasswordForm*>& test_stored_forms() {
     return test_stored_forms_;
   }
   ManagePasswordsState& passwords_data() { return passwords_data_; }
@@ -81,8 +88,8 @@ class ManagePasswordsStateTest : public testing::Test {
   // matches.
   std::unique_ptr<password_manager::PasswordFormManager> CreateFormManager();
 
-  // Returns a PasswordFormManager containing test_federated_form() as a stored
-  // federated credential.
+  // Returns a PasswordFormManager containing test_local_federated_form() as a
+  // stored federated credential.
   std::unique_ptr<password_manager::PasswordFormManager>
   CreateFormManagerWithFederation();
 
@@ -106,13 +113,14 @@ class ManagePasswordsStateTest : public testing::Test {
   password_manager::StubPasswordManagerClient stub_client_;
   password_manager::StubPasswordManagerDriver driver_;
   password_manager::PasswordManager password_manager_;
+  password_manager::FakeFormFetcher fetcher_;
 
   ManagePasswordsState passwords_data_;
   autofill::PasswordForm test_local_form_;
+  autofill::PasswordForm test_psl_form_;
   autofill::PasswordForm test_submitted_form_;
   autofill::PasswordForm test_local_federated_form_;
-  autofill::PasswordForm test_federated_form_;
-  std::vector<std::unique_ptr<autofill::PasswordForm>> test_stored_forms_;
+  std::vector<const autofill::PasswordForm*> test_stored_forms_;
 };
 
 std::unique_ptr<password_manager::PasswordFormManager>
@@ -131,12 +139,11 @@ ManagePasswordsStateTest::CreateFormManagerInternal(bool include_federated) {
       new password_manager::PasswordFormManager(
           &password_manager_, &stub_client_, driver_.AsWeakPtr(),
           test_local_form(),
-          base::WrapUnique(new password_manager::StubFormSaver)));
+          base::WrapUnique(new password_manager::StubFormSaver), &fetcher_));
+  fetcher_.SetNonFederated(test_stored_forms_, 0u);
   if (include_federated) {
-    test_stored_forms_.push_back(
-        base::MakeUnique<autofill::PasswordForm>(test_local_federated_form()));
+    fetcher_.set_federated({&test_local_federated_form()});
   }
-  test_form_manager->OnGetPasswordStoreResults(std::move(test_stored_forms_));
   EXPECT_EQ(include_federated ? 1u : 0u,
             test_form_manager->form_fetcher()->GetFederatedMatches().size());
   if (include_federated) {
@@ -150,8 +157,6 @@ ManagePasswordsStateTest::CreateFormManagerInternal(bool include_federated) {
 void ManagePasswordsStateTest::TestNoisyUpdates() {
   const std::vector<const autofill::PasswordForm*> forms =
       GetRawPointers(passwords_data_.GetCurrentForms());
-  const std::vector<const autofill::PasswordForm*> federated_forms =
-      GetRawPointers(passwords_data_.federation_providers_forms());
   const password_manager::ui::State state = passwords_data_.state();
   const GURL origin = passwords_data_.origin();
 
@@ -165,8 +170,6 @@ void ManagePasswordsStateTest::TestNoisyUpdates() {
   password_manager::PasswordStoreChangeList list(1, change);
   passwords_data().ProcessLoginsChanged(list);
   EXPECT_EQ(forms, GetRawPointers(passwords_data().GetCurrentForms()));
-  EXPECT_EQ(federated_forms,
-            GetRawPointers(passwords_data().federation_providers_forms()));
   EXPECT_EQ(state, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
 
@@ -176,8 +179,6 @@ void ManagePasswordsStateTest::TestNoisyUpdates() {
       password_manager::PasswordStoreChange::UPDATE, form);
   passwords_data().ProcessLoginsChanged(list);
   EXPECT_EQ(forms, GetRawPointers(passwords_data().GetCurrentForms()));
-  EXPECT_EQ(federated_forms,
-            GetRawPointers(passwords_data().federation_providers_forms()));
   EXPECT_EQ(state, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
 
@@ -186,8 +187,6 @@ void ManagePasswordsStateTest::TestNoisyUpdates() {
       password_manager::PasswordStoreChange::REMOVE, form);
   passwords_data().ProcessLoginsChanged(list);
   EXPECT_EQ(forms, GetRawPointers(passwords_data().GetCurrentForms()));
-  EXPECT_EQ(federated_forms,
-            GetRawPointers(passwords_data().federation_providers_forms()));
   EXPECT_EQ(state, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
 }
@@ -195,8 +194,6 @@ void ManagePasswordsStateTest::TestNoisyUpdates() {
 void ManagePasswordsStateTest::TestAllUpdates() {
   const std::vector<const autofill::PasswordForm*> forms =
       GetRawPointers(passwords_data_.GetCurrentForms());
-  const std::vector<const autofill::PasswordForm*> federated_forms =
-      GetRawPointers(passwords_data_.federation_providers_forms());
   const password_manager::ui::State state = passwords_data_.state();
   const GURL origin = passwords_data_.origin();
   EXPECT_NE(GURL::EmptyGURL(), origin);
@@ -211,8 +208,6 @@ void ManagePasswordsStateTest::TestAllUpdates() {
   password_manager::PasswordStoreChangeList list(1, change);
   passwords_data().ProcessLoginsChanged(list);
   EXPECT_THAT(passwords_data().GetCurrentForms(), Contains(Pointee(form)));
-  EXPECT_EQ(federated_forms,
-            GetRawPointers(passwords_data().federation_providers_forms()));
   EXPECT_EQ(state, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
 
@@ -222,8 +217,6 @@ void ManagePasswordsStateTest::TestAllUpdates() {
       password_manager::PasswordStoreChange::UPDATE, form);
   passwords_data().ProcessLoginsChanged(list);
   EXPECT_THAT(passwords_data().GetCurrentForms(), Contains(Pointee(form)));
-  EXPECT_EQ(federated_forms,
-            GetRawPointers(passwords_data().federation_providers_forms()));
   EXPECT_EQ(state, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
 
@@ -232,8 +225,6 @@ void ManagePasswordsStateTest::TestAllUpdates() {
       password_manager::PasswordStoreChange::REMOVE, form);
   passwords_data().ProcessLoginsChanged(list);
   EXPECT_EQ(forms, GetRawPointers(passwords_data().GetCurrentForms()));
-  EXPECT_EQ(federated_forms,
-            GetRawPointers(passwords_data().federation_providers_forms()));
   EXPECT_EQ(state, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
 
@@ -243,8 +234,6 @@ void ManagePasswordsStateTest::TestAllUpdates() {
 void ManagePasswordsStateTest::TestBlacklistedUpdates() {
   const std::vector<const autofill::PasswordForm*> forms =
       GetRawPointers(passwords_data_.GetCurrentForms());
-  const std::vector<const autofill::PasswordForm*> federated_forms =
-      GetRawPointers(passwords_data_.federation_providers_forms());
   const password_manager::ui::State state = passwords_data_.state();
   const GURL origin = passwords_data_.origin();
   EXPECT_NE(GURL::EmptyGURL(), origin);
@@ -258,8 +247,6 @@ void ManagePasswordsStateTest::TestBlacklistedUpdates() {
       password_manager::PasswordStoreChange::ADD, blacklisted));
   passwords_data().ProcessLoginsChanged(list);
   EXPECT_EQ(forms, GetRawPointers(passwords_data().GetCurrentForms()));
-  EXPECT_EQ(federated_forms,
-            GetRawPointers(passwords_data().federation_providers_forms()));
   EXPECT_EQ(state, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
 
@@ -268,15 +255,12 @@ void ManagePasswordsStateTest::TestBlacklistedUpdates() {
       password_manager::PasswordStoreChange::REMOVE, blacklisted);
   passwords_data().ProcessLoginsChanged(list);
   EXPECT_EQ(forms, GetRawPointers(passwords_data().GetCurrentForms()));
-  EXPECT_EQ(federated_forms,
-            GetRawPointers(passwords_data().federation_providers_forms()));
   EXPECT_EQ(state, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
 }
 
 TEST_F(ManagePasswordsStateTest, DefaultState) {
   EXPECT_THAT(passwords_data().GetCurrentForms(), IsEmpty());
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::INACTIVE_STATE, passwords_data().state());
   EXPECT_EQ(GURL::EmptyGURL(), passwords_data().origin());
   EXPECT_FALSE(passwords_data().form_manager());
@@ -285,8 +269,8 @@ TEST_F(ManagePasswordsStateTest, DefaultState) {
 }
 
 TEST_F(ManagePasswordsStateTest, PasswordSubmitted) {
-  test_stored_forms().push_back(
-      base::MakeUnique<autofill::PasswordForm>(test_local_form()));
+  test_stored_forms().push_back(&test_local_form());
+  test_stored_forms().push_back(&test_psl_form());
   std::unique_ptr<password_manager::PasswordFormManager> test_form_manager(
       CreateFormManager());
   test_form_manager->ProvisionallySave(
@@ -296,7 +280,6 @@ TEST_F(ManagePasswordsStateTest, PasswordSubmitted) {
 
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_local_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::PENDING_PASSWORD_STATE,
             passwords_data().state());
   EXPECT_EQ(test_submitted_form().origin, passwords_data().origin());
@@ -307,8 +290,7 @@ TEST_F(ManagePasswordsStateTest, PasswordSubmitted) {
 }
 
 TEST_F(ManagePasswordsStateTest, PasswordSaved) {
-  test_stored_forms().push_back(
-      base::MakeUnique<autofill::PasswordForm>(test_local_form()));
+  test_stored_forms().push_back(&test_local_form());
   std::unique_ptr<password_manager::PasswordFormManager> test_form_manager(
       CreateFormManager());
   test_form_manager->ProvisionallySave(
@@ -321,7 +303,6 @@ TEST_F(ManagePasswordsStateTest, PasswordSaved) {
   passwords_data().TransitionToState(password_manager::ui::MANAGE_STATE);
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_local_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::MANAGE_STATE,
             passwords_data().state());
   EXPECT_EQ(test_submitted_form().origin, passwords_data().origin());
@@ -338,24 +319,17 @@ TEST_F(ManagePasswordsStateTest, PasswordSubmittedFederationsPresent) {
 
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_local_federated_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
 }
 
 TEST_F(ManagePasswordsStateTest, OnRequestCredentials) {
   std::vector<std::unique_ptr<autofill::PasswordForm>> local_credentials;
   local_credentials.emplace_back(new autofill::PasswordForm(test_local_form()));
-  std::vector<std::unique_ptr<autofill::PasswordForm>> federated_credentials;
-  federated_credentials.emplace_back(
-      new autofill::PasswordForm(test_federated_form()));
   const GURL origin = test_local_form().origin;
-  passwords_data().OnRequestCredentials(
-      std::move(local_credentials), std::move(federated_credentials), origin);
+  passwords_data().OnRequestCredentials(std::move(local_credentials), origin);
   passwords_data().set_credentials_callback(base::Bind(
       &ManagePasswordsStateTest::CredentialCallback, base::Unretained(this)));
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_local_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(),
-              ElementsAre(Pointee(test_federated_form())));
   EXPECT_EQ(password_manager::ui::CREDENTIAL_REQUEST_STATE,
             passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
@@ -366,7 +340,6 @@ TEST_F(ManagePasswordsStateTest, OnRequestCredentials) {
   EXPECT_TRUE(passwords_data().credentials_callback().is_null());
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_local_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::MANAGE_STATE, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
   TestAllUpdates();
@@ -379,7 +352,6 @@ TEST_F(ManagePasswordsStateTest, AutoSignin) {
                                 test_local_form().origin);
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_local_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::AUTO_SIGNIN_STATE, passwords_data().state());
   EXPECT_EQ(test_local_form().origin, passwords_data().origin());
   TestAllUpdates();
@@ -387,13 +359,13 @@ TEST_F(ManagePasswordsStateTest, AutoSignin) {
   passwords_data().TransitionToState(password_manager::ui::MANAGE_STATE);
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_local_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::MANAGE_STATE, passwords_data().state());
   EXPECT_EQ(test_local_form().origin, passwords_data().origin());
   TestAllUpdates();
 }
 
 TEST_F(ManagePasswordsStateTest, AutomaticPasswordSave) {
+  test_stored_forms().push_back(&test_psl_form());
   std::unique_ptr<password_manager::PasswordFormManager> test_form_manager(
       CreateFormManager());
   test_form_manager->ProvisionallySave(
@@ -411,7 +383,6 @@ TEST_F(ManagePasswordsStateTest, AutomaticPasswordSave) {
   passwords_data().TransitionToState(password_manager::ui::MANAGE_STATE);
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_submitted_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::MANAGE_STATE, passwords_data().state());
   EXPECT_EQ(test_submitted_form().origin, passwords_data().origin());
   TestAllUpdates();
@@ -428,7 +399,6 @@ TEST_F(ManagePasswordsStateTest, AutomaticPasswordSaveWithFederations) {
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               UnorderedElementsAre(Pointee(test_submitted_form()),
                                    Pointee(test_local_federated_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
 }
 
 TEST_F(ManagePasswordsStateTest, PasswordAutofilled) {
@@ -440,7 +410,6 @@ TEST_F(ManagePasswordsStateTest, PasswordAutofilled) {
 
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_local_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::MANAGE_STATE, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
 
@@ -462,24 +431,18 @@ TEST_F(ManagePasswordsStateTest, PasswordAutofillWithSavedFederations) {
               UnorderedElementsAre(Pointee(test_local_form()),
                                    Pointee(test_local_federated_form())));
   // |federated_credentials_forms()| do not refer to the saved federations.
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::MANAGE_STATE, passwords_data().state());
 }
 
 TEST_F(ManagePasswordsStateTest, ActiveOnMixedPSLAndNonPSLMatched) {
   std::map<base::string16, const autofill::PasswordForm*> password_form_map;
-  password_form_map.insert(
-      std::make_pair(test_local_form().username_value, &test_local_form()));
-  autofill::PasswordForm psl_matched_test_form = test_local_form();
-  psl_matched_test_form.is_public_suffix_match = true;
-  password_form_map.insert(std::make_pair(psl_matched_test_form.username_value,
-                                          &psl_matched_test_form));
+  password_form_map[test_local_form().username_value] = &test_local_form();
+  password_form_map[test_psl_form().username_value] = &test_psl_form();
   GURL origin("https://example.com");
   passwords_data().OnPasswordAutofilled(password_form_map, origin, nullptr);
 
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_local_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::MANAGE_STATE, passwords_data().state());
   EXPECT_EQ(origin, passwords_data().origin());
 
@@ -487,16 +450,12 @@ TEST_F(ManagePasswordsStateTest, ActiveOnMixedPSLAndNonPSLMatched) {
 }
 
 TEST_F(ManagePasswordsStateTest, InactiveOnPSLMatched) {
-  autofill::PasswordForm psl_matched_test_form = test_local_form();
-  psl_matched_test_form.is_public_suffix_match = true;
   std::map<base::string16, const autofill::PasswordForm*> password_form_map;
-  password_form_map.insert(std::make_pair(psl_matched_test_form.username_value,
-                                          &psl_matched_test_form));
+  password_form_map[test_psl_form().username_value] = &test_psl_form();
   passwords_data().OnPasswordAutofilled(
-      password_form_map, GURL("https://m.example.com/"), nullptr);
+      password_form_map, GURL("https://example.com/"), nullptr);
 
   EXPECT_THAT(passwords_data().GetCurrentForms(), IsEmpty());
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::INACTIVE_STATE, passwords_data().state());
   EXPECT_EQ(GURL::EmptyGURL(), passwords_data().origin());
   EXPECT_FALSE(passwords_data().form_manager());
@@ -513,7 +472,6 @@ TEST_F(ManagePasswordsStateTest, OnInactive) {
             passwords_data().state());
   passwords_data().OnInactive();
   EXPECT_THAT(passwords_data().GetCurrentForms(), IsEmpty());
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::INACTIVE_STATE, passwords_data().state());
   EXPECT_EQ(GURL::EmptyGURL(), passwords_data().origin());
   EXPECT_FALSE(passwords_data().form_manager());
@@ -536,12 +494,8 @@ TEST_F(ManagePasswordsStateTest, PendingPasswordAddBlacklisted) {
 TEST_F(ManagePasswordsStateTest, RequestCredentialsAddBlacklisted) {
   std::vector<std::unique_ptr<autofill::PasswordForm>> local_credentials;
   local_credentials.emplace_back(new autofill::PasswordForm(test_local_form()));
-  std::vector<std::unique_ptr<autofill::PasswordForm>> federated_credentials;
-  federated_credentials.emplace_back(
-      new autofill::PasswordForm(test_federated_form()));
   const GURL origin = test_local_form().origin;
-  passwords_data().OnRequestCredentials(
-      std::move(local_credentials), std::move(federated_credentials), origin);
+  passwords_data().OnRequestCredentials(std::move(local_credentials), origin);
   passwords_data().set_credentials_callback(base::Bind(
       &ManagePasswordsStateTest::CredentialCallback, base::Unretained(this)));
   EXPECT_EQ(password_manager::ui::CREDENTIAL_REQUEST_STATE,
@@ -597,8 +551,8 @@ TEST_F(ManagePasswordsStateTest, PasswordUpdateAddBlacklisted) {
 }
 
 TEST_F(ManagePasswordsStateTest, PasswordUpdateSubmitted) {
-  test_stored_forms().push_back(
-      base::MakeUnique<autofill::PasswordForm>(test_local_form()));
+  test_stored_forms().push_back(&test_local_form());
+  test_stored_forms().push_back(&test_psl_form());
   std::unique_ptr<password_manager::PasswordFormManager> test_form_manager(
       CreateFormManager());
   test_form_manager->ProvisionallySave(
@@ -608,7 +562,6 @@ TEST_F(ManagePasswordsStateTest, PasswordUpdateSubmitted) {
 
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(test_local_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::PENDING_PASSWORD_UPDATE_STATE,
             passwords_data().state());
   EXPECT_EQ(test_submitted_form().origin, passwords_data().origin());
@@ -624,8 +577,7 @@ TEST_F(ManagePasswordsStateTest, AndroidPasswordUpdateSubmitted) {
   android_form.origin = GURL(android_form.signon_realm);
   android_form.username_value = test_submitted_form().username_value;
   android_form.password_value = base::ASCIIToUTF16("old pass");
-  test_stored_forms().push_back(
-      base::MakeUnique<autofill::PasswordForm>(android_form));
+  test_stored_forms().push_back(&android_form);
   std::unique_ptr<password_manager::PasswordFormManager> test_form_manager(
       CreateFormManager());
   test_form_manager->ProvisionallySave(
@@ -635,7 +587,6 @@ TEST_F(ManagePasswordsStateTest, AndroidPasswordUpdateSubmitted) {
 
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               ElementsAre(Pointee(android_form)));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
   EXPECT_EQ(password_manager::ui::PENDING_PASSWORD_UPDATE_STATE,
             passwords_data().state());
   EXPECT_EQ(test_submitted_form().origin, passwords_data().origin());
@@ -647,8 +598,7 @@ TEST_F(ManagePasswordsStateTest, AndroidPasswordUpdateSubmitted) {
 }
 
 TEST_F(ManagePasswordsStateTest, PasswordUpdateSubmittedWithFederations) {
-  test_stored_forms().push_back(
-      base::MakeUnique<autofill::PasswordForm>(test_local_form()));
+  test_stored_forms().push_back(&test_local_form());
   std::unique_ptr<password_manager::PasswordFormManager> test_form_manager(
       CreateFormManagerWithFederation());
   test_form_manager->ProvisionallySave(
@@ -659,12 +609,10 @@ TEST_F(ManagePasswordsStateTest, PasswordUpdateSubmittedWithFederations) {
   EXPECT_THAT(passwords_data().GetCurrentForms(),
               UnorderedElementsAre(Pointee(test_local_form()),
                                    Pointee(test_local_federated_form())));
-  EXPECT_THAT(passwords_data().federation_providers_forms(), IsEmpty());
 }
 
 TEST_F(ManagePasswordsStateTest, ChooseCredentialLocal) {
   passwords_data().OnRequestCredentials(
-      std::vector<std::unique_ptr<autofill::PasswordForm>>(),
       std::vector<std::unique_ptr<autofill::PasswordForm>>(),
       test_local_form().origin);
   passwords_data().set_credentials_callback(base::Bind(
@@ -675,21 +623,16 @@ TEST_F(ManagePasswordsStateTest, ChooseCredentialLocal) {
 
 TEST_F(ManagePasswordsStateTest, ChooseCredentialEmpty) {
   passwords_data().OnRequestCredentials(
-      std::vector<std::unique_ptr<autofill::PasswordForm>>(),
       std::vector<std::unique_ptr<autofill::PasswordForm>>(),
       test_local_form().origin);
   passwords_data().set_credentials_callback(base::Bind(
       &ManagePasswordsStateTest::CredentialCallback, base::Unretained(this)));
-  password_manager::CredentialInfo credential_info(
-      test_federated_form(),
-      password_manager::CredentialType::CREDENTIAL_TYPE_EMPTY);
   EXPECT_CALL(*this, CredentialCallback(nullptr));
   passwords_data().ChooseCredential(nullptr);
 }
 
 TEST_F(ManagePasswordsStateTest, ChooseCredentialLocalWithNonEmptyFederation) {
   passwords_data().OnRequestCredentials(
-      std::vector<std::unique_ptr<autofill::PasswordForm>>(),
       std::vector<std::unique_ptr<autofill::PasswordForm>>(),
       test_local_form().origin);
   passwords_data().set_credentials_callback(base::Bind(
