@@ -96,25 +96,26 @@ void ManagePasswordsUIController::OnUpdatePasswordSubmitted(
 
 bool ManagePasswordsUIController::OnChooseCredentials(
     std::vector<std::unique_ptr<autofill::PasswordForm>> local_credentials,
-    std::vector<std::unique_ptr<autofill::PasswordForm>> federated_credentials,
     const GURL& origin,
     const ManagePasswordsState::CredentialsCallback& callback) {
-  DCHECK(!local_credentials.empty() || !federated_credentials.empty());
+  DCHECK(!local_credentials.empty());
   if (!HasBrowserWindow())
     return false;
-  PasswordDialogController::FormsVector locals =
-      CopyFormVector(local_credentials);
-  PasswordDialogController::FormsVector federations =
-      CopyFormVector(federated_credentials);
-  passwords_data_.OnRequestCredentials(
-      std::move(local_credentials), std::move(federated_credentials), origin);
+  // If |local_credentials| contains PSL matches they shouldn't be propagated to
+  // the state because PSL matches aren't saved for current page. This logic is
+  // implemented here because Android uses ManagePasswordsState as a data source
+  // for account chooser.
+  PasswordDialogController::FormsVector locals;
+  if (!local_credentials[0]->is_public_suffix_match)
+    locals = CopyFormVector(local_credentials);
+  passwords_data_.OnRequestCredentials(std::move(locals), origin);
   passwords_data_.set_credentials_callback(callback);
   dialog_controller_.reset(new PasswordDialogControllerImpl(
       Profile::FromBrowserContext(web_contents()->GetBrowserContext()),
       this));
   dialog_controller_->ShowAccountChooser(
       CreateAccountChooser(dialog_controller_.get()),
-      std::move(locals), std::move(federations));
+      std::move(local_credentials));
   UpdateBubbleAndIconVisibility();
   return true;
 }
@@ -236,11 +237,6 @@ ManagePasswordsUIController::GetCurrentForms() const {
   return passwords_data_.GetCurrentForms();
 }
 
-const std::vector<std::unique_ptr<autofill::PasswordForm>>&
-ManagePasswordsUIController::GetFederatedForms() const {
-  return passwords_data_.federation_providers_forms();
-}
-
 const password_manager::InteractionsStats*
 ManagePasswordsUIController::GetCurrentInteractionStats() const {
   DCHECK_EQ(password_manager::ui::PENDING_PASSWORD_STATE, GetState());
