@@ -56,9 +56,9 @@ class MockSearchIPCRouterDelegate : public SearchIPCRouter::Delegate {
   MOCK_METHOD2(OnLogEvent, void(NTPLoggingEventType event,
                                 base::TimeDelta time));
   MOCK_METHOD2(OnLogMostVisitedImpression,
-               void(int position, NTPLoggingTileSource tile_source));
+               void(int position, ntp_tiles::NTPTileSource tile_source));
   MOCK_METHOD2(OnLogMostVisitedNavigation,
-               void(int position, NTPLoggingTileSource tile_source));
+               void(int position, ntp_tiles::NTPTileSource tile_source));
   MOCK_METHOD1(PasteIntoOmnibox, void(const base::string16&));
   MOCK_METHOD1(OnChromeIdentityCheck, void(const base::string16& identity));
   MOCK_METHOD0(OnHistorySyncCheck, void());
@@ -122,7 +122,7 @@ class SearchIPCRouterTest : public BrowserWithTestWindowTest {
 
   content::MockRenderProcessHost* process() {
     return static_cast<content::MockRenderProcessHost*>(
-        web_contents()->GetRenderViewHost()->GetProcess());
+        web_contents()->GetMainFrame()->GetProcess());
   }
 
   SearchTabHelper* GetSearchTabHelper(
@@ -196,7 +196,7 @@ TEST_F(SearchIPCRouterTest, IgnoreMessagesFromNonInstantRenderers) {
   EXPECT_CALL(*policy, ShouldProcessFocusOmnibox(is_active_tab)).Times(0);
 
   OnMessageReceived(ChromeViewHostMsg_FocusOmnibox(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
       OMNIBOX_FOCUS_VISIBLE));
 }
 
@@ -213,7 +213,7 @@ TEST_F(SearchIPCRouterTest, ProcessFocusOmniboxMsg) {
       .WillOnce(testing::Return(true));
 
   OnMessageReceived(ChromeViewHostMsg_FocusOmnibox(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
       OMNIBOX_FOCUS_VISIBLE));
 }
 
@@ -230,7 +230,7 @@ TEST_F(SearchIPCRouterTest, IgnoreFocusOmniboxMsg) {
       .WillOnce(testing::Return(false));
 
   OnMessageReceived(ChromeViewHostMsg_FocusOmnibox(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
       OMNIBOX_FOCUS_VISIBLE));
 }
 
@@ -259,14 +259,15 @@ TEST_F(SearchIPCRouterTest, ProcessLogEventMsg) {
   NavigateAndCommitActiveTab(GURL(chrome::kChromeSearchLocalNtpUrl));
   SetupMockDelegateAndPolicy();
   MockSearchIPCRouterPolicy* policy = GetSearchIPCRouterPolicy();
-  EXPECT_CALL(*mock_delegate(), OnLogEvent(NTP_TILE, delta)).Times(1);
+  EXPECT_CALL(*mock_delegate(), OnLogEvent(NTP_ALL_TILES_LOADED, delta))
+      .Times(1);
   EXPECT_CALL(*policy, ShouldProcessLogEvent()).Times(1)
       .WillOnce(testing::Return(true));
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_LogEvent(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(),
-      NTP_TILE, delta));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      NTP_ALL_TILES_LOADED, delta));
 }
 
 TEST_F(SearchIPCRouterTest, IgnoreLogEventMsg) {
@@ -274,14 +275,15 @@ TEST_F(SearchIPCRouterTest, IgnoreLogEventMsg) {
   NavigateAndCommitActiveTab(GURL("chrome-search://foo/bar"));
   SetupMockDelegateAndPolicy();
   MockSearchIPCRouterPolicy* policy = GetSearchIPCRouterPolicy();
-  EXPECT_CALL(*mock_delegate(), OnLogEvent(NTP_TILE, delta)).Times(0);
+  EXPECT_CALL(*mock_delegate(), OnLogEvent(NTP_ALL_TILES_LOADED, delta))
+      .Times(0);
   EXPECT_CALL(*policy, ShouldProcessLogEvent()).Times(1)
       .WillOnce(testing::Return(false));
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_LogEvent(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(),
-      NTP_TILE, delta));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      NTP_ALL_TILES_LOADED, delta));
 }
 
 TEST_F(SearchIPCRouterTest, ProcessLogMostVisitedImpressionMsg) {
@@ -289,14 +291,16 @@ TEST_F(SearchIPCRouterTest, ProcessLogMostVisitedImpressionMsg) {
   SetupMockDelegateAndPolicy();
   MockSearchIPCRouterPolicy* policy = GetSearchIPCRouterPolicy();
   EXPECT_CALL(*mock_delegate(),
-      OnLogMostVisitedImpression(3, NTPLoggingTileSource::SERVER)).Times(1);
+              OnLogMostVisitedImpression(
+                  3, ntp_tiles::NTPTileSource::SUGGESTIONS_SERVICE))
+      .Times(1);
   EXPECT_CALL(*policy, ShouldProcessLogEvent()).Times(1)
       .WillOnce(testing::Return(true));
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_LogMostVisitedImpression(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(), 3,
-      NTPLoggingTileSource::SERVER));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      3, ntp_tiles::NTPTileSource::SUGGESTIONS_SERVICE));
 }
 
 TEST_F(SearchIPCRouterTest, ProcessLogMostVisitedNavigationMsg) {
@@ -304,14 +308,16 @@ TEST_F(SearchIPCRouterTest, ProcessLogMostVisitedNavigationMsg) {
   SetupMockDelegateAndPolicy();
   MockSearchIPCRouterPolicy* policy = GetSearchIPCRouterPolicy();
   EXPECT_CALL(*mock_delegate(),
-      OnLogMostVisitedNavigation(3, NTPLoggingTileSource::SERVER)).Times(1);
+              OnLogMostVisitedNavigation(
+                  3, ntp_tiles::NTPTileSource::SUGGESTIONS_SERVICE))
+      .Times(1);
   EXPECT_CALL(*policy, ShouldProcessLogEvent()).Times(1)
       .WillOnce(testing::Return(true));
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_LogMostVisitedNavigation(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(), 3,
-      NTPLoggingTileSource::SERVER));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      3, ntp_tiles::NTPTileSource::SUGGESTIONS_SERVICE));
 }
 
 TEST_F(SearchIPCRouterTest, ProcessChromeIdentityCheckMsg) {
@@ -325,7 +331,8 @@ TEST_F(SearchIPCRouterTest, ProcessChromeIdentityCheckMsg) {
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_ChromeIdentityCheck(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(), test_identity));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      test_identity));
 }
 
 TEST_F(SearchIPCRouterTest, IgnoreChromeIdentityCheckMsg) {
@@ -340,7 +347,8 @@ TEST_F(SearchIPCRouterTest, IgnoreChromeIdentityCheckMsg) {
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_ChromeIdentityCheck(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(), test_identity));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      test_identity));
 }
 
 TEST_F(SearchIPCRouterTest, ProcessHistorySyncCheckMsg) {
@@ -353,7 +361,8 @@ TEST_F(SearchIPCRouterTest, ProcessHistorySyncCheckMsg) {
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_HistorySyncCheck(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo()));
+      contents->GetRenderViewHost()->GetRoutingID(),
+      GetSearchIPCRouterSeqNo()));
 }
 
 TEST_F(SearchIPCRouterTest, IgnoreHistorySyncCheckMsg) {
@@ -367,7 +376,8 @@ TEST_F(SearchIPCRouterTest, IgnoreHistorySyncCheckMsg) {
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_HistorySyncCheck(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo()));
+      contents->GetRenderViewHost()->GetRoutingID(),
+      GetSearchIPCRouterSeqNo()));
 }
 
 TEST_F(SearchIPCRouterTest, ProcessDeleteMostVisitedItemMsg) {
@@ -381,7 +391,8 @@ TEST_F(SearchIPCRouterTest, ProcessDeleteMostVisitedItemMsg) {
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_SearchBoxDeleteMostVisitedItem(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(), item_url));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      item_url));
 }
 
 TEST_F(SearchIPCRouterTest, IgnoreDeleteMostVisitedItemMsg) {
@@ -395,7 +406,8 @@ TEST_F(SearchIPCRouterTest, IgnoreDeleteMostVisitedItemMsg) {
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_SearchBoxDeleteMostVisitedItem(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(), item_url));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      item_url));
 }
 
 TEST_F(SearchIPCRouterTest, ProcessUndoMostVisitedDeletionMsg) {
@@ -409,7 +421,8 @@ TEST_F(SearchIPCRouterTest, ProcessUndoMostVisitedDeletionMsg) {
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_SearchBoxUndoMostVisitedDeletion(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(), item_url));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      item_url));
 }
 
 TEST_F(SearchIPCRouterTest, IgnoreUndoMostVisitedDeletionMsg) {
@@ -423,7 +436,8 @@ TEST_F(SearchIPCRouterTest, IgnoreUndoMostVisitedDeletionMsg) {
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_SearchBoxUndoMostVisitedDeletion(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(), item_url));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      item_url));
 }
 
 TEST_F(SearchIPCRouterTest, ProcessUndoAllMostVisitedDeletionsMsg) {
@@ -436,7 +450,8 @@ TEST_F(SearchIPCRouterTest, ProcessUndoAllMostVisitedDeletionsMsg) {
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_SearchBoxUndoAllMostVisitedDeletions(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo()));
+      contents->GetRenderViewHost()->GetRoutingID(),
+      GetSearchIPCRouterSeqNo()));
 }
 
 TEST_F(SearchIPCRouterTest, IgnoreUndoAllMostVisitedDeletionsMsg) {
@@ -449,7 +464,8 @@ TEST_F(SearchIPCRouterTest, IgnoreUndoAllMostVisitedDeletionsMsg) {
 
   content::WebContents* contents = web_contents();
   OnMessageReceived(ChromeViewHostMsg_SearchBoxUndoAllMostVisitedDeletions(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo()));
+      contents->GetRenderViewHost()->GetRoutingID(),
+      GetSearchIPCRouterSeqNo()));
 }
 
 TEST_F(SearchIPCRouterTest, IgnoreMessageIfThePageIsNotActive) {
@@ -468,35 +484,37 @@ TEST_F(SearchIPCRouterTest, IgnoreMessageIfThePageIsNotActive) {
   EXPECT_CALL(*mock_delegate(), OnDeleteMostVisitedItem(item_url)).Times(0);
   EXPECT_CALL(*policy, ShouldProcessDeleteMostVisitedItem()).Times(0);
   OnMessageReceived(ChromeViewHostMsg_SearchBoxDeleteMostVisitedItem(
-      contents->GetRoutingID(), page_seq_no, item_url));
+      contents->GetRenderViewHost()->GetRoutingID(), page_seq_no, item_url));
 
   EXPECT_CALL(*mock_delegate(), OnUndoMostVisitedDeletion(item_url)).Times(0);
   EXPECT_CALL(*policy, ShouldProcessUndoMostVisitedDeletion()).Times(0);
   OnMessageReceived(ChromeViewHostMsg_SearchBoxUndoMostVisitedDeletion(
-      contents->GetRoutingID(), page_seq_no, item_url));
+      contents->GetRenderViewHost()->GetRoutingID(), page_seq_no, item_url));
 
   EXPECT_CALL(*mock_delegate(), OnUndoAllMostVisitedDeletions()).Times(0);
   EXPECT_CALL(*policy, ShouldProcessUndoAllMostVisitedDeletions()).Times(0);
   OnMessageReceived(ChromeViewHostMsg_SearchBoxUndoAllMostVisitedDeletions(
-      contents->GetRoutingID(), page_seq_no));
+      contents->GetRenderViewHost()->GetRoutingID(), page_seq_no));
 
   EXPECT_CALL(*mock_delegate(), FocusOmnibox(OMNIBOX_FOCUS_VISIBLE)).Times(0);
   EXPECT_CALL(*policy, ShouldProcessFocusOmnibox(is_active_tab)).Times(0);
   OnMessageReceived(ChromeViewHostMsg_FocusOmnibox(
-      contents->GetRoutingID(), page_seq_no, OMNIBOX_FOCUS_VISIBLE));
+      contents->GetRenderViewHost()->GetRoutingID(), page_seq_no,
+      OMNIBOX_FOCUS_VISIBLE));
 
   base::TimeDelta delta = base::TimeDelta::FromMilliseconds(123);
-  EXPECT_CALL(*mock_delegate(), OnLogEvent(NTP_TILE, delta)).Times(0);
+  EXPECT_CALL(*mock_delegate(), OnLogEvent(NTP_ALL_TILES_LOADED, delta))
+      .Times(0);
   EXPECT_CALL(*policy, ShouldProcessLogEvent()).Times(0);
-  OnMessageReceived(ChromeViewHostMsg_LogEvent(contents->GetRoutingID(),
-                                               page_seq_no,
-                                               NTP_TILE, delta));
+  OnMessageReceived(
+      ChromeViewHostMsg_LogEvent(contents->GetRenderViewHost()->GetRoutingID(),
+                                 page_seq_no, NTP_ALL_TILES_LOADED, delta));
 
   base::string16 text;
   EXPECT_CALL(*mock_delegate(), PasteIntoOmnibox(text)).Times(0);
   EXPECT_CALL(*policy, ShouldProcessPasteIntoOmnibox(is_active_tab)).Times(0);
   OnMessageReceived(ChromeViewHostMsg_PasteAndOpenDropdown(
-      contents->GetRoutingID(), page_seq_no, text));
+      contents->GetRenderViewHost()->GetRoutingID(), page_seq_no, text));
 }
 
 TEST_F(SearchIPCRouterTest, ProcessPasteAndOpenDropdownMsg) {
@@ -513,7 +531,8 @@ TEST_F(SearchIPCRouterTest, ProcessPasteAndOpenDropdownMsg) {
   EXPECT_CALL(*policy, ShouldProcessPasteIntoOmnibox(is_active_tab)).Times(1)
       .WillOnce(testing::Return(true));
   OnMessageReceived(ChromeViewHostMsg_PasteAndOpenDropdown(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(), text));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      text));
 }
 
 TEST_F(SearchIPCRouterTest, IgnorePasteAndOpenDropdownMsg) {
@@ -531,7 +550,8 @@ TEST_F(SearchIPCRouterTest, IgnorePasteAndOpenDropdownMsg) {
       .WillOnce(testing::Return(false));
 
   OnMessageReceived(ChromeViewHostMsg_PasteAndOpenDropdown(
-      contents->GetRoutingID(), GetSearchIPCRouterSeqNo(), text));
+      contents->GetRenderViewHost()->GetRoutingID(), GetSearchIPCRouterSeqNo(),
+      text));
 }
 
 TEST_F(SearchIPCRouterTest, SendSetSuggestionToPrefetch) {
@@ -691,7 +711,7 @@ TEST_F(SearchIPCRouterTest, DoNotSendSubmitMsg) {
 TEST_F(SearchIPCRouterTest, SpuriousMessageTypesIgnored) {
   NavigateAndCommitActiveTab(GURL("chrome-search://foo/bar"));
   SetupMockDelegateAndPolicy();
-  const int routing_id = web_contents()->GetRoutingID();
+  const int routing_id = web_contents()->GetRenderViewHost()->GetRoutingID();
 
   // Construct a series of synthetic messages for each valid IPC message type,
   // ensuring the router ignores them all.
