@@ -59,7 +59,7 @@ bool IsCacheableNTP(const content::WebContents* contents) {
   const content::NavigationEntry* entry =
       contents->GetController().GetLastCommittedEntry();
   return search::NavEntryIsInstantNTP(contents, entry) &&
-         entry->GetURL() != GURL(chrome::kChromeSearchLocalNtpUrl);
+         entry->GetURL() != chrome::kChromeSearchLocalNtpUrl;
 }
 
 bool IsNTP(const content::WebContents* contents) {
@@ -67,7 +67,7 @@ bool IsNTP(const content::WebContents* contents) {
   // whereas we want the visible entry.
   const content::NavigationEntry* entry =
       contents->GetController().GetVisibleEntry();
-  if (entry && entry->GetVirtualURL() == GURL(chrome::kChromeUINewTabURL))
+  if (entry && entry->GetVirtualURL() == chrome::kChromeUINewTabURL)
     return true;
 
   return search::IsInstantNTP(contents);
@@ -78,7 +78,7 @@ bool IsLocal(const content::WebContents* contents) {
     return false;
   const content::NavigationEntry* entry =
       contents->GetController().GetVisibleEntry();
-  return entry && entry->GetURL() == GURL(chrome::kChromeSearchLocalNtpUrl);
+  return entry && entry->GetURL() == chrome::kChromeSearchLocalNtpUrl;
 }
 
 // Returns true if |contents| are rendered inside an Instant process.
@@ -186,10 +186,6 @@ void SearchTabHelper::NavigationEntryUpdated() {
   UpdateMode(false);
 }
 
-bool SearchTabHelper::SupportsInstant() const {
-  return model_.instant_support() == INSTANT_SUPPORT_YES;
-}
-
 void SearchTabHelper::SetSuggestionToPrefetch(
     const InstantSuggestion& suggestion) {
   ipc_router_.SetSuggestionToPrefetch(suggestion);
@@ -204,6 +200,9 @@ void SearchTabHelper::OnTabActivated() {
   ipc_router_.OnTabActivated();
 
   if (search::IsInstantNTP(web_contents_)) {
+    if (instant_service_)
+      instant_service_->OnNewTabPageOpened();
+
     // Force creation of NTPUserDataLogger, if we loaded an NTP. The
     // NTPUserDataLogger tries to detect whether the NTP is being created at
     // startup or from the user opening a new tab, and if we wait until later,
@@ -253,7 +252,7 @@ void SearchTabHelper::DidNavigateMainFrame(
   content::NavigationEntry* entry =
       web_contents_->GetController().GetLastCommittedEntry();
   if (entry && entry->GetTitle().empty() &&
-      (entry->GetVirtualURL() == GURL(chrome::kChromeUINewTabURL) ||
+      (entry->GetVirtualURL() == chrome::kChromeUINewTabURL ||
        search::NavEntryIsInstantNTP(web_contents_, entry))) {
     web_contents_->UpdateTitleForEntry(
         entry, l10n_util::GetStringUTF16(IDS_NEW_TAB_TITLE));
@@ -384,7 +383,8 @@ void SearchTabHelper::OnLogEvent(NTPLoggingEventType event,
 }
 
 void SearchTabHelper::OnLogMostVisitedImpression(
-    int position, NTPLoggingTileSource tile_source) {
+    int position,
+    ntp_tiles::NTPTileSource tile_source) {
 // TODO(kmadhusu): Move platform specific code from here and get rid of #ifdef.
 #if !defined(OS_ANDROID)
   NTPUserDataLogger::GetOrCreateFromWebContents(
@@ -393,7 +393,8 @@ void SearchTabHelper::OnLogMostVisitedImpression(
 }
 
 void SearchTabHelper::OnLogMostVisitedNavigation(
-    int position, NTPLoggingTileSource tile_source) {
+    int position,
+    ntp_tiles::NTPTileSource tile_source) {
 // TODO(kmadhusu): Move platform specific code from here and get rid of #ifdef.
 #if !defined(OS_ANDROID)
   NTPUserDataLogger::GetOrCreateFromWebContents(
