@@ -58,9 +58,9 @@ class MockSearchIPCRouterDelegate : public SearchIPCRouter::Delegate {
   MOCK_METHOD2(OnLogEvent, void(NTPLoggingEventType event,
                                 base::TimeDelta time));
   MOCK_METHOD2(OnLogMostVisitedImpression,
-               void(int position, NTPLoggingTileSource tile_source));
+               void(int position, ntp_tiles::NTPTileSource tile_source));
   MOCK_METHOD2(OnLogMostVisitedNavigation,
-               void(int position, NTPLoggingTileSource tile_source));
+               void(int position, ntp_tiles::NTPTileSource tile_source));
   MOCK_METHOD1(PasteIntoOmnibox, void(const base::string16&));
   MOCK_METHOD1(OnChromeIdentityCheck, void(const base::string16& identity));
   MOCK_METHOD0(OnHistorySyncCheck, void());
@@ -145,7 +145,7 @@ TEST_F(SearchTabHelperTest, DetermineIfPageSupportsInstant_NonLocal) {
 
   std::unique_ptr<IPC::Message> response(
       new ChromeViewHostMsg_InstantSupportDetermined(
-          web_contents()->GetRoutingID(),
+          web_contents()->GetRenderViewHost()->GetRoutingID(),
           search_tab_helper->ipc_router().page_seq_no_for_testing(), true));
   search_tab_helper->ipc_router().OnMessageReceived(*response);
 }
@@ -322,8 +322,7 @@ class TabTitleObserver : public content::WebContentsObserver {
   void DidStartProvisionalLoadForFrame(
       content::RenderFrameHost* /* render_frame_host */,
       const GURL& /* validated_url */,
-      bool /* is_error_page */,
-      bool /* is_iframe_srcdoc */) override {
+      bool /* is_error_page */) override {
     title_on_start_ = web_contents()->GetTitle();
   }
 
