@@ -88,7 +88,8 @@
 #include "chrome/installer/util/browser_distribution.h"
 #include "components/google/core/browser/google_util.h"
 #include "components/prefs/pref_service.h"
-#include "components/rappor/rappor_utils.h"
+#include "components/rappor/public/rappor_utils.h"
+#include "components/rappor/rappor_service_impl.h"
 #include "content/public/browser/child_process_security_policy.h"
 #include "content/public/browser/dom_storage_context.h"
 #include "content/public/browser/notification_observer.h"
@@ -279,10 +280,11 @@ void AppendTabs(const StartupTabs& from, StartupTabs* to) {
 }
 
 // Determines whether the Consolidated startup flow should be used, based on
-// the kUseConsolidatedStartupFlow Feature. Not enabled on Windows 10+.
+// OS, OS version, and the kUseConsolidatedStartupFlow Feature.
 bool UseConsolidatedFlow() {
 #if defined(OS_WIN)
-  // TODO(tmartino): Add a Win10+ specific experiment.
+  // TODO(tmartino): Enable for Windows 10+ once relevant Win 10-specific logic
+  // is added to StartupTabProvider.
   if (base::win::GetVersion() >= base::win::VERSION_WIN10)
     return false;
 #endif  // defined(OS_WIN)
