@@ -9,4 +9,9 @@ namespace features {
 const base::Feature kUseConsolidatedStartupFlow{
     "UseConsolidatedStartupFlow", base::FEATURE_DISABLED_BY_DEFAULT};
 
+#if defined(OS_WIN)
+const base::Feature kWelcomeWin10InlineStyle{"WelcomeWin10InlineStyle",
+                                             base::FEATURE_ENABLED_BY_DEFAULT};
+#endif
+
 }  // namespace features
