@@ -58,23 +58,13 @@ class StartupTabProviderImpl : public StartupTabProvider {
   // the respective Get*Tabs methods, but do not gather or interact with any
   // system state relating to making those policy decisions.
 
-  // Determines which tabs should be shown according to onboarding/first
+  // Determines which tabs which should be shown according to onboarding/first
   // run policy.
   static StartupTabs CheckStandardOnboardingTabPolicy(
       bool is_first_run,
       bool has_seen_welcome_page,
       bool is_signed_in);
 
-#if defined(OS_WIN)
-  // Determines which tabs should be shown according to onboarding/first run
-  // policy, including promo content specific to Windows 10.
-  static StartupTabs CheckWin10OnboardingTabPolicy(bool is_first_run,
-                                                   bool has_seen_welcome_page,
-                                                   bool has_seen_win10_promo,
-                                                   bool is_signed_in,
-                                                   bool is_default_browser);
-#endif
-
   // Processes first run URLs specified in Master Preferences file, replacing
   // any "magic word" URL hosts with appropriate URLs.
   static StartupTabs CheckMasterPrefsTabPolicy(
@@ -106,13 +96,6 @@ class StartupTabProviderImpl : public StartupTabProvider {
   // additional profile).
   static GURL GetWelcomePageUrl(bool use_later_run_variant);
 
-#if defined(OS_WIN)
-  // Gets the URL for the Windows 10 Welcome page. If |use_later_run_variant| is
-  // true, a URL parameter will be appended so as to access the variant page
-  // used when onboarding occurs after the first Chrome execution.
-  static GURL GetWin10WelcomePageUrl(bool use_later_run_variant);
-#endif
-
   // Gets the URL for the page which offers to reset the user's profile
   // settings.
   static GURL GetTriggeredResetSettingsUrl();
