@@ -13,7 +13,7 @@
 #include "ui/views/window/dialog_delegate.h"
 
 #if defined(OS_CHROMEOS)
-#include "chrome/browser/chromeos/arc/arc_auth_service.h"
+#include "chrome/browser/chromeos/arc/arc_session_manager.h"
 #include "components/arc/test/fake_arc_bridge_service.h"
 #endif
 
@@ -32,11 +32,11 @@ class AppInfoDialogAshTest : public ash::test::AshTestBase {
   void SetUp() override {
     ash::test::AshTestBase::SetUp();
 #if defined(OS_CHROMEOS)
-    arc::ArcAuthService::DisableUIForTesting();
+    arc::ArcSessionManager::DisableUIForTesting();
     bridge_service_ = base::MakeUnique<arc::FakeArcBridgeService>();
-    auth_service_ =
-        base::MakeUnique<arc::ArcAuthService>(bridge_service_.get());
-    auth_service_->OnPrimaryUserProfilePrepared(
+    arc_session_manager_ =
+        base::MakeUnique<arc::ArcSessionManager>(bridge_service_.get());
+    arc_session_manager_->OnPrimaryUserProfilePrepared(
         extension_environment_.profile());
 #endif
     widget_ = views::DialogDelegate::CreateDialogWidget(
@@ -45,13 +45,14 @@ class AppInfoDialogAshTest : public ash::test::AshTestBase {
         widget_->GetNativeWindow(), extension_environment_.profile(),
         extension_environment_.MakePackagedApp(kTestExtensionId, true).get());
     widget_->GetContentsView()->AddChildView(dialog_);
+    widget_->Show();
   }
 
   void TearDown() override {
     widget_->CloseNow();
 #if defined(OS_CHROMEOS)
-    if (auth_service_)
-      auth_service_->Shutdown();
+    if (arc_session_manager_)
+      arc_session_manager_->Shutdown();
 #endif
     ash::test::AshTestBase::TearDown();
   }
@@ -62,7 +63,7 @@ class AppInfoDialogAshTest : public ash::test::AshTestBase {
   AppInfoDialog* dialog_ = nullptr;  // Owned by |widget_|'s views hierarchy.
 #if defined(OS_CHROMEOS)
   std::unique_ptr<arc::FakeArcBridgeService> bridge_service_;
-  std::unique_ptr<arc::ArcAuthService> auth_service_;
+  std::unique_ptr<arc::ArcSessionManager> arc_session_manager_;
 #endif
 
  private:
