@@ -8,18 +8,19 @@
 #include "ash/aura/wm_window_aura.h"
 #include "ash/common/ash_constants.h"
 #include "ash/common/frame/custom_frame_view_ash.h"
-#include "ash/common/shell_window_ids.h"
+#include "ash/common/shelf/shelf_item_types.h"
+#include "ash/common/wm/panels/panel_frame_view.h"
 #include "ash/common/wm/window_state.h"
 #include "ash/common/wm/window_state_delegate.h"
 #include "ash/common/wm/window_state_observer.h"
+#include "ash/public/cpp/shell_window_ids.h"
 #include "ash/screen_util.h"
 #include "ash/shared/app_types.h"
 #include "ash/shared/immersive_fullscreen_controller.h"
 #include "ash/shell.h"
-#include "ash/wm/panels/panel_frame_view.h"
 #include "ash/wm/window_properties.h"
 #include "ash/wm/window_state_aura.h"
-#include "chrome/browser/chromeos/note_taking_app_utils.h"
+#include "chrome/browser/chromeos/note_taking_helper.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/ash/ash_util.h"
 #include "chrome/browser/ui/ash/multi_user/multi_user_context_menu.h"
@@ -120,30 +121,27 @@ class NativeAppWindowStateDelegate : public ash::wm::WindowStateDelegate,
 
 }  // namespace
 
-ChromeNativeAppWindowViewsAuraAsh::ChromeNativeAppWindowViewsAuraAsh() {
-}
+ChromeNativeAppWindowViewsAuraAsh::ChromeNativeAppWindowViewsAuraAsh() {}
 
-ChromeNativeAppWindowViewsAuraAsh::~ChromeNativeAppWindowViewsAuraAsh() {
-}
+ChromeNativeAppWindowViewsAuraAsh::~ChromeNativeAppWindowViewsAuraAsh() {}
 
 void ChromeNativeAppWindowViewsAuraAsh::InitializeWindow(
     AppWindow* app_window,
     const AppWindow::CreateParams& create_params) {
   ChromeNativeAppWindowViewsAura::InitializeWindow(app_window, create_params);
+  aura::Window* window = widget()->GetNativeWindow();
   // Restore docked state on ash desktop.
-  if (create_params.state == ui::SHOW_STATE_DOCKED) {
-    widget()->GetNativeWindow()->SetProperty(aura::client::kShowStateKey,
-                                             create_params.state);
-  }
+  if (create_params.state == ui::SHOW_STATE_DOCKED)
+    window->SetProperty(aura::client::kShowStateKey, create_params.state);
+  window->SetProperty(aura::client::kAppIdKey,
+                      new std::string(app_window->extension_id()));
 
-  if (!app_window->window_type_is_panel()) {
-    ash::AppType app_type = ash::AppType::CHROME_APP;
-    Profile* profile =
-        Profile::FromBrowserContext(app_window->browser_context());
-    if (profile && chromeos::IsNoteTakingAppWindow(app_window, profile))
-      app_type = ash::AppType::DEFAULT_NOTE_TAKING_APP;
-    widget()->GetNativeWindow()->SetProperty(aura::client::kAppType,
-                                             static_cast<int>(app_type));
+  if (app_window->window_type_is_panel()) {
+    // Ash's ShelfWindowWatcher handles app panel windows once this type is set.
+    window->SetProperty<int>(ash::kShelfItemTypeKey, ash::TYPE_APP_PANEL);
+  } else {
+    window->SetProperty(aura::client::kAppType,
+                        static_cast<int>(ash::AppType::CHROME_APP));
   }
 }
 
@@ -154,13 +152,13 @@ void ChromeNativeAppWindowViewsAuraAsh::OnBeforeWidgetInit(
   ChromeNativeAppWindowViewsAura::OnBeforeWidgetInit(create_params, init_params,
                                                      widget);
   if (create_params.is_ime_window) {
-    // Puts ime windows into ime window container.
+    // Puts ime windows into the ime window container.
     init_params->parent =
         ash::Shell::GetContainer(ash::Shell::GetPrimaryRootWindow(),
                                  ash::kShellWindowId_ImeWindowParentContainer);
   }
   init_params->mus_properties
-      [ui::mojom::WindowManager::kRemoveStandardFrame_Property] =
+      [ui::mojom::WindowManager::kRemoveStandardFrame_InitProperty] =
       mojo::ConvertTo<std::vector<uint8_t>>(init_params->remove_standard_frame);
 }
 
@@ -174,6 +172,7 @@ void ChromeNativeAppWindowViewsAuraAsh::OnBeforePanelWidgetInit(
 
   if (ash::Shell::HasInstance() && use_default_bounds) {
     // Open a new panel on the target root.
+    init_params->context = ash::Shell::GetTargetRootWindow();
     init_params->bounds = ash::ScreenUtil::ConvertRectToScreen(
         ash::Shell::GetTargetRootWindow(), gfx::Rect(GetPreferredSize()));
   }
@@ -239,10 +238,8 @@ ChromeNativeAppWindowViewsAuraAsh::GetRestoredState() const {
 }
 
 bool ChromeNativeAppWindowViewsAuraAsh::IsAlwaysOnTop() const {
-  if (app_window()->window_type_is_panel()) {
-    return
-        ash::wm::GetWindowState(widget()->GetNativeWindow())->panel_attached();
-  }
+  if (app_window()->window_type_is_panel())
+    return widget()->GetNativeWindow()->GetProperty(ash::kPanelAttachedKey);
   return widget()->IsAlwaysOnTop();
 }
 
