@@ -14,43 +14,26 @@
 #include "chrome/browser/chrome_browser_main.h"
 #include "chrome/browser/ui/ash/ash_init.h"
 #include "chrome/browser/ui/ash/ash_util.h"
-#include "chrome/browser/ui/ash/ime_driver_ash.h"
+#include "chrome/browser/ui/ash/cast_config_client_media_router.h"
+#include "chrome/browser/ui/ash/chrome_new_window_client.h"
 #include "chrome/browser/ui/ash/launcher/chrome_launcher_controller_mus.h"
 #include "chrome/browser/ui/views/ash/tab_scrubber.h"
 #include "chrome/browser/ui/views/frame/immersive_context_mus.h"
 #include "chrome/browser/ui/views/frame/immersive_handler_factory_mus.h"
 #include "chrome/common/chrome_switches.h"
-#include "content/public/common/service_manager_connection.h"
-#include "mojo/public/cpp/bindings/strong_binding.h"
-#include "services/service_manager/public/cpp/connector.h"
-#include "services/ui/public/interfaces/ime.mojom.h"
 #include "ui/aura/env.h"
 #include "ui/keyboard/content/keyboard.h"
 #include "ui/keyboard/keyboard_controller.h"
 
 #if defined(OS_CHROMEOS)
+#include "chrome/browser/ui/ash/session_controller_client.h"
 #include "chrome/browser/ui/ash/system_tray_client.h"
+#include "chrome/browser/ui/ash/volume_controller.h"
+#include "chrome/browser/ui/ash/vpn_list_forwarder.h"
 #include "chrome/browser/ui/views/select_file_dialog_extension.h"
 #include "chrome/browser/ui/views/select_file_dialog_extension_factory.h"
 #endif  // defined(OS_CHROMEOS)
 
-namespace {
-
-void RegisterIMEDriver() {
-  // Instantiate the IME driver and register it to the UI service.
-  DCHECK_CURRENTLY_ON(content::BrowserThread::UI);
-  ui::mojom::IMEDriverPtr ime_driver_ptr;
-  mojo::MakeStrongBinding(base::MakeUnique<IMEDriver>(),
-                          GetProxy(&ime_driver_ptr));
-  ui::mojom::IMERegistrarPtr ime_registrar;
-  content::ServiceManagerConnection::GetForProcess()
-      ->GetConnector()
-      ->ConnectToInterface("ui", &ime_registrar);
-  ime_registrar->RegisterDriver(std::move(ime_driver_ptr));
-}
-
-}  // namespace
-
 ChromeBrowserMainExtraPartsAsh::ChromeBrowserMainExtraPartsAsh() {}
 
 ChromeBrowserMainExtraPartsAsh::~ChromeBrowserMainExtraPartsAsh() {}
@@ -62,14 +45,18 @@ void ChromeBrowserMainExtraPartsAsh::PreProfileInit() {
   if (chrome::IsRunningInMash()) {
     immersive_context_ = base::MakeUnique<ImmersiveContextMus>();
     immersive_handler_factory_ = base::MakeUnique<ImmersiveHandlerFactoryMus>();
-    // IME driver must be available at login screen, so initialize before
-    // profile.
-    RegisterIMEDriver();
   }
 
 #if defined(OS_CHROMEOS)
+  // TODO(xiyuan): Update after SesssionStateDelegate is deprecated.
+  if (chrome::IsRunningInMash())
+    session_controller_client_ = base::MakeUnique<SessionControllerClient>();
+
   // Must be available at login screen, so initialize before profile.
   system_tray_client_ = base::MakeUnique<SystemTrayClient>();
+  new_window_client_ = base::MakeUnique<ChromeNewWindowClient>();
+  volume_controller_ = base::MakeUnique<VolumeController>();
+  vpn_list_forwarder_ = base::MakeUnique<VpnListForwarder>();
 
   // For OS_CHROMEOS, virtual keyboard needs to be initialized before profile
   // initialized. Otherwise, virtual keyboard extension will not load at login
@@ -89,6 +76,9 @@ void ChromeBrowserMainExtraPartsAsh::PostProfileInit() {
     chrome_launcher_controller_mus_->Init();
   }
 
+  cast_config_client_media_router_ =
+      base::MakeUnique<CastConfigClientMediaRouter>();
+
   if (!ash::Shell::HasInstance())
     return;
 
@@ -102,7 +92,12 @@ void ChromeBrowserMainExtraPartsAsh::PostProfileInit() {
 
 void ChromeBrowserMainExtraPartsAsh::PostMainMessageLoopRun() {
 #if defined(OS_CHROMEOS)
+  vpn_list_forwarder_.reset();
+  volume_controller_.reset();
+  new_window_client_.reset();
   system_tray_client_.reset();
+  cast_config_client_media_router_.reset();
+  session_controller_client_.reset();
 #endif
   chrome::CloseAsh();
 }
