@@ -69,10 +69,6 @@ class AppInfoView : public views::View {
               const base::string16& description,
               const gfx::ImageFamily& icon);
 
-  // Updates the title/description of the web app.
-  void UpdateText(const base::string16& title,
-                  const base::string16& description);
-
   // Updates the icon of the web app.
   void UpdateIcon(const gfx::ImageFamily& image);
 
@@ -170,14 +166,6 @@ void AppInfoView::SetupLayout() {
   }
 }
 
-void AppInfoView::UpdateText(const base::string16& title,
-                             const base::string16& description) {
-  title_->SetText(title);
-  PrepareDescriptionLabel(description);
-
-  SetupLayout();
-}
-
 void AppInfoView::UpdateIcon(const gfx::ImageFamily& image) {
   // Get an icon at the desired preview size (scaling from a larger image if
   // none is available at that exact size).
