@@ -290,7 +290,7 @@ base::string16 DesktopMediaPickerDialogView::GetWindowTitle() const {
 bool DesktopMediaPickerDialogView::IsDialogButtonEnabled(
     ui::DialogButton button) const {
   if (button == ui::DIALOG_BUTTON_OK)
-    return list_views_[pane_->selected_tab_index()]->GetSelection() != nullptr;
+    return list_views_[pane_->GetSelectedTabIndex()]->GetSelection() != nullptr;
   return true;
 }
 
@@ -315,7 +315,7 @@ views::View* DesktopMediaPickerDialogView::CreateExtraView() {
 
 bool DesktopMediaPickerDialogView::Accept() {
   DesktopMediaSourceView* selection =
-      list_views_[pane_->selected_tab_index()]->GetSelection();
+      list_views_[pane_->GetSelectedTabIndex()]->GetSelection();
 
   // Ok button should only be enabled when a source is selected.
   DCHECK(selection);
@@ -373,16 +373,16 @@ void DesktopMediaPickerDialogView::OnMediaListRowsChanged() {
 
 DesktopMediaListView* DesktopMediaPickerDialogView::GetMediaListViewForTesting()
     const {
-  return list_views_[pane_->selected_tab_index()];
+  return list_views_[pane_->GetSelectedTabIndex()];
 }
 
 DesktopMediaSourceView*
 DesktopMediaPickerDialogView::GetMediaSourceViewForTesting(int index) const {
-  if (list_views_[pane_->selected_tab_index()]->child_count() <= index)
+  if (list_views_[pane_->GetSelectedTabIndex()]->child_count() <= index)
     return nullptr;
 
   return reinterpret_cast<DesktopMediaSourceView*>(
-      list_views_[pane_->selected_tab_index()]->child_at(index));
+      list_views_[pane_->GetSelectedTabIndex()]->child_at(index));
 }
 
 views::Checkbox* DesktopMediaPickerDialogView::GetCheckboxForTesting() const {
