@@ -28,14 +28,13 @@
 #include "ui/base/hit_test.h"
 #include "ui/events/event_handler.h"
 #include "ui/gfx/font_list.h"
-#include "ui/views/controls/menu/menu_model_adapter.h"
+#include "ui/native_theme/native_theme_dark_aura.h"
 #include "ui/views/controls/menu/menu_runner.h"
 #include "ui/views/widget/native_widget.h"
 
 #if defined(OS_CHROMEOS)
 #include "ash/common/session/session_state_delegate.h"  // nogncheck
 #include "ash/common/wm_shell.h"  // nogncheck
-#include "ui/native_theme/native_theme_dark_aura.h"  // nogncheck
 #endif
 
 #if defined(OS_LINUX)
@@ -46,11 +45,6 @@
 #include "ui/views/widget/desktop_aura/x11_desktop_handler.h"
 #endif
 
-#if defined(OS_WIN)
-#include "base/win/windows_version.h"
-#include "ui/native_theme/native_theme_dark_win.h"
-#endif
-
 ////////////////////////////////////////////////////////////////////////////////
 // BrowserFrame, public:
 
@@ -147,16 +141,6 @@ bool BrowserFrame::UseCustomFrame() const {
   return native_browser_frame_->UseCustomFrame();
 }
 
-bool BrowserFrame::CustomDrawSystemTitlebar() const {
-#if defined(OS_WIN)
-  return base::CommandLine::ForCurrentProcess()->HasSwitch(
-             switches::kWindows10CustomTitlebar) &&
-         base::win::GetVersion() >= base::win::VERSION_WIN10;
-#else
-  return false;
-#endif
-}
-
 bool BrowserFrame::ShouldSaveWindowPlacement() const {
   return native_browser_frame_->ShouldSaveWindowPlacement();
 }
@@ -166,6 +150,16 @@ void BrowserFrame::GetWindowPlacement(gfx::Rect* bounds,
   return native_browser_frame_->GetWindowPlacement(bounds, show_state);
 }
 
+bool BrowserFrame::PreHandleKeyboardEvent(
+    const content::NativeWebKeyboardEvent& event) {
+  return native_browser_frame_->PreHandleKeyboardEvent(event);
+}
+
+bool BrowserFrame::HandleKeyboardEvent(
+    const content::NativeWebKeyboardEvent& event) {
+  return native_browser_frame_->HandleKeyboardEvent(event);
+}
+
 void BrowserFrame::OnBrowserViewInitViewsComplete() {
   browser_frame_view_->OnBrowserViewInitViewsComplete();
 }
@@ -195,16 +189,14 @@ const ui::ThemeProvider* BrowserFrame::GetThemeProvider() const {
 }
 
 const ui::NativeTheme* BrowserFrame::GetNativeTheme() const {
+#if defined(OS_WIN) || defined(OS_CHROMEOS)
   if (browser_view_->browser()->profile()->GetProfileType() ==
           Profile::INCOGNITO_PROFILE &&
       ThemeServiceFactory::GetForProfile(browser_view_->browser()->profile())
           ->UsingDefaultTheme()) {
-#if defined(OS_WIN)
-    return ui::NativeThemeDarkWin::instance();
-#elif defined(OS_CHROMEOS)
     return ui::NativeThemeDarkAura::instance();
-#endif
   }
+#endif
   return views::Widget::GetNativeTheme();
 }
 
@@ -239,7 +231,7 @@ void BrowserFrame::OnNativeWidgetActivationChanged(bool active) {
 
 void BrowserFrame::OnNativeWidgetWorkspaceChanged() {
   chrome::SaveWindowWorkspace(browser_view_->browser(), GetWorkspace());
-#if defined(OS_LINUX) && !defined(OS_CHROMEOS)
+#if !defined(OS_CHROMEOS) && defined(USE_X11)
   BrowserList::MoveBrowsersInWorkspaceToFront(
       views::X11DesktopHandler::get()->GetWorkspace());
 #endif
@@ -260,13 +252,11 @@ void BrowserFrame::ShowContextMenuForView(views::View* source,
   views::View::ConvertPointFromScreen(non_client_view(), &point_in_view_coords);
   int hit_test = non_client_view()->NonClientHitTest(point_in_view_coords);
   if (hit_test == HTCAPTION || hit_test == HTNOWHERE) {
-    menu_model_adapter_.reset(new views::MenuModelAdapter(
-        GetSystemMenuModel(),
-        base::Bind(&BrowserFrame::OnMenuClosed, base::Unretained(this))));
     menu_runner_.reset(new views::MenuRunner(
-        menu_model_adapter_->CreateMenu(), views::MenuRunner::HAS_MNEMONICS |
-                                               views::MenuRunner::CONTEXT_MENU |
-                                               views::MenuRunner::ASYNC));
+        GetSystemMenuModel(),
+        views::MenuRunner::HAS_MNEMONICS | views::MenuRunner::CONTEXT_MENU |
+            views::MenuRunner::ASYNC,
+        base::Bind(&BrowserFrame::OnMenuClosed, base::Unretained(this))));
     menu_runner_->RunMenuAt(source->GetWidget(), nullptr,
                             gfx::Rect(p, gfx::Size(0, 0)),
                             views::MENU_ANCHOR_TOPLEFT, source_type);
@@ -298,6 +288,5 @@ views::View* BrowserFrame::GetNewAvatarMenuButton() {
 }
 
 void BrowserFrame::OnMenuClosed() {
-  menu_model_adapter_.reset();
   menu_runner_.reset();
 }
