@@ -30,11 +30,11 @@ ui::Window* CreateMusWindow(BrowserView* browser_view) {
       GetWidgetParamsImpl(browser_view), &properties);
   const std::string chrome_app_id(extension_misc::kChromeAppId);
   // Indicates mash shouldn't handle immersive, rather we will.
-  properties[ui::mojom::WindowManager::kDisableImmersive_Property] =
+  properties[ui::mojom::WindowManager::kDisableImmersive_InitProperty] =
       mojo::ConvertTo<std::vector<uint8_t>>(true);
   properties[ui::mojom::WindowManager::kAppID_Property] =
       mojo::ConvertTo<std::vector<uint8_t>>(chrome_app_id);
-  return views::WindowManagerConnection::Get()->NewWindow(properties);
+  return views::WindowManagerConnection::Get()->NewTopLevelWindow(properties);
 }
 
 }  // namespace
@@ -43,7 +43,7 @@ BrowserFrameMus::BrowserFrameMus(BrowserFrame* browser_frame,
                                  BrowserView* browser_view)
     : views::NativeWidgetMus(browser_frame,
                              CreateMusWindow(browser_view),
-                             ui::mojom::SurfaceType::DEFAULT),
+                             ui::mojom::CompositorFrameSinkType::DEFAULT),
       browser_view_(browser_view) {}
 
 BrowserFrameMus::~BrowserFrameMus() {}
@@ -72,6 +72,16 @@ void BrowserFrameMus::GetWindowPlacement(
   *show_state = ui::SHOW_STATE_NORMAL;
 }
 
+bool BrowserFrameMus::PreHandleKeyboardEvent(
+    const content::NativeWebKeyboardEvent& event) {
+  return false;
+}
+
+bool BrowserFrameMus::HandleKeyboardEvent(
+    const content::NativeWebKeyboardEvent& event) {
+  return false;
+}
+
 int BrowserFrameMus::GetMinimizeButtonOffset() const {
   return 0;
 }
