@@ -17,16 +17,10 @@ class TabIconView;
 class WebAppLeftHeaderView;
 
 namespace ash {
-class FrameCaptionButton;
 class FrameCaptionButtonContainerView;
 class HeaderPainter;
 }
 
-namespace views {
-class ImageButton;
-class ToggleImageButton;
-}
-
 class BrowserNonClientFrameViewAsh : public BrowserNonClientFrameView,
                                      public ash::ShellObserver,
                                      public TabIconViewModel {
@@ -59,7 +53,7 @@ class BrowserNonClientFrameViewAsh : public BrowserNonClientFrameView,
   void OnPaint(gfx::Canvas* canvas) override;
   void Layout() override;
   const char* GetClassName() const override;
-  void GetAccessibleState(ui::AXViewState* state) override;
+  void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
   gfx::Size GetMinimumSize() const override;
   void ChildPreferredSizeChanged(views::View* child) override;
 
