@@ -19,7 +19,9 @@
 #include "chrome/browser/ui/views/tabs/tab.h"
 #include "chrome/browser/ui/views/tabs/tab_strip.h"
 #include "chrome/browser/ui/views/toolbar/toolbar_view.h"
+#include "chrome/browser/win/titlebar_config.h"
 #include "chrome/grit/theme_resources.h"
+#include "content/public/browser/web_contents.h"
 #include "skia/ext/image_operations.h"
 #include "ui/base/resource/resource_bundle_win.h"
 #include "ui/base/theme_provider.h"
@@ -89,6 +91,8 @@ base::win::ScopedHICON CreateHICONFromSkBitmapSizedTo(
 GlassBrowserFrameView::GlassBrowserFrameView(BrowserFrame* frame,
                                              BrowserView* browser_view)
     : BrowserNonClientFrameView(frame, browser_view),
+      window_icon_(nullptr),
+      window_title_(nullptr),
       profile_switcher_(this),
       minimize_button_(nullptr),
       maximize_button_(nullptr),
@@ -96,15 +100,35 @@ GlassBrowserFrameView::GlassBrowserFrameView(BrowserFrame* frame,
       close_button_(nullptr),
       throbber_running_(false),
       throbber_frame_(0) {
-  if (browser_view->ShouldShowWindowIcon())
+  // We initialize all fields despite some of them being unused in some modes,
+  // since it's possible for modes to flip dynamically (e.g. if the user enables
+  // a high-contrast theme). Throbber icons are only used when ShowSystemIcon()
+  // is true. Everything else here is only used when
+  // ShouldCustomDrawSystemTitlebar() is true.
+
+  if (browser_view->ShouldShowWindowIcon()) {
     InitThrobberIcons();
 
-  if (frame->CustomDrawSystemTitlebar()) {
-    minimize_button_ = CreateCaptionButton(VIEW_ID_MINIMIZE_BUTTON);
-    maximize_button_ = CreateCaptionButton(VIEW_ID_MAXIMIZE_BUTTON);
-    restore_button_ = CreateCaptionButton(VIEW_ID_RESTORE_BUTTON);
-    close_button_ = CreateCaptionButton(VIEW_ID_CLOSE_BUTTON);
+    window_icon_ = new TabIconView(this, nullptr);
+    window_icon_->set_is_light(true);
+    window_icon_->set_id(VIEW_ID_WINDOW_ICON);
+    AddChildView(window_icon_);
   }
+
+  if (browser_view->ShouldShowWindowTitle()) {
+    window_title_ =
+        new views::Label(browser_view->GetWindowTitle(),
+                         gfx::FontList(BrowserFrame::GetTitleFontList()));
+    window_title_->SetSubpixelRenderingEnabled(false);
+    window_title_->SetHorizontalAlignment(gfx::ALIGN_LEFT);
+    window_title_->set_id(VIEW_ID_WINDOW_TITLE);
+    AddChildView(window_title_);
+  }
+
+  minimize_button_ = CreateCaptionButton(VIEW_ID_MINIMIZE_BUTTON);
+  maximize_button_ = CreateCaptionButton(VIEW_ID_MAXIMIZE_BUTTON);
+  restore_button_ = CreateCaptionButton(VIEW_ID_RESTORE_BUTTON);
+  close_button_ = CreateCaptionButton(VIEW_ID_CLOSE_BUTTON);
 }
 
 GlassBrowserFrameView::~GlassBrowserFrameView() {
@@ -116,7 +140,7 @@ GlassBrowserFrameView::~GlassBrowserFrameView() {
 gfx::Rect GlassBrowserFrameView::GetBoundsForTabStrip(
     views::View* tabstrip) const {
   const int x =
-      incognito_bounds_.right() + GetLayoutInsets(AVATAR_ICON).right();
+      incognito_bounds_.right() + GetLayoutConstant(AVATAR_ICON_PADDING);
   int end_x = width() - ClientBorderThickness(false);
   if (!CaptionButtonsOnLeadingEdge()) {
     end_x = std::min(MinimizeButtonX(), end_x) -
@@ -151,6 +175,12 @@ int GlassBrowserFrameView::GetThemeBackgroundXInset() const {
 }
 
 void GlassBrowserFrameView::UpdateThrobber(bool running) {
+  if (ShowCustomIcon())
+    window_icon_->Update();
+
+  if (!ShowSystemIcon())
+    return;
+
   if (throbber_running_) {
     if (running) {
       DisplayNextThrobberFrame();
@@ -229,7 +259,7 @@ bool HitTestCaptionButton(Windows10CaptionButton* button,
 int GlassBrowserFrameView::NonClientHitTest(const gfx::Point& point) {
   // For app windows and popups without a custom titlebar we haven't customized
   // the frame at all so Windows can figure it out.
-  if (!frame()->CustomDrawSystemTitlebar() &&
+  if (!ShouldCustomDrawSystemTitlebar() &&
       !browser_view()->IsBrowserTypeNormal())
     return HTNOWHERE;
 
@@ -312,6 +342,16 @@ int GlassBrowserFrameView::NonClientHitTest(const gfx::Point& point) {
   return (window_component == HTNOWHERE) ? HTCAPTION : window_component;
 }
 
+void GlassBrowserFrameView::UpdateWindowIcon() {
+  if (ShowCustomIcon() && !frame()->IsFullscreen())
+    window_icon_->SchedulePaint();
+}
+
+void GlassBrowserFrameView::UpdateWindowTitle() {
+  if (ShowCustomTitle() && !frame()->IsFullscreen())
+    window_title_->SchedulePaint();
+}
+
 void GlassBrowserFrameView::ButtonPressed(views::Button* sender,
                                           const ui::Event& event) {
   if (sender == minimize_button_)
@@ -324,6 +364,18 @@ void GlassBrowserFrameView::ButtonPressed(views::Button* sender,
     frame()->Close();
 }
 
+bool GlassBrowserFrameView::ShouldTabIconViewAnimate() const {
+  DCHECK(ShowCustomIcon());
+  const content::WebContents* current_tab =
+      browser_view()->GetActiveWebContents();
+  return current_tab && current_tab->IsLoading();
+}
+
+gfx::ImageSkia GlassBrowserFrameView::GetFaviconForTabIconView() {
+  DCHECK(ShowCustomIcon());
+  return frame()->widget_delegate()->GetWindowIcon();
+}
+
 bool GlassBrowserFrameView::IsMaximized() const {
   return frame()->IsMaximized();
 }
@@ -332,7 +384,7 @@ bool GlassBrowserFrameView::IsMaximized() const {
 // GlassBrowserFrameView, views::View overrides:
 
 void GlassBrowserFrameView::OnPaint(gfx::Canvas* canvas) {
-  if (frame()->CustomDrawSystemTitlebar())
+  if (ShouldCustomDrawSystemTitlebar())
     PaintTitlebar(canvas);
   if (!browser_view()->IsTabStripVisible())
     return;
@@ -343,10 +395,11 @@ void GlassBrowserFrameView::OnPaint(gfx::Canvas* canvas) {
 }
 
 void GlassBrowserFrameView::Layout() {
-  if (frame()->CustomDrawSystemTitlebar()) {
+  if (ShouldCustomDrawSystemTitlebar()) {
     // The profile switcher button depends on the caption button layout, so this
     // must be called prior to LayoutProfileSwitcher().
     LayoutCaptionButtons();
+    LayoutTitleBar();
   }
   if (browser_view()->IsRegularOrGuestSession())
     LayoutProfileSwitcher();
@@ -371,7 +424,7 @@ void GlassBrowserFrameView::UpdateProfileIcons() {
 // views::NonClientFrameView:
 bool GlassBrowserFrameView::DoesIntersectRect(const views::View* target,
                                               const gfx::Rect& rect) const {
-  if (frame()->CustomDrawSystemTitlebar())
+  if (ShouldCustomDrawSystemTitlebar())
     return BrowserNonClientFrameView::DoesIntersectRect(target, rect);
 
   // TODO(bsep): This override has "dead zones" where you can't click on the
@@ -450,9 +503,8 @@ int GlassBrowserFrameView::TitlebarHeight(bool restored) const {
     return 0;
   // The titlebar's actual height is the same in restored and maximized, but
   // some of it is above the screen in maximized mode. See the comment in
-  // FrameTopBorderThickness().
-  return TitlebarMaximizedVisualHeight() +
-         display::win::ScreenWin::GetSystemMetricsInDIP(SM_CYSIZEFRAME);
+  // FrameTopBorderThicknessPx().
+  return TitlebarMaximizedVisualHeight() + FrameTopBorderThickness(false);
 }
 
 int GlassBrowserFrameView::WindowTopY() const {
@@ -472,9 +524,8 @@ int GlassBrowserFrameView::MinimizeButtonX() const {
   // need to ask Windows where the minimize button is.
   // TODO(bsep): Ideally these would always be the same. When we're always
   // custom drawing the caption buttons, remove GetMinimizeButtonOffset().
-  return frame()->CustomDrawSystemTitlebar()
-             ? minimize_button_->x()
-             : frame()->GetMinimizeButtonOffset();
+  return ShouldCustomDrawSystemTitlebar() ? minimize_button_->x()
+                                          : frame()->GetMinimizeButtonOffset();
 }
 
 bool GlassBrowserFrameView::IsToolbarVisible() const {
@@ -486,7 +537,26 @@ bool GlassBrowserFrameView::CaptionButtonsOnLeadingEdge() const {
   // Because we don't set WS_EX_LAYOUTRTL (which would conflict with Chrome's
   // own RTL layout logic), Windows always draws the caption buttons on the
   // right, even when we want to be RTL. See crbug.com/560619.
-  return !frame()->CustomDrawSystemTitlebar() && base::i18n::IsRTL();
+  return !ShouldCustomDrawSystemTitlebar() && base::i18n::IsRTL();
+}
+
+bool GlassBrowserFrameView::ShowCustomIcon() const {
+  return ShouldCustomDrawSystemTitlebar() &&
+         browser_view()->ShouldShowWindowIcon();
+}
+
+bool GlassBrowserFrameView::ShowCustomTitle() const {
+  return ShouldCustomDrawSystemTitlebar() &&
+         browser_view()->ShouldShowWindowTitle();
+}
+
+bool GlassBrowserFrameView::ShowSystemIcon() const {
+  return !ShouldCustomDrawSystemTitlebar() &&
+         browser_view()->ShouldShowWindowIcon();
+}
+
+SkColor GlassBrowserFrameView::GetTitlebarColor() const {
+  return GetThemeProvider()->GetColor(ThemeProperties::COLOR_FRAME);
 }
 
 Windows10CaptionButton* GlassBrowserFrameView::CreateCaptionButton(
@@ -498,25 +568,59 @@ Windows10CaptionButton* GlassBrowserFrameView::CreateCaptionButton(
 }
 
 void GlassBrowserFrameView::PaintTitlebar(gfx::Canvas* canvas) const {
-  SkColor frame_color = 0xFFCCCCCC;
   gfx::Rect tabstrip_bounds = GetBoundsForTabStrip(browser_view()->tabstrip());
 
+  SkPaint paint;
   gfx::ScopedCanvas scoped_canvas(canvas);
   float scale = canvas->UndoDeviceScaleFactor();
   // This is the pixel-accurate version of WindowTopY(). Scaling the DIP values
-  // here compounds precision error, which exposes the native Windows caption
-  // buttons we need to draw over. (see the comment in
-  // BrowserDesktopWindowTreeHostWin::UpdateDWMFrame()).
+  // here compounds precision error, which exposes unpainted client area.
   const int y = IsMaximized() ? FrameTopBorderThicknessPx(false) : 1;
-  SkPaint paint;
-  paint.setColor(frame_color);
-  canvas->DrawRect(
-      gfx::RectF(0, y, width() * scale, tabstrip_bounds.bottom() * scale - y),
-      paint);
 
-  // The 1 pixel line at the top is drawn by Windows when we leave that section
-  // of the window blank because we have called DwmExtendFrameIntoClientArea()
-  // inside BrowserDesktopWindowTreeHostWin::UpdateDWMFrame().
+  // Draw the top of the accent border.
+  //
+  // We let the DWM do this for the other sides of the window by insetting the
+  // client area to leave nonclient area available. However, along the top
+  // window edge, we have to have zero nonclient area or the DWM will draw a
+  // full native titlebar outside our client area. See
+  // BrowserDesktopWindowTreeHostWin::GetClientAreaInsets().
+  //
+  // We could ask the DWM to draw the top accent border in the client area (by
+  // calling DwmExtendFrameIntoClientArea() in
+  // BrowserDesktopWindowTreeHostWin::UpdateDWMFrame()), but this requires
+  // that we leave part of the client surface transparent. If we draw this
+  // ourselves, we can make the client surface fully opaque and avoid the
+  // power consumption needed for DWM to blend the window contents.
+  //
+  // So the accent border also has to be opaque, but native inactive borders
+  // are #565656 with 80% alpha. We copy Edge (which also custom-draws its top
+  // border) and use #A2A2A2 instead.
+  constexpr SkColor inactive_border_color = 0xFFA2A2A2;
+  paint.setColor(
+      ShouldPaintAsActive()
+          ? GetThemeProvider()->GetColor(ThemeProperties::COLOR_ACCENT_BORDER)
+          : inactive_border_color);
+  canvas->DrawRect(gfx::RectF(0, 0, width() * scale, y), paint);
+
+  const gfx::Rect titlebar_rect = gfx::ToEnclosingRect(
+      gfx::RectF(0, y, width() * scale, tabstrip_bounds.bottom() * scale - y));
+  // Paint the titlebar first so we have a background if an area isn't covered
+  // by the theme image.
+  paint.setColor(GetTitlebarColor());
+  canvas->DrawRect(titlebar_rect, paint);
+  const gfx::ImageSkia frame_image = GetFrameImage();
+  if (!frame_image.isNull()) {
+    canvas->TileImageInt(frame_image, 0, 0, scale, scale, titlebar_rect.x(),
+                         titlebar_rect.y(), titlebar_rect.width(),
+                         titlebar_rect.height());
+  }
+  const gfx::ImageSkia frame_overlay_image = GetFrameOverlayImage();
+  if (!frame_overlay_image.isNull()) {
+    canvas->DrawImageInt(frame_overlay_image, 0, 0, frame_overlay_image.width(),
+                         frame_overlay_image.height(), titlebar_rect.x(),
+                         titlebar_rect.y(), frame_overlay_image.width() * scale,
+                         frame_overlay_image.height() * scale, true);
+  }
 }
 
 void GlassBrowserFrameView::PaintToolbarBackground(gfx::Canvas* canvas) const {
@@ -550,7 +654,7 @@ void GlassBrowserFrameView::PaintToolbarBackground(gfx::Canvas* canvas) const {
   gfx::Rect tabstrip_bounds(GetBoundsForTabStrip(browser_view()->tabstrip()));
   tabstrip_bounds.set_x(GetMirroredXForRect(tabstrip_bounds));
   canvas->sk_canvas()->clipRect(gfx::RectToSkRect(tabstrip_bounds),
-                                SkRegion::kDifference_Op);
+                                kDifference_SkClipOp);
   separator_rect.set_y(tabstrip_bounds.bottom());
   BrowserView::Paint1pxHorizontalLine(canvas, GetToolbarTopSeparatorColor(),
                                       separator_rect, true);
@@ -635,7 +739,7 @@ void GlassBrowserFrameView::LayoutProfileSwitcher() {
 }
 
 void GlassBrowserFrameView::LayoutIncognitoIcon() {
-  const gfx::Insets insets(GetLayoutInsets(AVATAR_ICON));
+  const int pad = GetLayoutConstant(AVATAR_ICON_PADDING);
   const gfx::Size size(GetIncognitoAvatarIcon().size());
   int x = ClientBorderThickness(false);
   // In RTL, the icon needs to start after the caption buttons.
@@ -645,16 +749,48 @@ void GlassBrowserFrameView::LayoutIncognitoIcon() {
                                      kProfileSwitcherButtonOffset)
                                   : 0);
   }
-  const int bottom = GetTopInset(false) + browser_view()->GetTabStripHeight() -
-                     insets.bottom();
-  incognito_bounds_.SetRect(x + (profile_indicator_icon() ? insets.left() : 0),
-                            bottom - size.height(),
-                            profile_indicator_icon() ? size.width() : 0,
-                            size.height());
+  const int bottom =
+      GetTopInset(false) + browser_view()->GetTabStripHeight() - pad;
+  incognito_bounds_.SetRect(
+      x + (profile_indicator_icon() ? pad : 0), bottom - size.height(),
+      profile_indicator_icon() ? size.width() : 0, size.height());
   if (profile_indicator_icon())
     profile_indicator_icon()->SetBoundsRect(incognito_bounds_);
 }
 
+void GlassBrowserFrameView::LayoutTitleBar() {
+  if (!ShowCustomIcon() && !ShowCustomTitle())
+    return;
+
+  gfx::Rect window_icon_bounds;
+  const int icon_size =
+      display::win::ScreenWin::GetSystemMetricsInDIP(SM_CYSMICON);
+  constexpr int kIconMaximizedLeftMargin = 2;
+  const int titlebar_visual_height =
+      IsMaximized() ? TitlebarMaximizedVisualHeight() : TitlebarHeight(false);
+  // Don't include the area above the screen when maximized. However it only
+  // looks centered if we start from y=0 when restored.
+  const int window_top = IsMaximized() ? WindowTopY() : 0;
+  int x = IsMaximized()
+              ? kIconMaximizedLeftMargin
+              : display::win::ScreenWin::GetSystemMetricsInDIP(SM_CXSIZEFRAME);
+  const int y = window_top + (titlebar_visual_height - icon_size) / 2;
+  window_icon_bounds = gfx::Rect(x, y, icon_size, icon_size);
+
+  if (ShowCustomIcon()) {
+    window_icon_->SetBoundsRect(window_icon_bounds);
+    constexpr int kIconTitleSpacing = 5;
+    x = window_icon_bounds.right() + kIconTitleSpacing;
+  }
+
+  if (ShowCustomTitle()) {
+    window_title_->SetText(browser_view()->GetWindowTitle());
+    const int max_text_width = std::max(0, MinimizeButtonX() - x);
+    window_title_->SetBounds(x, window_icon_bounds.y(), max_text_width,
+                             window_icon_bounds.height());
+  }
+}
+
 void GlassBrowserFrameView::LayoutCaptionButton(Windows10CaptionButton* button,
                                                 int previous_button_x) {
   gfx::Size button_size = button->GetPreferredSize();
@@ -683,7 +819,7 @@ void GlassBrowserFrameView::LayoutClientView() {
 gfx::Insets GlassBrowserFrameView::GetClientAreaInsets(bool restored) const {
   if (!browser_view()->IsTabStripVisible()) {
     const int top =
-        frame()->CustomDrawSystemTitlebar() ? TitlebarHeight(restored) : 0;
+        ShouldCustomDrawSystemTitlebar() ? TitlebarHeight(restored) : 0;
     return gfx::Insets(top, 0, 0, 0);
   }
 
@@ -702,6 +838,7 @@ gfx::Rect GlassBrowserFrameView::CalculateClientAreaBounds() const {
 }
 
 void GlassBrowserFrameView::StartThrobber() {
+  DCHECK(ShowSystemIcon());
   if (!throbber_running_) {
     throbber_running_ = true;
     throbber_frame_ = 0;
@@ -713,6 +850,7 @@ void GlassBrowserFrameView::StartThrobber() {
 }
 
 void GlassBrowserFrameView::StopThrobber() {
+  DCHECK(ShowSystemIcon());
   if (throbber_running_) {
     throbber_running_ = false;
 
@@ -721,23 +859,20 @@ void GlassBrowserFrameView::StopThrobber() {
     HICON small_icon = nullptr;
     HICON big_icon = nullptr;
 
-    // Check if hosted BrowserView has a window icon to use.
-    if (browser_view()->ShouldShowWindowIcon()) {
-      gfx::ImageSkia icon = browser_view()->GetWindowIcon();
-      if (!icon.isNull()) {
-        // Keep previous icons alive as long as they are referenced by the HWND.
-        previous_small_icon = std::move(small_window_icon_);
-        previous_big_icon = std::move(big_window_icon_);
+    gfx::ImageSkia icon = browser_view()->GetWindowIcon();
+    if (!icon.isNull()) {
+      // Keep previous icons alive as long as they are referenced by the HWND.
+      previous_small_icon = std::move(small_window_icon_);
+      previous_big_icon = std::move(big_window_icon_);
 
-        // Take responsibility for eventually destroying the created icons.
-        small_window_icon_ = CreateHICONFromSkBitmapSizedTo(
-            icon, GetSystemMetrics(SM_CXSMICON), GetSystemMetrics(SM_CYSMICON));
-        big_window_icon_ = CreateHICONFromSkBitmapSizedTo(
-            icon, GetSystemMetrics(SM_CXICON), GetSystemMetrics(SM_CYICON));
+      // Take responsibility for eventually destroying the created icons.
+      small_window_icon_ = CreateHICONFromSkBitmapSizedTo(
+          icon, GetSystemMetrics(SM_CXSMICON), GetSystemMetrics(SM_CYSMICON));
+      big_window_icon_ = CreateHICONFromSkBitmapSizedTo(
+          icon, GetSystemMetrics(SM_CXICON), GetSystemMetrics(SM_CYICON));
 
-        small_icon = small_window_icon_.get();
-        big_icon = big_window_icon_.get();
-      }
+      small_icon = small_window_icon_.get();
+      big_icon = big_window_icon_.get();
     }
 
     // Fallback to class icon.
