@@ -13,7 +13,6 @@
 class LocationBarView;
 
 namespace ui {
-class KeyEvent;
 class LocatedEvent;
 }
 
@@ -37,6 +36,7 @@ class LocationIconView : public IconLabelBubbleView,
                       base::string16* tooltip) const override;
   SkColor GetTextColor() const override;
   bool OnActivate(const ui::Event& event) override;
+  void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
 
   // Whether we should show the tooltip for this icon or not.
   void set_show_tooltip(bool show_tooltip) { show_tooltip_ = show_tooltip; }
