@@ -20,7 +20,6 @@
 #include "ui/views/controls/image_view.h"
 #include "ui/views/view.h"
 
-class LocationBarView;
 class OmniboxPopupContentsView;
 
 namespace gfx {
@@ -50,7 +49,6 @@ class OmniboxResultView : public views::View,
 
   OmniboxResultView(OmniboxPopupContentsView* model,
                     int model_index,
-                    LocationBarView* location_bar_view,
                     const gfx::FontList& font_list);
   ~OmniboxResultView() override;
 
@@ -70,7 +68,7 @@ class OmniboxResultView : public views::View,
 
   // views::View:
   gfx::Size GetPreferredSize() const override;
-  void GetAccessibleState(ui::AXViewState* state) override;
+  void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
 
   ResultViewState GetState() const;
 
@@ -133,8 +131,6 @@ class OmniboxResultView : public views::View,
 
   gfx::ImageSkia GetIcon() const;
 
-  gfx::ImageSkia GetKeywordIcon() const;
-
   // Utility function for creating vector icons.
   gfx::ImageSkia GetVectorIcon(gfx::VectorIconId icon_id) const;
 
@@ -184,14 +180,10 @@ class OmniboxResultView : public views::View,
                               int text_type,
                               bool is_bold) const;
 
-  static int default_icon_size_;
-
   // This row's model and model index.
   OmniboxPopupContentsView* model_;
   size_t model_index_;
 
-  LocationBarView* location_bar_view_;
-
   const gfx::FontList font_list_;
   int font_height_;
 
