@@ -153,6 +153,10 @@ void OmniboxViewViews::Init() {
         GetFontList(), this, model(), location_bar_view_));
   }
 
+  // Override the default FocusableBorder from Textfield, since the
+  // LocationBarView will indicate the focus state.
+  SetBorder(views::NullBorder());
+
 #if defined(OS_CHROMEOS)
   chromeos::input_method::InputMethodManager::Get()->
       AddCandidateWindowObserver(this);
@@ -536,16 +540,6 @@ gfx::NativeView OmniboxViewViews::GetRelativeWindowForPopup() const {
   return GetWidget()->GetTopLevelWidget()->GetNativeView();
 }
 
-void OmniboxViewViews::SetGrayTextAutocompletion(const base::string16& input) {
-  if (location_bar_view_)
-    location_bar_view_->SetGrayTextAutocompletion(input);
-}
-
-base::string16 OmniboxViewViews::GetGrayTextAutocompletion() const {
-  return location_bar_view_ ?
-      location_bar_view_->GetGrayTextAutocompletion() : base::string16();
-}
-
 int OmniboxViewViews::GetWidth() const {
   return location_bar_view_ ? location_bar_view_->width() : 0;
 }
@@ -967,21 +961,6 @@ bool OmniboxViewViews::HandleKeyEvent(views::Textfield* textfield,
       model()->ClearKeyword();
       return true;
 
-    // Handle the right-arrow key for LTR text and the left-arrow key for RTL
-    // text if there is gray text that needs to be committed.
-    case ui::VKEY_RIGHT:
-      if (GetCursorPosition() == text().length() &&
-          GetTextDirection() == base::i18n::LEFT_TO_RIGHT) {
-        return model()->CommitSuggestedText();
-      }
-      break;
-    case ui::VKEY_LEFT:
-      if (GetCursorPosition() == text().length() &&
-          GetTextDirection() == base::i18n::RIGHT_TO_LEFT) {
-        return model()->CommitSuggestedText();
-      }
-      break;
-
     default:
       break;
   }
