@@ -47,7 +47,7 @@ void PlatformKeysCertificateSelector::Init() {
       new views::StyledLabel(text, nullptr /* no listener */));
 
   views::StyledLabel::RangeStyleInfo bold_style;
-  bold_style.font_style = gfx::Font::BOLD;
+  bold_style.weight = gfx::Font::Weight::BOLD;
   label->AddStyleRange(gfx::Range(offset, offset + name.size()), bold_style);
   CertificateSelector::InitWithText(std::move(label));
 }
