@@ -40,7 +40,9 @@
 #include "ash/wm/window_properties.h"             // nogncheck
 #include "ash/wm/window_util.h"                   // nogncheck
 #include "chrome/browser/ui/ash/ash_util.h"       // nogncheck
-#include "chrome/browser/ui/ash/property_util.h"  // nogncheck
+#include "ui/aura/client/aura_constants.h"
+#include "ui/base/resource/resource_bundle.h"
+#include "ui/gfx/image/image_skia.h"
 #endif  // defined(USE_ASH)
 
 #if defined(OS_WIN)
@@ -73,14 +75,14 @@ task_manager::TaskManagerTableModel* TaskManagerView::Show(Browser* browser) {
 
   g_task_manager_view = new TaskManagerView();
 
-  gfx::NativeWindow window =
+  gfx::NativeWindow context =
       browser ? browser->window()->GetNativeWindow() : nullptr;
 #if defined(USE_ASH)
-  if (!chrome::IsRunningInMash() && !window)
-    window = ash::wm::GetActiveWindow();
+  if (!chrome::IsRunningInMash() && !context)
+    context = ash::wm::GetActiveWindow();
 #endif
 
-  DialogDelegate::CreateDialogWidget(g_task_manager_view, window, nullptr);
+  DialogDelegate::CreateDialogWidget(g_task_manager_view, context, nullptr);
   g_task_manager_view->InitAlwaysOnTopState();
 
 #if defined(OS_WIN)
@@ -104,12 +106,12 @@ task_manager::TaskManagerTableModel* TaskManagerView::Show(Browser* browser) {
     focus_manager->SetFocusedView(g_task_manager_view->tab_table_);
 
 #if defined(USE_ASH)
-  aura::Window* aura_window =
-      g_task_manager_view->GetWidget()->GetNativeWindow();
-  property_util::SetIntProperty(aura_window, ash::kShelfItemTypeKey,
-                                ash::TYPE_DIALOG);
-  property_util::SetIntProperty(aura_window, ash::kShelfIconResourceIdKey,
-                                IDR_ASH_SHELF_ICON_TASK_MANAGER);
+  aura::Window* window = g_task_manager_view->GetWidget()->GetNativeWindow();
+  window->SetProperty<int>(ash::kShelfItemTypeKey, ash::TYPE_DIALOG);
+  ui::ResourceBundle& rb = ui::ResourceBundle::GetSharedInstance();
+  gfx::ImageSkia* icon = rb.GetImageSkiaNamed(IDR_ASH_SHELF_ICON_TASK_MANAGER);
+  // The new gfx::ImageSkia instance is owned by the window itself.
+  window->SetProperty(aura::client::kWindowIconKey, new gfx::ImageSkia(*icon));
 #endif
   return g_task_manager_view->table_model_.get();
 }
