@@ -7,7 +7,6 @@
 #include "base/macros.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/browser.h"
-#include "chrome/browser/ui/views/settings_api_bubble_helper_views.h"
 #include "chrome/common/pref_names.h"
 #include "chrome/grit/generated_resources.h"
 #include "components/prefs/pref_service.h"
@@ -184,8 +183,3 @@ int HomeButton::OnPerformDrop(const ui::DropTargetEvent& event) {
   }
   return ui::DragDropTypes::DRAG_NONE;
 }
-
-void HomeButton::NotifyClick(const ui::Event& event) {
-  ToolbarButton::NotifyClick(event);
-  extensions::MaybeShowExtensionControlledHomeNotification(browser_);
-}
