@@ -16,8 +16,6 @@
 #include "base/strings/string_util.h"
 #include "base/strings/utf_string_conversions.h"
 #include "chrome/browser/certificate_viewer.h"
-#include "chrome/browser/devtools/devtools_toggle_action.h"
-#include "chrome/browser/devtools/devtools_window.h"
 #include "chrome/browser/infobars/infobar_service.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/browser.h"
@@ -25,15 +23,14 @@
 #include "chrome/browser/ui/layout_constants.h"
 #include "chrome/browser/ui/views/collected_cookies_views.h"
 #include "chrome/browser/ui/views/website_settings/chosen_object_row.h"
+#include "chrome/browser/ui/views/website_settings/non_accessible_image_view.h"
 #include "chrome/browser/ui/views/website_settings/permission_selector_row.h"
 #include "chrome/browser/ui/website_settings/website_settings.h"
-#include "chrome/common/pref_names.h"
 #include "chrome/common/url_constants.h"
 #include "chrome/grit/chromium_strings.h"
 #include "chrome/grit/generated_resources.h"
 #include "chrome/grit/theme_resources.h"
 #include "components/content_settings/core/common/content_settings_types.h"
-#include "components/prefs/pref_service.h"
 #include "components/strings/grit/components_chromium_strings.h"
 #include "components/strings/grit/components_strings.h"
 #include "content/public/browser/browser_thread.h"
@@ -71,7 +68,8 @@ namespace {
 // to return a weak pointer from ShowPopup so callers can associate it with the
 // current window (or other context) and check if the popup they care about is
 // showing.
-bool is_popup_showing = false;
+WebsiteSettingsPopupView::PopupType g_shown_popup_type =
+    WebsiteSettingsPopupView::POPUP_NONE;
 
 // General constants -----------------------------------------------------------
 
@@ -129,8 +127,7 @@ class PopupHeaderView : public views::View {
   void SetSummary(const base::string16& summary_text);
 
   // Sets the security details for the current page.
-  void SetDetails(const base::string16& details_text,
-                  bool include_details_link);
+  void SetDetails(const base::string16& details_text);
 
   void AddResetDecisionsLabel();
 
@@ -142,7 +139,8 @@ class PopupHeaderView : public views::View {
   views::Label* summary_label_;
 
   // The label that displays the status of the identity check for this site.
-  // Includes a link to open the DevTools Security panel.
+  // Includes a link to open the Chrome Help Center article about connection
+  // security.
   views::StyledLabel* details_label_;
 
   // A container for the styled label with a link for resetting cert decisions.
@@ -222,7 +220,7 @@ PopupHeaderView::PopupHeaderView(
   const gfx::FontList& font_list = rb.GetFontListWithDelta(1);
   summary_label_ = new views::Label(base::string16(), font_list);
   summary_label_->SetMultiLine(true);
-  summary_label_->SetBorder(views::Border::CreateEmptyBorder(
+  summary_label_->SetBorder(views::CreateEmptyBorder(
       kHeaderPaddingTop - kHeaderPaddingForCloseButton, 0, 0, 0));
   layout->AddView(summary_label_, 1, 1, views::GridLayout::LEADING,
                   views::GridLayout::TRAILING);
@@ -272,33 +270,25 @@ void PopupHeaderView::SetSummary(const base::string16& summary_text) {
   summary_label_->SetText(summary_text);
 }
 
-void PopupHeaderView::SetDetails(const base::string16& details_text,
-                                 bool include_details_label_link) {
-  if (include_details_label_link) {
-    base::string16 details_link_text =
-        l10n_util::GetStringUTF16(IDS_WEBSITE_SETTINGS_DETAILS_LINK);
+void PopupHeaderView::SetDetails(const base::string16& details_text) {
+  std::vector<base::string16> subst;
+  subst.push_back(details_text);
+  subst.push_back(l10n_util::GetStringUTF16(IDS_LEARN_MORE));
 
-    std::vector<base::string16> subst;
-    subst.push_back(details_text);
-    subst.push_back(details_link_text);
+  std::vector<size_t> offsets;
 
-    std::vector<size_t> offsets;
+  base::string16 text = base::ReplaceStringPlaceholders(
+      base::ASCIIToUTF16("$1 $2"), subst, &offsets);
+  details_label_->SetText(text);
+  gfx::Range details_range(offsets[1], text.length());
 
-    base::string16 text = base::ReplaceStringPlaceholders(
-        base::ASCIIToUTF16("$1 $2"), subst, &offsets);
-    details_label_->SetText(text);
-    gfx::Range details_range(offsets[1], text.length());
+  views::StyledLabel::RangeStyleInfo link_style =
+      views::StyledLabel::RangeStyleInfo::CreateForLink();
+  if (!ui::MaterialDesignController::IsSecondaryUiMaterial())
+    link_style.font_style |= gfx::Font::FontStyle::UNDERLINE;
+  link_style.disable_line_wrapping = false;
 
-    views::StyledLabel::RangeStyleInfo link_style =
-        views::StyledLabel::RangeStyleInfo::CreateForLink();
-    if (!ui::MaterialDesignController::IsSecondaryUiMaterial())
-      link_style.font_style |= gfx::Font::FontStyle::UNDERLINE;
-    link_style.disable_line_wrapping = false;
-
-    details_label_->AddStyleRange(details_range, link_style);
-  } else {
-    details_label_->SetText(details_text);
-  }
+  details_label_->AddStyleRange(details_range, link_style);
 }
 
 void PopupHeaderView::AddResetDecisionsLabel() {
@@ -329,7 +319,7 @@ void PopupHeaderView::AddResetDecisionsLabel() {
 
   // Now that it contains a label, the container needs padding at the top.
   reset_decisions_label_container_->SetBorder(
-      views::Border::CreateEmptyBorder(8, 0, 0, 0));
+      views::CreateEmptyBorder(8, 0, 0, 0));
 
   InvalidateLayout();
 }
@@ -343,6 +333,7 @@ InternalPageInfoPopupView::InternalPageInfoPopupView(
     gfx::NativeView parent_window,
     const GURL& url)
     : BubbleDialogDelegateView(anchor_view, views::BubbleBorder::TOP_LEFT) {
+  g_shown_popup_type = WebsiteSettingsPopupView::POPUP_INTERNAL_PAGE;
   set_parent_window(parent_window);
 
   int text = IDS_PAGE_INFO_INTERNAL_PAGE;
@@ -354,7 +345,8 @@ InternalPageInfoPopupView::InternalPageInfoPopupView(
     text = IDS_PAGE_INFO_VIEW_SOURCE_PAGE;
     // view-source scheme uses the same icon as chrome:// pages.
     icon = IDR_PRODUCT_LOGO_16;
-  } else if (!url.SchemeIs(content::kChromeUIScheme)) {
+  } else if (!url.SchemeIs(content::kChromeUIScheme) &&
+             !url.SchemeIs(content::kChromeDevToolsScheme)) {
     NOTREACHED();
   }
 
@@ -366,7 +358,7 @@ InternalPageInfoPopupView::InternalPageInfoPopupView(
   SetLayoutManager(new views::BoxLayout(views::BoxLayout::kHorizontal, kSpacing,
                                         kSpacing, kSpacing));
   set_margins(gfx::Insets());
-  views::ImageView* icon_view = new views::ImageView();
+  views::ImageView* icon_view = new NonAccessibleImageView();
   ui::ResourceBundle& rb = ui::ResourceBundle::GetSharedInstance();
   icon_view->SetImage(rb.GetImageSkiaNamed(icon));
   AddChildView(icon_view);
@@ -394,7 +386,7 @@ views::NonClientFrameView* InternalPageInfoPopupView::CreateNonClientFrameView(
 }
 
 void InternalPageInfoPopupView::OnWidgetDestroying(views::Widget* widget) {
-  is_popup_showing = false;
+  g_shown_popup_type = WebsiteSettingsPopupView::POPUP_NONE;
 }
 
 int InternalPageInfoPopupView::GetDialogButtons() const {
@@ -415,11 +407,11 @@ void WebsiteSettingsPopupView::ShowPopup(
     Profile* profile,
     content::WebContents* web_contents,
     const GURL& url,
-    const security_state::SecurityStateModel::SecurityInfo& security_info) {
-  is_popup_showing = true;
+    const security_state::SecurityInfo& security_info) {
   gfx::NativeView parent_window =
       anchor_view ? nullptr : web_contents->GetNativeView();
   if (url.SchemeIs(content::kChromeUIScheme) ||
+      url.SchemeIs(content::kChromeDevToolsScheme) ||
       url.SchemeIs(extensions::kExtensionScheme) ||
       url.SchemeIs(content::kViewSourceScheme)) {
     // Use the concrete type so that |SetAnchorRect| can be called as a friend.
@@ -438,8 +430,9 @@ void WebsiteSettingsPopupView::ShowPopup(
 }
 
 // static
-bool WebsiteSettingsPopupView::IsPopupShowing() {
-  return is_popup_showing;
+WebsiteSettingsPopupView::PopupType
+WebsiteSettingsPopupView::GetShownPopupType() {
+  return g_shown_popup_type;
 }
 
 WebsiteSettingsPopupView::WebsiteSettingsPopupView(
@@ -448,7 +441,7 @@ WebsiteSettingsPopupView::WebsiteSettingsPopupView(
     Profile* profile,
     content::WebContents* web_contents,
     const GURL& url,
-    const security_state::SecurityStateModel::SecurityInfo& security_info)
+    const security_state::SecurityInfo& security_info)
     : content::WebContentsObserver(web_contents),
       BubbleDialogDelegateView(anchor_view, views::BubbleBorder::TOP_LEFT),
       profile_(profile),
@@ -459,11 +452,9 @@ WebsiteSettingsPopupView::WebsiteSettingsPopupView(
       cookie_dialog_link_(nullptr),
       permissions_view_(nullptr),
       weak_factory_(this) {
+  g_shown_popup_type = POPUP_WEBSITE_SETTINGS;
   set_parent_window(parent_window);
 
-  is_devtools_disabled_ =
-      profile->GetPrefs()->GetBoolean(prefs::kDevToolsDisabled);
-
   // Compensate for built-in vertical padding in the anchor view's image.
   set_anchor_view_insets(gfx::Insets(
       GetLayoutConstant(LOCATION_BAR_BUBBLE_ANCHOR_VERTICAL_INSET), 0));
@@ -527,7 +518,7 @@ void WebsiteSettingsPopupView::OnChosenObjectDeleted(
 }
 
 void WebsiteSettingsPopupView::OnWidgetDestroying(views::Widget* widget) {
-  is_popup_showing = false;
+  g_shown_popup_type = POPUP_NONE;
   presenter_->OnUIClosing();
 }
 
@@ -615,7 +606,7 @@ void WebsiteSettingsPopupView::SetCookieInfo(
     info.is_incognito =
         Profile::FromBrowserContext(web_contents()->GetBrowserContext())
             ->IsOffTheRecord();
-    views::ImageView* icon = new views::ImageView();
+    views::ImageView* icon = new NonAccessibleImageView();
     const gfx::Image& image = WebsiteSettingsUI::GetPermissionIcon(info);
     icon->SetImage(image.ToImageSkia());
     layout->AddView(
@@ -644,17 +635,14 @@ void WebsiteSettingsPopupView::SetCookieInfo(
 
 void WebsiteSettingsPopupView::SetPermissionInfo(
     const PermissionInfoList& permission_info_list,
-    const ChosenObjectInfoList& chosen_object_info_list) {
+    ChosenObjectInfoList chosen_object_info_list) {
   // When a permission is changed, WebsiteSettings::OnSitePermissionChanged()
   // calls this method with updated permissions. However, PermissionSelectorRow
   // will have already updated its state, so it's already reflected in the UI.
   // In addition, if a permission is set to the default setting, WebsiteSettings
   // removes it from |permission_info_list|, but the button should remain.
-  if (permissions_view_) {
-    base::STLDeleteContainerPointers(chosen_object_info_list.begin(),
-                                     chosen_object_info_list.end());
+  if (permissions_view_)
     return;
-  }
 
   permissions_view_ = new views::View();
   views::GridLayout* layout = new views::GridLayout(permissions_view_);
@@ -682,10 +670,10 @@ void WebsiteSettingsPopupView::SetPermissionInfo(
     layout->AddPaddingRow(1, kPermissionsVerticalSpacing);
   }
 
-  for (auto* object : chosen_object_info_list) {
+  for (auto& object : chosen_object_info_list) {
     layout->StartRow(1, content_column);
     // The view takes ownership of the object info.
-    auto* object_view = new ChosenObjectRow(base::WrapUnique(object));
+    auto* object_view = new ChosenObjectRow(std::move(object));
     object_view->AddObserver(this);
     layout->AddView(object_view, 1, 1, views::GridLayout::LEADING,
                     views::GridLayout::CENTER);
@@ -723,9 +711,7 @@ void WebsiteSettingsPopupView::SetIdentityInfo(
       header_->AddResetDecisionsLabel();
   }
 
-  bool include_details_link = !is_devtools_disabled_ || certificate_;
-
-  header_->SetDetails(security_description->details, include_details_link);
+  header_->SetDetails(security_description->details);
 
   Layout();
   SizeToContents();
@@ -785,20 +771,12 @@ void WebsiteSettingsPopupView::StyledLabelLinkClicked(views::StyledLabel* label,
                                                       int event_flags) {
   switch (label->id()) {
     case STYLED_LABEL_SECURITY_DETAILS:
+      web_contents()->OpenURL(content::OpenURLParams(
+          GURL(chrome::kPageInfoHelpCenterURL), content::Referrer(),
+          WindowOpenDisposition::NEW_FOREGROUND_TAB, ui::PAGE_TRANSITION_LINK,
+          false));
       presenter_->RecordWebsiteSettingsAction(
-          WebsiteSettings::WEBSITE_SETTINGS_SECURITY_DETAILS_OPENED);
-
-      if (is_devtools_disabled_) {
-        DCHECK(certificate_);
-        gfx::NativeWindow parent =
-            anchor_widget() ? anchor_widget()->GetNativeWindow() : nullptr;
-        presenter_->RecordWebsiteSettingsAction(
-            WebsiteSettings::WEBSITE_SETTINGS_CERTIFICATE_DIALOG_OPENED);
-        ShowCertificateViewer(web_contents(), parent, certificate_.get());
-      } else {
-        DevToolsWindow::OpenDevToolsWindow(
-            web_contents(), DevToolsToggleAction::ShowSecurityPanel());
-      }
+          WebsiteSettings::WEBSITE_SETTINGS_CONNECTION_HELP_OPENED);
       break;
     case STYLED_LABEL_RESET_CERTIFICATE_DECISIONS:
       presenter_->OnRevokeSSLErrorBypassButtonPressed();
