@@ -10,6 +10,7 @@
 #include "chrome/common/chrome_features.h"
 #include "chrome/grit/generated_resources.h"
 #include "content/public/common/origin_util.h"
+#include "ppapi/features/features.h"
 #include "ui/base/l10n/l10n_util.h"
 
 PermissionMenuModel::PermissionMenuModel(
@@ -27,11 +28,11 @@ PermissionMenuModel::PermissionMenuModel(
 
   ContentSetting effective_default_setting = permission_.default_setting;
 
-#if defined(ENABLE_PLUGINS)
+#if BUILDFLAG(ENABLE_PLUGINS)
   effective_default_setting = PluginsFieldTrial::EffectiveContentSetting(
       host_content_settings_map_, permission_.type,
       permission_.default_setting);
-#endif  // defined(ENABLE_PLUGINS)
+#endif  // BUILDFLAG(ENABLE_PLUGINS)
 
   switch (effective_default_setting) {
     case CONTENT_SETTING_ALLOW:
@@ -114,10 +115,10 @@ PermissionMenuModel::~PermissionMenuModel() {}
 bool PermissionMenuModel::IsCommandIdChecked(int command_id) const {
   ContentSetting setting = permission_.setting;
 
-#if defined(ENABLE_PLUGINS)
+#if BUILDFLAG(ENABLE_PLUGINS)
   setting = PluginsFieldTrial::EffectiveContentSetting(
       host_content_settings_map_, permission_.type, permission_.setting);
-#endif  // defined(ENABLE_PLUGINS)
+#endif  // BUILDFLAG(ENABLE_PLUGINS)
 
   return setting == command_id;
 }
