@@ -16,14 +16,9 @@
 #include "content/public/browser/permission_type.h"
 #include "ui/gfx/native_widget_types.h"
 
-class GURL;
 class Profile;
 class WebsiteSettings;
 
-namespace base {
-class Value;
-};
-
 namespace gfx {
 class Image;
 }
@@ -138,7 +133,7 @@ class WebsiteSettingsUI {
 
   using CookieInfoList = std::vector<CookieInfo>;
   using PermissionInfoList = std::vector<PermissionInfo>;
-  using ChosenObjectInfoList = std::vector<ChosenObjectInfo*>;
+  using ChosenObjectInfoList = std::vector<std::unique_ptr<ChosenObjectInfo>>;
 
   virtual ~WebsiteSettingsUI();
 
@@ -194,11 +189,10 @@ class WebsiteSettingsUI {
   // Sets cookie information.
   virtual void SetCookieInfo(const CookieInfoList& cookie_info_list) = 0;
 
-  // Sets permission information. The callee is expected to take ownership of
-  // the objects in |chosen_object_info_list|.
+  // Sets permission information.
   virtual void SetPermissionInfo(
       const PermissionInfoList& permission_info_list,
-      const ChosenObjectInfoList& chosen_object_info_list) = 0;
+      ChosenObjectInfoList chosen_object_info_list) = 0;
 
   // Sets site identity information.
   virtual void SetIdentityInfo(const IdentityInfo& identity_info) = 0;
