@@ -370,14 +370,16 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
                        TestSettingsContentSettingsExceptionsPage) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += std::string(chrome::kContentSettingsExceptionsSubPage);
+  url +=
+      std::string(chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage);
   RunBidiCheckerOnPage(url);
 }
 
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
                        TestSettingsContentSettingsExceptionsPage) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += std::string(chrome::kContentSettingsExceptionsSubPage);
+  url +=
+      std::string(chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage);
   RunBidiCheckerOnPage(url);
 }
 
@@ -470,7 +472,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
                        TestSettingsFrameContentExceptionsCookies) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#cookies";
   RunBidiCheckerOnPage(url);
 }
@@ -478,7 +480,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
                        TestSettingsFrameContentExceptionsCookies) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#cookies";
   RunBidiCheckerOnPage(url);
 }
@@ -490,7 +492,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
                        TestSettingsFrameContentExceptionsImages) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#images";
   RunBidiCheckerOnPage(url);
 }
@@ -498,7 +500,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
                        TestSettingsFrameContentExceptionsImages) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#images";
   RunBidiCheckerOnPage(url);
 }
@@ -510,7 +512,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
                        TestSettingsFrameContentExceptionsJavascript) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#javascript";
   RunBidiCheckerOnPage(url);
 }
@@ -518,7 +520,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
                        TestSettingsFrameContentExceptionsJavascript) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#javascript";
   RunBidiCheckerOnPage(url);
 }
@@ -530,7 +532,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
                        TestSettingsFrameContentExceptionsPlugins) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#plugins";
   RunBidiCheckerOnPage(url);
 }
@@ -538,7 +540,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
                        TestSettingsFrameContentExceptionsPlugins) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#plugins";
   RunBidiCheckerOnPage(url);
 }
@@ -550,7 +552,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
                        TestSettingsFrameContentExceptionsPopups) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#popups";
   RunBidiCheckerOnPage(url);
 }
@@ -558,7 +560,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
                        TestSettingsFrameContentExceptionsPopups) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#popups";
   RunBidiCheckerOnPage(url);
 }
@@ -570,7 +572,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
                        TestSettingsFrameContentExceptionsLocation) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#location";
   RunBidiCheckerOnPage(url);
 }
@@ -578,7 +580,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
                        TestSettingsFrameContentExceptionsLocation) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#location";
   RunBidiCheckerOnPage(url);
 }
@@ -590,7 +592,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
                        TestSettingsFrameContentExceptionsNotifications) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#notifications";
   RunBidiCheckerOnPage(url);
 }
@@ -598,7 +600,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
                        TestSettingsFrameContentExceptionsNotifications) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#notifications";
   RunBidiCheckerOnPage(url);
 }
@@ -610,7 +612,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
                        TestSettingsFrameContentExceptionsMouseLock) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#mouselock";
   RunBidiCheckerOnPage(url);
 }
@@ -618,7 +620,7 @@ IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestLTR,
 IN_PROC_BROWSER_TEST_F(DISABLED_WebUIBidiCheckerBrowserTestRTL,
                        TestSettingsFrameContentExceptionsMouseLock) {
   std::string url(chrome::kChromeUISettingsFrameURL);
-  url += chrome::kContentSettingsExceptionsSubPage;
+  url += chrome::kDeprecatedOptionsContentSettingsExceptionsSubPage;
   url += "#mouselock";
   RunBidiCheckerOnPage(url);
 }
