@@ -6,6 +6,7 @@
 #define CHROME_BROWSER_UI_WEBUI_CHROMEOS_LOGIN_EULA_SCREEN_HANDLER_H_
 
 #include "base/compiler_specific.h"
+#include "base/macros.h"
 #include "base/memory/ref_counted.h"
 #include "chrome/browser/chromeos/login/screens/eula_view.h"
 #include "chrome/browser/ui/webui/chromeos/login/base_screen_handler.h"
@@ -31,7 +32,6 @@ class EulaScreenHandler : public EulaView,
   ~EulaScreenHandler() override;
 
   // EulaView implementation:
-  void PrepareToShow() override;
   void Show() override;
   void Hide() override;
   void Bind(EulaModel& model) override;
