@@ -15,8 +15,6 @@
 
 namespace chromeos {
 
-class SigninScreenHandler;
-
 // A class that handles WebUI hooks in Gaia screen.
 class UserBoardScreenHandler : public BaseScreenHandler, public UserBoardView {
  public:
@@ -56,10 +54,8 @@ class UserBoardScreenHandler : public BaseScreenHandler, public UserBoardView {
 
   void Bind(UserBoardModel& model) override;
   void Unbind() override;
-  base::WeakPtr<UserBoardView> GetWeakPtr() override;
 
   UserBoardModel* model_;
-  base::WeakPtrFactory<UserBoardScreenHandler> weak_factory_;
 
   DISALLOW_COPY_AND_ASSIGN(UserBoardScreenHandler);
 };
