@@ -36,8 +36,11 @@
 #include "chrome/browser/ui/webui/media_router/media_router_localized_strings_provider.h"
 #include "chrome/browser/ui/webui/media_router/media_router_resources_provider.h"
 #include "chrome/browser/ui/webui/media_router/media_router_webui_message_handler.h"
+#include "chrome/common/pref_names.h"
 #include "chrome/common/url_constants.h"
 #include "chrome/grit/generated_resources.h"
+#include "components/prefs/pref_service.h"
+#include "components/prefs/scoped_user_pref_update.h"
 #include "content/public/browser/web_contents.h"
 #include "content/public/browser/web_ui.h"
 #include "content/public/browser/web_ui_data_source.h"
@@ -47,6 +50,7 @@
 #include "third_party/icu/source/i18n/unicode/coll.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/web_dialogs/web_dialog_delegate.h"
+#include "url/origin.h"
 
 namespace media_router {
 
@@ -88,6 +92,15 @@ base::TimeDelta GetRouteRequestTimeout(MediaCastMode cast_mode) {
   }
 }
 
+// Returns the first source in |sources| that can be connected to by using the
+// "Cast" button in the dialog, or an empty source if there is none.  This is
+// used by the Media Router to find such a matching route if it exists.
+MediaSource GetSourceForRouteObserver(const std::vector<MediaSource>& sources) {
+  auto source_it =
+      std::find_if(sources.begin(), sources.end(), CanConnectToMediaSource);
+  return source_it != sources.end() ? *source_it : MediaSource("");
+}
+
 }  // namespace
 
 // static
@@ -135,29 +148,7 @@ MediaRouterUI::UIMediaRoutesObserver::~UIMediaRoutesObserver() {}
 void MediaRouterUI::UIMediaRoutesObserver::OnRoutesUpdated(
     const std::vector<MediaRoute>& routes,
     const std::vector<MediaRoute::Id>& joinable_route_ids) {
-  std::vector<MediaRoute> routes_for_display;
-  std::vector<MediaRoute::Id> joinable_route_ids_for_display;
-  for (const MediaRoute& route : routes) {
-    if (route.for_display()) {
-#ifndef NDEBUG
-      for (const MediaRoute& existing_route : routes_for_display) {
-        if (existing_route.media_sink_id() == route.media_sink_id()) {
-          DVLOG(2) << "Received another route for display with the same sink"
-                   << " id as an existing route. " << route.media_route_id()
-                   << " has the same sink id as "
-                   << existing_route.media_sink_id() << ".";
-        }
-      }
-#endif
-      if (base::ContainsValue(joinable_route_ids, route.media_route_id())) {
-        joinable_route_ids_for_display.push_back(route.media_route_id());
-      }
-
-      routes_for_display.push_back(route);
-    }
-  }
-
-  callback_.Run(routes_for_display, joinable_route_ids_for_display);
+  callback_.Run(routes, joinable_route_ids);
 }
 
 MediaRouterUI::MediaRouterUI(content::WebUI* web_ui)
@@ -222,17 +213,20 @@ MediaRouterUI::~MediaRouterUI() {
 }
 
 void MediaRouterUI::InitWithDefaultMediaSource(
-    const base::WeakPtr<PresentationServiceDelegateImpl>& delegate) {
-  DCHECK(delegate);
+    content::WebContents* initiator,
+    PresentationServiceDelegateImpl* delegate) {
+  DCHECK(initiator);
   DCHECK(!presentation_service_delegate_);
   DCHECK(!query_result_manager_.get());
 
-  presentation_service_delegate_ = delegate;
-  presentation_service_delegate_->AddDefaultPresentationRequestObserver(this);
-  InitCommon(presentation_service_delegate_->web_contents());
-  if (presentation_service_delegate_->HasDefaultPresentationRequest()) {
-    OnDefaultPresentationChanged(
-        presentation_service_delegate_->GetDefaultPresentationRequest());
+  InitCommon(initiator);
+  if (delegate) {
+    presentation_service_delegate_ = delegate->GetWeakPtr();
+    presentation_service_delegate_->AddDefaultPresentationRequestObserver(this);
+  }
+
+  if (delegate && delegate->HasDefaultPresentationRequest()) {
+    OnDefaultPresentationChanged(delegate->GetDefaultPresentationRequest());
   } else {
     // Register for MediaRoute updates without a media source.
     routes_observer_.reset(new UIMediaRoutesObserver(
@@ -243,16 +237,17 @@ void MediaRouterUI::InitWithDefaultMediaSource(
 
 void MediaRouterUI::InitWithPresentationSessionRequest(
     content::WebContents* initiator,
-    const base::WeakPtr<PresentationServiceDelegateImpl>& delegate,
+    PresentationServiceDelegateImpl* delegate,
     std::unique_ptr<CreatePresentationConnectionRequest>
         create_session_request) {
   DCHECK(initiator);
+  DCHECK(delegate);
   DCHECK(create_session_request);
   DCHECK(!create_session_request_);
   DCHECK(!query_result_manager_);
 
   create_session_request_ = std::move(create_session_request);
-  presentation_service_delegate_ = delegate;
+  presentation_service_delegate_ = delegate->GetWeakPtr();
   InitCommon(initiator);
   OnDefaultPresentationChanged(create_session_request_->presentation_request());
 }
@@ -293,7 +288,12 @@ void MediaRouterUI::InitCommon(content::WebContents* initiator) {
     query_result_manager_->SetSourcesForCastMode(MediaCastMode::TAB_MIRROR,
                                                  {mirroring_source}, origin);
   }
+
   UpdateCastModes();
+
+  // Get the current list of media routes, so that the WebUI will have routes
+  // information at initialization.
+  OnRoutesUpdated(router_->GetCurrentRoutes(), std::vector<MediaRoute::Id>());
 }
 
 void MediaRouterUI::InitForTest(
@@ -319,10 +319,15 @@ void MediaRouterUI::OnDefaultPresentationChanged(
   query_result_manager_->SetSourcesForCastMode(
       MediaCastMode::DEFAULT, sources,
       presentation_request_->frame_url().GetOrigin());
-  // Register for MediaRoute updates.
-  // TODO(crbug.com/627655): Use multiple URLs.
+  // Register for MediaRoute updates.  NOTE(mfoltz): If there are multiple
+  // sources that can be connected to via the dialog, this will break.  We will
+  // need to observe multiple sources (keyed by sinks) in that case.  As this is
+  // Cast-specific for the forseeable future, it may be simpler to plumb a new
+  // observer API for this case.
+  const MediaSource source_for_route_observer =
+      GetSourceForRouteObserver(sources);
   routes_observer_.reset(new UIMediaRoutesObserver(
-      router_, sources[0].id(),
+      router_, source_for_route_observer.id(),
       base::Bind(&MediaRouterUI::OnRoutesUpdated, base::Unretained(this))));
 
   UpdateCastModes();
@@ -346,6 +351,25 @@ void MediaRouterUI::UpdateCastModes() {
   }
 }
 
+void MediaRouterUI::UpdateRoutesToCastModesMapping() {
+  std::unordered_map<MediaSource::Id, MediaCastMode> available_source_map;
+  for (const auto& cast_mode : cast_modes_) {
+    for (const auto& source :
+         query_result_manager_->GetSourcesForCastMode(cast_mode)) {
+      available_source_map.insert(std::make_pair(source.id(), cast_mode));
+    }
+  }
+
+  routes_and_cast_modes_.clear();
+  for (const auto& route : routes_) {
+    auto source_entry = available_source_map.find(route.media_source().id());
+    if (source_entry != available_source_map.end()) {
+      routes_and_cast_modes_.insert(
+          std::make_pair(route.media_route_id(), source_entry->second));
+    }
+  }
+}
+
 void MediaRouterUI::Close() {
   ConstrainedWebDialogDelegate* delegate = GetConstrainedDelegate();
   if (delegate) {
@@ -417,8 +441,6 @@ bool MediaRouterUI::SetRouteParameters(
   current_route_request_id_ = ++route_request_counter_;
   *origin = for_default_source ? presentation_request_->frame_url().GetOrigin()
                                : GURL(chrome::kChromeUIMediaRouterURL);
-  DCHECK(origin->is_valid());
-
   DVLOG(1) << "DoCreateRoute: origin: " << *origin;
 
   // There are 3 cases. In cases (1) and (3) the MediaRouterUI will need to be
@@ -505,6 +527,37 @@ void MediaRouterUI::SearchSinksAndCreateRoute(
                  weak_factory_.GetWeakPtr(), cast_mode));
 }
 
+bool MediaRouterUI::UserSelectedTabMirroringForCurrentOrigin() const {
+  const base::ListValue* origins =
+      Profile::FromWebUI(web_ui())->GetPrefs()->GetList(
+          prefs::kMediaRouterTabMirroringSources);
+  return origins->Find(base::StringValue(GetSerializedInitiatorOrigin())) !=
+         origins->end();
+}
+
+void MediaRouterUI::RecordCastModeSelection(MediaCastMode cast_mode) {
+  ListPrefUpdate update(Profile::FromWebUI(web_ui())->GetPrefs(),
+                        prefs::kMediaRouterTabMirroringSources);
+
+  switch (cast_mode) {
+    case MediaCastMode::DEFAULT:
+      update->Remove(base::StringValue(GetSerializedInitiatorOrigin()),
+                     nullptr);
+      break;
+    case MediaCastMode::TAB_MIRROR:
+      update->AppendIfNotPresent(
+          base::MakeUnique<base::StringValue>(GetSerializedInitiatorOrigin()));
+      break;
+    case MediaCastMode::DESKTOP_MIRROR:
+      // Desktop mirroring isn't domain-specific, so we don't record the
+      // selection.
+      break;
+    default:
+      NOTREACHED();
+      break;
+  }
+}
+
 void MediaRouterUI::OnResultsUpdated(
     const std::vector<MediaSinkWithCastModes>& sinks) {
   sinks_ = sinks;
@@ -526,28 +579,33 @@ void MediaRouterUI::SetIssue(const Issue* issue) {
 void MediaRouterUI::OnRoutesUpdated(
     const std::vector<MediaRoute>& routes,
     const std::vector<MediaRoute::Id>& joinable_route_ids) {
-  routes_ = routes;
-  joinable_route_ids_ = joinable_route_ids;
+  routes_.clear();
+  joinable_route_ids_.clear();
 
-  std::unordered_map<MediaSource::Id, MediaCastMode> available_source_map;
-  for (const auto& cast_mode : cast_modes_) {
-    for (const auto& source :
-         query_result_manager_->GetSourcesForCastMode(cast_mode)) {
-      available_source_map.insert(std::make_pair(source.id(), cast_mode));
-    }
-  }
+  for (const MediaRoute& route : routes) {
+    if (route.for_display()) {
+#ifndef NDEBUG
+      for (const MediaRoute& existing_route : routes_) {
+        if (existing_route.media_sink_id() == route.media_sink_id()) {
+          DVLOG(2) << "Received another route for display with the same sink"
+                   << " id as an existing route. " << route.media_route_id()
+                   << " has the same sink id as "
+                   << existing_route.media_sink_id() << ".";
+        }
+      }
+#endif
+      if (base::ContainsValue(joinable_route_ids, route.media_route_id())) {
+        joinable_route_ids_.push_back(route.media_route_id());
+      }
 
-  current_cast_modes_.clear();
-  for (const auto& route : routes) {
-    auto source_entry = available_source_map.find(route.media_source().id());
-    if (source_entry != available_source_map.end()) {
-      current_cast_modes_.insert(
-          std::make_pair(route.media_route_id(), source_entry->second));
+      routes_.push_back(route);
     }
   }
+  UpdateRoutesToCastModesMapping();
 
   if (ui_initialized_)
-    handler_->UpdateRoutes(routes_, joinable_route_ids_, current_cast_modes_);
+    handler_->UpdateRoutes(routes_, joinable_route_ids_,
+                           routes_and_cast_modes_);
 }
 
 void MediaRouterUI::OnRouteResponseReceived(
@@ -694,4 +752,11 @@ void MediaRouterUI::UpdateMaxDialogHeight(int height) {
   handler_->UpdateMaxDialogHeight(height);
 }
 
+std::string MediaRouterUI::GetSerializedInitiatorOrigin() const {
+  url::Origin origin = initiator_
+                           ? url::Origin(initiator_->GetLastCommittedURL())
+                           : url::Origin();
+  return origin.Serialize();
+}
+
 }  // namespace media_router
