@@ -23,6 +23,7 @@
 #include "chrome/browser/ui/webui/media_router/query_result_manager.h"
 #include "content/public/browser/web_ui_data_source.h"
 #include "third_party/icu/source/common/unicode/uversion.h"
+#include "url/gurl.h"
 
 namespace content {
 class WebContents;
@@ -42,11 +43,9 @@ class CreatePresentationConnectionRequest;
 class IssuesObserver;
 class MediaRoute;
 class MediaRouter;
-class MediaRouterDialogCallbacks;
 class MediaRoutesObserver;
 class MediaRouterWebUIMessageHandler;
 class MediaSink;
-class MediaSinksObserver;
 class RouteRequestResult;
 
 // Implements the chrome://media-router user interface.
@@ -61,6 +60,8 @@ class MediaRouterUI : public ConstrainedWebDialogUI,
 
   // Initializes internal state (e.g. starts listening for MediaSinks) for
   // targeting the default MediaSource (if any) of the initiator tab that owns
+  // |initiator|: Reference to the WebContents that initiated the dialog.
+  //              Must not be null.
   // |delegate|, as well as mirroring sources of that tab.
   // The contents of the UI will change as the default MediaSource changes.
   // If there is a default MediaSource, then DEFAULT MediaCastMode will be
@@ -70,8 +71,8 @@ class MediaRouterUI : public ConstrainedWebDialogUI,
   //             Must not be null.
   // TODO(imcheng): Replace use of impl with an intermediate abstract
   // interface.
-  void InitWithDefaultMediaSource(
-      const base::WeakPtr<PresentationServiceDelegateImpl>& delegate);
+  void InitWithDefaultMediaSource(content::WebContents* initiator,
+                                  PresentationServiceDelegateImpl* delegate);
 
   // Initializes internal state targeting the presentation specified in
   // |request|. Also sets up mirroring sources based on |initiator|.
@@ -87,7 +88,7 @@ class MediaRouterUI : public ConstrainedWebDialogUI,
   //                         ownership of it. Must not be null.
   void InitWithPresentationSessionRequest(
       content::WebContents* initiator,
-      const base::WeakPtr<PresentationServiceDelegateImpl>& delegate,
+      PresentationServiceDelegateImpl* delegate,
       std::unique_ptr<CreatePresentationConnectionRequest>
           presentation_request);
 
@@ -125,6 +126,14 @@ class MediaRouterUI : public ConstrainedWebDialogUI,
                                  const std::string& domain,
                                  MediaCastMode cast_mode);
 
+  // Returns true if the cast mode last chosen for the current origin is tab
+  // mirroring.
+  bool UserSelectedTabMirroringForCurrentOrigin() const;
+
+  // Records the cast mode selection for the current origin, unless the cast
+  // mode is MediaCastMode::DESKTOP_MIRROR.
+  void RecordCastModeSelection(MediaCastMode cast_mode);
+
   // Returns the hostname of the default source's parent frame URL.
   std::string GetPresentationRequestSourceName() const;
   std::string GetTruncatedPresentationRequestSourceName() const;
@@ -137,9 +146,9 @@ class MediaRouterUI : public ConstrainedWebDialogUI,
     return joinable_route_ids_;
   }
   const std::set<MediaCastMode>& cast_modes() const { return cast_modes_; }
-  const std::unordered_map<MediaRoute::Id, MediaCastMode>& current_cast_modes()
-      const {
-    return current_cast_modes_;
+  const std::unordered_map<MediaRoute::Id, MediaCastMode>&
+  routes_and_cast_modes() const {
+    return routes_and_cast_modes_;
   }
   const content::WebContents* initiator() const { return initiator_; }
 
@@ -162,10 +171,8 @@ class MediaRouterUI : public ConstrainedWebDialogUI,
  private:
   FRIEND_TEST_ALL_PREFIXES(MediaRouterUITest, SortedSinks);
   FRIEND_TEST_ALL_PREFIXES(MediaRouterUITest, SortSinksByIconType);
-  FRIEND_TEST_ALL_PREFIXES(MediaRouterUITest,
-                           UIMediaRoutesObserverFiltersNonDisplayRoutes);
-  FRIEND_TEST_ALL_PREFIXES(MediaRouterUITest,
-      UIMediaRoutesObserverFiltersNonDisplayJoinableRoutes);
+  FRIEND_TEST_ALL_PREFIXES(MediaRouterUITest, FilterNonDisplayRoutes);
+  FRIEND_TEST_ALL_PREFIXES(MediaRouterUITest, FilterNonDisplayJoinableRoutes);
   FRIEND_TEST_ALL_PREFIXES(MediaRouterUITest,
       UIMediaRoutesObserverAssignsCurrentCastModes);
   FRIEND_TEST_ALL_PREFIXES(MediaRouterUITest,
@@ -269,10 +276,18 @@ class MediaRouterUI : public ConstrainedWebDialogUI,
   // |handler_|.
   void UpdateCastModes();
 
+  // Updates the routes-to-cast-modes mapping in |routes_and_cast_modes_| to
+  // match the value of |routes_|.
+  void UpdateRoutesToCastModesMapping();
+
   // Returns the default presentation request's frame URL if there is one.
   // Otherwise returns an empty GURL.
   GURL GetFrameURL() const;
 
+  // Returns the serialized origin for |initiator_|, or the serialization of an
+  // opaque origin ("null") if |initiator_| is not set.
+  std::string GetSerializedInitiatorOrigin() const;
+
   // Owned by the |web_ui| passed in the ctor, and guaranteed to be deleted
   // only after it has deleted |this|.
   MediaRouterWebUIMessageHandler* handler_;
@@ -300,7 +315,7 @@ class MediaRouterUI : public ConstrainedWebDialogUI,
   std::vector<MediaRoute> routes_;
   std::vector<MediaRoute::Id> joinable_route_ids_;
   CastModeSet cast_modes_;
-  std::unordered_map<MediaRoute::Id, MediaCastMode> current_cast_modes_;
+  std::unordered_map<MediaRoute::Id, MediaCastMode> routes_and_cast_modes_;
 
   std::unique_ptr<QueryResultManager> query_result_manager_;
 
