@@ -17,20 +17,19 @@
 #include "chrome/browser/media/router/issue.h"
 #include "chrome/browser/media/router/media_router_metrics.h"
 #include "chrome/browser/profiles/profile.h"
+#include "chrome/browser/signin/signin_manager_factory.h"
+#include "chrome/browser/sync/profile_sync_service_factory.h"
+#include "chrome/browser/ui/webui/media_router/media_cast_mode.h"
 #include "chrome/browser/ui/webui/media_router/media_router_ui.h"
 #include "chrome/common/pref_names.h"
 #include "chrome/grit/generated_resources.h"
+#include "components/browser_sync/profile_sync_service.h"
 #include "components/prefs/pref_service.h"
+#include "components/signin/core/browser/signin_manager.h"
 #include "content/public/browser/web_ui.h"
 #include "extensions/common/constants.h"
 #include "ui/base/l10n/l10n_util.h"
 
-#if defined(GOOGLE_CHROME_BUILD)
-#include "chrome/browser/signin/signin_manager_factory.h"
-#include "chrome/browser/sync/profile_sync_service_factory.h"
-#include "components/browser_sync/profile_sync_service.h"
-#include "components/signin/core/browser/signin_manager.h"
-#endif  // defined(GOOGLE_CHROME_BUILD)
 
 namespace media_router {
 
@@ -275,7 +274,7 @@ void MediaRouterWebUIMessageHandler::OnCreateRouteResponseReceived(
   DVLOG(2) << "OnCreateRouteResponseReceived";
   if (route) {
     int current_cast_mode = CurrentCastModeForRouteId(
-        route->media_route_id(), media_router_ui_->current_cast_modes());
+        route->media_route_id(), media_router_ui_->routes_and_cast_modes());
     std::unique_ptr<base::DictionaryValue> route_value(RouteToValue(
         *route, false, media_router_ui_->GetRouteProviderExtensionId(),
         incognito_, current_cast_mode));
@@ -413,7 +412,7 @@ void MediaRouterWebUIMessageHandler::OnRequestInitialData(
 
   std::unique_ptr<base::ListValue> routes(RoutesToValue(
       media_router_ui_->routes(), media_router_ui_->joinable_route_ids(),
-      media_router_ui_->current_cast_modes()));
+      media_router_ui_->routes_and_cast_modes()));
   initial_data.Set("routes", routes.release());
 
   const std::set<MediaCastMode> cast_modes = media_router_ui_->cast_modes();
@@ -421,6 +420,14 @@ void MediaRouterWebUIMessageHandler::OnRequestInitialData(
       cast_modes, media_router_ui_->GetPresentationRequestSourceName()));
   initial_data.Set("castModes", cast_modes_list.release());
 
+  // If the cast mode last chosen for the current origin is tab mirroring,
+  // that should be the cast mode initially selected in the dialog. Otherwise
+  // the initial cast mode should be chosen automatically by the dialog.
+  bool use_tab_mirroring =
+      base::ContainsKey(cast_modes, MediaCastMode::TAB_MIRROR) &&
+      media_router_ui_->UserSelectedTabMirroringForCurrentOrigin();
+  initial_data.SetBoolean("useTabMirroring", use_tab_mirroring);
+
   web_ui()->CallJavascriptFunctionUnsafe(kSetInitialData, initial_data);
   media_router_ui_->UIInitialized();
 }
@@ -480,7 +487,6 @@ void MediaRouterWebUIMessageHandler::OnAcknowledgeFirstRunFlow(
   Profile::FromWebUI(web_ui())->GetPrefs()->SetBoolean(
       prefs::kMediaRouterFirstRunFlowAcknowledged, true);
 
-#if defined(GOOGLE_CHROME_BUILD)
   bool enabled_cloud_services = false;
   // Do not set the relevant cloud services prefs if the user was not shown
   // the cloud services prompt.
@@ -493,7 +499,6 @@ void MediaRouterWebUIMessageHandler::OnAcknowledgeFirstRunFlow(
   pref_service->SetBoolean(prefs::kMediaRouterEnableCloudServices,
                            enabled_cloud_services);
   pref_service->SetBoolean(prefs::kMediaRouterCloudServicesPrefSet, true);
-#endif  // defined(GOOGLE_CHROME_BUILD)
 }
 
 void MediaRouterWebUIMessageHandler::OnActOnIssue(
@@ -700,8 +705,11 @@ void MediaRouterWebUIMessageHandler::OnReportSelectedCastMode(
     DVLOG(1) << "Unable to extract args.";
     return;
   }
+  DCHECK(IsValidCastModeNum(cast_mode_type));
   UMA_HISTOGRAM_SPARSE_SLOWLY("MediaRouter.Ui.Navigate.SourceSelection",
                               cast_mode_type);
+  media_router_ui_->RecordCastModeSelection(
+      static_cast<MediaCastMode>(cast_mode_type));
 }
 
 void MediaRouterWebUIMessageHandler::OnReportSinkCount(
@@ -805,7 +813,6 @@ void MediaRouterWebUIMessageHandler::MaybeUpdateFirstRunFlowData() {
   bool first_run_flow_acknowledged =
       pref_service->GetBoolean(prefs::kMediaRouterFirstRunFlowAcknowledged);
   bool show_cloud_pref = false;
-#if defined(GOOGLE_CHROME_BUILD)
   // Cloud services preference is shown if user is logged in. If the user
   // enables sync after acknowledging the first run flow, this is treated as
   // the user opting into Google services, including cloud services, if the
@@ -832,7 +839,6 @@ void MediaRouterWebUIMessageHandler::MaybeUpdateFirstRunFlowData() {
           base::StringPrintf(kHelpPageUrlPrefix, 6320939));
     }
   }
-#endif  // defined(GOOGLE_CHROME_BUILD)
 
   // Return early if the first run flow won't be surfaced.
   if (first_run_flow_acknowledged && !show_cloud_pref)
@@ -849,14 +855,10 @@ void MediaRouterWebUIMessageHandler::MaybeUpdateFirstRunFlowData() {
 }
 
 AccountInfo MediaRouterWebUIMessageHandler::GetAccountInfo() {
-#if defined(GOOGLE_CHROME_BUILD)
   SigninManagerBase* signin_manager =
       SigninManagerFactory::GetForProfile(Profile::FromWebUI(web_ui()));
-  if (signin_manager)
-    return signin_manager->GetAuthenticatedAccountInfo();
-#endif  // defined(GOOGLE_CHROME_BUILD)
-
-  return AccountInfo();
+  return signin_manager ? signin_manager->GetAuthenticatedAccountInfo()
+                        : AccountInfo();
 }
 
 int MediaRouterWebUIMessageHandler::CurrentCastModeForRouteId(
