@@ -335,7 +335,7 @@ void CheckVersion(const base::FilePath& pnacl_path, std::string* version) {
   JSONFileValueDeserializer deserializer(pnacl_json_path);
   std::string error;
   std::unique_ptr<base::Value> root = deserializer.Deserialize(NULL, &error);
-  if (!root || !root->IsType(base::Value::TYPE_DICTIONARY))
+  if (!root || !root->IsType(base::Value::Type::DICTIONARY))
     return;
 
   // Now try to get the field. This may leave version empty if the
