@@ -21,14 +21,14 @@
 #include "chrome/browser/browsing_data/browsing_data_indexed_db_helper.h"
 #include "chrome/browser/browsing_data/browsing_data_local_storage_helper.h"
 #include "chrome/browser/browsing_data/browsing_data_service_worker_helper.h"
-#include "chrome/browser/chromeos/arc/arc_auth_service.h"
+#include "chrome/browser/chromeos/arc/arc_session_manager.h"
 #include "chrome/browser/chromeos/drive/file_system_util.h"
 #include "chrome/browser/chromeos/file_manager/path_util.h"
 #include "chrome/browser/platform_util.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/grit/generated_resources.h"
 #include "chromeos/cryptohome/homedir_methods.h"
-#include "components/browsing_data/storage_partition_http_cache_data_remover.h"
+#include "components/browsing_data/content/storage_partition_http_cache_data_remover.h"
 #include "components/drive/chromeos/file_system_interface.h"
 #include "components/user_manager/user_manager.h"
 #include "content/public/browser/browser_context.h"
@@ -368,7 +368,7 @@ void StorageManagerHandler::UpdateOtherUsersSize() {
   user_sizes_.clear();
   const user_manager::UserList& users =
       user_manager::UserManager::Get()->GetUsers();
-  for (const auto& user : users) {
+  for (auto* user : users) {
     if (user->is_active())
       continue;
     other_users_.push_back(user);
@@ -411,9 +411,9 @@ void StorageManagerHandler::UpdateArcSize() {
   updating_arc_size_ = true;
 
   Profile* const profile = Profile::FromWebUI(web_ui());
-  if (!arc::ArcAuthService::IsAllowedForProfile(profile) ||
-      arc::ArcAuthService::IsOptInVerificationDisabled() ||
-      !arc::ArcAuthService::Get()->IsArcEnabled()) {
+  if (!arc::ArcSessionManager::IsAllowedForProfile(profile) ||
+      arc::ArcSessionManager::IsOptInVerificationDisabled() ||
+      !arc::ArcSessionManager::Get()->IsArcEnabled()) {
     return;
   }
 
