@@ -2,6 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+GEN_INCLUDE(['options_browsertest_base.js']);
 GEN('#include "chrome/browser/ui/webui/options/' +
     'multilanguage_options_browsertest.h"');
 
@@ -13,7 +14,7 @@ GEN('#include "chrome/browser/ui/webui/options/' +
 function MultilanguageOptionsWebUIBrowserTest() {}
 
 MultilanguageOptionsWebUIBrowserTest.prototype = {
-  __proto__: testing.Test.prototype,
+  __proto__: OptionsBrowsertestBase.prototype,
 
   /** @override */
   browsePreload: 'chrome://settings-frame/languages',
@@ -32,26 +33,47 @@ MultilanguageOptionsWebUIBrowserTest.prototype = {
 
   /** @override */
   setUp: function() {
-    testing.Test.prototype.setUp.call(this);
+    OptionsBrowsertestBase.prototype.setUp.call(this);
 
-    assertTrue(loadTimeData.getBoolean('enableMultilingualSpellChecker'));
     assertFalse(cr.isMac);
-    expectTrue($('spellcheck-language-button').hidden);
     expectFalse($('edit-custom-dictionary-button').hidden);
-    this.expectEnableSpellcheckCheckboxHidden();
+    this.expectEnableSpellcheckCheckboxVisible();
     this.expectCurrentlySelected('fr');
+
+    var requiredOwnedAriaRoleMissingSelectors = [
+      '#default-search-engine-list',
+      '#other-search-engine-list',
+    ];
+
+    // Enable when failure is resolved.
+    // AX_ARIA_08: http://crbug.com/559320
+    this.accessibilityAuditConfig.ignoreSelectors(
+        'requiredOwnedAriaRoleMissing',
+        requiredOwnedAriaRoleMissingSelectors);
+
+    // Enable when failure is resolved.
+    // AX_ARIA_10: http://crbug.com/559266
+    this.accessibilityAuditConfig.ignoreSelectors(
+        'unsupportedAriaAttribute',
+        '#language-options-list');
+
+    // Enable when failure is resolved.
+    // AX_TEXT_04: http://crbug.com/559271
+    this.accessibilityAuditConfig.ignoreSelectors(
+        'linkWithUnclearPurpose',
+        '#languagePage > .content-area > .language-options-header > A');
   },
 
   /** @override */
   tearDown: function() {
     testing.Test.prototype.tearDown.call(this);
-    this.expectEnableSpellcheckCheckboxHidden();
+    this.expectEnableSpellcheckCheckboxVisible();
   },
 
-  /** Make sure the 'Enable spell checking' checkbox is not visible. */
-  expectEnableSpellcheckCheckboxHidden: function() {
+  /** Make sure the 'Enable spell checking' checkbox is visible. */
+  expectEnableSpellcheckCheckboxVisible: function() {
     if ($('enable-spellcheck-container'))
-      expectTrue($('enable-spellcheck-container').hidden);
+      expectFalse($('enable-spellcheck-container').hidden);
   },
 };
 
@@ -140,15 +162,31 @@ MultilanguagePreferenceWebUIBrowserTest.prototype = {
 
   /** @override */
   setUp: function() {
-    testing.Test.prototype.setUp.call(this);
+    OptionsBrowsertestBase.prototype.setUp.call(this);
 
-    assertTrue(loadTimeData.getBoolean('enableMultilingualSpellChecker'));
     assertFalse(cr.isMac);
-    expectTrue($('spellcheck-language-button').hidden);
     expectTrue($('edit-custom-dictionary-button').hidden);
-    this.expectEnableSpellcheckCheckboxHidden();
+    this.expectEnableSpellcheckCheckboxVisible();
     this.expectCurrentlySelected('');
     this.expectRegisteredDictionariesPref('');
+
+    // Enable when failure is resolved.
+    // AX_ARIA_10: http://crbug.com/559266
+    this.accessibilityAuditConfig.ignoreSelectors(
+        'unsupportedAriaAttribute',
+        '#language-options-list');
+
+    // Enable when failure is resolved.
+    // AX_TEXT_04: http://crbug.com/559271
+    this.accessibilityAuditConfig.ignoreSelectors(
+        'linkWithUnclearPurpose',
+        '#languagePage > .content-area > .language-options-header > A');
+
+    // Enable when failure is resolved.
+    // AX_FOCUS_01: http://crbug.com/570046
+    this.accessibilityAuditConfig.ignoreSelectors(
+        'focusableElementNotVisibleAndNotAriaHidden',
+        '#offer-to-translate-in-this-language');
   },
 };
 
