@@ -156,8 +156,6 @@ std::string GetSyncErrorAction(sync_ui_util::ActionType action_type) {
   switch (action_type) {
     case sync_ui_util::REAUTHENTICATE:
       return "reauthenticate";
-    case sync_ui_util::SIGNOUT_AND_SIGNIN:
-      return "signOutAndSignIn";
     case sync_ui_util::UPGRADE_CLIENT:
       return "upgradeClient";
     case sync_ui_util::ENTER_PASSPHRASE:
@@ -317,11 +315,11 @@ void PeopleHandler::DisplaySpinner() {
   configuring_sync_ = true;
 
   const int kTimeoutSec = 30;
-  DCHECK(!backend_start_timer_);
-  backend_start_timer_.reset(new base::OneShotTimer());
-  backend_start_timer_->Start(FROM_HERE,
-                              base::TimeDelta::FromSeconds(kTimeoutSec), this,
-                              &PeopleHandler::DisplayTimeout);
+  DCHECK(!engine_start_timer_);
+  engine_start_timer_.reset(new base::OneShotTimer());
+  engine_start_timer_->Start(FROM_HERE,
+                             base::TimeDelta::FromSeconds(kTimeoutSec), this,
+                             &PeopleHandler::DisplayTimeout);
 
   CallJavascriptFunction("cr.webUIListenerCallback",
                          base::StringValue("page-status-changed"),
@@ -332,7 +330,7 @@ void PeopleHandler::DisplaySpinner() {
 // http://crbug.com/128692
 void PeopleHandler::DisplayTimeout() {
   // Stop a timer to handle timeout in waiting for checking network connection.
-  backend_start_timer_.reset();
+  engine_start_timer_.reset();
 
   // Do not listen to sync startup events.
   sync_startup_tracker_.reset();
@@ -349,7 +347,7 @@ void PeopleHandler::OnDidClosePage(const base::ListValue* args) {
 
 void PeopleHandler::SyncStartupFailed() {
   // Stop a timer to handle timeout in waiting for checking network connection.
-  backend_start_timer_.reset();
+  engine_start_timer_.reset();
 
   // Just close the sync overlay (the idea is that the base settings page will
   // display the current error.)
@@ -358,10 +356,10 @@ void PeopleHandler::SyncStartupFailed() {
 
 void PeopleHandler::SyncStartupCompleted() {
   ProfileSyncService* service = GetSyncService();
-  DCHECK(service->IsBackendInitialized());
+  DCHECK(service->IsEngineInitialized());
 
   // Stop a timer to handle timeout in waiting for checking network connection.
-  backend_start_timer_.reset();
+  engine_start_timer_.reset();
 
   sync_startup_tracker_.reset();
 
@@ -391,7 +389,7 @@ void PeopleHandler::HandleSetDatatypes(const base::ListValue* args) {
 
   // If the sync engine has shutdown for some reason, just close the sync
   // dialog.
-  if (!service || !service->IsBackendInitialized()) {
+  if (!service || !service->IsEngineInitialized()) {
     CloseSyncSetup();
     ResolveJavascriptCallback(*callback_id, base::StringValue(kDonePageStatus));
     return;
@@ -422,7 +420,7 @@ void PeopleHandler::HandleSetEncryption(const base::ListValue* args) {
 
   // If the sync engine has shutdown for some reason, just close the sync
   // dialog.
-  if (!service || !service->IsBackendInitialized()) {
+  if (!service || !service->IsEngineInitialized()) {
     CloseSyncSetup();
     ResolveJavascriptCallback(*callback_id, base::StringValue(kDonePageStatus));
     return;
@@ -436,7 +434,7 @@ void PeopleHandler::HandleSetEncryption(const base::ListValue* args) {
 
   // Note: Data encryption will not occur until configuration is complete
   // (when the PSS receives its CONFIGURE_DONE notification from the sync
-  // backend), so the user still has a chance to cancel out of the operation
+  // engine), so the user still has a chance to cancel out of the operation
   // if (for example) some kind of passphrase error is encountered.
   if (configuration.encrypt_all)
     service->EnableEncryptEverything();
@@ -507,7 +505,7 @@ void PeopleHandler::HandleShowSetupUI(const base::ListValue* args) {
     return;
   }
 
-  OpenSyncSetup();
+  OpenSyncSetup(false /* creating_supervised_user */);
 }
 
 #if defined(OS_CHROMEOS)
@@ -523,12 +521,11 @@ void PeopleHandler::HandleAttemptUserExit(const base::ListValue* args) {
 void PeopleHandler::HandleStartSignin(const base::ListValue* args) {
   AllowJavascript();
 
-  // Should only be called if the user is not already signed in or has an auth
-  // error.
-  DCHECK(!SigninManagerFactory::GetForProfile(profile_)->IsAuthenticated() ||
-         SigninErrorControllerFactory::GetForProfile(profile_)->HasError());
-
-  OpenSyncSetup();
+  // Should only be called if the user is not already signed in.
+  DCHECK(!SigninManagerFactory::GetForProfile(profile_)->IsAuthenticated());
+  bool creating_supervised_user = false;
+  args->GetBoolean(0, &creating_supervised_user);
+  OpenSyncSetup(creating_supervised_user);
 }
 
 void PeopleHandler::HandleStopSyncing(const base::ListValue* args) {
@@ -571,7 +568,7 @@ void PeopleHandler::HandleManageOtherPeople(const base::ListValue* /* args */) {
 
 void PeopleHandler::CloseSyncSetup() {
   // Stop a timer to handle timeout in waiting for checking network connection.
-  backend_start_timer_.reset();
+  engine_start_timer_.reset();
 
   // Clear the sync startup tracker, since the setup wizard is being closed.
   sync_startup_tracker_.reset();
@@ -593,7 +590,7 @@ void PeopleHandler::CloseSyncSetup() {
             ProfileSyncService::CANCEL_DURING_CONFIGURE);
 
         // If the user clicked "Cancel" while setting up sync, disable sync
-        // because we don't want the sync backend to remain in the
+        // because we don't want the sync engine to remain in the
         // first-setup-incomplete state.
         // Note: In order to disable sync across restarts on Chrome OS,
         // we must call RequestStop(CLEAR_DATA), which suppresses sync startup
@@ -626,7 +623,7 @@ void PeopleHandler::CloseSyncSetup() {
   configuring_sync_ = false;
 }
 
-void PeopleHandler::OpenSyncSetup() {
+void PeopleHandler::OpenSyncSetup(bool creating_supervised_user) {
   // Notify services that login UI is now active.
   GetLoginUIService()->SetLoginUI(this);
 
@@ -646,14 +643,18 @@ void PeopleHandler::OpenSyncSetup() {
   //    sync configure UI, not login UI).
   // 7) User re-enables sync after disabling it via advanced settings.
 #if !defined(OS_CHROMEOS)
-  if (!SigninManagerFactory::GetForProfile(profile_)->IsAuthenticated() ||
+  SigninManagerBase* signin = SigninManagerFactory::GetForProfile(profile_);
+  if (!signin->IsAuthenticated() ||
       SigninErrorControllerFactory::GetForProfile(profile_)->HasError()) {
     // User is not logged in (cases 1-2), or login has been specially requested
     // because previously working credentials have expired (case 3). Close sync
     // setup including any visible overlays, and display the gaia auth page.
     // Control will be returned to the sync settings page once auth is complete.
     CloseUI();
-    DisplayGaiaLogin(signin_metrics::AccessPoint::ACCESS_POINT_SETTINGS);
+    DisplayGaiaLogin(
+        creating_supervised_user ?
+            signin_metrics::AccessPoint::ACCESS_POINT_SUPERVISED_USER :
+            signin_metrics::AccessPoint::ACCESS_POINT_SETTINGS);
     return;
   }
 #endif
@@ -778,10 +779,10 @@ void PeopleHandler::PushSyncPrefs() {
 
   ProfileSyncService* service = GetSyncService();
   DCHECK(service);
-  if (!service->IsBackendInitialized()) {
+  if (!service->IsEngineInitialized()) {
     service->RequestStart();
 
-    // See if it's even possible to bring up the sync backend - if not
+    // See if it's even possible to bring up the sync engine - if not
     // (unrecoverable error?), don't bother displaying a spinner that will be
     // immediately closed because this leads to some ugly infinite UI loop (see
     // http://crbug.com/244769).
@@ -796,8 +797,8 @@ void PeopleHandler::PushSyncPrefs() {
   }
 
   configuring_sync_ = true;
-  DCHECK(service->IsBackendInitialized())
-      << "Cannot configure sync until the sync backend is initialized";
+  DCHECK(service->IsEngineInitialized())
+      << "Cannot configure sync until the sync engine is initialized";
 
   // Setup args for the sync configure screen:
   //   syncAllDataTypes: true if the user wants to sync everything
